% FILENAME:    ahelp_quad_rev12.m 
% DESCRIPTION: QUAD PENDULUM

% VERSION 1 Calum Torrie Jan 01
% VERSION 2 Phil Willems RM20020913
% VERSION 3 by CIT on 29th January 2003  
% VERSION 4 by CIT on 4th February 2003 
% VERSION % by CIT on 10th FEB 2003
% VERSION 9 by NAR on March 5th 2003
% VERSION 10 by CIT May 7th 2003
% VERSION 11 by CIT for a QUAD
% VERSION 12 by MB; early as-build controls
% VERSION 13 by MB/NAR; final as-built quad controls March 31, 2006; new matrix elements by MB; help
%   text revised and corrected by MB
% The generic names for the parameter file and pendulum file have been chosen so as no 
% changes are required in other files that call this set if the set of files is used
% for a new suspension.

% TEXT FILE EXPLAINING THE VARIOUS FILES ASSOCIATED WITH THE 
% ADVANCED LIGO QUADRUPLE PENDULUM MODEL


% 1) TO OBTAIN PARAMETERS AND FREQUENCIES ONLY: -
% 
%  a) The file quadopt.m contains a pointer to the file with the current
%     parameters, currently 'quadopt20060331asbuiltsym.m'.
%  b) To change parameters, copy file quadopt20060331asbuiltsym.m, choosing a new
%     name reflecting the date and/or purpose, and change the call in
%     quadopt.m to point to the new file.
%  b) Run 'quad_ref.m' for a list of parameters and frequencies. 'quad_ref.m' calls 'ssmake4pv2eMB4.m' to 
%      create the state space for the system and 'ssmake4pv2eMB4.m' calls 'symbexport4.m' or 'symbexport4lat.m' 
%      to get mass and stiffness matrices exported from the Mathematica model by MB. 
%  
%         
% 2) TO OBTAIN CLOSED LOOP TRANSFER FUNCTIONS, IMPULSE RESPONSE etc..:-
% 
%  a) Again view and edit parameters in the file linked to by 'quadopt.m'.
%  b) Open 'generate_simulink.m'. Set damper = 1 or 2 for either active damping or eddy current (velocity) damping
%      as desired. The selected type of damping is implemented in the file called 'localdamp.m', directly for
%      eddy current damping or via a call to 'local4ss.m' for active damping. 
%      'local4ss.m' calls 'highpass.m', 'lowpass.m' and 'transdif.m'.
%  c) Run 'generate_simulink.m'. This in turns calls 'ssmake4pv2eMB4.m' 
%      and the damping set selected in 2b).
% 
% 3) NOTES ON THE NEW FEATURES IN THE MATRIX ELEMENTS IN 'ssmake4pv2eMB4.m'
% 
%  a) The files 'symbexport4.m' and 'symbexport4lat.m' contain definitions for
%     mass and stiffness matrices equivalent to the Mathematica 'xtra-lite'
%     and 'xtra-lite lateral' quad models by MB.
%  b) The lateral version elements are used if pend.kxn, pend.kx1 and
%     pend.kx3 are all defined.
%  c) If pend.ribbon is defined and non-zero, the lowest stage is assumed to be ribbons
%     with width W3 and thickness t3 rather than fibres of radius r3.
%  d) The matrix elements were derived from the 'Stage 0' results in the Mathematica
%     and do not incorporate the stiffness of wires/fibres directly. However if 
%     pend.stage2 is defined and non-zero, then certain fudges are
%     applied to approximate the 'Stage 2' results from the Mathematica,
%     i.e., with the wire stiffness included. With this enabled the parameters
%     dm through d4 are interpreted as 'raw' values, i.e., as vertical distances to
%     actual wire attachment points rather than effective bending points, 
%     and the user should not attempt to apply flexure correction manually.
%     At least for the case of round fibres, the 'fudges' are very precise, and give 
%     four figure agreement in mode frequencies with the Mathematica. With
%     pend.ribbon enabled, the fudges don't give quite as
%     pristine agreement (some frequencies are off by a few percent), but should still be useful.
%
% 4) NOTES ON THE MECHANICALLY GENERATED MATRIX ELEMENTS IN 'symbexport4.m'
%    AND 'symbexport4lat.m' 
%  a) The matrix elements were derived from symmetrical cases in the Mathematica and 
%     so divide up into four independent sub-problems. In the following, * stands for one of 
%     lp = longitudinal/pitch, tr = transverse/roll, y = yaw or v = vertical.
%  b) The matrices qm, cqsm, xm*, cqxm*, cxsm* and km* correspond to the
%     discussion in section 2.2 of T020205-01. Briefly, xm* is a partial
%     stiffness matrix for the artificial case of the masses free but the
%     blade tips fixed (relative to their respective masses), qm is a similar matrix for 
%     the masses fixed and the blade tips free, and cqxm* is a cross-coupling matrix between the
%     masses and the tips. After numerical values are assigned, they are combined to 
%     produce the full stiffness matrix and then multiplied by the inverse
%     of the mass matrix to give the lower left corner of the state-space A
%     matrix (AAA*). 
%  c) cxsm* and cqsm are partial stiffness matrices from the structure
%     to the masses and blade tips and are used to calculate the structure displacement 
%     input part of the B matrix (BBB*).  
%     
% 4) % FILES NO LONGER CALLED or REQUIRED 
%  a) These can be found in /outdated
%  b) Read through the older help files ('ahelp*.m') for more information.

'This file is nothing but comments. Read it in the editor.'
