%adapted from Calum Torrie's ssmake4p by Ken Strain 3/01
%yaw and roll bugs fixed?  
% 
% 2/14/02, Mark Barton: 
%   corrected quad matrix elements derived by generalizing 
%   Calum's triple matrix elements using Mathematica
%   rename to ssmake4pv2eMB
% 2/24/05, Mark Barton: 
%   new matrix elements with more realistic blades
%   generated from scratch in Mathematica
%   rename to ssmake4pv2eMB2
% 3/30/05, Mark Barton: 
%   adjust sign of certain elements to match
%   conventions in Calum's original code 

% 12/12/05, Mark Barton: 
%   allow for lateral model with backward
%   compatibility to older elements 
%   rename to ssmake4pv2eMB3

% 3/30/06, Mark Barton
% eliminate use of && operator for backwards compatibility with R6

% 4/6/06, Mark Barton
% rename ssmake4pv2eMB4
% allow for ribbons

% 4/26/06, Mark Barton
% include calculation of useful stuff formerly in quadopt.m: pend.tln, pend.tl1, pend.tl2, 
%  pend.tl3, pend.l_suspoint_to_centreofoptic and pend.l_suspoint_to_bottomofoptic
% force calculation of flexn,... flex3 even if stage2 not set; export to pend

% 5/9/06, Mark Barton
% If pend.kcn is defined, use directly as kcn, rather than calculating kcn from
% ufcn. Similarly for pend.kc1 and pend.kc2.

% 9/15/06, Mark Barton
% Removed erroneous factor of 1/4 in M31 and M32 for ribbons

% 8/8/08, Mark Barton
% Added various defaults and checks to increase compatibility with
% ssmakeTN.m.

global pend
quadopt;

% general redefinition of variables to simplify notation
% and cope with different pendulum designs

% Make sure all flags are defined
if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false
end

g = pend.g;
Yn   = pend.Yn;
Y1   = pend.Y1;
Y2   = pend.Y2;
Y3   = pend.Y3;
if isfield(pend, 'kcn')
    kcn = pend.kcn;
    pend.ufcn = sqrt(2*kcn/pend.mn)/2/pi;
else
    kcn	=  1/2 * (2*pi*pend.ufcn)^2*pend.mn;
    pend.kcn = kcn;
end
if isfield(pend, 'kc1')
    kc1 = pend.kc1;
    pend.ufc1 = sqrt(2*kc1/pend.m1)/2/pi;
else
    kc1	=  1/2 * (2*pi*pend.ufc1)^2*pend.m1;
    pend.kc1 = kc1;
end
if isfield(pend, 'kc2')
    kc2 = pend.kc2;
    pend.ufc2 = sqrt(2*kc2/pend.m2)/2/pi;
else
    kc2	=  1/2 * (2*pi*pend.ufc2)^2*pend.m2;
    pend.kc2 = kc2;
end
ln   = pend.ln;
l1   = pend.l1;
l2   = pend.l2;
l3   = pend.l3;
kwn	=pend.Yn*pi*pend.rn^2/ln*pend.nwn/2;
kw1	=pend.Y1*pi*pend.r1^2/l1*pend.nw1/2;	
kw2	=pend.Y2*pi*pend.r2^2/l2*pend.nw2/2;

if not(isfield(pend,'kw3'))
    if pend.ribbon
        kw3	=pend.Y3*pend.W3*pend.t3/l3*pend.nw3/2;
    else
        kw3	=pend.Y3*pi*pend.r3^2/l3*pend.nw3/2;	
    end
else
    kw3 = pend.kw3;
end
pend.kwn = kwn;
pend.kw1 = kw1;
pend.kw2 = kw2;
pend.kw3 = kw3;
%********************************************************************
% allows choice of 2 wires to set separation to zero
sm = 0; % separation of top wires at structure
sn = 0; % separation of top wires at mass N

s0=pend.su;
s1=pend.su;
s2=pend.si;
s3=pend.si;
s4=pend.sl;
s5=pend.sl;

dm=pend.dm;
dn=pend.dn;
d0=pend.d0;
d1=pend.d1;
d2=pend.d2;
d3=pend.d3;
d4=pend.d4;


%********************************************************************
mn = pend.mn;
m1 = pend.m1;
m2 = pend.m2;
m3 = pend.m3;
Inx = pend.Inx;
I1x = pend.I1x;
I2x = pend.I2x;
I3x = pend.I3x;
Iny = pend.Iny;
I1y = pend.I1y;
I2y = pend.I2y;
I3y = pend.I3y;
Inz = pend.Inz;
I1z = pend.I1z;
I2z = pend.I2z;
I3z = pend.I3z;

mn3  = mn+m1+m2+m3;
m13	= m1+m2+m3;
m23	= m2+m3;

nn0 = pend.nn0;
nn1 = pend.nn1;
n0  = pend.n0;
n1  = pend.n1;
n2  = pend.n2;
n3  = pend.n3;
n4  = pend.n4;
n5  = pend.n5;

%***********************************************************************************
% cosine and sine of the angle the wire makes with the vertical (z)

sin=(nn1-nn0)/ln;			%sin(omegan)
si1=(n1-n0)/l1;			%sin(omega1)
si2=(n3-n2)/l2;			%sin(omega2)
si3=(n5-n4)/l3;			%sin(omega3)	

cn=(ln^2-(nn1-nn0)^2)^0.5/ln;	%cos(omegan)
c1=(l1^2-(n1-n0)^2)^0.5/l1;	%cos(omega1)
c2=(l2^2-(n3-n2)^2)^0.5/l2;	%cos(omega2)
c3=(l3^2-(n5-n4)^2)^0.5/l3;	%cos(omega3)

%********************************************************
bd = pend.bd;
%********************************************************************

kn = kwn;
k1 = kw1;
k2 = kw2;
k3 = kw3;
su=pend.su;
si=pend.si;
sl=pend.sl;

% Vertical distances between centres of mass 
pend.tln = sqrt(pend.ln^2 - (pend.nn0-pend.nn1)^2) + pend.dm;
pend.tl1 = sqrt(pend.l1^2 - (pend.n0-pend.n1)^2) + pend.dn + pend.d0;
pend.tl2 = sqrt(pend.l2^2 - (pend.n2-pend.n3)^2) + pend.d1 + pend.d2;
pend.tl3 = sqrt(pend.l3^2 - (pend.n4-pend.n5)^2) + pend.d3 + pend.d4;

% Distance to the centre of mass from suspension point 
pend.l_suspoint_to_centreofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3;

% Distance to the bottom of the test mass from suspension point 
pend.l_suspoint_to_bottomofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3+pend.tr;

% Stiffness of fibres/ribbons
pi = 4*atan(1);
Mn1 = (1/4)*pi*pend.rn^4;
M11 = (1/4)*pi*pend.r1^4;
M21 = (1/4)*pi*pend.r2^4;
pend.flexn = sqrt(2*Mn1*Yn/mn3/g)*cn^(3/2);
pend.flex1 = sqrt(4*M11*Y1/m13/g)*c1^(3/2);
pend.flex2 = sqrt(4*M21*Y2/m23/g)*c2^(3/2);

if not(isfield(pend,'flex3'))
	if pend.ribbon
	    M31 = pend.W3*pend.t3^3/12;
	else
	    M31 = (1/4)*pi*pend.r3^4;
	end
	pend.flex3 = sqrt(4*M31*Y3/m3/g)*c3^(3/2); % for long/pitch, yaw and vertical
end
if not(isfield(pend,'flex3tr'))
	if pend.ribbon
	    M32 = pend.W3^3*pend.t3/12;
	else
	    M32 = (1/4)*pi*pend.r3^4;
	end
	pend.flex3tr = sqrt(4*M32*Y3/m3/g)*c3^(3/2); % for trans/roll, with M32 instead of M31
end

flexn = pend.flexn;
flex1 = pend.flex1;
flex2 = pend.flex2;
flex3 = pend.flex3; % for long/pitch, yaw and vertical; see below for trans/roll

if pend.stage2
    % apply fudges to approximate Mathematica Stage2 results
    dm = dm + flexn;
    dn = dn + flex1;
    d0 = d0 + flex1; 
    d1 = d1 + flex2;
    d2 = d2 + flex2;
    d3 = d3 + flex3;
    d4 = d4 + flex3;
    ln = ln - 2*flexn/cn;
    l1 = l1 - 2*flex1/c1;
    l2 = l2 - 2*flex2/c2;
    l3 = l3 - 2*flex3/c3;
    nn0 = nn0 + sin*flexn/cn;
    nn1 = nn1 - sin*flexn/cn;
    n0 = n0 + si1*flex1/c1;
    n1 = n1 - si1*flex1/c1;
    n2 = n2 + si2*flex2/c2;
    n3 = n3 - si2*flex2/c2;
    n4 = n4 + si3*flex3/c3;
    n5 = n5 - si3*flex3/c3;
end

newelements=0; 
if isfield(pend,'kxn')
    if isfield(pend,'kx1') 
        if isfield(pend,'kx2')
            % lateral compliances have been defined - use lateral model matrix
            % elements

            kxn = pend.kxn;
            kx1 = pend.kx1;
            kx2 = pend.kx2;

            symbexport4lat
            newelements = 1;
        end
    end   
end

if not(newelements)
    symbexport4
end


FFFLP = diag([-1 1 -1 1 -1 1 -1 1]); % allow for different sign conventions

% LONGITUDINAL-PITCH
AAALP = [...
    zeros(8) eye(8)
    FFFLP'*(-kmlp)\(xmlp-cqxmlp'/qm*cqxmlp)*FFFLP -bd*eye(8)
];

bmlp = FFFLP'*(-kmlp)\(cxsmlp-cqxmlp'/qm*cqsm); % ground displacement inputs: x,y,z,yaw,pitch,roll
bmlp2 = FFFLP'*kmlp\eye(8); % coordinate force inputs: pitchn,xn,pitch1,x1,...

%NOTE: -ve signs in last four entries below are a fudge to match the sign
%of the old matrix elements - needs triple-checking.
BBBLP = [...
    zeros(8,9)
    bmlp(:,1) bmlp2(:,2) bmlp2(:,4) bmlp2(:,6) bmlp2(:,8)  -bmlp2(:,1) -bmlp2(:,3) -bmlp2(:,5) -bmlp2(:,7)
];

CCCLP = [...
 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 %l n
 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 %l 
 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0
 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 %long vel
 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 %pitch vel

 ];
 
 DDDLP = [...
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 0 0 0 0 0 0 0 0 0 
 ];

lpe = ss(AAALP,BBBLP,CCCLP,DDDLP);


%YAW

FFFY = diag([1 1 1 1]); % allow for different sign conventions

AAAY = [...
    zeros(4) eye(4)
    FFFY'*(-kmy)\(xmy-cqxmy'/qm*cqxmy)*FFFY -bd*eye(4)
];
bmy = FFFY'*(-kmy)\(cxsmy-cqxmy'/qm*cqsm); % ground displacement inputs: x,y,z,yaw,pitch,roll
bmy2 = FFFY'*kmy\eye(4); % coordinate force inputs: yawn,yaw1,...

BBBY = [...
    zeros(4,5)
    bmy(:,4) bmy2(:,1) bmy2(:,2) bmy2(:,3) bmy2(:,4)
];

CCCY = [...
    1	0	0	0	0	0 0 0	
   	0	1	0	0	0	0 0 0	
   	0	0	1	0	0	0 0 0
    0	0	0 	1	0	0 0 0
    0   0   0   0   1   0 0 0
];

DDDY = [
    0 0 0 0 0 
    0 0 0 0 0 
    0 0 0 0 0 
    0 0 0 0 0
    0 0 0 0 0  
];

ye = ss(AAAY,BBBY,CCCY,DDDY);


% VERTICAL
FFFV = diag([1 1 1 1]); % allow for different sign conventions

AAAV = [...
    zeros(4) eye(4)
    FFFV'*(-kmv)\(xmv-cqxmv'/qm*cqxmv)*FFFV -bd*eye(4)
];

bmv = FFFV'*(-kmv)\(cxsmv-cqxmv'/qm*cqsm); % ground displacement inputs: x,y,z,yaw,pitch,roll
bmv2 = FFFV'*kmv\eye(4); % coordinate force inputs: yawn,yaw1,...

BBBV = [...
    zeros(4,3)
    bmv(:,3) bmv2(:,1) bmv2(:,2)
];

CCCV = [
    1	0	0 0 0	0	0	0	
    0	1	0 0 0	0	0	0	
    0	0	1 0 0	0	0	0	
    0	0	0 1 0	0	0	0
    0	0	0 0 1	0	0	0
];
   
DDDV = [
    0 0 0 
    0 0 0 
    0 0 0  
    0 0 0 
    0 0 0
];

ve = ss(AAAV,BBBV,CCCV,DDDV);


% TRANSVERSE-ROLL

flex3 = pend.flex3tr;

if pend.ribbon
    d3 = d3 + flex3;
    d4 = d4 + flex3;
    l3 = l3 - 2*flex3/c3;
    n4 = n4 + si3*flex3/c3;
    n5 = n5 - si3*flex3/c3;

    if newelements
        symbexport4lat
    else
        symbexport4
    end
end


FFFTR = diag([1 1 1 1 1 1 1 1]); % allow for different sign conventions

AAATR = [...
    zeros(8) eye(8)
    FFFTR'*(-kmtr)\(xmtr-cqxmtr'/qm*cqxmtr)*FFFTR -bd*eye(8)
];

bmtr = FFFTR'*(-kmtr)\(cxsmtr-cqxmtr'/qm*cqsm); % ground displacement inputs: x,y,z,yaw,pitch,roll
bmtr2 = FFFTR'*kmtr\eye(8); % coordinate force inputs: rolln,yn,roll1,y1,...

BBBTR = [...
    zeros(8,6)
    bmtr(:,2) bmtr2(:,2) bmtr2(:,4) bmtr(:,6) bmtr2(:,1)  bmtr2(:,3)
];

CCCTR = [...
    0	1	0	0	0	0	0	0	0	0	0	0	0	0	0	0 
    0	0	0	1	0	0	0	0	0	0	0	0	0	0	0	0
    0	0 	0	0	0	1	0	0	0	0	0	0	0	0	0	0
    0	0 	0	0	0	0	0	1	0	0	0	0	0	0	0	0
    1	0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	1	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	1	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	0	0	1	0	0	0	0	0	0	0	0	0  
    0	0	0	0	0	0	0	0	0	1	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	1	0	0	0	0	0	0	0
];
 
DDDTR = [...
    0   0  0  0  0  0
    0   0  0  0  0  0
    0   0  0  0  0  0
    0   0  0  0  0  0   
    0   0  0  0  0  0     
    0   0  0  0  0  0     
    0   0  0  0  0  0     
    0   0  0  0  0  0     
  	0   0  0  0  0  0     
    0   0  0  0  0  0     
];

trer = ss(AAATR,BBBTR,CCCTR,DDDTR);   
