function [ln dm] = tldquadn(tln,dmeff)

% A function to calculate wire length and raw d to meet a specification of the total
% vertical height and effective d at the bottom end at the top level in a
% quad.
%
% The function looks in the structure pend to find other required data and
% flags, which may include pretty much anything,
% so the call needs to be placed near the end of quadopt.m.
%
% The d*eff argument is always interpreted as an effective d. If pend.stage2
% is defined and non-zero, flexure correction is applied and the d
% returned is raw, otherwise flexure correction is omitted and the d
% returned is effective.
% 8 Sep 2006: initial release
% 14 Sep 2006: minor tidy-ups
% 15 Oct 2006: rework to eliminate fsolve

global pend;

if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false (wire flexure correction neglected or implicit)
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false (round fibres)
end
if isfield(pend,'g')
    g=pend.g;
else
    g=9.81;
end

Mn1 = (1/4)*pi*pend.rn^4;
mn3	= pend.mn+pend.m1+pend.m2+pend.m3;

if not(pend.stage2) % old-style, assume flexure correction already applied except for blade component
	dm = dmeff;
	ln = sqrt(tln^2+(pend.nn1-pend.nn0)^2);
	return;
end

fn=sqrt(pend.nwn*Mn1*pend.Yn/mn3/g); % flexure correction basic factor

% pend.stage2==1 -> new-style
ln = sqrt(tln^2+(pend.nn1-pend.nn0)^2); % initial guess
for i=1:5 % hardwire five rounds of Newton-Raphson
	vn=sqrt(ln^2-(pend.nn1-pend.nn0)^2); % vertical component of wire length
    cn=vn/ln; % cosine of wire angle
    flexn = fn*cn^(3/2); % flexure correction
	deriv = ln/vn-3*sqrt(vn/ln)*(1/vn-vn/ln^2)*fn; % derivative of tln w.r.t. ln
	tlndiff = sqrt(ln^2 - (pend.nn0-pend.nn1)^2) + dmeff - flexn - tln;
	ln = ln-(tlndiff/deriv);
end
vn=sqrt(ln^2-(pend.nn1-pend.nn0)^2); % vertical component of wire length
cn=vn/ln; % cosine of wire angle
flexn = fn*cn^(3/2); % flexure correction
dm = dmeff - flexn;
