(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2589969,      45857]
NotebookOptionsPosition[   2560371,      44817]
NotebookOutlinePosition[   2560982,      44840]
CellTagsIndexPosition[   2560939,      44837]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["TM Transfer Functions and Mode Shape Plots (T1000263-v1)", "Section",
 CellChangeTimes->{{3.39246579667696*^9, 3.3924658043635807`*^9}, {
   3.392466756125457*^9, 3.392466756881913*^9}, 3.478439466642891*^9, {
   3.478527687402707*^9, 3.478527687616362*^9}, {3.483299443920679*^9, 
   3.483299448607518*^9}, {3.4833779728320503`*^9, 3.483377995177311*^9}}],

Cell["\<\
Horizontal axis on all plots is log10 of frequency in Hz
Vertical axis on all plots is log10 of transfer function from structure \
displacement (in m or rad) to optic displacement (in m or rad)\
\>", "Text",
 CellChangeTimes->{{3.392465853238858*^9, 3.3924659398361177`*^9}, {
  3.392466593740906*^9, 3.392466614519272*^9}, {3.478439238098783*^9, 
  3.4784392558720417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["modelcase"], "Input",
 CellChangeTimes->{{3.478377413889029*^9, 3.478377419815885*^9}}],

Cell[BoxData["\<\"20090819TM\"\>"], "Output",
 CellChangeTimes->{3.478377964045413*^9, 3.47843929444989*^9, 
  3.478439480514563*^9, 3.478527698363605*^9, 3.483280294317986*^9, 
  3.483295029609899*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["modelcasecomment"], "Input",
 CellChangeTimes->{{3.4783774300487537`*^9, 3.478377433023731*^9}}],

Cell[BoxData["\<\"20090819TM, based on 20080326TM (Norna's conceptual design \
from T060283-02 with improved damping parameters from Alastair Heptonstall) \
larger d2 per M080134-00, latest monolithic parameters.\"\>"], "Output",
 CellChangeTimes->{3.4783779641455383`*^9, 3.4784392945510406`*^9, 
  3.4784394806318407`*^9, 3.4785276983994493`*^9, 3.4832802944356194`*^9, 
  3.483295029710084*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utility stuff", "Text",
 CellChangeTimes->{{3.478378859781518*^9, 3.478378862211884*^9}}],

Cell[BoxData[
 RowBox[{"Calculate", "[", "Stage2", "]"}]], "Input",
 CellChangeTimes->{{3.483280279894972*^9, 3.4832802876953087`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"inputs", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "supportxinput", ",", "supportyinput", ",", "supportzinput", ",", 
     "supportyawinput", ",", "supportpitchinput", ",", "supportrollinput"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.4783775366286592`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"finputs", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"makefinputvector", "[", "x0", "]"}], ",", 
     RowBox[{"makefinputvector", "[", "y0", "]"}], ",", 
     RowBox[{"makefinputvector", "[", "z0", "]"}], ",", 
     RowBox[{"makefinputvector", "[", "yaw0", "]"}], ",", 
     RowBox[{"makefinputvector", "[", "pitch0", "]"}], ",", 
     RowBox[{"makefinputvector", "[", "roll0", "]"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.4783775366286592`*^9}, 
   3.483280185648883*^9, {3.4832802268679457`*^9, 3.483280264501474*^9}, {
   3.4832803222098913`*^9, 3.483280331449799*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"outputs", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "opticxoutput", ",", "opticyoutput", ",", "opticzoutput", ",", 
     "opticyawoutput", ",", "opticpitchoutput", ",", "opticrolloutput"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.4783775366286592`*^9}, {
  3.4783776148981256`*^9, 3.478377657123701*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"inputnames", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\"\<x in\>\"", ",", "\"\<y in\>\"", ",", "\"\<z in\>\"", ",", 
     "\"\<yaw in\>\"", ",", "\"\<pitch in\>\"", ",", "\"\<roll in\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.478377602242098*^9}, {
  3.47837768296446*^9, 3.478377697562696*^9}, {3.478378324241866*^9, 
  3.4783783462021008`*^9}, {3.4832804367977867`*^9, 3.4832804861233597`*^9}, {
  3.483299491778411*^9, 3.483299525268388*^9}, {3.483299864450955*^9, 
  3.483299864544404*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"finputnames", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\"\<x in\>\"", ",", "\"\<y in\>\"", ",", "\"\<z in\>\"", ",", 
     "\"\<yaw in\>\"", ",", "\"\<pitch in\>\"", ",", "\"\<roll in\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.478377602242098*^9}, {
  3.47837768296446*^9, 3.478377697562696*^9}, {3.478378324241866*^9, 
  3.4783783462021008`*^9}, {3.483280371818128*^9, 3.483280424594593*^9}, {
  3.483299538749501*^9, 3.483299541895886*^9}, {3.4832995845571527`*^9, 
  3.483299614642461*^9}, {3.4832997643225822`*^9, 3.4832997678426943`*^9}, {
  3.483299933488553*^9, 3.483299953119533*^9}, {3.483300002579462*^9, 
  3.483300017784403*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"outputnames", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\"\<x out\>\"", ",", "\"\<y out\>\"", ",", "\"\<z out\>\"", ",", 
     "\"\<yaw out\>\"", ",", "\"\<pitch out\>\"", ",", "\"\<roll out\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478377470875369*^9, 3.478377602242098*^9}, {
  3.47837768296446*^9, 3.478377697562696*^9}, {3.478378324241866*^9, 
  3.47837836968052*^9}, {3.483280497692464*^9, 3.4832805135550623`*^9}, {
  3.483300037959289*^9, 3.483300041420814*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rawtable10", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{"calcTF", "[", 
       RowBox[{"eom2", ",", "coupling2", ",", 
        RowBox[{"inputs", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"outputs", "[", 
         RowBox[{"[", "j", "]"}], "]"}], ",", "10"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "inputs", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "outputs", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4783777047338943`*^9, 3.478377720875102*^9}, {
  3.478377800381075*^9, 3.4783778733414593`*^9}, {3.47837799120883*^9, 
  3.478378035710968*^9}, {3.478378416171441*^9, 3.4783784166983843`*^9}, {
  3.478378572685566*^9, 3.478378572955084*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tftablere", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"calcTF", "[", 
      RowBox[{"eom2", ",", "coupling2", ",", 
       RowBox[{"inputs", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"outputs", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", "f"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "inputs", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "outputs", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478378647254692*^9, 3.478378670133548*^9}, {
  3.478378905399074*^9, 3.478378905470738*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tfftablere", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{"calcTFf", "[", 
      RowBox[{"eom2", ",", 
       RowBox[{"finputs", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"outputs", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", "f"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "finputs", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "outputs", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478378647254692*^9, 3.478378670133548*^9}, {
   3.478378905399074*^9, 3.478378905470738*^9}, {3.483280530052217*^9, 
   3.483280543186902*^9}, 3.4832806042044563`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettytftablere", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{
           RowBox[{"tftablere", "[", "f", "]"}], ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "15"}]}]}], "]"}], ",", "outputnames"}], "]"}], 
       "]"}], ",", 
      RowBox[{"Prepend", "[", 
       RowBox[{"inputnames", ",", "\"\<\>\""}], "]"}]}], "]"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.478378676265243*^9, 3.4783787291887836`*^9}, {
  3.4783789096958923`*^9, 3.47837891427041*^9}, {3.483300146530405*^9, 
  3.483300158504299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettytfftablere", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{
           RowBox[{"tfftablere", "[", "f", "]"}], ",", 
           RowBox[{"10", "^", 
            RowBox[{"-", "15"}]}]}], "]"}], ",", "outputnames"}], "]"}], 
       "]"}], ",", 
      RowBox[{"Prepend", "[", 
       RowBox[{"finputnames", ",", "\"\<\>\""}], "]"}]}], "]"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.478378676265243*^9, 3.4783787291887836`*^9}, {
  3.4783789096958923`*^9, 3.47837891427041*^9}, {3.483280558643626*^9, 
  3.483280565164105*^9}, {3.4833001689203367`*^9, 3.4833001793726807`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tftableim", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"calcTF", "[", 
      RowBox[{"eom2", ",", "coupling2", ",", 
       RowBox[{"inputs", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"outputs", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", "f"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "inputs", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "outputs", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478378647254692*^9, 3.478378670133548*^9}, {
  3.478378905399074*^9, 3.478378905470738*^9}, {3.478378949858716*^9, 
  3.478378954543363*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tfftableim", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"calcTFf", "[", 
      RowBox[{"eom2", ",", 
       RowBox[{"finputs", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"outputs", "[", 
        RowBox[{"[", "j", "]"}], "]"}], ",", "f"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "finputs", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "outputs", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478378647254692*^9, 3.478378670133548*^9}, {
  3.478378905399074*^9, 3.478378905470738*^9}, {3.478378949858716*^9, 
  3.478378954543363*^9}, {3.483280579908332*^9, 3.483280590019616*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettytftableim", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"Prepend", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{"tftableim", "[", "f", "]"}], ",", "outputnames"}], "]"}], 
       "]"}], ",", 
      RowBox[{"Prepend", "[", 
       RowBox[{"inputnames", ",", "\"\<\>\""}], "]"}]}], "]"}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.478378676265243*^9, 3.4783787291887836`*^9}, {
  3.4783789096958923`*^9, 3.478378929904002*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettytftable", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"prettytftablere", "[", "f", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.478379191993986*^9, 3.478379210016069*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettytfftable", "[", "f_", "]"}], " ", ":=", " ", 
  RowBox[{"prettytfftablere", "[", "f", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.478379191993986*^9, 3.478379210016069*^9}, {
  3.483280666467944*^9, 3.48328066797064*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transfer function tables (values less than 10^-15 suppressed)\
\>", "Subsection",
 CellChangeTimes->{{3.483294556670236*^9, 3.483294562029215*^9}, {
  3.4833003150563717`*^9, 3.483300328799108*^9}}],

Cell[CellGroupData[{

Cell["\<\
Structure displacement to optic displacement TFs at different frequencies\
\>", "Subsubsection",
 CellChangeTimes->{{3.483280617625147*^9, 3.4832806242569857`*^9}, {
   3.4832994642388783`*^9, 3.4832994688795843`*^9}, 3.483299864577013*^9, {
   3.4832999752457113`*^9, 3.4832999838994427`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "0.1", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
  3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
  3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
  3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
  3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
  3.478439285738247*^9, 3.4784392869529552`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "1.0697302275673062`", "0", "0", "0", 
     RowBox[{"-", "0.04443104501610491`"}], "0"},
    {"\<\"y in\"\>", "0", "1.0616402298141066`", "0", "0", "0", 
     "0.02225538942755139`"},
    {"\<\"z in\"\>", "0", 
     RowBox[{"-", "1.1783037434089664`*^-14"}], "1.0332191411425695`", "0", 
     "2.6894955006209353`*^-15", 
     RowBox[{"-", "3.189034744040069`*^-13"}]},
    {"\<\"yaw in\"\>", "0", "0", "0", "1.037372048154342`", "0", "0"},
    {"\<\"pitch in\"\>", "0.0020627400453520645`", "0", "0", "0", 
     RowBox[{"-", "0.00008567552821442342`"}], "0"},
    {"\<\"roll in\"\>", "0", "0.18987481425715952`", 
     RowBox[{"-", "9.038125687810195`*^-15"}], "0", "0", "0.4918395912348482`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, {3.478439289538196*^9, 
   3.478439294975244*^9}, 3.47843948108943*^9, 3.47852769886201*^9, 
   3.483280712718313*^9, 3.483295047276457*^9, 3.4832996242348948`*^9, 
   3.483299780601419*^9, 3.483300046848987*^9, 3.483300184154887*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "0.3", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
  3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
  3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
  3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
  3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
  3.478439301658358*^9, 3.478439302545047*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "2.153683622404665`", "0", "0", "0", 
     RowBox[{"-", "1.1031274780878022`"}], "0"},
    {"\<\"y in\"\>", "0", "1.9286182138681853`", 
     RowBox[{"-", "4.3836098095425004`*^-15"}], "0", "0", 
     "0.3711716743890941`"},
    {"\<\"z in\"\>", "0", "0", "1.395900698157104`", "0", 
     "5.553952208628154`*^-15", 
     RowBox[{"-", "1.485646771325473`*^-14"}]},
    {"\<\"yaw in\"\>", "0", "0", "0", "1.4421389084723522`", "0", "0"},
    {"\<\"pitch in\"\>", "0.004152898048947268`", "0", "0", "0", 
     RowBox[{"-", "0.002127134069676856`"}], "0"},
    {"\<\"roll in\"\>", "0", "0.3463040950813963`", 
     RowBox[{"-", "1.3705726195067016`*^-14"}], "0", "0", 
     "0.6239853092998258`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439303331007*^9, 
   3.478439481251789*^9, 3.478527699028904*^9, 3.483280712995326*^9, 
   3.483295047459231*^9, 3.483299624421412*^9, 3.483299780824497*^9, 
   3.483300047056027*^9, 3.483300184440383*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.478439311034396*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "13.297451740707073`", "0", "0", "0", 
     RowBox[{"-", "10.740057486076354`"}], "4.001744848374547`*^-15"},
    {"\<\"y in\"\>", "0", 
     RowBox[{"-", "4.583736155251086`"}], 
     RowBox[{"-", "1.9223086774049735`*^-14"}], "0", 
     "1.837306603302727`*^-15", 
     RowBox[{"-", "3.8270612911210633`"}]},
    {"\<\"z in\"\>", "0", "1.2014487090425432`*^-14", 
     RowBox[{"-", "0.6812469226310341`"}], "0", "1.3082203341821085`*^-15", 
     RowBox[{"-", "2.1652081783426432`*^-13"}]},
    {"\<\"yaw in\"\>", "0", "0", "0", 
     RowBox[{"-", "1.6849354946617638`"}], "0", "0"},
    {"\<\"pitch in\"\>", "0.025641194443277518`", "0", "0", "0", 
     RowBox[{"-", "0.02070979792564053`"}], "0"},
    {"\<\"roll in\"\>", "0", 
     RowBox[{"-", "0.6202951702410973`"}], 
     RowBox[{"-", "8.167866752596423`*^-15"}], "0", 
     "1.0749869947679517`*^-15", 
     RowBox[{"-", "2.239169116411404`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439311869143*^9, 
   3.4784394814080677`*^9, 3.47852769919309*^9, 3.4832807131746492`*^9, 
   3.4832950476386003`*^9, 3.483299624728953*^9, 3.4832997811109867`*^9, 
   3.4833000473571053`*^9, 3.483300184642479*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.478439315898244*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", 
     RowBox[{"-", "0.009363724359911814`"}], "0", "0", "0", 
     RowBox[{"-", "0.023662628306647827`"}], "0"},
    {"\<\"y in\"\>", "0", 
     RowBox[{"-", "0.009645797074943153`"}], "0", "0", "0", 
     RowBox[{"-", "2.355240726165069`"}]},
    {"\<\"z in\"\>", "0", "0", "0.18710903977411003`", "0", "0", 
     RowBox[{"-", "8.925952267323297`*^-14"}]},
    {"\<\"yaw in\"\>", "0", "0", "0", 
     RowBox[{"-", "0.6269415990757083`"}], "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.000018055892619974967`"}], "0", "0", "0", 
     RowBox[{"-", "0.000045628019794128194`"}], "0"},
    {"\<\"roll in\"\>", "0", 
     RowBox[{"-", "0.0004232288391784533`"}], "0", "0", "0", 
     "0.44310149601604265`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439316682165*^9, 
   3.478439481594943*^9, 3.478527699360606*^9, 3.483280713360211*^9, 
   3.4832950479386473`*^9, 3.483299624944721*^9, 3.483299781321292*^9, 
   3.483300047567217*^9, 3.483300184853889*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "10", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
  3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
  3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
  3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
  3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "1.0554333770303139`*^-7", "0", "0", "0", 
     "2.5117020011533553`*^-7", "0"},
    {"\<\"y in\"\>", "0", "2.9682870255439804`*^-7", "0", "0", "0", 
     RowBox[{"-", "0.00011829209421412047`"}]},
    {"\<\"z in\"\>", "0", "0", "0.00013818778230846257`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "4.1705841629687216`*^-7", "0", "0"},
    {"\<\"pitch in\"\>", "2.0351729518330832`*^-10", "0", "0", "0", 
     "4.843270557656856`*^-10", "0"},
    {"\<\"roll in\"\>", "0", "7.858493082745122`*^-8", "0", "0", "0", 
     RowBox[{"-", "0.00014817922255072174`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439323968999*^9, 
   3.478439481830212*^9, 3.478527699625802*^9, 3.4832807135465097`*^9, 
   3.483295048144103*^9, 3.483299625159758*^9, 3.48329978153944*^9, 
   3.483300047776504*^9, 3.4833001850597057`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "30", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
  3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
  3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
  3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
  3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
  3.4784393265866823`*^9, 3.478439327025166*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "1.3731323570132935`*^-11", "0", "0", "0", 
     "3.229370955973355`*^-11", "0"},
    {"\<\"y in\"\>", "0", "3.373391106150998`*^-11", "0", "0", "0", 
     "6.674403299800333`*^-9"},
    {"\<\"z in\"\>", "0", "0", "3.6297650544578732`*^-9", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "5.418061040224313`*^-11", "0", "0"},
    {"\<\"pitch in\"\>", "2.6477863056714793`*^-14", "0", "0", "0", 
     "6.227141402406371`*^-14", "0"},
    {"\<\"roll in\"\>", "0", "8.5016169293727`*^-12", "0", "0", "0", 
     "1.3320042137495404`*^-8"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.4784393276648903`*^9, 
   3.478439482002164*^9, 3.4785276998139343`*^9, 3.483280713731583*^9, 
   3.483295048351413*^9, 3.483299625374124*^9, 3.483299781757387*^9, 
   3.483300047985611*^9, 3.4833001852613373`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytftable", "[", "100", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.47843933446629*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0", "0", "0", "0", "2.0799572628699376`*^-15", "0"},
    {"\<\"y in\"\>", "0", "2.149190386690179`*^-15", "0", "0", "0", 
     "3.317069725670704`*^-13"},
    {"\<\"z in\"\>", "0", "0", "2.1408247709262823`*^-13", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "3.4930654654174465`*^-15", "0", "0"},
    {"\<\"pitch in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"roll in\"\>", "0", "0", "0", "0", "0", "7.025234562486361`*^-13"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.4784393359072123`*^9, 
   3.4784394821835537`*^9, 3.478527700002694*^9, 3.483280713994863*^9, 
   3.4832950485575953`*^9, 3.483299625588212*^9, 3.483299781966673*^9, 
   3.483300048197105*^9, 3.4833001855283613`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Top mass force TFs", "Subsubsection",
 CellChangeTimes->{{3.483280617625147*^9, 3.483280643496773*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "0.01", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
   3.478439285738247*^9, 3.4784392869529552`*^9}, 3.48328064731398*^9, {
   3.483280737500011*^9, 3.483280737842721*^9}, {3.4832832776023693`*^9, 
   3.483283278095291*^9}, 3.483294456199143*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0.00034901995649859376`", "0", "0", "0", 
     RowBox[{"-", "0.00004539503363571686`"}], "0"},
    {"\<\"y in\"\>", "0", "0.0002489417446227197`", "0", "0", "0", 
     RowBox[{"-", "0.00013507813332000348`"}]},
    {"\<\"z in\"\>", "0", "0", "0.00031187049847050923`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "0.01514863948558365`", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.0011685525608781816`"}], "0", "0", "0", 
     "0.045254980071017234`", "0"},
    {"\<\"roll in\"\>", "0", "0.0004924469398008457`", "0", "0", "0", 
     "0.004769061127585851`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, {3.478439289538196*^9, 
   3.478439294975244*^9}, 3.47843948108943*^9, 3.47852769886201*^9, {
   3.483280647945613*^9, 3.483280672735189*^9}, {3.483280714123165*^9, 
   3.4832807392806187`*^9}, 3.4832832791266537`*^9, 3.483295048706049*^9, 
   3.483299625827649*^9, 3.4832997822103033`*^9, 3.483300048437169*^9, 
   3.483300185672168*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "0.03", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
   3.478439285738247*^9, 3.4784392869529552`*^9}, 3.48328064731398*^9, {
   3.483280737500011*^9, 3.483280737842721*^9}, {3.4832832776023693`*^9, 
   3.483283278095291*^9}, {3.483294456199143*^9, 3.4832944686561832`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0.00035087106892818184`", "0", "0", "0", 
     RowBox[{"-", "0.00004670696486442207`"}], "0"},
    {"\<\"y in\"\>", "0", "0.00025011309126982167`", "0", "0", "0", 
     RowBox[{"-", "0.00013482853115007426`"}]},
    {"\<\"z in\"\>", "0", "0", "0.00031267678801088496`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "0.015192714591296445`", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.001176483548321404`"}], "0", "0", "0", 
     "0.045436850946126935`", "0"},
    {"\<\"roll in\"\>", "0", "0.000494822662954596`", "0", "0", "0", 
     "0.004775863077516207`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, {3.478439289538196*^9, 
   3.478439294975244*^9}, 3.47843948108943*^9, 3.47852769886201*^9, {
   3.483280647945613*^9, 3.483280672735189*^9}, {3.483280714123165*^9, 
   3.4832807392806187`*^9}, 3.4832832791266537`*^9, 3.483295048952536*^9, 
   3.483299625982498*^9, 3.483299782362363*^9, 3.483300048587236*^9, 
   3.483300185814653*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "0.1", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
   3.478439285738247*^9, 3.4784392869529552`*^9}, 3.48328064731398*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0.0003731347485718726`", "0", "0", "0", 
     RowBox[{"-", "0.0000630380551312601`"}], "0"},
    {"\<\"y in\"\>", "0", "0.0002641105818888095`", "0", "0", "0", 
     RowBox[{"-", "0.00013171464401924094`"}]},
    {"\<\"z in\"\>", "0", "0", "0.00032212664875141636`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "0.0157090749802158`", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.0012728361418409965`"}], "0", "0", "0", 
     "0.04759280896044773`", "0"},
    {"\<\"roll in\"\>", "0", "0.0005232366245280745`", "0", "0", "0", 
     "0.0048547816924963405`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, {3.478439289538196*^9, 
   3.478439294975244*^9}, 3.47843948108943*^9, 3.47852769886201*^9, {
   3.483280647945613*^9, 3.483280672735189*^9}, 3.483280714123165*^9, 
   3.483295049101625*^9, 3.483299626137484*^9, 3.483299782513105*^9, 
   3.4833000487367973`*^9, 3.483300185957152*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "0.3", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
   3.478439301658358*^9, 3.478439302545047*^9}, 3.483280681411322*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0.0007517920999099748`", "0", "0", "0", 
     RowBox[{"-", "0.00046090393190221504`"}], "0"},
    {"\<\"y in\"\>", "0", "0.000479408469651392`", "0", "0", "0", 
     RowBox[{"-", "0.00006453341204067099`"}]},
    {"\<\"z in\"\>", "0", "0", "0.0004351994461227023`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "0.021838518022185657`", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.0031239934963862566`"}], "0", "0", "0", 
     "0.07743233014230795`", "0"},
    {"\<\"roll in\"\>", "0", "0.0009641335829785068`", "0", "0", "0", 
     "0.005719194038221114`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439303331007*^9, 
   3.478439481251789*^9, 3.478527699028904*^9, 3.483280682114339*^9, 
   3.483280714249555*^9, 3.483295049254734*^9, 3.4832996262936563`*^9, 
   3.483299782663628*^9, 3.483300048886137*^9, 3.483300186100584*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.478439311034396*^9, 3.483280684380209*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0.004635166185315223`", "0", "0", "0", 
     RowBox[{"-", "0.003651296813118674`"}], "0"},
    {"\<\"y in\"\>", "0", 
     RowBox[{"-", "0.001196451740671821`"}], "0", "0", "0", 
     RowBox[{"-", "0.0005146920028694907`"}]},
    {"\<\"z in\"\>", "0", "0", 
     RowBox[{"-", "0.00021239234995423822`"}], "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", 
     RowBox[{"-", "0.025515221864050606`"}], "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "0.012677553823851306`"}], "0", "0", "0", 
     RowBox[{"-", "0.08218479825308118`"}], "0"},
    {"\<\"roll in\"\>", "0", 
     RowBox[{"-", "0.0002782672088351326`"}], "0", "0", "0", 
     RowBox[{"-", "0.01732233425668958`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439311869143*^9, 
   3.4784394814080677`*^9, 3.47852769919309*^9, {3.4832806852199793`*^9, 
   3.483280714372868*^9}, 3.483295049402076*^9, 3.483299626448237*^9, 
   3.483299782811202*^9, 3.483300049032753*^9, 3.483300186239862*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.478439315898244*^9, 3.483280688075436*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", 
     RowBox[{"-", "3.246363558911849`*^-6"}], "0", "0", "0", 
     RowBox[{"-", "0.000011050848538538854`"}], "0"},
    {"\<\"y in\"\>", "0", 
     RowBox[{"-", "2.765918330569971`*^-6"}], "0", "0", "0", 
     RowBox[{"-", "0.0008290945419662362`"}]},
    {"\<\"z in\"\>", "0", "0", "0.00005833498668862906`", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", 
     RowBox[{"-", "0.009493867304860149`"}], "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "8.674391015783563`*^-6"}], "0", "0", "0", 
     "0.002825206858068003`", "0"},
    {"\<\"roll in\"\>", "0", "8.172448596761462`*^-6", "0", "0", "0", 
     "0.007420959351033907`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439316682165*^9, 
   3.478439481594943*^9, 3.478527699360606*^9, {3.483280688792561*^9, 
   3.483280714499345*^9}, 3.483295049554523*^9, 3.4832996266023903`*^9, 
   3.483299782961042*^9, 3.483300049182008*^9, 3.483300186382154*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "10", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.483280690379517*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "3.671062214556251`*^-11", "0", "0", "0", 
     "8.284959103026183`*^-11", "0"},
    {"\<\"y in\"\>", "0", "6.667068688624446`*^-11", "0", "0", "0", 
     "6.307519232961928`*^-9"},
    {"\<\"z in\"\>", "0", "0", "4.308280430112808`*^-8", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "6.3155759339504766`*^-9", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "2.1421094102875577`*^-11"}], "0", "0", "0", 
     "4.462731949362664`*^-9", "0"},
    {"\<\"roll in\"\>", "0", "3.9944630306539126`*^-10", "0", "0", "0", 
     RowBox[{"-", "1.3194720900949725`*^-6"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.478439323968999*^9, 
   3.478439481830212*^9, 3.478527699625802*^9, {3.48328069108643*^9, 
   3.483280714626874*^9}, 3.4832950497106457`*^9, 3.483299626756833*^9, 
   3.483299783113016*^9, 3.483300049331313*^9, 3.483300186587657*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "30", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, {
   3.4784393265866823`*^9, 3.478439327025166*^9}, 3.4832806926282*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "4.776259472433807`*^-15", "0", "0", "0", 
     "1.0622344383203527`*^-14", "0"},
    {"\<\"y in\"\>", "0", "7.697772723468344`*^-15", "0", "0", "0", 
     RowBox[{"-", "1.75111229372323`*^-12"}]},
    {"\<\"z in\"\>", "0", "0", "1.1316518088862438`*^-12", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "8.2046482211685`*^-13", "0", "0"},
    {"\<\"pitch in\"\>", 
     RowBox[{"-", "2.9473772894230783`*^-15"}], "0", "0", "0", 
     "6.036642111538346`*^-13", "0"},
    {"\<\"roll in\"\>", "0", "4.113295145535281`*^-14", "0", "0", "0", 
     "1.236882758462311`*^-10"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.4784393276648903`*^9, 
   3.478439482002164*^9, 3.4785276998139343`*^9, {3.48328069332445*^9, 
   3.4832807147536097`*^9}, 3.4832950498621197`*^9, 3.483299626997964*^9, 
   3.483299783363563*^9, 3.483300049575411*^9, 3.483300186730556*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prettytfftable", "[", "100", "]"}]], "Input",
 CellChangeTimes->{{3.478378043974338*^9, 3.478378298951976*^9}, {
   3.478378377722856*^9, 3.478378396608973*^9}, {3.478378431379973*^9, 
   3.478378483219603*^9}, {3.478378518523675*^9, 3.478378577426412*^9}, {
   3.478378718086051*^9, 3.478378720531826*^9}, {3.478378969135449*^9, 
   3.478378969198318*^9}, {3.478379213642312*^9, 3.4783792137838287`*^9}, 
   3.47843933446629*^9, 3.4832806949633617`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x out\"\>", "\<\"y out\"\>", "\<\"z out\"\>", "\<\"yaw \
out\"\>", "\<\"pitch out\"\>", "\<\"roll out\"\>"},
    {"\<\"x in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"y in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"z in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"yaw in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"pitch in\"\>", "0", "0", "0", "0", "0", "0"},
    {"\<\"roll in\"\>", "0", "0", "0", "0", "0", "6.54960641726574`*^-15"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.478378294347533*^9, 3.4783783010485477`*^9}, {
   3.478378397973549*^9, 3.478378420154148*^9}, {3.4783784667642508`*^9, 
   3.478378591240942*^9}, {3.478378721126087*^9, 3.478378732678831*^9}, 
   3.478378969915823*^9, 3.4783792143693657`*^9, 3.4784393359072123`*^9, 
   3.4784394821835537`*^9, 3.478527700002694*^9, {3.483280695702497*^9, 
   3.483280715099801*^9}, 3.483295050106127*^9, 3.4832996271542387`*^9, 
   3.483299783516213*^9, 3.483300049726606*^9, 3.483300186874199*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Subsection"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-1]]", "Input"],

Cell[BoxData["0.4333409185137215`"], "Output",
 CellChangeTimes->{3.404735866983717*^9, 3.411511413849082*^9, 
  3.4115642173425283`*^9, 3.4115652742905273`*^9, 3.41156897073517*^9, 
  3.415473800956965*^9, 3.4155058839063883`*^9, 3.4155563754622183`*^9, 
  3.415640821560472*^9, 3.459802011090353*^9, 3.459872743736216*^9, 
  3.4832950501636066`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "1"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0.05193802873663657`", "0", "0", "0", 
     RowBox[{"-", "0.3597551819771514`"}], "0"},
    {"\<\"Mass U\"\>", "0.09184600269615312`", "0", "0", "0", 
     RowBox[{"-", "0.4003234347629621`"}], "0"},
    {"\<\"Mass 2\"\>", "0.1504482080037696`", "0", "0", "0", 
     RowBox[{"-", "0.4833073064028744`"}], "0"},
    {"\<\"optic\"\>", "0.27756132119164834`", "0", "0", "0", 
     RowBox[{"-", "0.6049158675752031`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735867015347*^9, 3.411511413883232*^9, 
  3.4115642173698063`*^9, 3.411565274691354*^9, 3.411568970824692*^9, 
  3.415473801472353*^9, 3.41550588394384*^9, 3.415556375531049*^9, 
  3.41564082158225*^9, 3.459802011106659*^9, 3.4598727437615833`*^9, 
  3.483295050230832*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 1\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "1"}], "]"}], "]"}], ",", " ", "0.5", ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", "0"}], "}"}], ",", " ", "floatmatrix2"}],
     "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.390911277235773*^9, 3.390980006510783*^9, 3.390980356382886*^9, {
   3.390980386765141*^9, 3.3909803883648653`*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{0.00037093633548678965`, 0.25, -7.968298282823696*^-8}, {
    0.02651799694348298, 0.09, -0.419019070196215}}], 
   Line3DBox[{{0.00037093633548678965`, -0.25, -7.968298282816337*^-8}, {
    0.02651799694348298, -0.09, -0.419019070196215}}], 
   Line3DBox[{{0.02306948271126055, 0.2, -0.41980771901341496`}, {
    0.043317839709198565`, 0.06, -0.6952471772223902}}], 
   Line3DBox[{{0.023069482711260546`, -0.2, -0.41980771901341496`}, {
    0.043317839709198565`, -0.06, -0.6952471772223902}}], 
   Line3DBox[{{0.0289726763127619, 0.2, -0.4187342641689089}, {
    0.049198046329649504`, 0.06, -0.6940542102904071}}], 
   Line3DBox[{{0.028972676312761896`, -0.2, -0.4187342641689089}, {
    0.049198046329649504`, -0.06, -0.6940542102904071}}], 
   Line3DBox[{{0.04302448470483318, 0.14, -0.696712620697438}, {
    0.07058578571624244, 0.1762, -1.027716784734329}}], 
   Line3DBox[{{0.04302448470483318, -0.14, -0.696712620697438}, {
    0.07058578571624244, -0.1762, -1.027716784734329}}], 
   Line3DBox[{{0.04890469132528412, 0.14, -0.695519653765455}, {
    0.07641144713160436, 0.1762, -1.02628093339329}}], 
   Line3DBox[{{0.04890469132528412, -0.14, -0.695519653765455}, {
    0.07641144713160436, -0.1762, -1.02628093339329}}], 
   Line3DBox[{{0.05997497794457314, 0.1712, -1.0348101559543565`}, {
    0.06165618443787982, 0.1712, -1.049644103514596}}], 
   Line3DBox[{{0.05997497794457314, -0.1712, -1.0348101559543565`}, {
    0.06165618443787982, -0.1712, -1.049644103514596}}], 
   Line3DBox[{{0.08910328502138275, 0.1712, -1.0276308992491618`}, {
    0.09165618443787982, 0.1712, -1.0423828127683377`}}], 
   Line3DBox[{{0.08910328502138275, -0.1712, -1.0276308992491618`}, {
    0.09165618443787982, -0.1712, -1.0423828127683377`}}], 
   Line3DBox[{{0.06165618443787982, 0.1712, -1.049644103514596}, {
    0.1222720695881344, 0.1712, -1.6285168820716673`}}], 
   Line3DBox[{{0.06165618443787982, -0.1712, -1.049644103514596}, {
    0.1222720695881344, -0.1712, -1.6285168820716673`}}], 
   Line3DBox[{{0.09165618443787982, 0.1712, -1.0423828127683377`}, {
    0.15227206958813438`, 0.1712, -1.6194548252082546`}}], 
   Line3DBox[{{0.09165618443787982, -0.1712, -1.0423828127683377`}, {
    0.15227206958813438`, -0.1712, -1.6194548252082546`}}], 
   Line3DBox[{{0.1222720695881344, 0.1712, -1.6285168820716673`}, {
    0.1253141376656209, 0.1712, -1.6432000367375987`}}], 
   Line3DBox[{{0.1222720695881344, -0.1712, -1.6285168820716673`}, {
    0.1253141376656209, -0.1712, -1.6432000367375987`}}], 
   Line3DBox[{{0.15227206958813438`, 0.1712, -1.6194548252082546`}, {
    0.1539523547142483, 0.1712, -1.634264012774129}}], 
   Line3DBox[{{0.15227206958813438`, -0.1712, -1.6194548252082546`}, {
    0.1539523547142483, -0.1712, -1.634264012774129}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.00037093633548678965`, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.00037093633548678965`, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.0579956991152811`*^-32}, {0., -1.0579956991152811`*^-32, 1.}}, {0., 
        0., 0.}}], {{{0.9838656002502252, 0., -0.17890914075100817`}, {0., 1.,
        0.}, {0.17890914075100817`, 0., 0.9838656002502252}}, {0., 0., 
       0.}}], {{{1., 5.017007906972523*^-18, 0.}, {-5.017007906972523*^-18, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.025969014368318284`, -9.8116201608063*^-34, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.0579956991152811`*^-32}, {
        0., -1.0579956991152811`*^-32, 1.}}, {0., 0., 0.}}], {{{
       0.9838656002502252, 0., -0.17890914075100817`}, {0., 1., 0.}, {
       0.17890914075100817`, 0., 0.9838656002502252}}, {0., 0., 0.}}], {{{1., 
      5.017007906972523*^-18, 0.}, {-5.017007906972523*^-18, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {0.026021079512011224`, 
    0.2, -0.41927099159116193`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.0579956991152811`*^-32}, {
        0., -1.0579956991152811`*^-32, 1.}}, {0., 0., 0.}}], {{{
       0.9838656002502252, 0., -0.17890914075100817`}, {0., 1., 0.}, {
       0.17890914075100817`, 0., 0.9838656002502252}}, {0., 0., 0.}}], {{{1., 
      5.017007906972523*^-18, 0.}, {-5.017007906972523*^-18, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {
    0.02602107951201122, -0.2, -0.41927099159116193`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -5.511618046193144*^-32}, {0., 5.511618046193144*^-32, 1.}}, {0., 
        0., 0.}}], {{{0.9800344367418237, 0., -0.198827821997165}, {0., 1., 
       0.}, {0.198827821997165, 0., 0.9800344367418237}}, {0., 0., 0.}}], {{{
      1., -2.8689997069486534`*^-18, 0.}, {2.8689997069486534`*^-18, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.04592300134807656, -5.246169195337925*^-34, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -5.511618046193144*^-32}, {0., 5.511618046193144*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9800344367418237, 
       0., -0.198827821997165}, {0., 1., 0.}, {0.198827821997165, 0., 
       0.9800344367418237}}, {0., 0., 0.}}], {{{1., -2.8689997069486534`*^-18,
       0.}, {2.8689997069486534`*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {0.04596458801505865, 0.14, -0.6961161372314465}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -5.511618046193144*^-32}, {0., 5.511618046193144*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9800344367418237, 
       0., -0.198827821997165}, {0., 1., 0.}, {0.198827821997165, 0., 
       0.9800344367418237}}, {0., 0., 0.}}], {{{1., -2.8689997069486534`*^-18,
       0.}, {2.8689997069486534`*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {0.04596458801505865, -0.14, -0.6961161372314465}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600310988*^-19}, {
        0., -7.621041600310988*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9709435692269868, 0., -0.23930855683982455`}, {0., 1., 0.}, {
       0.23930855683982455`, 0., 0.9709435692269868}}, {0., 0., 0.}}], {{{1., 
      7.89764771998285*^-19, 0.}, {-7.89764771998285*^-19, 1., 0.}, {0., 0., 
      1.}}, {0., 0., 0.}}], {0.0752241040018848, 
    7.032439475650728*^-34, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.4491735405148794`*^-30}, {0., 1.4491735405148794`*^-30, 1.}}, {
        0., 0., 0.}}], {{{0.9546072349542475, 0., -0.29786746544899134`}, {0.,
        1., 0.}, {0.29786746544899134`, 0., 0.9546072349542475}}, {0., 0., 
       0.}}], {{{1., 9.346704203953372*^-20, 0.}, {-9.346704203953372*^-20, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.13878066059582417`, -8.740937077222924*^-37, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, 0}]], "Output",
 CellChangeTimes->{3.459872746158669*^9, 3.4832950525020847`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-2]]", "Input"],

Cell[BoxData["0.46247636741479725`"], "Output",
 CellChangeTimes->{3.404735868227392*^9, 3.411511414892909*^9, 
  3.411564218426928*^9, 3.411565275073606*^9, 3.411568973295472*^9, 
  3.415473804368799*^9, 3.4155058851401052`*^9, 3.415556376512018*^9, 
  3.41564082249828*^9, 3.459802011510723*^9, 3.45987274621978*^9, 
  3.4832950526205807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "2"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", 
     RowBox[{"-", "0.0997679425952572`"}], "0", "0", "0", 
     RowBox[{"-", "0.20825566406925664`"}]},
    {"\<\"Mass U\"\>", "0", 
     RowBox[{"-", "0.1889329953232171`"}], "0", "0", "0", 
     RowBox[{"-", "0.26376057631500327`"}]},
    {"\<\"Mass 2\"\>", "0", 
     RowBox[{"-", "0.341112384660628`"}], "0", "0", "0", 
     RowBox[{"-", "0.33558532230426413`"}]},
    {"\<\"optic\"\>", "0", 
     RowBox[{"-", "0.7065207768444276`"}], "0", "0", "0", 
     RowBox[{"-", "0.33654693884477144`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735868252931*^9, 3.411511414908813*^9, 
  3.411564218447817*^9, 3.411565275325781*^9, 3.4115689733963346`*^9, 
  3.4154738045590687`*^9, 3.415505885193851*^9, 3.4155563765647306`*^9, 
  3.415640822524446*^9, 3.459802011530697*^9, 3.4598727462431297`*^9, 
  3.483295052668233*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 2\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "2"}], "]"}], "]"}], ",", " ", "0.5", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "0", ",", " ", "0"}], "}"}], ",", " ", 
     "floatmatrix2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.390911277302986*^9, 3.3909800115008173`*^9, {3.390980360364532*^9, 
   3.390980384828684*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{1.25421328981185*^-17, 0.25, -0.028329929244414912`}, {
    8.495094278772856*^-16, 0.039309613061879176`, -0.42840653715943916`}}], 
   Line3DBox[{{-1.25421328981185*^-17, -0.25, 
    0.028329769878453034`}, {-8.55584792395541*^-16, -0.13971543384882146`, \
-0.4096973795455476}}], 
   Line3DBox[{{-0.0029999999999981053`, 
    0.1476981915730063, -0.44955819217395954`}, {-0.002999999999998724, \
-0.03520903383415743, -0.7025595991955487}}], 
   Line3DBox[{{-0.0030000000000019013`, -0.2481370555851844, \
-0.3888619100627344}, {-0.0030000000000012855`, -0.15416700081300216`, \
-0.6867797990618307}}], 
   Line3DBox[{{0.003000000000001895, 
    0.14769819157300623`, -0.44955819217395954`}, {
    0.003000000000001276, -0.03520903383415757, -0.7025595991955487}}], 
   Line3DBox[{{
    0.002999999999998099, -0.24813705558518445`, -0.3888619100627344}, {
    0.0029999999999987146`, -0.1541670008130023, -0.6867797990618307}}], 
   Line3DBox[{{-0.002999999999997013, 
    0.04352846042826032, -0.717360024774786}, {-0.0029999999999951368`, 
    0.004373388241390691, -1.0563171472989874`}}], 
   Line3DBox[{{-0.0030000000000030046`, -0.2332668671222874, \
-0.6747111597929412}, {-0.0030000000000047966`, -0.3430774386121088, \
-0.9974640851966681}}], 
   Line3DBox[{{0.0030000000000029873`, 
    0.04352846042826018, -0.717360024774786}, {0.0030000000000048634`, 
    0.0043733882413905245`, -1.0563171472989874`}}], 
   Line3DBox[{{
    0.0029999999999969955`, -0.2332668671222875, -0.6747111597929412}, {
    0.0029999999999952036`, -0.34307743861210904`, -0.9974640851966681}}], 
   Line3DBox[{{-0.014999999999995293`, -0.0012825357252637393`, \
-1.0597690570480762`}, {-0.014999999999995205`, -0.0028376833949916858`, \
-1.074740088846332}}], 
   Line3DBox[{{-0.01500000000000468, -0.33887380449551985`, \
-1.0025860591370828`}, {-0.015000000000004794`, -0.34523768339499167`, \
-1.0172868274365936`}}], 
   Line3DBox[{{
    0.015000000000004706`, -0.001282535725264572, -1.0597690570480762`}, {
    0.015000000000004794`, -0.0028376833949925184`, -1.074740088846332}}], 
   Line3DBox[{{
    0.01499999999999532, -0.3388738044955206, -1.0025860591370828`}, {
    0.014999999999995205`, -0.3452376833949925, -1.0172868274365936`}}], 
   Line3DBox[{{-0.014999999999995205`, -0.0028376833949916858`, \
-1.074740088846332}, {-0.014999999999993269`, -0.17857829535438427`, \
-1.6527937444894452`}}], 
   Line3DBox[{{-0.015000000000004794`, -0.34523768339499167`, \
-1.0172868274365936`}, {-0.01500000000000673, -0.5209782953543842, \
-1.5951779627904685`}}], 
   Line3DBox[{{
    0.015000000000004794`, -0.0028376833949925184`, -1.074740088846332}, {
    0.01500000000000673, -0.17857829535438538`, -1.6527937444894452`}}], 
   Line3DBox[{{
    0.014999999999995205`, -0.3452376833949925, -1.0172868274365936`}, {
    0.014999999999993269`, -0.5209782953543853, -1.5951779627904685`}}], 
   Line3DBox[{{-0.014999999999993269`, -0.17857829535438427`, \
-1.6527937444894452`}, {-0.014999999999993349`, -0.1849578996300571, \
-1.667494177551114}}], 
   Line3DBox[{{-0.01500000000000673, -0.5209782953543842, \
-1.5951779627904685`}, {-0.015000000000006689`, -0.5225216353214601, \
-1.6101488695820694`}}], 
   Line3DBox[{{
    0.01500000000000673, -0.17857829535438538`, -1.6527937444894452`}, {
    0.01500000000000665, -0.18495789963005832`, -1.667494177551114}}], 
   Line3DBox[{{
    0.014999999999993269`, -0.5209782953543853, -1.5951779627904685`}, {
    0.01499999999999331, -0.5225216353214613, -1.6101488695820694`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    1.25421328981185*^-17, 0.25, -0.028329929244414912`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-1.25421328981185*^-17, -0.25, 0.028329769878453034`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9945835939483368, 0.10393976452162015`}, {0., -0.10393976452162015`,
         0.9945835939483368}}, {0., 0., 0.}}], {{{1., 
       0., -1.1085086497709578`*^-31}, {0., 1., 0.}, {
       1.1085086497709578`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      9.524333324841097*^-15, 0.}, {-9.524333324841097*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-4.321707671003629*^-33, -0.0498839712976286, \
-0.41600007927951627`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9945835939483368, 0.10393976452162015`}, {
        0., -0.10393976452162015`, 0.9945835939483368}}, {0., 0., 0.}}], {{{
       1., 0., -1.1085086497709578`*^-31}, {0., 1., 0.}, {
       1.1085086497709578`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      9.524333324841097*^-15, 0.}, {-9.524333324841097*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {1.894999203314143*^-15, 
    0.14769819157300623`, -0.44955819217395954`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9945835939483368, 0.10393976452162015`}, {
        0., -0.10393976452162015`, 0.9945835939483368}}, {0., 0., 0.}}], {{{
       1., 0., -1.1085086497709578`*^-31}, {0., 1., 0.}, {
       1.1085086497709578`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      9.524333324841097*^-15, 0.}, {-9.524333324841097*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-1.9013892825236734`*^-15, -0.24813705558518445`, \
-0.3888619100627344}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9913163914903729, 0.13149833444764905`}, {0., -0.13149833444764905`,
         0.9913163914903729}}, {0., 0., 0.}}], {{{1., 
       0., -1.1173947480548164`*^-31}, {0., 1., 0.}, {
       1.1173947480548164`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.15306142917193*^-14, 0.}, {-2.15306142917193*^-14, 1., 0.}, {0., 0., 
      1.}}, {0., 0., 
      0.}}], {-7.444979169864195*^-33, -0.09446649766160856, \
-0.6929997458713197}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9913163914903729, 0.13149833444764905`}, {
        0., -0.13149833444764905`, 0.9913163914903729}}, {0., 0., 0.}}], {{{
       1., 0., -1.1173947480548164`*^-31}, {0., 1., 0.}, {
       1.1173947480548164`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.15306142917193*^-14, 0.}, {-2.15306142917193*^-14, 1., 0.}, {0., 0., 
      1.}}, {0., 0., 0.}}], {2.9873349560633753`*^-15, 
    0.04352846042826025, -0.717360024774786}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9913163914903729, 0.13149833444764905`}, {
        0., -0.13149833444764905`, 0.9913163914903729}}, {0., 0., 0.}}], {{{
       1., 0., -1.1173947480548164`*^-31}, {0., 1., 0.}, {
       1.1173947480548164`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.15306142917193*^-14, 0.}, {-2.15306142917193*^-14, 1., 0.}, {0., 0., 
      1.}}, {0., 0., 
      0.}}], {-3.0046759576344516`*^-15, -0.23326686712228745`, \
-0.6747111597929412}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.985955808324346, 
        0.16700641913257502`}, {0., -0.16700641913257502`, 
        0.985955808324346}}, {0., 0., 0.}}], {{{1., 
       0., -1.1602153217078682`*^-31}, {0., 1., 0.}, {
       1.1602153217078682`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.7801631361319807`*^-14, 0.}, {-2.7801631361319807`*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-1.068250202135416*^-32, -0.170556192330314, \
-1.033999657905796}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9858753962949856, 
        0.1674804555170698}, {0., -0.1674804555170698, 0.9858753962949856}}, {
        0., 0., 0.}}], {{{1., 0., -1.5778391347133468`*^-31}, {0., 1., 0.}, {
       1.5778391347133468`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      3.952221725708089*^-14, 0.}, {-3.952221725708089*^-14, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-2.1453242943286088`*^-32, -0.3532603884222138, \
-1.6359996539166048`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, 0}]], "Output",
 CellChangeTimes->{3.459872746587894*^9, 3.48329505312987*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-3]]", "Input"],

Cell[BoxData["0.5248819383200826`"], "Output",
 CellChangeTimes->{3.4047358688743553`*^9, 3.411511415405081*^9, 
  3.411564218966248*^9, 3.4115652756799927`*^9, 3.411568975120023*^9, 
  3.415473805677074*^9, 3.415505885931168*^9, 3.4155563774148808`*^9, 
  3.4156408230321407`*^9, 3.459802011897476*^9, 3.459872746611052*^9, 
  3.483295053188334*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "3"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", 
     RowBox[{"-", "0.005177266010365551`"}], "0", "0", "0", 
     RowBox[{"-", "0.31059925443104597`"}], "0"},
    {"\<\"Mass U\"\>", 
     RowBox[{"-", "0.008564707749641957`"}], "0", "0", "0", 
     RowBox[{"-", "0.37241421415194587`"}], "0"},
    {"\<\"Mass 2\"\>", 
     RowBox[{"-", "0.008491770412281482`"}], "0", "0", "0", 
     RowBox[{"-", "0.5049817080801986`"}], "0"},
    {"\<\"optic\"\>", 
     RowBox[{"-", "0.02074946934918791`"}], "0", "0", "0", 
     RowBox[{"-", "0.7136010242451208`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735868899602*^9, 3.411511415422866*^9, 
  3.41156421898813*^9, 3.411565275878087*^9, 3.411568975193429*^9, 
  3.415473805858309*^9, 3.415505885980221*^9, 3.4155563775505943`*^9, 
  3.415640823053733*^9, 3.459802011914135*^9, 3.4598727466348886`*^9, 
  3.4832950532392893`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 3\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "3"}], "]"}], "]"}], ",", ".5", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277369274*^9, 3.390980017004929*^9, {3.39098036492443*^9, 
   3.39098038165333*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.00003946717392174915, 
    0.25, -7.968298282823696*^-8}, {-0.002114009414485228, 
    0.09, -0.41903164990711134`}}], 
   Line3DBox[{{-0.00003946717392174916, -0.25, -7.968298282816337*^-8}, \
{-0.0021140094144852287`, -0.09, -0.41903164990711134`}}], 
   Line3DBox[{{-0.005842943102758619, 
    0.2, -0.4197763428619598}, {-0.006918622875597563, 
    0.06, -0.6952106055679085}}], 
   Line3DBox[{{-0.005842943102758621, -0.2, -0.4197763428619598}, \
{-0.006918622875597563, -0.06, -0.6952106055679085}}], 
   Line3DBox[{{0.00008484827691472097, 
    0.2, -0.4188482860969554}, {-0.0010223419271967744`, 
    0.06, -0.6940998081167383}}], 
   Line3DBox[{{
    0.0000848482769147188, -0.2, -0.4188482860969554}, \
{-0.0010223419271967742`, -0.06, -0.6940998081167383}}], 
   Line3DBox[{{-0.007590082192930819, 
    0.14, -0.6967391967224794}, {-0.00895201854661524, 
    0.1762, -1.0277674190793917`}}], 
   Line3DBox[{{-0.007590082192930818, -0.14, -0.6967391967224794}, \
{-0.00895201854661524, -0.1762, -1.0277674190793917`}}], 
   Line3DBox[{{-0.0016938012445300301`, 
    0.14, -0.6956283992713093}, {-0.0031422595298538445`, 
    0.1762, -1.0262685194272605`}}], 
   Line3DBox[{{-0.0016938012445300297`, -0.14, -0.6956283992713093}, \
{-0.0031422595298538454`, -0.1762, -1.0262685194272605`}}], 
   Line3DBox[{{-0.01948533244780365, 
    0.1712, -1.034975362967316}, {-0.019051881608796402`, 
    0.1712, -1.0498108404504753`}}], 
   Line3DBox[{{-0.01948533244780365, -0.1712, -1.034975362967316}, \
{-0.019051881608796402`, -0.1712, -1.0498108404504753`}}], 
   Line3DBox[{{0.009563462636003321, 0.1712, -1.027480864706659}, {
    0.010948118391203597`, 0.1712, -1.0422160758324583`}}], 
   Line3DBox[{{0.009563462636003321, -0.1712, -1.027480864706659}, {
    0.010948118391203597`, -0.1712, -1.0422160758324583`}}], 
   Line3DBox[{{-0.019051881608796402`, 
    0.1712, -1.0498108404504753`}, {-0.025699994075171158`, 
    0.1712, -1.6293278418233923`}}], 
   Line3DBox[{{-0.019051881608796402`, -0.1712, -1.0498108404504753`}, \
{-0.025699994075171158`, -0.1712, -1.6293278418233923`}}], 
   Line3DBox[{{0.010948118391203597`, 0.1712, -1.0422160758324583`}, {
    0.004300005924828841, 0.1712, -1.6186438654565296`}}], 
   Line3DBox[{{0.010948118391203597`, -0.1712, -1.0422160758324583`}, {
    0.004300005924828841, -0.1712, -1.6186438654565296`}}], 
   Line3DBox[{{-0.025699994075171158`, 
    0.1712, -1.6293278418233923`}, {-0.023430283586926646`, 
    0.1712, -1.6439208530175142`}}], 
   Line3DBox[{{-0.025699994075171158`, -0.1712, -1.6293278418233923`}, \
{-0.023430283586926646`, -0.1712, -1.6439208530175142`}}], 
   Line3DBox[{{0.004300005924828841, 0.1712, -1.6186438654565296`}, {
    0.00468029027226847, 0.1712, -1.633442511674213}}], 
   Line3DBox[{{0.004300005924828841, -0.1712, -1.6186438654565296`}, {
    0.00468029027226847, -0.1712, -1.633442511674213}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.00003946717392174915, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.00003946717392174916, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.118980697991748*^-32}, {0., -1.118980697991748*^-32, 1.}}, {0., 0., 
        0.}}], {{{0.9879652299455566, 0., -0.15467612750073442`}, {0., 1., 
       0.}, {0.15467612750073442`, 0., 0.9879652299455566}}, {0., 0., 
       0.}}], {{{1., 5.356907083580243*^-18, 0.}, {-5.356907083580243*^-18, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0025886330051827756`, -1.0386387648969247`*^-33, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.118980697991748*^-32}, {0., -1.118980697991748*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9879652299455566, 
       0., -0.15467612750073442`}, {0., 1., 0.}, {0.15467612750073442`, 0., 
       0.9879652299455566}}, {0., 0., 0.}}], {{{1., 5.356907083580243*^-18, 
      0.}, {-5.356907083580243*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.002879047412921949, 0.2, -0.4193123144794576}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.118980697991748*^-32}, {0., -1.118980697991748*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9879652299455566, 
       0., -0.15467612750073442`}, {0., 1., 0.}, {0.15467612750073442`, 0., 
       0.9879652299455566}}, {0., 0., 0.}}], {{{1., 5.356907083580243*^-18, 
      0.}, {-5.356907083580243*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.002879047412921951, -0.2, -0.4193123144794576}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -5.815797904835835*^-32}, {0., 5.815797904835835*^-32, 1.}}, {0., 
        0., 0.}}], {{{0.9827134914001316, 0., -0.18513290852834216`}, {0., 1.,
        0.}, {0.18513290852834216`, 0., 0.9827134914001316}}, {0., 0., 
       0.}}], {{{1., -3.0527508284014147`*^-18, 0.}, {
      3.0527508284014147`*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.004282353874820979, -5.504018143019031*^-34, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -5.815797904835835*^-32}, {0., 5.815797904835835*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9827134914001316, 
       0., -0.18513290852834216`}, {0., 1., 0.}, {0.18513290852834216`, 0., 
       0.9827134914001316}}, {0., 0., 0.}}], {{{1., -3.0527508284014147`*^-18,
       0.}, {3.0527508284014147`*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.004641941718730425, 0.14, -0.6961837979968943}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -5.815797904835835*^-32}, {0., 5.815797904835835*^-32, 
        1.}}, {0., 0., 0.}}], {{{0.9827134914001316, 
       0., -0.18513290852834216`}, {0., 1., 0.}, {0.18513290852834216`, 0., 
       0.9827134914001316}}, {0., 0., 0.}}], {{{1., -3.0527508284014147`*^-18,
       0.}, {3.0527508284014147`*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.004641941718730424, -0.14, -0.6961837979968943}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600311823*^-19}, {
        0., -7.621041600311823*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9682931694602324, 0., -0.24981660868856942`}, {0., 1., 0.}, {
       0.24981660868856942`, 0., 0.9682931694602324}}, {0., 0., 0.}}], {{{1., 
      8.283612871382569*^-19, 0.}, {-8.283612871382569*^-19, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {-0.004245885206140741, 
    7.4187393829119305`*^-34, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.529082554355853*^-30}, {0., 1.529082554355853*^-30, 1.}}, {0., 
        0., 0.}}], {{{0.9370191286398372, 0., -0.3492780447767084}, {0., 1., 
       0.}, {0.3492780447767084, 0., 0.9370191286398372}}, {0., 0., 0.}}], {{{
      1., 1.022328439206943*^-19, 0.}, {-1.022328439206943*^-19, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-0.010374734674593955`, -9.174171820491013*^-37, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, -0.25}]], "Output",
 CellChangeTimes->{3.459872746983068*^9, 3.4832950537151213`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-4]]", "Input"],

Cell[BoxData["0.5815111974615327`"], "Output",
 CellChangeTimes->{3.404735869451833*^9, 3.4115114159571333`*^9, 
  3.411564222807501*^9, 3.4115652762284613`*^9, 3.411568976423884*^9, 
  3.415473806953964*^9, 3.415505886853517*^9, 3.415556378355906*^9, 
  3.415640823633286*^9, 3.459802012426248*^9, 3.4598727470063543`*^9, 
  3.48329505384203*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "4"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", 
     RowBox[{"-", "0.26140864792234575`"}], "0", "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", 
     RowBox[{"-", "0.47245510113978834`"}], "0", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", 
     RowBox[{"-", "0.592610384930713`"}], "0", "0", "0"},
    {"\<\"optic\"\>", "0", "0", 
     RowBox[{"-", "0.5977161766847837`"}], "0", "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735869479521*^9, 3.411511415972418*^9, 
  3.411564222830456*^9, 3.411565276545508*^9, 3.4115689765246143`*^9, 
  3.415473807089169*^9, 3.4155058869048986`*^9, 3.415556378406434*^9, 
  3.415640823654846*^9, 3.459802012443286*^9, 3.459872747029756*^9, 
  3.4832950538906803`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 4\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "4"}], "]"}], "]"}], ",", ".5", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277436495*^9, 3.390980019485515*^9, {3.390980603754201*^9, 
   3.390980607583726*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-2.2899399952916566`*^-17, 
    0.25, -0.1301064951773803}, {-1.565055703650149*^-15, 
    0.089999999999997, -0.549772902551904}}], 
   Line3DBox[{{2.2899399952916566`*^-17, -0.25, -0.13010649517738374`}, {
    1.5650557036501454`*^-15, -0.090000000000003, -0.5497729025519098}}], 
   Line3DBox[{{-0.0030000000000035007`, 
    0.20000000000000032`, -0.6550019771041147}, {-0.003000000000002292, 
    0.05999999999999685, -0.9309118779448597}}], 
   Line3DBox[{{-0.0029999999999964994`, -0.1999999999999997, \
-0.6550019771041307}, {-0.002999999999997708, -0.06000000000000315, \
-0.9309118779448755}}], 
   Line3DBox[{{0.0029999999999964994`, 
    0.20000000000000043`, -0.6550019771041147}, {0.002999999999997708, 
    0.059999999999997077`, -0.9309118779448597}}], 
   Line3DBox[{{
    0.0030000000000035007`, -0.1999999999999996, -0.6550019771041307}, {
    0.003000000000002292, -0.06000000000000292, -0.9309118779448755}}], 
   Line3DBox[{{-0.0030000000000053773`, 
    0.14000000000000495`, -0.9919539338964382}, {-0.0030000000000087227`, 
    0.17619999999999666`, -1.3230945458139238`}}], 
   Line3DBox[{{-0.002999999999994623, -0.13999999999999507`, \
-0.9919539338964848}, {-0.0029999999999912774`, -0.17620000000000333`, \
-1.3230945458139705`}}], 
   Line3DBox[{{0.002999999999994623, 
    0.14000000000000518`, -0.9919539338964382}, {0.0029999999999912774`, 
    0.17619999999999697`, -1.3230945458139238`}}], 
   Line3DBox[{{
    0.0030000000000053773`, -0.13999999999999485`, -0.9919539338964848}, {
    0.0030000000000087227`, -0.17620000000000302`, -1.3230945458139705`}}], 
   Line3DBox[{{-0.015000000000008475`, 
    0.17119999999999663`, -1.327442551889407}, {-0.015000000000008541`, 
    0.17119999999999702`, -1.342334998556833}}], 
   Line3DBox[{{-0.014999999999991524`, -0.17120000000000335`, \
-1.3274425518894524`}, {-0.014999999999991458`, -0.17120000000000296`, \
-1.3423349985568782`}}], 
   Line3DBox[{{0.014999999999991524`, 
    0.1711999999999981, -1.327442551889407}, {0.014999999999991458`, 
    0.17119999999999852`, -1.342334998556833}}], 
   Line3DBox[{{
    0.015000000000008475`, -0.17120000000000188`, -1.3274425518894524`}, {
    0.015000000000008541`, -0.17120000000000146`, -1.3423349985568782`}}], 
   Line3DBox[{{-0.015000000000008541`, 
    0.17119999999999702`, -1.342334998556833}, {-0.015000000000012136`, 
    0.17119999999998864`, -1.9228275940322979`}}], 
   Line3DBox[{{-0.014999999999991458`, -0.17120000000000296`, \
-1.3423349985568782`}, {-0.014999999999987863`, -0.17120000000001134`, \
-1.9228275940323434`}}], 
   Line3DBox[{{0.014999999999991458`, 
    0.17119999999999852`, -1.342334998556833}, {0.014999999999987863`, 
    0.17119999999999075`, -1.9228275940322979`}}], 
   Line3DBox[{{
    0.015000000000008541`, -0.17120000000000146`, -1.3423349985568782`}, {
    0.015000000000012136`, -0.17120000000000923`, -1.9228275940323434`}}], 
   Line3DBox[{{-0.015000000000012136`, 
    0.17119999999998864`, -1.9228275940322979`}, {-0.015000000000012203`, 
    0.17119999999998903`, -1.9377200407407047`}}], 
   Line3DBox[{{-0.014999999999987863`, -0.17120000000001134`, \
-1.9228275940323434`}, {-0.014999999999987796`, -0.17120000000001095`, \
-1.9377200407407504`}}], 
   Line3DBox[{{0.014999999999987863`, 
    0.17119999999999075`, -1.9228275940322979`}, {0.014999999999987796`, 
    0.17119999999999116`, -1.9377200407407047`}}], 
   Line3DBox[{{
    0.015000000000012136`, -0.17120000000000923`, -1.9228275940323434`}, {
    0.015000000000012203`, -0.17120000000000882`, -1.9377200407407504`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-2.2899399952916566`*^-17, 0.25, -0.1301064951773803}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    2.2899399952916566`*^-17, -0.25, -0.13010649517738374`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -3.195783187836776*^-14}, {0., 3.195783187836776*^-14, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 1.6033547072802787`*^-31}, {0., 1., 
       0.}, {-1.6033547072802787`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.738950781833497*^-14, 0.}, {1.738950781833497*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    4.4335741729731*^-33, -3.098100098426221*^-15, -0.546704403240691}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -3.195783187836776*^-14}, {0., 3.195783187836776*^-14, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.6033547072802787`*^-31}, {0., 1., 
       0.}, {-1.6033547072802787`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.738950781833497*^-14, 0.}, {1.738950781833497*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {-3.5007153851679933`*^-15, 
    0.20000000000000037`, -0.6550019771041147}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -3.195783187836776*^-14}, {0., 3.195783187836776*^-14, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.6033547072802787`*^-31}, {0., 1., 
       0.}, {-1.6033547072802787`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.738950781833497*^-14, 0.}, {1.738950781833497*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    3.5007153851678726`*^-15, -0.19999999999999965`, -0.6550019771041307}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.3209309325776613`*^-13}, {0., 1.3209309325776613`*^-13, 1.}}, {
        0., 0., 0.}}], {{{1., 0., 3.1736699756560813`*^-31}, {0., 1., 
       0.}, {-3.1736699756560813`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -3.820196820519653*^-14, 0.}, {3.820196820519653*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    7.28865843123888*^-33, -3.2566000461033814`*^-15, -0.9292272964412174}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.3209309325776613`*^-13}, {0., 
        1.3209309325776613`*^-13, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       3.1736699756560813`*^-31}, {0., 1., 0.}, {-3.1736699756560813`*^-31, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -3.820196820519653*^-14, 0.}, {
      3.820196820519653*^-14, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-5.377509144367986*^-15, 
    0.14000000000000506`, -0.9919539338964382}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.3209309325776613`*^-13}, {0., 
        1.3209309325776613`*^-13, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       3.1736699756560813`*^-31}, {0., 1., 0.}, {-3.1736699756560813`*^-31, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -3.820196820519653*^-14, 0.}, {
      3.820196820519653*^-14, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    5.3775091443673535`*^-15, -0.13999999999999496`, -0.9919539338964848}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.3240303797554664`*^-13}, {0., 1.3240303797554664`*^-13, 1.}}, {
        0., 0., 0.}}], {{{1., 0., 6.520215004415737*^-31}, {0., 1., 
       0.}, {-6.520215004415737*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -4.950521284604701*^-14, 0.}, {4.950521284604701*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    4.642746312002258*^-33, -2.232132038989971*^-15, -1.3303048503711565`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.3299197072798688`*^-13}, {0., 1.3299197072798688`*^-13, 1.}}, {
        0., 0., 0.}}], {{{1., 0., 9.819266737954798*^-31}, {0., 1., 
       0.}, {-9.819266737954798*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -7.128227706891426*^-14, 0.}, {7.128227706891426*^-14, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    1.4020949338332048`*^-32, -1.0278634879330092`*^-14, \
-1.9348577422590008`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.459872747369392*^9, 3.483295054333049*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-5]]", "Input"],

Cell[BoxData["0.5981380128696127`"], "Output",
 CellChangeTimes->{3.404735870030877*^9, 3.411511416472554*^9, 
  3.411564223481174*^9, 3.411565276946089*^9, 3.411568977971497*^9, 
  3.415473808132886*^9, 3.415505887660866*^9, 3.4155563793345327`*^9, 
  3.41564082416164*^9, 3.459802012808825*^9, 3.459872747424693*^9, 
  3.483295054393291*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "5"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0", 
     RowBox[{"-", "0.17058183373682642`"}], "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0", 
     RowBox[{"-", "0.3913035174792254`"}], "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", "0", 
     RowBox[{"-", "0.5171581310128481`"}], "0", "0"},
    {"\<\"optic\"\>", "0", "0", "0", 
     RowBox[{"-", "0.7418428827822404`"}], "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358700520363`*^9, 3.4115114164954147`*^9, 
  3.4115642235067472`*^9, 3.411565277147341*^9, 3.411568978017267*^9, 
  3.415473808204982*^9, 3.415505887696287*^9, 3.41555637938873*^9, 
  3.415640824183281*^9, 3.459802012828807*^9, 3.459872747448058*^9, 
  3.483295054442498*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 5\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "5"}], "]"}], "]"}], ",", " ", 
     RowBox[{"-", "0.2"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", "1"}], ",", " ", 
       RowBox[{"-", "0.25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277503449*^9, 3.390980022393909*^9, {3.3909806204267607`*^9, 
   3.390980624200344*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.000044926189702998986`, 
    0.25, -7.968298283395223*^-8}, {-0.0030698774077857313`, 
    0.08994762838841927, -0.41906857859073404`}}], 
   Line3DBox[{{0.000044926189702998986`, -0.25, -7.968298282240617*^-8}, {
    0.0030698774077857313`, -0.08994762838841924, -0.41906857859073404`}}], 
   Line3DBox[{{-0.00986856524685763, 
    0.1997796388460978, -0.41922753231450055`}, {-0.007681667996116927, 
    0.05958180910980658, -0.6946843273749734}}], 
   Line3DBox[{{
    0.00387205668762968, -0.19998429733995016`, -0.4192275323145006}, {
    0.001700032833063316, -0.06005089415126563, -0.6946843273749734}}], 
   Line3DBox[{{-0.00387205668762968, 
    0.19998429733995018`, -0.41922753231450055`}, {-0.001700032833063316, 
    0.06005089415126559, -0.6946843273749734}}], 
   Line3DBox[{{
    0.00986856524685763, -0.19977963884609778`, -0.4192275323145006}, {
    0.007681667996116927, -0.05958180910980662, -0.6946843273749734}}], 
   Line3DBox[{{-0.014001035546978183`, 
    0.13933185507664952`, -0.696062185309029}, {-0.021176142200092476`, 
    0.17494859531165566`, -1.0267893533485906`}}], 
   Line3DBox[{{
    0.008019400383924572, -0.13980094011810856`, -0.6960621853090289}, {
    0.015208207901847657`, -0.17556807913858993`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.008019400383924572, 
    0.13980094011810854`, -0.696062185309029}, {-0.015208207901847657`, 
    0.17556807913858993`, -1.0267893533485906`}}], 
   Line3DBox[{{
    0.014001035546978183`, -0.13933185507664955`, -0.6960621853090289}, {
    0.021176142200092476`, -0.17494859531165566`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.032595774274136874`, 
    0.16873634907591642`, -1.0311373594240731`}, {-0.03284552001214385, 
    0.16963643224192665`, -1.0460134581414668`}}], 
   Line3DBox[{{
    0.0027561027829127917`, -0.1718337682105878, -1.0311373594240731`}, {
    0.0028455200121438526`, -0.17276356775807333`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.0027561027829127917`, 
    0.17183376821058782`, -1.0311373594240731`}, {-0.0028455200121438526`, 
    0.17276356775807336`, -1.0460134581414668`}}], 
   Line3DBox[{{
    0.032595774274136874`, -0.1687363490759164, -1.0311373594240731`}, {
    0.03284552001214385, -0.16963643224192662`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.03284552001214385, 
    0.16963643224192665`, -1.0460134581414668`}, {-0.04026267481138905, 
    0.16898656470694606`, -1.623985853639961}}], 
   Line3DBox[{{
    0.0028455200121438526`, -0.17276356775807333`, -1.0460134581414668`}, {
    0.010262674811389053`, -0.17341343529305392`, -1.623985853639961}}], 
   Line3DBox[{{-0.0028455200121438526`, 
    0.17276356775807336`, -1.0460134581414668`}, {-0.010262674811389053`, 
    0.17341343529305395`, -1.623985853639961}}], 
   Line3DBox[{{
    0.03284552001214385, -0.16963643224192662`, -1.0460134581414668`}, {
    0.04026267481138905, -0.16898656470694604`, -1.623985853639961}}], 
   Line3DBox[{{-0.04026267481138905, 
    0.16898656470694606`, -1.623985853639961}, {-0.040142814279841885`, 
    0.1671017488289519, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.010262674811389053`, -0.17341343529305392`, -1.623985853639961}, {
    0.010472407513658886`, -0.17153649372908336`, -1.6388619523983357`}}], 
   Line3DBox[{{-0.010262674811389053`, 
    0.17341343529305395`, -1.623985853639961}, {-0.010472407513658886`, 
    0.1715364937290834, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.04026267481138905, -0.16898656470694604`, -1.623985853639961}, {
    0.040142814279841885`, -0.16710174882895187`, -1.6388619523983357`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.000044926189702998986`, 0.25, -7.968298283395223*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.000044926189702998986`, -0.25, -7.968298282240617*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.317667021585333*^-16}, {0., -1.317667021585333*^-16, 1.}}, {0., 0., 
        0.}}], {{{1., 0., 1.5527131608655041`*^-21}, {0., 1., 
       0.}, {-1.5527131608655041`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9994180932046585, -0.034109748975397015`, 0.}, {0.034109748975397015`,
       0.9994180932046585, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.5400307664884654`*^-23, 
    1.6440868962708488`*^-17, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.317667021585333*^-16}, {0., -1.317667021585333*^-16, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.5527131608655041`*^-21}, {0., 1., 
       0.}, {-1.5527131608655041`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9994180932046585, -0.034109748975397015`, 0.}, {0.034109748975397015`,
       0.9994180932046585, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.006870310967243656, 
    0.199881968093024, -0.41922753231450055`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.317667021585333*^-16}, {0., -1.317667021585333*^-16, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.5527131608655041`*^-21}, {0., 1., 
       0.}, {-1.5527131608655041`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9994180932046585, -0.034109748975397015`, 0.}, {0.034109748975397015`,
       0.9994180932046585, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.006870310967243656, -0.19988196809302397`, -0.4192275323145006}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.7170827502335736`*^-16}, {0., 1.7170827502335736`*^-16, 1.}}, {
        0., 0., 0.}}], {{{1., 0., 1.8064557845269906`*^-21}, {0., 1., 
       0.}, {-1.8064557845269906`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9969391938422685, -0.0781808402431687, 0.}, {0.0781808402431687, 
      0.9969391938422685, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    2.4346102078574824`*^-23, -2.0278011932876183`*^-17, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.7170827502335736`*^-16}, {0., 
        1.7170827502335736`*^-16, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       1.8064557845269906`*^-21}, {0., 1., 0.}, {-1.8064557845269906`*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9969391938422685, -0.0781808402431687, 
      0.}, {0.0781808402431687, 0.9969391938422685, 0.}, {0., 0., 1.}}, {0., 
      0., 0.}}], {-0.011010217965451376`, 
    0.13956639759737902`, -0.696062185309029}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.7170827502335736`*^-16}, {0., 
        1.7170827502335736`*^-16, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       1.8064557845269906`*^-21}, {0., 1., 0.}, {-1.8064557845269906`*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9969391938422685, -0.0781808402431687, 
      0.}, {0.0781808402431687, 0.9969391938422685, 0.}, {0., 0., 1.}}, {0., 
      0., 0.}}], {
    0.011010217965451376`, -0.13956639759737907`, -0.6960621853090289}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 5.255090033394939*^-17}, {
        0., -5.255090033394939*^-17, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       2.339864756465993*^-21}, {0., 1., 0.}, {-2.339864756465993*^-21, 0., 
       1.}}, {0., 0., 0.}}], {{{0.9946557163741362, -0.10324730448904693`, 
      0.}, {0.10324730448904693`, 0.9946557163741362, 0.}, {0., 0., 1.}}, {0.,
       0., 0.}}], {1.475551835292525*^-23, 
    6.826493460436061*^-18, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 5.828171605637645*^-17}, {
        0., -5.828171605637645*^-17, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       3.84168678247899*^-21}, {0., 1., 0.}, {-3.84168678247899*^-21, 0., 
       1.}}, {0., 0., 0.}}], {{{0.9890135588727665, -0.1478248300043831, 
      0.}, {0.1478248300043831, 0.9890135588727665, 0.}, {0., 0., 1.}}, {0., 
      0., 0.}}], {5.097192631205806*^-23, 
    1.1784359393305765`*^-17, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, -0.25}]], "Output",
 CellChangeTimes->{3.459872747808277*^9, 3.483295054902577*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-6]]", "Input"],

Cell[BoxData["0.863442833415718`"], "Output",
 CellChangeTimes->{3.4047358706122017`*^9, 3.411511417068576*^9, 
  3.411564224111504*^9, 3.411565277582728*^9, 3.4115689788709507`*^9, 
  3.415473808840106*^9, 3.415505888570499*^9, 3.415556380238632*^9, 
  3.415640824750462*^9, 3.459802013183013*^9, 3.459872747831641*^9, 
  3.483295055028689*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "6"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0.007332088922940507`", "0", "0", "0", 
     RowBox[{"-", "0.15716850889678308`"}]},
    {"\<\"Mass U\"\>", "0", "0.0014448653413463065`", "0", "0", "0", 
     RowBox[{"-", "0.592319095464889`"}]},
    {"\<\"Mass 2\"\>", "0", 
     RowBox[{"-", "0.011035911635801783`"}], "0", "0", "0", 
     RowBox[{"-", "0.556080512365257`"}]},
    {"\<\"optic\"\>", "0", "0.015579297155109124`", "0", "0", "0", 
     RowBox[{"-", "0.561079548475171`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735870638212*^9, 3.411511417083826*^9, 
  3.4115642241376677`*^9, 3.411565277782012*^9, 3.4115689791323433`*^9, 
  3.415473808965592*^9, 3.4155058886217813`*^9, 3.415556380412455*^9, 
  3.415640824771962*^9, 3.45980201319946*^9, 3.4598727478559713`*^9, 
  3.4832950550766706`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 6\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "6"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277569565*^9, 3.390980025485722*^9, {3.390980630628484*^9, 
   3.3909806411800203`*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{3.616544336103041*^-18, 0.25, 0.002297723432288088}, {
    2.4731487642768617`*^-16, 0.08858556079305574, -0.41623849545871894`}}], 
   Line3DBox[{{-3.616544336103041*^-18, -0.25, -0.0022978827982531908`}, \
{-2.4678516783985113`*^-16, -0.09132551954425344, -0.42189563005692954`}}], 
   Line3DBox[{{-0.002999999999999447, 
    0.19848970980071087`, -0.4114611973388004}, {-0.002999999999999611, 
    0.05948960428987908, -0.6875813047783222}}], 
   Line3DBox[{{-0.0030000000000005526`, -0.20121967718957265`, \
-0.4269906785786974}, {-0.0030000000000003865`, -0.059669359383920414`, \
-0.7017637367343067}}], 
   Line3DBox[{{0.003000000000000553, 
    0.19848970980071085`, -0.4114611973388004}, {0.003000000000000389, 
    0.05948960428987904, -0.6875813047783222}}], 
   Line3DBox[{{
    0.0029999999999994476`, -0.20121967718957268`, -0.4269906785786974}, {
    0.0029999999999996137`, -0.059669359383920456`, -0.7017637367343067}}], 
   Line3DBox[{{-0.0029999999999990898`, 
    0.13875693768608807`, -0.676681432330357}, {-0.00299999999999847, 
    0.17651834442702619`, -1.0072779951730644`}}], 
   Line3DBox[{{-0.003000000000000906, -0.13861100317355027`, \
-0.7154000112408008}, {-0.003000000000001544, -0.17370447951029094`, \
-1.0463898040467405`}}], 
   Line3DBox[{{0.0030000000000009104`, 
    0.13875693768608804`, -0.676681432330357}, {0.00300000000000153, 
    0.17651834442702613`, -1.0072779951730644`}}], 
   Line3DBox[{{
    0.002999999999999094, -0.1386110031735503, -0.7154000112408008}, {
    0.002999999999998456, -0.173704479510291, -1.0463898040467405`}}], 
   Line3DBox[{{-0.01499999999999851, 
    0.1720318071481366, -1.0121540735232928`}, {-0.014999999999998482`, 
    0.17344658330620608`, -1.0269721652979489`}}], 
   Line3DBox[{{-0.015000000000001495`, -0.16825279817574929`, \
-1.0501560126786467`}, {-0.015000000000001517`, -0.1689534166937939, \
-1.065054750984983}}], 
   Line3DBox[{{0.01500000000000149, 
    0.17203180714813632`, -1.0121540735232928`}, {0.015000000000001517`, 
    0.1734465833062058, -1.0269721652979489`}}], 
   Line3DBox[{{
    0.014999999999998504`, -0.16825279817574956`, -1.0501560126786467`}, {
    0.014999999999998482`, -0.16895341669379418`, -1.065054750984983}}], 
   Line3DBox[{{-0.014999999999998482`, 
    0.17344658330620608`, -1.0269721652979489`}, {-0.01499999999999762, 
    0.1680434816699725, -1.6047755860003008`}}], 
   Line3DBox[{{-0.015000000000001517`, -0.1689534166937939, \
-1.065054750984983}, {-0.01500000000000238, -0.1743565183300275, \
-1.6431961212796193`}}], 
   Line3DBox[{{0.015000000000001517`, 
    0.1734465833062058, -1.0269721652979489`}, {0.01500000000000238, 
    0.16804348166997207`, -1.6047755860003008`}}], 
   Line3DBox[{{
    0.014999999999998482`, -0.16895341669379418`, -1.065054750984983}, {
    0.01499999999999762, -0.1743565183300279, -1.6431961212796193`}}], 
   Line3DBox[{{-0.01499999999999762, 
    0.1680434816699725, -1.6047755860003008`}, {-0.014999999999997614`, 
    0.16732788263727114`, -1.6196728801276505`}}], 
   Line3DBox[{{-0.01500000000000238, -0.1743565183300275, \
-1.6431961212796193`}, {-0.015000000000002376`, -0.17291855800303244`, \
-1.6580150192386125`}}], 
   Line3DBox[{{0.01500000000000238, 
    0.16804348166997207`, -1.6047755860003008`}, {0.015000000000002385`, 
    0.16732788263727072`, -1.6196728801276505`}}], 
   Line3DBox[{{
    0.01499999999999762, -0.1743565183300279, -1.6431961212796193`}, {
    0.014999999999997623`, -0.17291855800303285`, -1.6580150192386125`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    3.616544336103041*^-18, 0.25, 0.002297723432288088}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-3.616544336103041*^-18, -0.25, -0.0022978827982531908`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.99950600187394, -0.03142852554561415}, {0., 0.03142852554561415, 
        0.99950600187394}}, {0., 0., 0.}}], {{{1., 
       0., -1.0583498138392997`*^-32}, {0., 1., 0.}, {
       1.0583498138392997`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.746356941113165*^-15, 0.}, {-2.746356941113165*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {
    2.5613020559804673`*^-35, -0.0014664177845881013`, -0.4160000792795179}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.99950600187394, -0.03142852554561415}, {0., 
        0.03142852554561415, 0.99950600187394}}, {0., 0., 0.}}], {{{1., 
       0., -1.0583498138392997`*^-32}, {0., 1., 0.}, {
       1.0583498138392997`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.746356941113165*^-15, 0.}, {-2.746356941113165*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {5.532703775837226*^-16, 
    0.19848970980071085`, -0.4114611973388004}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.99950600187394, -0.03142852554561415}, {0., 
        0.03142852554561415, 0.99950600187394}}, {0., 0., 0.}}], {{{1., 
       0., -1.0583498138392997`*^-32}, {0., 1., 0.}, {
       1.0583498138392997`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.746356941113165*^-15, 0.}, {-2.746356941113165*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-5.527132291485852*^-16, -0.20121967718957268`, \
-0.4269906785786974}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9929913639483292, -0.11818693296653718`}, {0., 0.11818693296653718`,
         0.9929913639483292}}, {0., 0., 0.}}], {{{1., 
       0., -6.25128072478625*^-33}, {0., 1., 0.}, {6.25128072478625*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.504450983635326*^-15, 
      0.}, {-6.504450983635326*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    5.013384331049833*^-35, -0.0002889730682692613, -0.6929997458713227}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9929913639483292, -0.11818693296653718`}, {0., 
        0.11818693296653718`, 0.9929913639483292}}, {0., 0., 0.}}], {{{1., 
       0., -6.25128072478625*^-33}, {0., 1., 0.}, {6.25128072478625*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.504450983635326*^-15, 
      0.}, {-6.504450983635326*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    9.10294784909301*^-16, 0.13875693768608807`, -0.676681432330357}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9929913639483292, -0.11818693296653718`}, {0., 
        0.11818693296653718`, 0.9929913639483292}}, {0., 0., 0.}}], {{{1., 
       0., -6.25128072478625*^-33}, {0., 1., 0.}, {6.25128072478625*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.504450983635326*^-15, 
      0.}, {-6.504450983635326*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-9.05586338709382*^-16, -0.13861100317355027`, \
-0.7154000112408008}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9938218613431247, -0.11098697183222477`}, {0., 0.11098697183222477`,
         0.9938218613431247}}, {0., 0., 0.}}], {{{1., 0., 
       2.2938788195293474`*^-33}, {0., 1., 0.}, {-2.2938788195293474`*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 8.776991335795375*^-15, 
      0.}, {-8.776991335795375*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    3.130392095764954*^-35, 0.0022071823271603568`, -1.033999657905799}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9937103990663072, -0.11198054646893131`}, {0., 0.11198054646893131`,
         0.9937103990663072}}, {0., 0., 0.}}], {{{1., 0., 
       7.035594730172525*^-33}, {0., 1., 0.}, {-7.035594730172525*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 1.3997712193425828`*^-14, 
      0.}, {-1.3997712193425828`*^-14, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.65461549369477*^-35, -0.003115859431021825, \
-1.635999653916608}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872748194768*^9, 3.48329505555367*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#7", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-7]]", "Input"],

Cell[BoxData["0.9871952883656314`"], "Output",
 CellChangeTimes->{3.404735871142128*^9, 3.411511417662822*^9, 
  3.411564224670741*^9, 3.4115652781518173`*^9, 3.411568980257285*^9, 
  3.415473809721449*^9, 3.4155058893980093`*^9, 3.415556381141128*^9, 
  3.41564082530834*^9, 3.4598020135829697`*^9, 3.459872748217774*^9, 
  3.483295055613181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "7"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", 
     RowBox[{"-", "0.2232216126848385`"}], "0", "0", "0", 
     "0.5862066238288947`", "0"},
    {"\<\"Mass U\"\>", 
     RowBox[{"-", "0.35032274292433524`"}], "0", "0", "0", 
     "0.3986801580048183`", "0"},
    {"\<\"Mass 2\"\>", 
     RowBox[{"-", "0.422562894047208`"}], "0", "0", "0", 
     "0.06964386278966855`", "0"},
    {"\<\"optic\"\>", "0.31262087826233015`", "0", "0", "0", 
     RowBox[{"-", "0.20909455429877474`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358711652613`*^9, 3.411511417678076*^9, 
  3.411564224696357*^9, 3.411565278351*^9, 3.41156898031046*^9, 
  3.415473809767476*^9, 3.415505889434478*^9, 3.415556381195182*^9, 
  3.415640825330233*^9, 3.459802013598934*^9, 3.459872748241294*^9, 
  3.483295055662566*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 7\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "7"}], "]"}], "]"}], ",", " ", 
     RowBox[{"-", "0.2"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", " ", 
       RowBox[{"-", "0.25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277636512*^9, 3.390980028369113*^9, {3.3909806513477716`*^9, 
   3.390980655465293*^9}, {3.483295111045762*^9, 3.483295113444569*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{0.0006404523157072787, 0.25, -7.968298282823696*^-8}, {
    0.04500325385726018, 0.09, -0.419047513664414}}], 
   Line3DBox[{{0.0006404523157072787, -0.25, -7.968298282816337*^-8}, {
    0.04500325385726018, -0.09, -0.419047513664414}}], 
   Line3DBox[{{0.0419179375265488, 0.2, -0.4195709592433906}, {
    0.06720825984185119, 0.06, -0.694917929767346}}], 
   Line3DBox[{{0.04191793752654879, -0.2, -0.4195709592433906}, {
    0.06720825984185119, -0.06, -0.694917929767346}}], 
   Line3DBox[{{0.04787674815509992, 0.2, -0.4188691217315218}, {
    0.07318919644101901, 0.06, -0.6944400203651213}}], 
   Line3DBox[{{0.047876748155099916`, -0.2, -0.4188691217315218}, {
    0.07318919644101901, -0.06, -0.6944400203651213}}], 
   Line3DBox[{{0.06714089527330559, 0.14, -0.6963055622271471}, {
    0.08141244237595001, 0.1762, -1.026831837741939}}], 
   Line3DBox[{{0.06714089527330559, -0.14, -0.6963055622271471}, {
    0.08141244237595001, -0.1762, -1.026831837741939}}], 
   Line3DBox[{{0.07312183187247341, 0.14, -0.6958276528249224}, {
    0.08741186035324507, 0.1762, -1.026748267808896}}], 
   Line3DBox[{{0.07312183187247341, -0.14, -0.6958276528249224}, {
    0.08741186035324507, -0.1762, -1.026748267808896}}], 
   Line3DBox[{{0.06947416685079286, 0.1712, -1.0313465619104645`}, {
    0.06689271472296486, 0.1712, -1.0462170348678272`}}], 
   Line3DBox[{{0.06947416685079286, -0.1712, -1.0313465619104645`}, {
    0.06689271472296486, -0.1712, -1.0462170348678272`}}], 
   Line3DBox[{{0.09947125673726817, 0.1712, -1.0309287122452502`}, {
    0.09689271472296486, 0.1712, -1.0458098814151064`}}], 
   Line3DBox[{{0.09947125673726817, -0.1712, -1.0309287122452502`}, {
    0.09689271472296486, -0.1712, -1.0458098814151064`}}], 
   Line3DBox[{{0.06689271472296486, 
    0.1712, -1.0462170348678272`}, {-0.07483416451514596, 
    0.1712, -1.6233639248390732`}}], 
   Line3DBox[{{
    0.06689271472296486, -0.1712, -1.0462170348678272`}, \
{-0.07483416451514596, -0.1712, -1.6233639248390732`}}], 
   Line3DBox[{{0.09689271472296486, 
    0.1712, -1.0458098814151064`}, {-0.044834164515145956`, 
    0.1712, -1.6246077824408487`}}], 
   Line3DBox[{{
    0.09689271472296486, -0.1712, -1.0458098814151064`}, \
{-0.044834164515145956`, -0.1712, -1.6246077824408487`}}], 
   Line3DBox[{{-0.07483416451514596, 
    0.1712, -1.6233639248390732`}, {-0.07763072472369838, 
    0.1712, -1.6382323490944026`}}], 
   Line3DBox[{{-0.07483416451514596, -0.1712, -1.6233639248390732`}, \
{-0.07763072472369838, -0.1712, -1.6382323490944026`}}], 
   Line3DBox[{{-0.044834164515145956`, 
    0.1712, -1.6246077824408487`}, {-0.047656953220533725`, 
    0.1712, -1.639486550783157}}], 
   Line3DBox[{{-0.044834164515145956`, -0.1712, -1.6246077824408487`}, \
{-0.047656953220533725`, -0.1712, -1.639486550783157}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.0006404523157072787, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.0006404523157072787, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        2.316189303425035*^-33}, {0., -2.316189303425035*^-33, 1.}}, {0., 0., 
        0.}}], {{{0.9931351047585207, 0., -0.11697291864479574`}, {0., 1., 
       0.}, {0.11697291864479574`, 0., 0.9931351047585207}}, {0., 0., 
       0.}}], {{{1., 1.204109936975697*^-18, 0.}, {-1.204109936975697*^-18, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.04464432253696771, -2.1659579457780964`*^-34, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.316189303425035*^-33}, {0., -2.316189303425035*^-33, 
        1.}}, {0., 0., 0.}}], {{{0.9931351047585207, 
       0., -0.11697291864479574`}, {0., 1., 0.}, {0.11697291864479574`, 0., 
       0.9931351047585207}}, {0., 0., 0.}}], {{{1., 1.204109936975697*^-18, 
      0.}, {-1.204109936975697*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.04489734284082436, 0.2, -0.4192200404874562}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.316189303425035*^-33}, {0., -2.316189303425035*^-33, 
        1.}}, {0., 0., 0.}}], {{{0.9931351047585207, 
       0., -0.11697291864479574`}, {0., 1., 0.}, {0.11697291864479574`, 0., 
       0.9931351047585207}}, {0., 0., 0.}}], {{{1., 1.204109936975697*^-18, 
      0.}, {-1.204109936975697*^-18, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.044897342840824354`, -0.2, -0.4192200404874562}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.1814133435298714`*^-32}, {0., 1.1814133435298714`*^-32, 1.}}, {
        0., 0., 0.}}], {{{0.9968227665279707, 0., -0.07965156703745845}, {0., 
       1., 0.}, {0.07965156703745845, 0., 0.9968227665279707}}, {0., 0., 
       0.}}], {{{1., -6.640703670186706*^-19, 0.}, {6.640703670186706*^-19, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.07006454858486705, -1.0647999190728083`*^-34, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.1814133435298714`*^-32}, {0., 
        1.1814133435298714`*^-32, 1.}}, {0., 0., 0.}}], {{{0.9968227665279707,
        0., -0.07965156703745845}, {0., 1., 0.}, {0.07965156703745845, 0., 
       0.9968227665279707}}, {0., 0., 0.}}], {{{1., -6.640703670186706*^-19, 
      0.}, {6.640703670186706*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0701313635728895, 0.14, -0.6960666075260348}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.1814133435298714`*^-32}, {0., 
        1.1814133435298714`*^-32, 1.}}, {0., 0., 0.}}], {{{0.9968227665279707,
        0., -0.07965156703745845}, {0., 1., 0.}, {0.07965156703745845, 0., 
       0.9968227665279707}}, {0., 0., 0.}}], {{{1., -6.640703670186706*^-19, 
      0.}, {6.640703670186706*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0701313635728895, -0.14, -0.6960666075260348}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600299085*^-19}, {
        0., -7.621041600299085*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9999029962158442, 0., -0.013928322173805479`}, {0., 1., 0.}, {
       0.013928322173805479`, 0., 0.9999029962158442}}, {0., 0., 0.}}], {{{1.,
       1.5661340112093747`*^-19, 0.}, {-1.5661340112093747`*^-19, 1., 0.}, {
      0., 0., 1.}}, {0., 0., 0.}}], {0.0845125788094416, 
    1.5042894747634958`*^-34, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -3.1050963134870314`*^-31}, {0., 3.1050963134870314`*^-31, 1.}}, {
        0., 0., 0.}}], {{{0.9991257167721552, 0., 0.04180672295847947}, {0., 
       1., 0.}, {-0.04180672295847947, 0., 0.9991257167721552}}, {0., 0., 
       0.}}], {{{1., 2.8355169958589415`*^-20, 
      0.}, {-2.8355169958589415`*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.06252417565246603, -1.981593672233893*^-37, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.459872748590416*^9, 3.483295056137842*^9, 
  3.483295455156125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#8", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-8]]", "Input"],

Cell[BoxData["1.0443794741943906`"], "Output",
 CellChangeTimes->{3.4047358717277317`*^9, 3.411511418237007*^9, 
  3.411564225289967*^9, 3.41156527881887*^9, 3.411568981362171*^9, 
  3.415473810867049*^9, 3.415505890286727*^9, 3.415556382127468*^9, 
  3.4156408259391737`*^9, 3.4598020139563713`*^9, 3.4598727486457987`*^9, 
  3.483295056264613*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "8"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0.228602790894103`", "0", "0", "0", 
     "0.11006174253038767`"},
    {"\<\"Mass U\"\>", "0", "0.3712920086449123`", "0", "0", "0", 
     RowBox[{"-", "0.45892211471505007`"}]},
    {"\<\"Mass 2\"\>", "0", "0.4965490473316979`", "0", "0", "0", 
     RowBox[{"-", "0.3498106405921218`"}]},
    {"\<\"optic\"\>", "0", 
     RowBox[{"-", "0.30382874379052605`"}], "0", "0", "0", 
     RowBox[{"-", "0.35485147250318394`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735871753512*^9, 3.4115114182539167`*^9, 
  3.411564225316033*^9, 3.4115652790348663`*^9, 3.4115689814127197`*^9, 
  3.415473811116873*^9, 3.415505890338401*^9, 3.415556382218766*^9, 
  3.415640825963128*^9, 3.459802013972492*^9, 3.459872748668929*^9, 
  3.483295056314233*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 8\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "8"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112777039003`*^9, 3.3909800333212023`*^9, {3.3909806638150883`*^9, 
   3.390980669329957*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{6.604966043681376*^-19, 0.25, -0.019301721406230272`}, {
    4.5096719223520656`*^-17, 0.044190098823072274`, -0.4210487865903953}}], 
   Line3DBox[{{-6.604966043681376*^-19, -0.25, 
    0.019301562040264744`}, {-4.516447106596102*^-17, -0.13576629402395946`, \
-0.4170868838297522}}], 
   Line3DBox[{{-0.002999999999999899, 
    0.15406285439038145`, -0.42803917419368065`}, {-0.002999999999999917, \
-0.014356554423501734`, -0.6891779002133573}}], 
   Line3DBox[{{-0.003000000000000101, -0.24564604691567976`, \
-0.4104143266571182}, {-0.003000000000000083, -0.13385144635708798`, \
-0.7001765729414888}}], 
   Line3DBox[{{0.003000000000000101, 
    0.15406285439038145`, -0.42803917419368065`}, {
    0.0030000000000000833`, -0.014356554423501734`, -0.6891779002133573}}], 
   Line3DBox[{{
    0.002999999999999899, -0.24564604691567976`, -0.4104143266571182}, {
    0.0029999999999999172`, -0.13385144635708798`, -0.7001765729414888}}], 
   Line3DBox[{{-0.0029999999999998045`, 
    0.06522489257249225, -0.6809565817388107}, {-0.0029999999999996605`, 
    0.07595510655116068, -1.0144897192799023`}}], 
   Line3DBox[{{-0.003000000000000195, -0.21318031654503974`, \
-0.7111420078315316}, {-0.003000000000000342, -0.27558279914680606`, \
-1.0391242652973844`}}], 
   Line3DBox[{{0.0030000000000001957`, 
    0.06522489257249225, -0.6809565817388107}, {0.0030000000000003396`, 
    0.07595510655116068, -1.0144897192799023`}}], 
   Line3DBox[{{
    0.0029999999999998053`, -0.21318031654503974`, -0.7111420078315316}, {
    0.0029999999999996583`, -0.27558279914680606`, -1.0391242652973844`}}], 
   Line3DBox[{{-0.014999999999999668`, 
    0.07127128597017586, -1.0191766139445577`}, {-0.01499999999999966, 
    0.07484699766639447, -1.0340348365432184`}}], 
   Line3DBox[{{-0.01500000000000033, -0.2702910832437396, \
-1.0431121092804996`}, {-0.01500000000000034, -0.2675530023336055, \
-1.0579920797397147`}}], 
   Line3DBox[{{0.01500000000000033, 
    0.0712712859701758, -1.0191766139445577`}, {0.01500000000000034, 
    0.07484699766639441, -1.0340348365432184`}}], 
   Line3DBox[{{
    0.014999999999999668`, -0.2702910832437397, -1.0431121092804996`}, {
    0.01499999999999966, -0.26755300233360557`, -1.0579920797397147`}}], 
   Line3DBox[{{-0.01499999999999966, 
    0.07484699766639447, -1.0340348365432184`}, {-0.01499999999999921, 
    0.22900767548555706`, -1.6118368444858255`}}], 
   Line3DBox[{{-0.01500000000000034, -0.2675530023336055, \
-1.0579920797397147`}, {-0.015000000000000789`, -0.11339232451444292`, \
-1.6361348627940957`}}], 
   Line3DBox[{{0.01500000000000034, 
    0.07484699766639441, -1.0340348365432184`}, {0.015000000000000789`, 
    0.22900767548555692`, -1.6118368444858255`}}], 
   Line3DBox[{{
    0.01499999999999966, -0.26755300233360557`, -1.0579920797397147`}, {
    0.01499999999999921, -0.11339232451444306`, -1.6361348627940957`}}], 
   Line3DBox[{{-0.01499999999999921, 
    0.22900767548555706`, -1.6118368444858255`}, {-0.014999999999999203`, 
    0.23173774877729672`, -1.6267148296298442`}}], 
   Line3DBox[{{-0.015000000000000789`, -0.11339232451444292`, \
-1.6361348627940957`}, {-0.015000000000000794`, -0.10980031589707909`, \
-1.6509946644415119`}}], 
   Line3DBox[{{0.015000000000000789`, 
    0.22900767548555692`, -1.6118368444858255`}, {0.015000000000000796`, 
    0.23173774877729658`, -1.6267148296298442`}}], 
   Line3DBox[{{
    0.01499999999999921, -0.11339232451444306`, -1.6361348627940957`}, {
    0.014999999999999205`, -0.10980031589707923`, -1.6509946644415119`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    6.604966043681376*^-19, 0.25, -0.019301721406230272`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-6.604966043681376*^-19, -0.25, 0.019301562040264744`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9997577380390651, 0.022010570892461844`}, {
        0., -0.022010570892461844`, 0.9997577380390651}}, {0., 0., 0.}}], {{{
       1., 0., -9.744130652328235*^-32}, {0., 1., 0.}, {
       9.744130652328235*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.015725691179327*^-16, 0.}, {-5.015725691179327*^-16, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-7.504575643769361*^-34, -0.0457205581788206, \
-0.4160000792795181}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9997577380390651, 0.022010570892461844`}, {
        0., -0.022010570892461844`, 0.9997577380390651}}, {0., 0., 0.}}], {{{
       1., 0., -9.744130652328235*^-32}, {0., 1., 0.}, {
       9.744130652328235*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.015725691179327*^-16, 0.}, {-5.015725691179327*^-16, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {1.0118249823146033`*^-16, 
    0.15406285439038145`, -0.42803917419368065`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9997577380390651, 0.022010570892461844`}, {
        0., -0.022010570892461844`, 0.9997577380390651}}, {0., 0., 0.}}], {{{
       1., 0., -9.744130652328235*^-32}, {0., 1., 0.}, {
       9.744130652328235*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.015725691179327*^-16, 0.}, {-5.015725691179327*^-16, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-1.0125375973988255`*^-16, -0.24564604691567976`, \
-0.4104143266571182}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9957907661132187, -0.09165560606776302}, {0., 0.09165560606776302, 
        0.9957907661132187}}, {0., 0., 0.}}], {{{1., 
       0., -6.487773108529433*^-32}, {0., 1., 0.}, {6.487773108529433*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.3925166164969651`*^-15, 
      0.}, {-1.3925166164969651`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.0722425595161864`*^-33, -0.07425840172898246, \
-0.6929997458713231}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9957907661132187, -0.09165560606776302}, {0., 
        0.09165560606776302, 0.9957907661132187}}, {0., 0., 0.}}], {{{1., 
       0., -6.487773108529433*^-32}, {0., 1., 0.}, {6.487773108529433*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.3925166164969651`*^-15, 
      0.}, {-1.3925166164969651`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {1.95643190029986*^-16, 
    0.06522489257249225, -0.6809565817388107}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9957907661132187, -0.09165560606776302}, {0., 
        0.09165560606776302, 0.9957907661132187}}, {0., 0., 0.}}], {{{1., 
       0., -6.487773108529433*^-32}, {0., 1., 0.}, {6.487773108529433*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.3925166164969651`*^-15, 
      0.}, {-1.3925166164969651`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.9486145976838172`*^-16, -0.21318031654503974`, \
-0.7111420078315316}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.997553648405127, -0.06990506815403576}, {0., 0.06990506815403576, 
        0.997553648405127}}, {0., 0., 0.}}], {{{1., 
       0., -3.225177029048825*^-33}, {0., 1., 0.}, {3.225177029048825*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.937845586368887*^-15, 
      0.}, {-1.937845586368887*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.2927452915220832`*^-33, -0.09930980946633959, \
-1.0339996579057997`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9974826655209574, -0.07091073251071212}, {0., 0.07091073251071212, 
        0.9974826655209574}}, {0., 0., 0.}}], {{{1., 0., 
       3.5265302353393795`*^-32}, {0., 1., 0.}, {-3.5265302353393795`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 4.656164163178335*^-15, 
      0.}, {-4.656164163178335*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    8.167302428577272*^-34, 0.06076574875810521, -1.6359996539166086`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-3, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872749013568*^9, 3.483295056773488*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#9", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-9]]", "Input"],

Cell[BoxData["1.233936871103572`"], "Output",
 CellChangeTimes->{3.404735872316998*^9, 3.4115114187632027`*^9, 
  3.411564225836266*^9, 3.411565279403284*^9, 3.411568982464014*^9, 
  3.415473816155715*^9, 3.415505891110361*^9, 3.415556383130007*^9, 
  3.4156408264794407`*^9, 3.459802014341497*^9, 3.4598727490369053`*^9, 
  3.483295056833156*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "9"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0.0025751194808265932`", "0", "0", "0", 
     "0.7751883690279271`", "0"},
    {"\<\"Mass U\"\>", "0.002977752983620491`", "0", "0", "0", 
     "0.5621545936506342`", "0"},
    {"\<\"Mass 2\"\>", "0.0016862570414215205`", "0", "0", "0", 
     "0.17727367058504004`", "0"},
    {"\<\"optic\"\>", 
     RowBox[{"-", "0.000654283337257228`"}], "0", "0", "0", 
     RowBox[{"-", "0.22720141125431506`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735872338664*^9, 3.4115114187800217`*^9, 
  3.4115642258632193`*^9, 3.411565279720922*^9, 3.411568982516122*^9, 
  3.415473816330142*^9, 3.4155058911462383`*^9, 3.4155563831983747`*^9, 
  3.415640826503675*^9, 3.459802014357987*^9, 3.459872749060321*^9, 
  3.48329505688199*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 9\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "9"}], "]"}], "]"}], ",", " ", 
     RowBox[{"-", "0.2"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"0", ",", " ", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "0.25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112777704697`*^9, 3.390980036780466*^9, {3.3909806819103003`*^9, 
   3.390980686018442*^9}, {3.4832991075767717`*^9, 3.483299118009059*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-9.637787175380925*^-6, 
    0.25, -7.968298282823696*^-8}, {-0.0000411944520062917, 
    0.09, -0.41903177413236536`}}], 
   Line3DBox[{{-9.637787175380925*^-6, -0.25, -7.968298282816337*^-8}, \
{-0.0000411944520062917, -0.09, -0.41903177413236536`}}], 
   Line3DBox[{{-0.003739273936041924, 
    0.2, -0.4197706375229753}, {-0.003387609219392897, 
    0.06, -0.6950102740332799}}], 
   Line3DBox[{{-0.003739273936041924, -0.2, -0.4197706375229753}, \
{-0.003387609219392897, -0.06, -0.6950102740332799}}], 
   Line3DBox[{{0.0021887603478815414`, 0.2, -0.41884413359495987`}, {
    0.002574508576216216, 0.06, -0.694337108829722}}], 
   Line3DBox[{{0.002188760347881541, -0.2, -0.41884413359495987`}, {
    0.002574508576216216, -0.06, -0.694337108829722}}], 
   Line3DBox[{{-0.0037781654771386355`, 
    0.14, -0.6964409831838708}, {-0.0035909519247946877`, 
    0.1762, -1.0269002266076905`}}], 
   Line3DBox[{{-0.0037781654771386355`, -0.14, -0.6964409831838708}, \
{-0.0035909519247946877`, -0.1762, -1.0269002266076905`}}], 
   Line3DBox[{{0.002183952318470477, 0.14, -0.695767817980313}, {
    0.002405277355711078, 0.1762, -1.0266875427681417`}}], 
   Line3DBox[{{0.002183952318470477, -0.14, -0.695767817980313}, {
    0.002405277355711078, -0.1762, -1.0266875427681417`}}], 
   Line3DBox[{{-0.015429285381386874`, 
    0.1712, -1.0316708678437263`}, {-0.015284013600662352`, 
    0.1712, -1.046537508755902}}], 
   Line3DBox[{{-0.015429285381386874`, -0.1712, -1.0316708678437263`}, \
{-0.015284013600662352`, -0.1712, -1.046537508755902}}], 
   Line3DBox[{{0.014551861021141952`, 0.1712, -1.030607448645981}, {
    0.014715986399337647`, 0.1712, -1.0454894075270318`}}], 
   Line3DBox[{{0.014551861021141952`, -0.1712, -1.030607448645981}, {
    0.014715986399337647`, -0.1712, -1.0454894075270318`}}], 
   Line3DBox[{{-0.015284013600662352`, 
    0.1712, -1.046537508755902}, {-0.01482058819281395, 
    0.1712, -1.6233120198035182`}}], 
   Line3DBox[{{-0.015284013600662352`, -0.1712, -1.046537508755902}, \
{-0.01482058819281395, -0.1712, -1.6233120198035182`}}], 
   Line3DBox[{{0.014715986399337647`, 0.1712, -1.0454894075270318`}, {
    0.01517941180718605, 0.1712, -1.6246596874764037`}}], 
   Line3DBox[{{0.014715986399337647`, -0.1712, -1.0454894075270318`}, {
    0.01517941180718605, -0.1712, -1.6246596874764037`}}], 
   Line3DBox[{{-0.01482058819281395, 
    0.1712, -1.6233120198035182`}, {-0.014983678748518107`, 
    0.1712, -1.6381776281492153`}}], 
   Line3DBox[{{-0.01482058819281395, -0.1712, -1.6233120198035182`}, \
{-0.014983678748518107`, -0.1712, -1.6381776281492153`}}], 
   Line3DBox[{{0.01517941180718605, 0.1712, -1.6246596874764037`}, {
    0.014985354291697705`, 0.1712, -1.6395403675353244`}}], 
   Line3DBox[{{0.01517941180718605, -0.1712, -1.6246596874764037`}, {
    0.014985354291697705`, -0.1712, -1.6395403675353244`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-9.637787175380925*^-6, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-9.637787175380925*^-6, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        9.796337746647045*^-34}, {0., -9.796337746647045*^-34, 1.}}, {0., 0., 
        0.}}], {{{0.9880057139872441, 0., -0.1544173213359041}, {0., 1., 
       0.}, {0.1544173213359041, 0., 0.9880057139872441}}, {0., 0., 0.}}], {{{
      1., 5.48514226567792*^-19, 0.}, {-5.48514226567792*^-19, 1., 0.}, {0., 
      0., 1.}}, {0., 0., 
      0.}}], {-0.0005150238961653187, -9.218563860735369*^-35, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 9.796337746647045*^-34}, {0., -9.796337746647045*^-34, 
        1.}}, {0., 0., 0.}}], {{{0.9880057139872441, 
       0., -0.1544173213359041}, {0., 1., 0.}, {0.1544173213359041, 0., 
       0.9880057139872441}}, {0., 0., 0.}}], {{{1., 5.48514226567792*^-19, 
      0.}, {-5.48514226567792*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.000775256794080191, 0.2, -0.41930738555896757`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 9.796337746647045*^-34}, {0., -9.796337746647045*^-34, 
        1.}}, {0., 0., 0.}}], {{{0.9880057139872441, 
       0., -0.1544173213359041}, {0., 1., 0.}, {0.1544173213359041, 0., 
       0.9880057139872441}}, {0., 0., 0.}}], {{{1., 5.48514226567792*^-19, 
      0.}, {-5.48514226567792*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0007752567940801912, -0.2, -0.41930738555896757`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -4.922104075056916*^-33}, {0., 4.922104075056916*^-33, 1.}}, {0., 
        0., 0.}}], {{{0.9936862992681854, 0., -0.11219420059298199`}, {0., 1.,
        0.}, {0.11219420059298199`, 0., 0.9936862992681854}}, {0., 0., 
       0.}}], {{{1., -2.9292155314856354`*^-19, 0.}, {
      2.9292155314856354`*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0005955505967240982, -4.249268724655379*^-35, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.922104075056916*^-33}, {0., 4.922104075056916*^-33, 
        1.}}, {0., 0., 0.}}], {{{0.9936862992681854, 
       0., -0.11219420059298199`}, {0., 1., 0.}, {0.11219420059298199`, 0., 
       0.9936862992681854}}, {0., 0., 0.}}], {{{1., -2.9292155314856354`*^-19,
       0.}, {2.9292155314856354`*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0007971065793340794, 0.14, -0.6961044005820919}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.922104075056916*^-33}, {0., 4.922104075056916*^-33, 
        1.}}, {0., 0., 0.}}], {{{0.9936862992681854, 
       0., -0.11219420059298199`}, {0., 1., 0.}, {0.11219420059298199`, 0., 
       0.9936862992681854}}, {0., 0., 0.}}], {{{1., -2.9292155314856354`*^-19,
       0.}, {2.9292155314856354`*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0007971065793340793, -0.14, -0.6961044005820919}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600297191*^-19}, {
        0., -7.621041600297191*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.999371546750961, 0., -0.03544730659150109}, {0., 1., 0.}, {
       0.03544730659150109, 0., 0.999371546750961}}, {0., 0., 0.}}], {{{1., 
      5.828479686885968*^-20, 0.}, {-5.828479686885968*^-20, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {-0.00033725140828430415`, 
    6.261607564813197*^-35, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.2933614255095617`*^-31}, {0., 1.2933614255095617`*^-31, 1.}}, {
        0., 0., 0.}}], {{{0.9989677680071938, 0., 0.04542464620363685}, {0., 
       1., 0.}, {-0.04542464620363685, 0., 0.9989677680071938}}, {0., 0., 
       0.}}], {{{1., 1.6167592533571004`*^-20, 
      0.}, {-1.6167592533571004`*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {0.0001308566674514456, -9.210984943704172*^-38, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{
  3.459872749405278*^9, 3.483295057341873*^9, {3.4832991112033033`*^9, 
   3.483299119327549*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#10", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-10]]", "Input"],

Cell[BoxData["1.3456398908617206`"], "Output",
 CellChangeTimes->{3.404735872889802*^9, 3.411511419323038*^9, 
  3.411564226485491*^9, 3.4115652800717373`*^9, 3.411568983500371*^9, 
  3.415473819689023*^9, 3.415505892017899*^9, 3.4155563840015593`*^9, 
  3.415640827072793*^9, 3.4598020147522078`*^9, 3.4598727494284563`*^9, 
  3.4832950574671593`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "10"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0", "0.3091452430893065`", "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0", "0.5341466073939052`", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", "0", "0.37004841982637177`", "0", "0"},
    {"\<\"optic\"\>", "0", "0", "0", 
     RowBox[{"-", "0.6943923872486222`"}], "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735872916325*^9, 3.4115114193402157`*^9, 
  3.4115642265123253`*^9, 3.411565280269515*^9, 3.4115689835641947`*^9, 
  3.4154738198585043`*^9, 3.4155058920718517`*^9, 3.415556384052054*^9, 
  3.4156408270979567`*^9, 3.459802014768729*^9, 3.459872749452244*^9, 
  3.4832950575144873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 10\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "10"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911277836615*^9, 3.390980040222446*^9, {3.390980693294628*^9, 
   3.390980698666833*^9}, 3.4832991260882*^9}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{0.00008141967718694729, 0.25, -7.96829826763913*^-8}, {
    0.00556106962293394, 0.08982802738927792, -0.4190685785907339}}], 
   Line3DBox[{{-0.00008141967718694729, -0.25, -7.968298297997352*^-8}, \
{-0.00556106962293394, -0.08982802738927811, -0.4190685785907342}}], 
   Line3DBox[{{0.009412898234911482, 
    0.19980015969608514`, -0.41922753231450055`}, {0.003414676824760632, 
    0.05997782908860957, -0.6946843273749735}}], 
   Line3DBox[{{-0.015401433394196681`, -0.19942942172122308`, \
-0.41922753231450066`}, {-0.009380471861904912, -0.05933807165427601, \
-0.6946843273749733}}], 
   Line3DBox[{{0.015401433394196681`, 
    0.19942942172122288`, -0.41922753231450055`}, {0.009380471861904912, 
    0.05933807165427629, -0.6946843273749735}}], 
   Line3DBox[{{-0.009412898234911482, -0.19980015969608533`, \
-0.41922753231450066`}, {-0.003414676824760632, -0.05997782908860928, \
-0.6946843273749733}}], 
   Line3DBox[{{0.011860378374562873`, 
    0.13953081350902896`, -0.6960621853090287}, {0.010036817224376871`, 
    0.17593948476679255`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.01782617341170715, -0.13889105607469537`, \
-0.696062185309029}, {-0.01602039242361457, -0.17549583193510154`, \
-1.0267893533485906`}}], 
   Line3DBox[{{0.01782617341170715, 
    0.13889105607469568`, -0.6960621853090287}, {0.01602039242361457, 
    0.17549583193510143`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.011860378374562873`, -0.13953081350902866`, \
-0.696062185309029}, {-0.010036817224376871`, -0.17593948476679266`, \
-1.0267893533485906`}}], 
   Line3DBox[{{-0.0023000438671744537`, 
    0.17184047776414338`, -1.0311373594240731`}, {-0.002983436446312396, 
    0.17225285311510108`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.027617832129014037`, -0.16962221360568788`, \
-1.0311373594240731`}, {-0.027016563553687603`, -0.1701471468848989, \
-1.0460134581414668`}}], 
   Line3DBox[{{0.027617832129014037`, 
    0.1696222136056878, -1.0311373594240731`}, {0.027016563553687603`, 
    0.17014714688489882`, -1.0460134581414668`}}], 
   Line3DBox[{{
    0.0023000438671744537`, -0.17184047776414346`, -1.0311373594240731`}, {
    0.002983436446312396, -0.17225285311510116`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.002983436446312396, 
    0.17225285311510108`, -1.0460134581414668`}, {-0.03812210152498215, 
    0.16917411493647935`, -1.623985853639961}}], 
   Line3DBox[{{-0.027016563553687603`, -0.1701471468848989, \
-1.0460134581414668`}, {
    0.008122101524982144, -0.17322588506352063`, -1.6239858536399612`}}], 
   Line3DBox[{{0.027016563553687603`, 
    0.17014714688489882`, -1.0460134581414668`}, {-0.008122101524982144, 
    0.17322588506352063`, -1.623985853639961}}], 
   Line3DBox[{{
    0.002983436446312396, -0.17225285311510116`, -1.0460134581414668`}, {
    0.03812210152498215, -0.16917411493647935`, -1.6239858536399612`}}], 
   Line3DBox[{{-0.03812210152498215, 
    0.16917411493647935`, -1.623985853639961}, {-0.03855521826888241, 
    0.16747517769579714`, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.008122101524982144, -0.17322588506352063`, -1.6239858536399612`}, {
    0.008844062043587087, -0.17162815202224016`, -1.6388619523983357`}}], 
   Line3DBox[{{-0.008122101524982144, 
    0.17322588506352063`, -1.623985853639961}, {-0.008844062043587087, 
    0.17162815202224016`, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.03812210152498215, -0.16917411493647935`, -1.6239858536399612`}, {
    0.03855521826888241, -0.16747517769579714`, -1.6388619523983357`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.00008141967718694729, 0.25, -7.96829826763913*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.00008141967718694729, -0.25, -7.968298297997352*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -2.0961415660156268`*^-15}, {0., 2.0961415660156268`*^-15, 1.}}, {
        0., 0., 0.}}], {{{1., 0., -9.084979557220661*^-21}, {0., 1., 0.}, {
       9.084979557220661*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9980891932142002, 0.06178966247704378, 0.}, {-0.06178966247704378, 
      0.9980891932142002, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-9.101143970680946*^-24, -1.0148650791172335`*^-16, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.0961415660156268`*^-15}, {0., 
        2.0961415660156268`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 
       0., -9.084979557220661*^-21}, {0., 1., 0.}, {9.084979557220661*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9980891932142002, 0.06178966247704378, 
      0.}, {-0.06178966247704378, 0.9980891932142002, 0.}, {0., 0., 1.}}, {0.,
       0., 0.}}], {0.012407165814554082`, 
    0.199614790708654, -0.41922753231450055`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.0961415660156268`*^-15}, {0., 
        2.0961415660156268`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 
       0., -9.084979557220661*^-21}, {0., 1., 0.}, {9.084979557220661*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9980891932142002, 0.06178966247704378, 
      0.}, {-0.06178966247704378, 0.9980891932142002, 0.}, {0., 0., 1.}}, {0.,
       0., 0.}}], {-0.012407165814554082`, -0.1996147907086542, \
-0.41922753231450066`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.72607743701295*^-15}, {0., -1.72607743701295*^-15, 1.}}, {0., 0., 
        0.}}], {{{1., 0., -5.602446787822218*^-21}, {0., 1., 0.}, {
       5.602446787822218*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9942991728573798, 0.10662623905554619`, 0.}, {-0.10662623905554619`, 
      0.9942991728573798, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-5.0338309321949575`*^-24, 
    1.4419919314203472`*^-16, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.72607743701295*^-15}, {0., -1.72607743701295*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., -5.602446787822218*^-21}, {0., 1., 
       0.}, {5.602446787822218*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9942991728573798, 0.10662623905554619`, 0.}, {-0.10662623905554619`, 
      0.9942991728573798, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.014843275893135013`, 0.1392109347918623, -0.6960621853090287}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.72607743701295*^-15}, {0., -1.72607743701295*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., -5.602446787822218*^-21}, {0., 1., 
       0.}, {5.602446787822218*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9942991728573798, 0.10662623905554619`, 0.}, {-0.10662623905554619`, 
      0.9942991728573798, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.014843275893135013`, -0.13921093479186203`, \
-0.696062185309029}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -5.580343127820212*^-16}, {0., 5.580343127820212*^-16, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 2.9466589855030255`*^-22}, {0., 1., 
       0.}, {-2.9466589855030255`*^-22, 0., 1.}}, {0., 0., 0.}}], {{{
      0.997262533206283, 0.0739421386151857, 0.}, {-0.0739421386151857, 
      0.997262533206283, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.5287822887904576`*^-23, -4.658151610961909*^-17, \
-1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -6.479198479058947*^-16}, {0., 6.479198479058947*^-16, 1.}}, {0., 
        0., 0.}}], {{{1., 0., -2.6099828109190595`*^-22}, {0., 1., 0.}, {
       2.6099828109190595`*^-22, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9903718741765108, -0.13843247754810017`, 0.}, {0.13843247754810017`, 
      0.9903718741765108, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    4.551131676504309*^-24, 2.37609186824329*^-18, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.459872749815744*^9, 3.483295057993444*^9, 
  3.483299127262167*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#11", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-11]]", "Input"],

Cell[BoxData["1.5686566191057036`"], "Output",
 CellChangeTimes->{3.4047358734224653`*^9, 3.411511419854344*^9, 
  3.4115642270427027`*^9, 3.411565280708577*^9, 3.4115689845282373`*^9, 
  3.41547382207069*^9, 3.415505892860509*^9, 3.4155563849335003`*^9, 
  3.415640827648295*^9, 3.459802015143217*^9, 3.459872749871537*^9, 
  3.483295058052679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "11"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", 
     RowBox[{"-", "0.003761061203889694`"}], "0", "0", "0", 
     "0.8135836479728089`", "0"},
    {"\<\"Mass U\"\>", 
     RowBox[{"-", "0.004989444572693055`"}], "0", "0", "0", 
     "0.302890287155307`", "0"},
    {"\<\"Mass 2\"\>", "0.003258160325551175`", "0", "0", "0", 
     RowBox[{"-", "0.4392016504063449`"}], "0"},
    {"\<\"optic\"\>", 
     RowBox[{"-", "0.0007130823753418617`"}], "0", "0", "0", 
     "0.23106463975448646`", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735873445698*^9, 3.411511419870069*^9, 
  3.411564227068288*^9, 3.411565280906892*^9, 3.4115689846215067`*^9, 
  3.415473822248372*^9, 3.415505892913781*^9, 3.415556385017207*^9, 
  3.415640827669518*^9, 3.459802015160907*^9, 3.4598727498983917`*^9, 
  3.483295058102512*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 11\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "11"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112779038877`*^9, 3.390980044182578*^9, {3.390980702299431*^9, 
   3.390980710067102*^9}, 3.48329913214573*^9}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{8.478968427974763*^-6, 0.25, -7.968298282823696*^-8}, {
    0.0012493080397524485`, 0.09, -0.41902804621949197`}}], 
   Line3DBox[{{8.478968427974763*^-6, -0.25, -7.968298282816337*^-8}, {
    0.0012493080397524485`, -0.09, -0.41902804621949197`}}], 
   Line3DBox[{{-0.0024736839814381625`, 
    0.2, -0.41980032449451915`}, {-0.0018946219451921513`, 
    0.06, -0.6948628604058541}}], 
   Line3DBox[{{-0.0024736839814381625`, -0.2, -0.41980032449451915`}, \
{-0.0018946219451921513`, -0.06, -0.6948628604058541}}], 
   Line3DBox[{{0.003447060916055008, 0.2, -0.41882832662476394`}, {
    0.004094372317946125, 0.06, -0.6944996143238423}}], 
   Line3DBox[{{0.003447060916055008, -0.2, -0.41882832662476394`}, {
    0.004094372317946125, -0.06, -0.6944996143238423}}], 
   Line3DBox[{{-0.0021168103648813085`, 
    0.14, -0.6962567266061664}, {-0.0030075242604364273`, 
    0.1762, -1.02655397031017}}], 
   Line3DBox[{{-0.0021168103648813085`, -0.14, -0.6962567266061664}, \
{-0.0030075242604364273`, -0.1762, -1.02655397031017}}], 
   Line3DBox[{{0.0038721838982569675`, 0.14, -0.6958934805241547}, {
    0.0029693428488388545`, 0.1762, -1.0270803347828157`}}], 
   Line3DBox[{{0.0038721838982569675`, -0.14, -0.6958934805241547}, {
    0.0029693428488388545`, -0.1762, -1.0270803347828157`}}], 
   Line3DBox[{{-0.015342697799817106`, 
    0.1712, -1.029832483782126}, {-0.015746975056171886`, 
    0.1712, -1.0447087297199}}], 
   Line3DBox[{{-0.015342697799817106`, -0.1712, -1.029832483782126}, \
{-0.015746975056171886`, -0.1712, -1.0447087297199}}], 
   Line3DBox[{{0.014541637746559305`, 0.1712, -1.0324643061453533`}, {
    0.01425302494382811, 0.1712, -1.0473181865630337`}}], 
   Line3DBox[{{0.014541637746559305`, -0.1712, -1.0324643061453533`}, {
    0.01425302494382811, -0.1712, -1.0473181865630337`}}], 
   Line3DBox[{{-0.015746975056171886`, 
    0.1712, -1.0447087297199}, {-0.014930724344657652`, 
    0.1712, -1.6246661710295722`}}], 
   Line3DBox[{{-0.015746975056171886`, -0.1712, -1.0447087297199}, \
{-0.014930724344657652`, -0.1712, -1.6246661710295722`}}], 
   Line3DBox[{{0.01425302494382811, 0.1712, -1.0473181865630337`}, {
    0.015069275655342346`, 0.1712, -1.6233055362503497`}}], 
   Line3DBox[{{0.01425302494382811, -0.1712, -1.0473181865630337`}, {
    0.015069275655342346`, -0.1712, -1.6233055362503497`}}], 
   Line3DBox[{{-0.014930724344657652`, 
    0.1712, -1.6246661710295722`}, {-0.01470914099836852, 
    0.1712, -1.639551843741028}}], 
   Line3DBox[{{-0.014930724344657652`, -0.1712, -1.6246661710295722`}, \
{-0.01470914099836852, -0.1712, -1.639551843741028}}], 
   Line3DBox[{{0.015069275655342346`, 0.1712, -1.6233055362503497`}, {
    0.015258830181748234`, 0.1712, -1.6381659493194751`}}], 
   Line3DBox[{{0.015069275655342346`, -0.1712, -1.6233055362503497`}, {
    0.015258830181748234`, -0.1712, -1.6381659493194751`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    8.478968427974763*^-6, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    8.478968427974763*^-6, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        2.8146210940933857`*^-34}, {0., -2.8146210940933857`*^-34, 1.}}, {0., 
        0., 0.}}], {{{0.9867908162488618, 0., -0.16199964495919447`}, {0., 1.,
        0.}, {0.16199964495919447`, 0., 0.9867908162488618}}, {0., 0., 
       0.}}], {{{1., 1.8270662317892947`*^-19, 
      0.}, {-1.8270662317892947`*^-19, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {0.0007522122407779389, -2.679235755578906*^-35, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.8146210940933857`*^-34}, {
        0., -2.8146210940933857`*^-34, 1.}}, {0., 0., 0.}}], {{{
       0.9867908162488618, 0., -0.16199964495919447`}, {0., 1., 0.}, {
       0.16199964495919447`, 0., 0.9867908162488618}}, {0., 0., 0.}}], {{{1., 
      1.8270662317892947`*^-19, 0.}, {-1.8270662317892947`*^-19, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {0.00048668846730842296`, 
    0.2, -0.41931432555964154`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.8146210940933857`*^-34}, {
        0., -2.8146210940933857`*^-34, 1.}}, {0., 0., 0.}}], {{{
       0.9867908162488618, 0., -0.16199964495919447`}, {0., 1., 0.}, {
       0.16199964495919447`, 0., 0.9867908162488618}}, {0., 0., 0.}}], {{{1., 
      1.8270662317892947`*^-19, 0.}, {-1.8270662317892947`*^-19, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    0.00048668846730842296`, -0.2, -0.41931432555964154`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.3773328877827715`*^-33}, {0., 1.3773328877827715`*^-33, 1.}}, {
        0., 0., 0.}}], {{{0.9981657105230459, 0., -0.06054101366861066}, {0., 
       1., 0.}, {0.06054101366861066, 0., 0.9981657105230459}}, {0., 0., 
       0.}}], {{{1., -9.277433261285645*^-20, 0.}, {9.277433261285645*^-20, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.000997888914538611, -1.0896377131158361`*^-35, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.3773328877827715`*^-33}, {0., 
        1.3773328877827715`*^-33, 1.}}, {0., 0., 0.}}], {{{0.9981657105230459,
        0., -0.06054101366861066}, {0., 1., 0.}, {0.06054101366861066, 0., 
       0.9981657105230459}}, {0., 0., 0.}}], {{{1., -9.277433261285645*^-20, 
      0.}, {9.277433261285645*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0008776867666878291, 0.14, -0.6960751035651606}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.3773328877827715`*^-33}, {0., 
        1.3773328877827715`*^-33, 1.}}, {0., 0., 0.}}], {{{0.9981657105230459,
        0., -0.06054101366861066}, {0., 1., 0.}, {0.06054101366861066, 0., 
       0.9981657105230459}}, {0., 0., 0.}}], {{{1., -9.277433261285645*^-20, 
      0.}, {9.277433261285645*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0008776867666878291, -0.14, -0.6960751035651606}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600296217*^-19}, {
        0., -7.621041600296217*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.996144518212547, 0., 0.08772741210757629}, {0., 1., 
       0.}, {-0.08772741210757629, 0., 0.996144518212547}}, {0., 0., 
       0.}}], {{{1., 8.914437502963874*^-21, 0.}, {-8.914437502963874*^-21, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {-0.000651632065110235, 
    1.751437575406028*^-35, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., -3.61794219764352*^-32}, {
        0., 3.61794219764352*^-32, 1.}}, {0., 0., 0.}}], {{{
       0.9989323726705586, 0., -0.046196480718430695`}, {0., 1., 0.}, {
       0.046196480718430695`, 0., 0.9989323726705586}}, {0., 0., 0.}}], {{{1.,
       7.936097675612025*^-21, 0.}, {-7.936097675612025*^-21, 1., 0.}, {0., 
      0., 1.}}, {0., 0., 0.}}], {
    0.00014261647506837234`, -2.9737832838004306`*^-38, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.459872750240069*^9, 3.483295058561552*^9, 
  3.483299133312644*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#12", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-12]]", "Input"],

Cell[BoxData["2.007268469974114`"], "Output",
 CellChangeTimes->{3.4047358739947567`*^9, 3.4115114204123383`*^9, 
  3.4115642276335163`*^9, 3.4115652812911873`*^9, 3.4115689856731243`*^9, 
  3.415473823334188*^9, 3.415505893820676*^9, 3.415556385934019*^9, 
  3.415640828221084*^9, 3.4598020155286922`*^9, 3.459872750263164*^9, 
  3.483295058688302*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "12"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0.5357131674623197`", "0", "0", "0", 
     "0.2927299353104222`", "0"},
    {"\<\"Mass U\"\>", "0.4395600455681977`", "0", "0", "0", 
     "0.09741491908128891`", "0"},
    {"\<\"Mass 2\"\>", 
     RowBox[{"-", "0.32496689943946094`"}], "0", "0", "0", 
     RowBox[{"-", "0.5433345585416326`"}], "0"},
    {"\<\"optic\"\>", "0.037208826436860507`", "0", "0", "0", 
     "0.14972462075216175`", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.40473587402451*^9, 3.411511420427495*^9, 
  3.4115642276594763`*^9, 3.411565281491942*^9, 3.411568985696784*^9, 
  3.415473823475425*^9, 3.415505893853545*^9, 3.415556385973493*^9, 
  3.415640828242687*^9, 3.459802015546563*^9, 3.459872750289341*^9, 
  3.483295058736403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 12\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "12"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112779880457`*^9, 3.390980047322597*^9, {3.390980719391368*^9, 
   3.39098072427566*^9}, {3.4832991412403*^9, 3.483299143056827*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.0015419210484869297`, 
    0.25, -7.968298282823696*^-8}, {-0.10696308778197597`, 
    0.09, -0.4190633212485402}}], 
   Line3DBox[{{-0.0015419210484869297`, -0.25, -7.968298282816337*^-8}, \
{-0.10696308778197597`, -0.09, -0.4190633212485402}}], 
   Line3DBox[{{-0.10989421375023108`, 
    0.2, -0.41939434977865553`}, {-0.09087862115383198, 
    0.06, -0.6947424529165336}}], 
   Line3DBox[{{-0.10989421375023108`, -0.2, -0.41939434977865553`}, \
{-0.09087862115383198, -0.06, -0.6947424529165336}}], 
   Line3DBox[{{-0.10390449371120354`, 
    0.2, -0.41904327449602785`}, {-0.08487975987778608, 
    0.06, -0.6946255624089763}}], 
   Line3DBox[{{-0.10390449371120354`, -0.2, -0.41904327449602785`}, \
{-0.08487975987778608, -0.06, -0.6946255624089763}}], 
   Line3DBox[{{-0.08868275975724565, 0.14, -0.6960777850541756}, {
    0.06279305561477151, 0.1762, -1.0265065233880677`}}], 
   Line3DBox[{{-0.08868275975724565, -0.14, -0.6960777850541756}, {
    0.06279305561477151, -0.1762, -1.0265065233880677`}}], 
   Line3DBox[{{-0.08268389848119975, 0.14, -0.6959608945466184}, {
    0.06875766496810669, 0.1762, -1.0271572424227566`}}], 
   Line3DBox[{{-0.08268389848119975, -0.14, -0.6959608945466184}, {
    0.06875766496810669, -0.1762, -1.0271572424227566`}}], 
   Line3DBox[{{0.050392281855391144`, 0.1712, -1.0295274449363867`}, {
    0.048558841848113196`, 0.1712, -1.044396768871182}}], 
   Line3DBox[{{0.050392281855391144`, -0.1712, -1.0295274449363867`}, {
    0.048558841848113196`, -0.1712, -1.044396768871182}}], 
   Line3DBox[{{0.08021532862206697, 0.1712, -1.0327810401098318`}, {
    0.0785588418481132, 0.1712, -1.0476301474117518`}}], 
   Line3DBox[{{0.08021532862206697, -0.1712, -1.0327810401098318`}, {
    0.0785588418481132, -0.1712, -1.0476301474117518`}}], 
   Line3DBox[{{0.048558841848113196`, 
    0.1712, -1.044396768871182}, {-0.021181648371593597`, 
    0.1712, -1.6244217130968774`}}], 
   Line3DBox[{{
    0.048558841848113196`, -0.1712, -1.044396768871182}, \
{-0.021181648371593597`, -0.1712, -1.6244217130968774`}}], 
   Line3DBox[{{0.0785588418481132, 0.1712, -1.0476301474117518`}, {
    0.008818351628406402, 0.1712, -1.6235499941830445`}}], 
   Line3DBox[{{0.0785588418481132, -0.1712, -1.0476301474117518`}, {
    0.008818351628406402, -0.1712, -1.6235499941830445`}}], 
   Line3DBox[{{-0.021181648371593597`, 
    0.1712, -1.6244217130968774`}, {-0.022349342049310102`, 
    0.1712, -1.6393097759212216`}}], 
   Line3DBox[{{-0.021181648371593597`, -0.1712, -1.6244217130968774`}, \
{-0.022349342049310102`, -0.1712, -1.6393097759212216`}}], 
   Line3DBox[{{0.008818351628406402, 0.1712, -1.6235499941830445`}, {
    0.007637208478509439, 0.1712, -1.6384115624485294`}}], 
   Line3DBox[{{0.008818351628406402, -0.1712, -1.6235499941830445`}, {
    0.007637208478509439, -0.1712, -1.6384115624485294`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.0015419210484869297`, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.0015419210484869297`, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.982419776586529*^-35}, {0., -1.982419776586529*^-35, 1.}}, {0., 0., 
        0.}}], {{{0.9982866731712545, 0., -0.05851254710460736}, {0., 1., 
       0.}, {0.05851254710460736, 0., 0.9982866731712545}}, {0., 0., 
       0.}}], {{{1., 1.7294303591323728`*^-20, 
      0.}, {-1.7294303591323728`*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.10714263349246395`, -1.9269232785780122`*^-36, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.982419776586529*^-35}, {0., -1.982419776586529*^-35, 
        1.}}, {0., 0., 0.}}], {{{0.9982866731712545, 
       0., -0.05851254710460736}, {0., 1., 0.}, {0.05851254710460736, 0., 
       0.9982866731712545}}, {0., 0., 0.}}], {{{1., 1.7294303591323728`*^-20, 
      0.}, {-1.7294303591323728`*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.10689935373071731`, 0.2, -0.4192188121373417}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.982419776586529*^-35}, {0., -1.982419776586529*^-35, 
        1.}}, {0., 0., 0.}}], {{{0.9982866731712545, 
       0., -0.05851254710460736}, {0., 1., 0.}, {0.05851254710460736, 0., 
       0.9982866731712545}}, {0., 0., 0.}}], {{{1., 1.7294303591323728`*^-20, 
      0.}, {-1.7294303591323728`*^-20, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.10689935373071731`, -0.2, -0.4192188121373417}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -9.267314299942922*^-35}, {0., 9.267314299942922*^-35, 1.}}, {0., 
        0., 0.}}], {{{0.9998102126743164, 0., -0.019481751259530757`}, {0., 
       1., 0.}, {0.019481751259530757`, 0., 0.9998102126743164}}, {0., 0., 
       0.}}], {{{1., -9.194503079973109*^-21, 0.}, {9.194503079973109*^-21, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.08791200911363956, -5.962458984515492*^-37, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -9.267314299942922*^-35}, {0., 9.267314299942922*^-35, 
        1.}}, {0., 0., 0.}}], {{{0.9998102126743164, 
       0., -0.019481751259530757`}, {0., 1., 0.}, {0.019481751259530757`, 0., 
       0.9998102126743164}}, {0., 0., 0.}}], {{{1., -9.194503079973109*^-21, 
      0.}, {9.194503079973109*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0856833291192227, 0.14, -0.696019339800397}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -9.267314299942922*^-35}, {0., 9.267314299942922*^-35, 
        1.}}, {0., 0., 0.}}], {{{0.9998102126743164, 
       0., -0.019481751259530757`}, {0., 1., 0.}, {0.019481751259530757`, 0., 
       0.9998102126743164}}, {0., 0., 0.}}], {{{1., -9.194503079973109*^-21, 
      0.}, {9.194503079973109*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0856833291192227, -0.14, -0.696019339800397}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600295864*^-19}, {
        0., -7.621041600295864*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9941015588891944, 0., 0.10845317244817511`}, {0., 1., 
       0.}, {-0.10845317244817511`, 0., 0.9941015588891944}}, {0., 0., 
       0.}}], {{{1., -1.1460441022994773`*^-21, 0.}, {
      1.1460441022994773`*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0649933798878922, 1.1732607212838088`*^-36, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -2.433589570201162*^-33}, {0., 2.433589570201162*^-33, 1.}}, {0., 
        0., 0.}}], {{{0.9995516842606514, 0., -0.029940449089735983`}, {0., 
       1., 0.}, {0.029940449089735983`, 0., 0.9995516842606514}}, {0., 0., 
       0.}}], {{{1., 9.591861516181805*^-22, 0.}, {-9.591861516181805*^-22, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.007441765287372101, -1.4636135858321952`*^-39, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.4598727506285*^9, 3.483295059214246*^9, 
  3.483299144191493*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#13", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-13]]", "Input"],

Cell[BoxData["2.124001763723306`"], "Output",
 CellChangeTimes->{3.4047358745264463`*^9, 3.411511420950346*^9, 
  3.411564228267112*^9, 3.411565281941524*^9, 3.411568986557522*^9, 
  3.415473824290551*^9, 3.415505894781646*^9, 3.4155563867916403`*^9, 
  3.415640828746086*^9, 3.459802015945355*^9, 3.4598727506519403`*^9, 
  3.483295059272173*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "13"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", 
     RowBox[{"-", "0.4519502303639887`"}], "0", "0", "0", 
     "0.06391731740757059`"},
    {"\<\"Mass U\"\>", "0", 
     RowBox[{"-", "0.41797179778853566`"}], "0", "0", "0", 
     RowBox[{"-", "0.7414015545553408`"}]},
    {"\<\"Mass 2\"\>", "0", "0.25741746876380733`", "0", "0", "0", 
     "0.012666065395241483`"},
    {"\<\"optic\"\>", "0", 
     RowBox[{"-", "0.026047862892623598`"}], "0", "0", "0", 
     "0.013274161633261929`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358745524673`*^9, 3.411511420966034*^9, 
  3.411564228292491*^9, 3.411565282108033*^9, 3.411568986584435*^9, 
  3.415473824456482*^9, 3.4155058948310213`*^9, 3.415556386838661*^9, 
  3.4156408287671824`*^9, 3.4598020159638042`*^9, 3.459872750675447*^9, 
  3.483295059321629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 13\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "13"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112780542793`*^9, 3.390980050579473*^9, {3.390980731079631*^9, 
   3.390980737148151*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{7.406212039610107*^-18, 0.25, 0.03304971932447347}, {
    5.059143705804602*^-16, 0.18034346743017515`, -0.420218808249842}}], 
   Line3DBox[{{-7.406212039610107*^-18, -0.25, -0.0330498786904391}, \
{-5.063555874021523*^-16, 0.0003581747543605074, -0.4179178474936914}}], 
   Line3DBox[{{-0.002999999999998877, 
    0.29043624724015377`, -0.41366450455183296`}, {-0.002999999999999764, 
    0.1431848316465001, -0.6858015897826273}}], 
   Line3DBox[{{-0.0030000000000011237`, -0.10973866890317839`, \
-0.42479003266385623`}, {-0.0030000000000002343`, 
    0.024501639301601166`, -0.7035300938036586}}], 
   Line3DBox[{{0.0030000000000011233`, 
    0.2904362472401537, -0.41366450455183296`}, {0.003000000000000236, 
    0.1431848316465001, -0.6858015897826273}}], 
   Line3DBox[{{
    0.0029999999999988764`, -0.10973866890317842`, -0.42479003266385623`}, {
    0.002999999999999766, 0.02450163930160114, -0.7035300938036586}}], 
   Line3DBox[{{-0.0029999999999994614`, 
    0.22345483455823034`, -0.6816670161708568}, {-0.0030000000000003496`, 
    0.12473420611326871`, -1.02723572815059}}], 
   Line3DBox[{{-0.0030000000000005352`, -0.055361240944723875`, \
-0.7103901437189534}, {-0.0029999999999996505`, -0.22766466318224557`, \
-1.0263430248163055`}}], 
   Line3DBox[{{0.0030000000000005387`, 
    0.22345483455823034`, -0.6816670161708568}, {0.0029999999999996505`, 
    0.12473420611326874`, -1.02723572815059}}], 
   Line3DBox[{{
    0.002999999999999465, -0.0553612409447239, -0.7103901437189534}, {
    0.0030000000000003496`, -0.22766466318224554`, -1.0263430248163055`}}], 
   Line3DBox[{{-0.01500000000000034, 
    0.11972320774210342`, -1.0315710542232879`}, {-0.015000000000000317`, 
    0.12073057930360392`, -1.0464472775531766`}}], 
   Line3DBox[{{-0.01499999999999966, -0.22267569363923617`, \
-1.0307036829927003`}, {-0.014999999999999682`, -0.22166942069639606`, \
-1.045579638729757}}], 
   Line3DBox[{{0.01499999999999966, 
    0.11972320774210347`, -1.0315710542232879`}, {0.014999999999999682`, 
    0.12073057930360398`, -1.0464472775531766`}}], 
   Line3DBox[{{
    0.01500000000000034, -0.22267569363923612`, -1.0307036829927003`}, {
    0.015000000000000317`, -0.221669420696396, -1.045579638729757}}], 
   Line3DBox[{{-0.015000000000000317`, 
    0.12073057930360392`, -1.0464472775531766`}, {-0.014999999999999092`, 
    0.17539565337340748`, -1.6244402276017071`}}], 
   Line3DBox[{{-0.014999999999999682`, -0.22166942069639606`, \
-1.045579638729757}, {-0.015000000000000907`, -0.1670043466265925, \
-1.6235314796782148`}}], 
   Line3DBox[{{0.014999999999999682`, 
    0.12073057930360398`, -1.0464472775531766`}, {0.015000000000000907`, 
    0.17539565337340732`, -1.6244402276017071`}}], 
   Line3DBox[{{
    0.015000000000000317`, -0.221669420696396, -1.045579638729757}, {
    0.014999999999999092`, -0.16700434662659266`, -1.6235314796782148`}}], 
   Line3DBox[{{-0.014999999999999092`, 
    0.17539565337340748`, -1.6244402276017071`}, {-0.01499999999999907, 
    0.17640137034493888`, -1.6393164490718273`}}], 
   Line3DBox[{{-0.015000000000000907`, -0.1670043466265925, \
-1.6235314796782148`}, {-0.01500000000000093, -0.16599742301511214`, \
-1.6384074355509908`}}], 
   Line3DBox[{{0.015000000000000907`, 
    0.17539565337340732`, -1.6244402276017071`}, {0.01500000000000093, 
    0.17640137034493872`, -1.6393164490718273`}}], 
   Line3DBox[{{
    0.014999999999999092`, -0.16700434662659266`, -1.6235314796782148`}, {
    0.01499999999999907, -0.1659974230151123, -1.6384074355509908`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    7.406212039610107*^-18, 0.25, 0.03304971932447347}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-7.406212039610107*^-18, -0.25, -0.0330498786904391}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9999182926434147, 0.012783115311947865`}, {
        0., -0.012783115311947865`, 0.9999182926434147}}, {0., 0., 0.}}], {{{
       1., 0., -3.6322116324463624`*^-32}, {0., 1., 0.}, {
       3.6322116324463624`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.624181525797721*^-15, 0.}, {-5.624181525797721*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {-9.244363884267157*^-35, 
    0.09039004607279774, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999182926434147, 0.012783115311947865`}, {
        0., -0.012783115311947865`, 0.9999182926434147}}, {0., 0., 0.}}], {{{
       1., 0., -3.6322116324463624`*^-32}, {0., 1., 0.}, {
       3.6322116324463624`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.624181525797721*^-15, 0.}, {-5.624181525797721*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {1.123272105265253*^-15, 
    0.2904362472401537, -0.41366450455183296`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999182926434147, 0.012783115311947865`}, {
        0., -0.012783115311947865`, 0.9999182926434147}}, {0., 0., 0.}}], {{{
       1., 0., -3.6322116324463624`*^-32}, {0., 1., 0.}, {
       3.6322116324463624`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      5.624181525797721*^-15, 0.}, {-5.624181525797721*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-1.1237361779033177`*^-15, -0.1097386689031784, \
-0.42479003266385623`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9890266028741578, -0.14773753350859442`}, {0., 0.14773753350859442`,
         0.9890266028741578}}, {0., 0., 0.}}], {{{1., 
       0., -1.285874813489133*^-32}, {0., 1., 0.}, {1.285874813489133*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.960153597421523*^-15, 
      0.}, {-3.960153597421523*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-4.6554167266575966`*^-35, 
    0.08359435955770714, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9890266028741578, -0.14773753350859442`}, {0., 
        0.14773753350859442`, 0.9890266028741578}}, {0., 0., 0.}}], {{{1., 
       0., -1.285874813489133*^-32}, {0., 1., 0.}, {1.285874813489133*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.960153597421523*^-15, 
      0.}, {-3.960153597421523*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    5.384935285625083*^-16, 0.22345483455823034`, -0.6816670161708568}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9890266028741578, -0.14773753350859442`}, {0., 
        0.14773753350859442`, 0.9890266028741578}}, {0., 0., 0.}}], {{{1., 
       0., -1.285874813489133*^-32}, {0., 1., 0.}, {1.285874813489133*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.960153597421523*^-15, 
      0.}, {-3.960153597421523*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-5.349100865636736*^-16, -0.05536124094472389, \
-0.7103901437189534}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9999967914174639, 
        0.002533210369706636}, {0., -0.002533210369706636, 
        0.9999967914174639}}, {0., 0., 0.}}], {{{1., 0., 
       1.1057373380915471`*^-33}, {0., 1., 0.}, {-1.1057373380915471`*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -1.9847975958508672`*^-15, 0.}, {
      1.9847975958508672`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    3.2440705912512526`*^-35, -0.05148349375276147, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9999964759347285, 
        0.0026548292080508518`}, {0., -0.0026548292080508518`, 
        0.9999964759347285}}, {0., 0., 0.}}], {{{1., 
       0., -8.609020650286427*^-34}, {0., 1., 0.}, {8.609020650286427*^-34, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 5.435659236819374*^-15, 
      0.}, {-5.435659236819374*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.446468783062629*^-35, 
    0.00520957257852472, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-3, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872751022128*^9, 3.483295059780966*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#14", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-14]]", "Input"],

Cell[BoxData["2.33857202004181`"], "Output",
 CellChangeTimes->{3.404735875099977*^9, 3.411511421508195*^9, 
  3.411564228890437*^9, 3.411565282459826*^9, 3.411568987630291*^9, 
  3.415473825210335*^9, 3.4155058956037188`*^9, 3.415556387707799*^9, 
  3.415640829325349*^9, 3.459802016410117*^9, 3.459872751083706*^9, 
  3.483295059907816*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "14"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0.8339601723084135`", "0", "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0.47188674003113207`", "0", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", 
     RowBox[{"-", "0.1867560245053691`"}], "0", "0", "0"},
    {"\<\"optic\"\>", "0", "0", 
     RowBox[{"-", "0.21669223081841615`"}], "0", "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358751283407`*^9, 3.41151142152521*^9, 
  3.4115642289164047`*^9, 3.411565282677906*^9, 3.411568987715143*^9, 
  3.4154738252644243`*^9, 3.4155058956558104`*^9, 3.4155563877594147`*^9, 
  3.415640829346449*^9, 3.45980201643152*^9, 3.459872751107506*^9, 
  3.4832950599565487`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 14\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "14"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", " ", 
     "floatmatrix2"}], "]"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{
  3.390911278120858*^9, 3.390980054950472*^9, {3.3909807445189342`*^9, 
   3.3909807528847513`*^9}, {3.4832991567925863`*^9, 3.483299158439147*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-8.342470242229481*^-18, 
    0.25, -0.1660291220218906}, {-5.701647493811273*^-16, 
    0.09000000000000064, -0.5858606130524174}}], 
   Line3DBox[{{8.342470242229481*^-18, -0.25, -0.16602912202188982`}, {
    5.701647493811275*^-16, -0.08999999999999936, -0.5858606130524161}}], 
   Line3DBox[{{-0.003000000000001261, 
    0.20000000000000112`, -0.5139158214667116}, {-0.003000000000000056, 
    0.05999999999999982, -0.7890616753812006}}], 
   Line3DBox[{{-0.002999999999998739, -0.1999999999999989, \
-0.513915821466709}, {-0.002999999999999944, -0.06000000000000018, \
-0.7890616753811991}}], 
   Line3DBox[{{0.002999999999998739, 
    0.20000000000000115`, -0.5139158214667116}, {0.002999999999999944, 
    0.059999999999999824`, -0.7890616753812006}}], 
   Line3DBox[{{
    0.003000000000001261, -0.19999999999999887`, -0.513915821466709}, {
    0.003000000000000056, -0.06000000000000017, -0.7890616753811991}}], 
   Line3DBox[{{-0.0030000000000001137`, 
    0.14000000000000154`, -0.6596175133880953}, {-0.0029999999999990234`, 
    0.1761999999999999, -0.9894381484475167}}], 
   Line3DBox[{{-0.0029999999999998864`, -0.1399999999999985, \
-0.6596175133880954}, {-0.0030000000000009767`, -0.17620000000000008`, \
-0.9894381484475169}}], 
   Line3DBox[{{0.0029999999999998864`, 
    0.14000000000000154`, -0.6596175133880953}, {0.0030000000000009767`, 
    0.17619999999999988`, -0.9894381484475167}}], 
   Line3DBox[{{
    0.0030000000000001137`, -0.1399999999999985, -0.6596175133880954}, {
    0.0029999999999990234`, -0.1762000000000001, -0.9894381484475169}}], 
   Line3DBox[{{-0.01499999999999905, 
    0.1712, -0.9937861545229992}, {-0.014999999999999071`, 
    0.1712, -1.0086239128122256`}}], 
   Line3DBox[{{-0.015000000000000948`, -0.1712, -0.9937861545229995}, \
{-0.015000000000000928`, -0.1712, -1.0086239128122259`}}], 
   Line3DBox[{{0.015000000000000948`, 
    0.17119999999999982`, -0.9937861545229992}, {0.015000000000000928`, 
    0.17119999999999982`, -1.0086239128122256`}}], 
   Line3DBox[{{
    0.01499999999999905, -0.17120000000000016`, -0.9937861545229995}, {
    0.014999999999999071`, -0.17120000000000016`, -1.0086239128122259`}}], 
   Line3DBox[{{-0.014999999999999071`, 
    0.1712, -1.0086239128122256`}, {-0.01500000000000022, 
    0.17119999999999996`, -1.580685747904445}}], 
   Line3DBox[{{-0.015000000000000928`, -0.1712, -1.0086239128122259`}, \
{-0.01499999999999978, -0.17120000000000002`, -1.5806857479044452`}}], 
   Line3DBox[{{0.015000000000000928`, 
    0.17119999999999982`, -1.0086239128122256`}, {0.01499999999999978, 
    0.17120000000000002`, -1.580685747904445}}], 
   Line3DBox[{{
    0.014999999999999071`, -0.17120000000000016`, -1.0086239128122259`}, {
    0.01500000000000022, -0.17119999999999996`, -1.5806857479044452`}}], 
   Line3DBox[{{-0.01500000000000022, 
    0.17119999999999996`, -1.580685747904445}, {-0.01500000000000024, 
    0.1712, -1.5955235062346522`}}], 
   Line3DBox[{{-0.01499999999999978, -0.17120000000000002`, \
-1.5806857479044452`}, {-0.014999999999999758`, -0.1712, \
-1.5955235062346527`}}], 
   Line3DBox[{{0.01499999999999978, 
    0.17120000000000002`, -1.580685747904445}, {0.014999999999999758`, 
    0.17120000000000002`, -1.5955235062346522`}}], 
   Line3DBox[{{
    0.01500000000000022, -0.17119999999999996`, -1.5806857479044452`}, {
    0.01500000000000024, -0.17119999999999996`, -1.5955235062346527`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-8.342470242229481*^-18, 0.25, -0.1660291220218906}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    8.342470242229481*^-18, -0.25, -0.16602912202188982`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        6.9616122551158935`*^-15}, {0., -6.9616122551158935`*^-15, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 6.273419796364938*^-32}, {0., 1., 
       0.}, {-6.273419796364938*^-32, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -6.335163882012527*^-15, 0.}, {6.335163882012527*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {4.929707198450017*^-35, 
    6.564158275929114*^-16, -0.5827921137412009}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 6.9616122551158935`*^-15}, {
        0., -6.9616122551158935`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       6.273419796364938*^-32}, {0., 1., 0.}, {-6.273419796364938*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -6.335163882012527*^-15, 0.}, {
      6.335163882012527*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.2611089355488682`*^-15, 
    0.20000000000000115`, -0.5139158214667116}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 6.9616122551158935`*^-15}, {
        0., -6.9616122551158935`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       6.273419796364938*^-32}, {0., 1., 0.}, {-6.273419796364938*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -6.335163882012527*^-15, 0.}, {
      6.335163882012527*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.2611089355488623`*^-15, -0.19999999999999887`, -0.513915821466709}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.3200200508321345`*^-14}, {0., -1.3200200508321345`*^-14, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 2.1026006004543132`*^-32}, {0., 1., 
       0.}, {-2.1026006004543132`*^-32, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -9.309968028852824*^-16, 0.}, {9.309968028852824*^-16, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-1.0102088242940683`*^-35, -1.5725724666215923`*^-16, \
-0.7873770938775496}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.3200200508321345`*^-14}, {
        0., -1.3200200508321345`*^-14, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       2.1026006004543132`*^-32}, {0., 1., 0.}, {-2.1026006004543132`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -9.309968028852824*^-16, 0.}, {
      9.309968028852824*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.1359390773114154`*^-16, 
    0.14000000000000154`, -0.6596175133880953}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.3200200508321345`*^-14}, {
        0., -1.3200200508321345`*^-14, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       2.1026006004543132`*^-32}, {0., 1., 0.}, {-2.1026006004543132`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -9.309968028852824*^-16, 0.}, {
      9.309968028852824*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.135939077311384*^-16, -0.1399999999999985, -0.6596175133880954}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., -6.72773830703796*^-16}, {
        0., 6.72773830703796*^-16, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       9.003094991703401*^-34}, {0., 1., 0.}, {-9.003094991703401*^-34, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 5.543749606530452*^-15, 
      0.}, {-5.543749606530452*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.6096337443437368`*^-35, -8.861110912085325*^-17, -0.9966484530047262}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -7.400019052222053*^-16}, {0., 7.400019052222053*^-16, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 2.8305461329873225`*^-33}, {0., 1., 
       0.}, {-2.8305461329873225`*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.410175976501726*^-15, 0.}, {1.410175976501726*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {-7.598591919854353*^-37, 
    7.784716099995837*^-18, -1.5926612077529256`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, 0}]], "Output",
 CellChangeTimes->{3.4598727514515038`*^9, 3.483295060432663*^9, 
  3.483299159298777*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#15", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-15]]", "Input"],

Cell[BoxData["2.408404511481978`"], "Output",
 CellChangeTimes->{3.404735875636271*^9, 3.411511422042094*^9, 
  3.411564229491045*^9, 3.411565283180654*^9, 3.411568988548635*^9, 
  3.415473826067622*^9, 3.415505896513637*^9, 3.415556388613299*^9, 
  3.415640829854239*^9, 3.459802016798421*^9, 3.459872751474783*^9, 
  3.483295060492498*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "15"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0", 
     RowBox[{"-", "0.7489569959616069`"}], "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0", 
     RowBox[{"-", "0.12982688133342304`"}], "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", "0", "0.6295174471290748`", "0", "0"},
    {"\<\"optic\"\>", "0", "0", "0", 
     RowBox[{"-", "0.16098503919152043`"}], "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358756584377`*^9, 3.411511422059517*^9, 
  3.411564229533519*^9, 3.411565283397335*^9, 3.4115689885766983`*^9, 
  3.415473826139*^9, 3.415505896564989*^9, 3.4155563887147827`*^9, 
  3.4156408298755827`*^9, 3.4598020168186693`*^9, 3.459872751498156*^9, 
  3.4832950605414333`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 15\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "15"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112782039747`*^9, 3.390980058946517*^9, {3.390980760825371*^9, 
   3.390980765908987*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.0001972530330039199, 
    0.25, -7.968298282246391*^-8}, {-0.013430868370045267`, 
    0.08899220064042981, -0.41906857859073404`}}], 
   Line3DBox[{{0.0001972530330039199, -0.25, -7.968298283393561*^-8}, {
    0.013430868370045267`, -0.08899220064042981, -0.41906857859073404`}}], 
   Line3DBox[{{-0.03267856741342491, 
    0.1973330059957019, -0.4192275323145006}, {-0.004556736278806931, 
    0.059901887737244176`, -0.6946843273749734}}], 
   Line3DBox[{{
    0.026745754037396256`, -0.19822839722037155`, -0.4192275323145006}, \
{-0.0014412412325331715`, -0.06005766248955787, -0.6946843273749734}}], 
   Line3DBox[{{-0.026745754037396256`, 
    0.19822839722037155`, -0.4192275323145006}, {0.0014412412325331715`, 
    0.060057662489557864`, -0.6946843273749734}}], 
   Line3DBox[{{
    0.03267856741342491, -0.19733300599570186`, -0.4192275323145006}, {
    0.004556736278806931, -0.05990188773724418, -0.6946843273749734}}], 
   Line3DBox[{{-0.006241086738926673, 
    0.13988511872089615`, -0.6960621853090289}, {0.0191493779207502, 
    0.1751820234077923, -1.0267893533485906`}}], 
   Line3DBox[{{
    0.00024310922758657028`, -0.14004089347320986`, -0.6960621853090289}, \
{-0.025101885640626154`, -0.17442859667292207`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.00024310922758657028`, 
    0.14004089347320986`, -0.6960621853090289}, {0.025101885640626154`, 
    0.17442859667292207`, -1.0267893533485906`}}], 
   Line3DBox[{{
    0.006241086738926673, -0.13988511872089618`, -0.6960621853090289}, \
{-0.0191493779207502, -0.1751820234077923, -1.0267893533485906`}}], 
   Line3DBox[{{0.006616506868606457, 
    0.17172845377763604`, -1.0311373594240731`}, {0.006069065508749381, 
    0.17304600457144415`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.036379045467986225`, -0.16796132010328504`, \
-1.0311373594240731`}, {-0.03606906550874938, -0.16935399542855584`, \
-1.0460134581414668`}}], 
   Line3DBox[{{0.036379045467986225`, 
    0.16796132010328504`, -1.0311373594240731`}, {0.03606906550874938, 
    0.16935399542855584`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.006616506868606457, -0.17172845377763604`, \
-1.0311373594240731`}, {-0.006069065508749381, -0.17304600457144415`, \
-1.0460134581414668`}}], 
   Line3DBox[{{0.006069065508749381, 
    0.17304600457144415`, -1.0460134581414668`}, {-0.02002651625216116, 
    0.17075959261809334`, -1.623985853639961}}], 
   Line3DBox[{{-0.03606906550874938, -0.16935399542855584`, \
-1.0460134581414668`}, {-0.009973483747838838, -0.17164040738190664`, \
-1.623985853639961}}], 
   Line3DBox[{{0.03606906550874938, 
    0.16935399542855584`, -1.0460134581414668`}, {0.009973483747838838, 
    0.17164040738190664`, -1.623985853639961}}], 
   Line3DBox[{{-0.006069065508749381, -0.17304600457144415`, \
-1.0460134581414668`}, {
    0.02002651625216116, -0.17075959261809334`, -1.623985853639961}}], 
   Line3DBox[{{-0.02002651625216116, 
    0.17075959261809334`, -1.623985853639961}, {-0.020503401252648774`, 
    0.1706283989758823, -1.6388619523983357`}}], 
   Line3DBox[{{-0.009973483747838838, -0.17164040738190664`, \
-1.623985853639961}, {-0.009481050380895775, -0.1715941423349728, \
-1.6388619523983357`}}], 
   Line3DBox[{{0.009973483747838838, 
    0.17164040738190664`, -1.623985853639961}, {0.009481050380895775, 
    0.1715941423349728, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.02002651625216116, -0.17075959261809334`, -1.623985853639961}, {
    0.020503401252648774`, -0.1706283989758823, -1.6388619523983357`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.0001972530330039199, 0.25, -7.968298282246391*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.0001972530330039199, -0.25, -7.968298283393561*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -4.291484592829043*^-17}, {0., 4.291484592829043*^-17, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 2.2966020593204965`*^-21}, {0., 1., 
       0.}, {-2.2966020593204965`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9888022293381091, -0.14923187077828076`, 0.}, {0.14923187077828076`, 
      0.9888022293381091, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    4.2242774397510344`*^-23, 4.961689629675295*^-18, -0.41600007927951815`}],
    GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.291484592829043*^-17}, {0., 4.291484592829043*^-17, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 2.2966020593204965`*^-21}, {0., 1., 
       0.}, {-2.2966020593204965`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9888022293381091, -0.14923187077828076`, 0.}, {0.14923187077828076`, 
      0.9888022293381091, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.029712160725410584`, 
    0.1977807016080367, -0.4192275323145006}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.291484592829043*^-17}, {0., 4.291484592829043*^-17, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 2.2966020593204965`*^-21}, {0., 1., 
       0.}, {-2.2966020593204965`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9888022293381091, -0.14923187077828076`, 0.}, {0.14923187077828076`, 
      0.9888022293381091, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.029712160725410584`, -0.1977807016080367, -0.4192275323145006}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        8.82211977416333*^-18}, {0., -8.82211977416333*^-18, 1.}}, {0., 0., 
        0.}}], {{{1., 0., -1.98750622481735*^-21}, {0., 1., 0.}, {
       1.98750622481735*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9996629185566838, -0.025962458718948, 0.}, {0.025962458718948, 
      0.9996629185566838, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.7932771093908993`*^-23, -2.6466856161732202`*^-18, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 8.82211977416333*^-18}, {0., -8.82211977416333*^-18, 
        1.}}, {0., 0., 0.}}], {{{1., 0., -1.98750622481735*^-21}, {0., 1., 
       0.}, {1.98750622481735*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9996629185566838, -0.025962458718948, 0.}, {0.025962458718948, 
      0.9996629185566838, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.0032420979832566217`, 
    0.139963006097053, -0.6960621853090289}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 8.82211977416333*^-18}, {0., -8.82211977416333*^-18, 
        1.}}, {0., 0., 0.}}], {{{1., 0., -1.98750622481735*^-21}, {0., 1., 
       0.}, {1.98750622481735*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9996629185566838, -0.025962458718948, 0.}, {0.025962458718948, 
      0.9996629185566838, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0032420979832566217`, -0.139963006097053, -0.6960621853090289}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -1.1874664558193831`*^-17}, {0., 1.1874664558193831`*^-17, 1.}}, {
        0., 0., 0.}}], {{{1., 0., -3.2921482930176456`*^-21}, {0., 1., 0.}, {
       3.2921482930176456`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9920846199793257, 0.1255711224783665, 0.}, {-0.1255711224783665, 
      0.9920846199793257, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.0281843096550174`*^-23, -1.2564050178536727`*^-18, \
-1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 
        1.3604656176486496`*^-17}, {0., -1.3604656176486496`*^-17, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 5.59791195617943*^-22}, {0., 1., 
       0.}, {-5.59791195617943*^-22, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9994817211181517, -0.03219144530301694, 0.}, {0.03219144530301694, 
      0.9994817211181517, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.296309282188004*^-24, 9.807476075045506*^-20, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, -0.25}]], "Output",
 CellChangeTimes->{3.4598727518554707`*^9, 3.483295061001597*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#16", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-16]]", "Input"],

Cell[BoxData["2.6927430388830498`"], "Output",
 CellChangeTimes->{3.4047358762096786`*^9, 3.4115114226238127`*^9, 
  3.411564230125808*^9, 3.411565283765347*^9, 3.411568989537155*^9, 
  3.415473826839261*^9, 3.415505897440486*^9, 3.415556389462895*^9, 
  3.415640830419379*^9, 3.459802017216982*^9, 3.4598727518787537`*^9, 
  3.48329506112805*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "16"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0.057192768809129574`", "0", "0", "0", 
     RowBox[{"-", "0.5854958227158541`"}]},
    {"\<\"Mass U\"\>", "0", 
     RowBox[{"-", "0.037589612788337945`"}], "0", "0", "0", 
     RowBox[{"-", "0.6108523638716254`"}]},
    {"\<\"Mass 2\"\>", "0", "0.0018124664248780193`", "0", "0", "0", 
     "0.35590353113504375`"},
    {"\<\"optic\"\>", "0", 
     RowBox[{"-", "0.00016686296876046862`"}], "0", "0", "0", 
     "0.39076770975723646`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735876236244*^9, 3.411511422639668*^9, 
  3.411564230149168*^9, 3.411565284046438*^9, 3.411568989577977*^9, 
  3.415473826899461*^9, 3.4155058974908123`*^9, 3.415556389554564*^9, 
  3.415640830440831*^9, 3.459802017233574*^9, 3.459872751905046*^9, 
  3.483295061176817*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 16\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "16"}], "]"}], "]"}], ",", " ", 
     RowBox[{"-", "0.2"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", " ", "0", ",", " ", 
       RowBox[{"-", "0.25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278271929*^9, 3.3909800625029984`*^9, {3.3909807737849617`*^9, 
   3.3909807776856527`*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-6.790952523047581*^-18, 0.25, 
    0.006298223534840305}, {-4.627968214843018*^-16, 
    0.07830359945662055, -0.4085327086753626}}], 
   Line3DBox[{{6.790952523047581*^-18, -0.25, -0.00629838290080664}, {
    4.590992998210202*^-16, -0.10046371079483943`, -0.42956242064339134`}}], 
   Line3DBox[{{-0.003000000000001024, 
    0.1883264995501346, -0.40227955197890825`}, {-0.0029999999999999775`, 
    0.06727600502030073, -0.6873597640245814}}], 
   Line3DBox[{{-0.00299999999999898, -0.21044946921027521`, \
-0.4361313076693139}, {-0.0030000000000000226`, -0.05182957083191997, \
-0.7019837785524359}}], 
   Line3DBox[{{0.002999999999998976, 
    0.18832649955013464`, -0.40227955197890825`}, {0.0030000000000000226`, 
    0.06727600502030073, -0.6873597640245814}}], 
   Line3DBox[{{
    0.00300000000000102, -0.2104494692102752, -0.4361313076693139}, {
    0.0029999999999999775`, -0.05182957083191997, -0.7019837785524359}}], 
   Line3DBox[{{-0.002999999999999936, 
    0.15033505497466154`, -0.7073813507096066}, {-0.0029999999999992654`, 
    0.17590412078591502`, -1.039339063845735}}], 
   Line3DBox[{{-0.003000000000000064, -0.13455279054553165`, \
-0.6846973679120477}, {-0.003000000000000731, -0.17560350479597223`, \
-1.014276159828368}}], 
   Line3DBox[{{0.0030000000000000642`, 
    0.15033505497466154`, -0.7073813507096066}, {0.0030000000000007347`, 
    0.175904120785915, -1.039339063845735}}], 
   Line3DBox[{{
    0.0029999999999999363`, -0.13455279054553165`, -0.6846973679120477}, {
    0.0029999999999992693`, -0.17560350479597225`, -1.014276159828368}}], 
   Line3DBox[{{-0.014999999999999286`, 
    0.17060754931359332`, -1.0433204565004504`}, {-0.014999999999999292`, 
    0.17075841123176413`, -1.0582072394473516`}}], 
   Line3DBox[{{-0.01500000000000071, -0.1709253990383879, \
-1.0189687586129748`}, {-0.015000000000000707`, -0.17164158876823585`, \
-1.033819676835582}}], 
   Line3DBox[{{0.015000000000000712`, 
    0.17060754931359318`, -1.0433204565004504`}, {0.015000000000000707`, 
    0.17075841123176402`, -1.0582072394473516`}}], 
   Line3DBox[{{
    0.014999999999999288`, -0.17092539903838805`, -1.0189687586129748`}, {
    0.014999999999999292`, -0.17164158876823596`, -1.033819676835582}}], 
   Line3DBox[{{-0.014999999999999292`, 
    0.17075841123176413`, -1.0582072394473516`}, {-0.01499999999999964, 
    0.17132124207315327`, -1.6373580956222278`}}], 
   Line3DBox[{{-0.015000000000000707`, -0.17164158876823585`, \
-1.033819676835582}, {-0.015000000000000359`, -0.1710787579268467, \
-1.610613611657694}}], 
   Line3DBox[{{0.015000000000000707`, 
    0.17075841123176402`, -1.0582072394473516`}, {0.015000000000000359`, 
    0.17132124207315322`, -1.6373580956222278`}}], 
   Line3DBox[{{
    0.014999999999999292`, -0.17164158876823596`, -1.033819676835582}, {
    0.01499999999999964, -0.17107875792684676`, -1.610613611657694}}], 
   Line3DBox[{{-0.01499999999999964, 
    0.17132124207315327`, -1.6373580956222278`}, {-0.014999999999999649`, 
    0.17048732480010922`, -1.6522194852915468`}}], 
   Line3DBox[{{-0.015000000000000359`, -0.1710787579268467, \
-1.610613611657694}, {-0.015000000000000352`, -0.17086752183171292`, \
-1.6254869455512757`}}], 
   Line3DBox[{{0.015000000000000359`, 
    0.17132124207315322`, -1.6373580956222278`}, {0.01500000000000035, 
    0.17048732480010914`, -1.6522194852915468`}}], 
   Line3DBox[{{
    0.01499999999999964, -0.17107875792684676`, -1.610613611657694}, {
    0.014999999999999647`, -0.170867521831713, -1.6254869455512757`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-6.790952523047581*^-18, 0.25, 0.006298223534840305}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    6.790952523047581*^-18, -0.25, -0.00629838290080664}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9931517236192221, -0.1168317331557151}, {0., 0.1168317331557151, 
        0.9931517236192221}}, {0., 0., 0.}}], {{{1., 
       0., -1.0142203029488286`*^-31}, {0., 1., 0.}, {
       1.0142203029488286`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -5.156961415420708*^-15, 0.}, {5.156961415420708*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-4.430639544734587*^-35, -0.011438553761825915`, \
-0.4160000792795185}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9931517236192221, -0.1168317331557151}, {0., 
        0.1168317331557151, 0.9931517236192221}}, {0., 0., 0.}}], {{{1., 
       0., -1.0142203029488286`*^-31}, {0., 1., 0.}, {
       1.0142203029488286`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -5.156961415420708*^-15, 0.}, {5.156961415420708*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {-1.0241119306965816`*^-15, 
    0.1883264995501346, -0.40227955197890825`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9931517236192221, -0.1168317331557151}, {0., 
        0.1168317331557151, 0.9931517236192221}}, {0., 0., 0.}}], {{{1., 
       0., -1.0142203029488286`*^-31}, {0., 1., 0.}, {
       1.0142203029488286`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -5.156961415420708*^-15, 0.}, {5.156961415420708*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    1.0202228708325462`*^-15, -0.21044946921027521`, -0.4361313076693139}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9925464654351726, -0.12186678773212084`}, {0., 0.12186678773212084`,
         0.9925464654351726}}, {0., 0., 0.}}], {{{1., 0., 
       1.7352524688583474`*^-32}, {0., 1., 0.}, {-1.7352524688583474`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.793946755355321*^-16, 
      0.}, {-3.793946755355321*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    3.800830853058905*^-36, 0.007517922557667589, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9925464654351726, -0.12186678773212084`}, {0., 
        0.12186678773212084`, 0.9925464654351726}}, {0., 0., 0.}}], {{{1., 0.,
        1.7352524688583474`*^-32}, {0., 1., 0.}, {-1.7352524688583474`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.793946755355321*^-16, 
      0.}, {-3.793946755355321*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    6.398536499990853*^-17, 0.15033505497466154`, -0.7073813507096066}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9925464654351726, -0.12186678773212084`}, {0., 
        0.12186678773212084`, 0.9925464654351726}}, {0., 0., 0.}}], {{{1., 0.,
        1.7352524688583474`*^-32}, {0., 1., 0.}, {-1.7352524688583474`*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 3.793946755355321*^-16, 
      0.}, {-3.793946755355321*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-6.370217748653794*^-17, -0.13455279054553165`, \
-0.6846973679120477}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9974677229905995, 
        0.07112061298912302}, {0., -0.07112061298912302, 
        0.9974677229905995}}, {0., 0., 0.}}], {{{1., 
       0., -5.615521274633262*^-33}, {0., 1., 0.}, {5.615521274633262*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 4.169094510525633*^-15, 
      0.}, {-4.169094510525633*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.959140623644296*^-35, -0.00036249328497560385`, \
-1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9969475660976115, 
        0.07807400625079174}, {0., -0.07807400625079174, 
        0.9969475660976115}}, {0., 0., 0.}}], {{{1., 
       0., -2.9845590826231194`*^-33}, {0., 1., 0.}, {
       2.9845590826231194`*^-33, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.059488450314342*^-15, 0.}, {-2.059488450314342*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {2.4037099371860828`*^-35, 
    0.00003337259375209373, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-3, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872752244746*^9, 3.483295061637204*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#17", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-17]]", "Input"],

Cell[BoxData["2.9453872005145967`"], "Output",
 CellChangeTimes->{3.40473587674083*^9, 3.411511423133644*^9, 
  3.4115642306945887`*^9, 3.411565284421967*^9, 3.411568990500313*^9, 
  3.415473827674478*^9, 3.4155058982661123`*^9, 3.415556390359934*^9, 
  3.4156408309388103`*^9, 3.459802017591997*^9, 3.459872752300104*^9, 
  3.4832950616958027`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "17"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", 
     RowBox[{"-", "0.00032813123028092633`"}], "0", "0", "0", 
     "0.45832184344172217`", "0"},
    {"\<\"Mass U\"\>", "0.0009011956767364023`", "0", "0", "0", 
     RowBox[{"-", "0.8871740019877742`"}], "0"},
    {"\<\"Mass 2\"\>", 
     RowBox[{"-", "0.0002848320710209451`"}], "0", "0", "0", 
     "0.05319555851740161`", "0"},
    {"\<\"optic\"\>", "0", "0", "0", "0", 
     RowBox[{"-", "0.00571045735305754`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358767634087`*^9, 3.411511423148967*^9, 
  3.411564230719129*^9, 3.4115652846177063`*^9, 3.411568990529829*^9, 
  3.4154738277396507`*^9, 3.41550589831605*^9, 3.415556390463293*^9, 
  3.41564083096064*^9, 3.459802017608612*^9, 3.459872752329132*^9, 
  3.483295061745207*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 17\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "17"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112783379707`*^9, 3.390980064918396*^9, {3.390980796785705*^9, 
   3.390980801966262*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-3.7451823986273393`*^-7, 0.25, -7.968298282823696*^-8}, {
    0.00034650457234503603`, 0.09, -0.4190556963021101}}], 
   Line3DBox[{{-3.7451823986273393`*^-7, -0.25, -7.968298282816337*^-8}, {
    0.00034650457234503603`, -0.09, -0.4190556963021101}}], 
   Line3DBox[{{-0.0030775963565824816`, 
    0.2, -0.41953007025641686`}, {-0.0034304756897172144`, 
    0.06, -0.6941283632480624}}], 
   Line3DBox[{{-0.0030775963565824816`, -0.2, -0.41953007025641686`}, \
{-0.0034304756897172144`, -0.06, -0.6941283632480624}}], 
   Line3DBox[{{0.002897214218912438, 0.2, -0.4189808539174811}, {
    0.0024753225217342472`, 0.06, -0.6951873946383511}}], 
   Line3DBox[{{0.002897214218912438, -0.2, -0.4189808539174811}, {
    0.0024753225217342472`, -0.06, -0.6951873946383511}}], 
   Line3DBox[{{-0.0028217784720687834`, 
    0.14, -0.695637350982815}, {-0.0030195735897926364`, 
    0.1762, -1.0268216781474333`}}], 
   Line3DBox[{{-0.0028217784720687834`, -0.14, -0.695637350982815}, \
{-0.0030195735897926364`, -0.1762, -1.0268216781474333`}}], 
   Line3DBox[{{0.0030840197393826783`, 0.14, -0.6966963823731037}, {
    0.002980086841316868, 0.1762, -1.026757844681454}}], 
   Line3DBox[{{0.0030840197393826783`, -0.14, -0.6966963823731037}, {
    0.002980086841316868, -0.1762, -1.026757844681454}}], 
   Line3DBox[{{-0.014972636402362183`, 
    0.1712, -1.0312971050802744`}, {-0.014930944513102852`, 
    0.1712, -1.0461719131696854`}}], 
   Line3DBox[{{-0.014972636402362183`, -0.1712, -1.0312971050802744`}, \
{-0.014930944513102852`, -0.1712, -1.0461719131696854`}}], 
   Line3DBox[{{0.015025665753185334`, 0.1712, -1.0309779377503785`}, {
    0.015069055486897147`, 0.1712, -1.0458550031132483`}}], 
   Line3DBox[{{0.015025665753185334`, -0.1712, -1.0309779377503785`}, {
    0.015069055486897147`, -0.1712, -1.0458550031132483`}}], 
   Line3DBox[{{-0.014930944513102852`, 
    0.1712, -1.0461719131696854`}, {-0.015000722456037844`, 
    0.1712, -1.6239698539152354`}}], 
   Line3DBox[{{-0.014930944513102852`, -0.1712, -1.0461719131696854`}, \
{-0.015000722456037844`, -0.1712, -1.6239698539152354`}}], 
   Line3DBox[{{0.015069055486897147`, 0.1712, -1.0458550031132483`}, {
    0.014999277543962155`, 0.1712, -1.6240018533646865`}}], 
   Line3DBox[{{0.015069055486897147`, -0.1712, -1.0458550031132483`}, {
    0.014999277543962155`, -0.1712, -1.6240018533646865`}}], 
   Line3DBox[{{-0.015000722456037844`, 
    0.1712, -1.6239698539152354`}, {-0.015006717305036991`, 
    0.1712, -1.6388448191632488`}}], 
   Line3DBox[{{-0.015000722456037844`, -0.1712, -1.6239698539152354`}, \
{-0.015006717305036991`, -0.1712, -1.6388448191632488`}}], 
   Line3DBox[{{0.014999277543962155`, 0.1712, -1.6240018533646865`}, {
    0.014993263129371225`, 0.1712, -1.6388790818999184`}}], 
   Line3DBox[{{0.014999277543962155`, -0.1712, -1.6240018533646865`}, {
    0.014993263129371225`, -0.1712, -1.6388790818999184`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-3.7451823986273393`*^-7, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-3.7451823986273393`*^-7, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        2.9657223517535624`*^-36}, {0., -2.9657223517535624`*^-36, 1.}}, {0., 
        0., 0.}}], {{{0.9958017625824865, 0., -0.09153605648930437}, {0., 1., 
       0.}, {0.09153605648930437, 0., 0.9958017625824865}}, {0., 0., 
       0.}}], {{{1., 6.703532491401651*^-21, 0.}, {-6.703532491401651*^-21, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.00006562624605618527, -3.085446706891492*^-37, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.9657223517535624`*^-36}, {
        0., -2.9657223517535624`*^-36, 1.}}, {0., 0., 0.}}], {{{
       0.9958017625824865, 0., -0.09153605648930437}, {0., 1., 0.}, {
       0.09153605648930437, 0., 0.9958017625824865}}, {0., 0., 0.}}], {{{1., 
      6.703532491401651*^-21, 0.}, {-6.703532491401651*^-21, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {-0.00009019106883502209, 
    0.2, -0.41925546208694897`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.9657223517535624`*^-36}, {
        0., -2.9657223517535624`*^-36, 1.}}, {0., 0., 0.}}], {{{
       0.9958017625824865, 0., -0.09153605648930437}, {0., 1., 0.}, {
       0.09153605648930437, 0., 0.9958017625824865}}, {0., 0., 0.}}], {{{1., 
      6.703532491401651*^-21, 0.}, {-6.703532491401651*^-21, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 
      0.}}], {-0.00009019106883502209, -0.2, -0.41925546208694897`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.2000298362510249`*^-35}, {0., 1.2000298362510249`*^-35, 1.}}, {
        0., 0., 0.}}], {{{0.984299701908577, 0., 0.17650523171477545`}, {0., 
       1., 0.}, {-0.17650523171477545`, 0., 0.984299701908577}}, {0., 0., 
       0.}}], {{{1., -9.386998568052586*^-21, 0.}, {9.386998568052586*^-21, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {-0.00018023913534728048`, 
    1.2824789372416456`*^-38, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.2000298362510249`*^-35}, {0., 
        1.2000298362510249`*^-35, 1.}}, {0., 0., 0.}}], {{{0.984299701908577, 
       0., 0.17650523171477545`}, {0., 1., 0.}, {-0.17650523171477545`, 0., 
       0.984299701908577}}, {0., 0., 0.}}], {{{1., -9.386998568052586*^-21, 
      0.}, {9.386998568052586*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0001311206336569472, 0.14, -0.6961668666779594}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.2000298362510249`*^-35}, {0., 
        1.2000298362510249`*^-35, 1.}}, {0., 0., 0.}}], {{{0.984299701908577, 
       0., 0.17650523171477545`}, {0., 1., 0.}, {-0.17650523171477545`, 0., 
       0.984299701908577}}, {0., 0., 0.}}], {{{1., -9.386998568052586*^-21, 
      0.}, {9.386998568052586*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.0001311206336569472, -0.14, -0.6961668666779594}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600295842*^-19}, {
        0., -7.621041600295842*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9999434051849173, 0., -0.01063891099653655}, {0., 1., 0.}, {
       0.01063891099653655, 0., 0.9999434051849173}}, {0., 0., 0.}}], {{{1., 
      8.711201193589917*^-21, 0.}, {-8.711201193589917*^-21, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {0.000056966414204189024`, 
    9.051505079516017*^-38, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -3.157738818847419*^-34}, {0., 3.157738818847419*^-34, 1.}}, {0., 
        0., 0.}}], {{{0.9999993478136072, 0., 0.0011420912223259918`}, {0., 
       1., 0.}, {-0.0011420912223259918`, 0., 0.9999993478136072}}, {0., 0., 
       0.}}], {{{1., -1.3499326002538325`*^-21, 0.}, {
      1.3499326002538325`*^-21, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-3.458081861224861*^-6, 
    2.204386341363249*^-39, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -3, -0.25}]], "Output",
 CellChangeTimes->{3.45987275267451*^9, 3.483295062221723*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#18", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-18]]", "Input"],

Cell[BoxData["3.0462741773155018`"], "Output",
 CellChangeTimes->{3.404735877311082*^9, 3.411511423710294*^9, 
  3.411564231347134*^9, 3.411565285100924*^9, 3.4115689913398743`*^9, 
  3.4154738283813467`*^9, 3.4155058991998672`*^9, 3.415556391377193*^9, 
  3.415640831528895*^9, 3.459802017967266*^9, 3.459872752697962*^9, 
  3.483295062347397*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "18"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0", 
     RowBox[{"-", "0.5451032003344559`"}], "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0", "0.6444799279501074`", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", "0", 
     RowBox[{"-", "0.5305834696623338`"}], "0", "0"},
    {"\<\"optic\"\>", "0", "0", "0", "0.07739060133916517`", "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735877337325*^9, 3.41151142373001*^9, 
  3.4115642313718767`*^9, 3.4115652852966223`*^9, 3.411568991363187*^9, 
  3.4154738284330797`*^9, 3.415505899256926*^9, 3.415556391421932*^9, 
  3.4156408315504627`*^9, 3.459802017984614*^9, 3.45987275272162*^9, 
  3.4832950623947153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 18\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "18"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", " ", "floatmatrix2"}], 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.39091127842209*^9, 3.390980070390746*^9, {3.390980808400976*^9, 
   3.390980814278782*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.00014356399652567858`, 
    0.25, -7.968298282804857*^-8}, {-0.009792432681163253, 
    0.08946568203610189, -0.41906857859073404`}}], 
   Line3DBox[{{0.00014356399652567858`, -0.25, -7.968298282835187*^-8}, {
    0.009792432681163253, -0.08946568203610189, -0.41906857859073404`}}], 
   Line3DBox[{{-0.024483904132853514`, 
    0.19851458808350922`, -0.4192275323145006}, {0.00473724869115614, 
    0.059887882537606386`, -0.6946843273749734}}], 
   Line3DBox[{{
    0.01851952533044672, -0.1991674169289201, -0.4192275323145006}, \
{-0.01068747513535051, -0.05911664634628105, -0.6946843273749734}}], 
   Line3DBox[{{-0.01851952533044672, 
    0.1991674169289201, -0.4192275323145006}, {0.01068747513535051, 
    0.05911664634628105, -0.6946843273749734}}], 
   Line3DBox[{{
    0.024483904132853514`, -0.19851458808350922`, -0.4192275323145006}, \
{-0.00473724869115614, -0.059887882537606386`, -0.6946843273749734}}], 
   Line3DBox[{{0.014417626498060913`, 
    0.1393023630992098, -0.6960621853090289}, {-0.02164581412771349, 
    0.17489110535058228`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.020367852942255286`, -0.13853112690788447`, \
-0.6960621853090289}, {
    0.01567956469666584, -0.17552661123294971`, -1.0267893533485906`}}], 
   Line3DBox[{{0.020367852942255286`, 
    0.13853112690788447`, -0.6960621853090289}, {-0.01567956469666584, 
    0.17552661123294971`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.014417626498060913`, -0.1393023630992098, \
-0.6960621853090289}, {
    0.02164581412771349, -0.17489110535058228`, -1.0267893533485906`}}], 
   Line3DBox[{{-0.033048724754502615`, 
    0.16864821905997443`, -1.0311373594240731`}, {-0.032793694758241634`, 
    0.16964097300599518`, -1.0460134581414668`}}], 
   Line3DBox[{{
    0.0032174775992643585`, -0.1718257484718115, -1.0311373594240731`}, {
    0.0027936947582416355`, -0.1727590269940048, -1.0460134581414668`}}], 
   Line3DBox[{{-0.0032174775992643585`, 
    0.1718257484718115, -1.0311373594240731`}, {-0.0027936947582416355`, 
    0.1727590269940048, -1.0460134581414668`}}], 
   Line3DBox[{{
    0.033048724754502615`, -0.16864821905997443`, -1.0311373594240731`}, {
    0.032793694758241634`, -0.16964097300599518`, -1.0460134581414668`}}], 
   Line3DBox[{{-0.032793694758241634`, 
    0.16964097300599518`, -1.0460134581414668`}, {-0.01272362875227732, 
    0.17139944841539625`, -1.623985853639961}}], 
   Line3DBox[{{
    0.0027936947582416355`, -0.1727590269940048, -1.0460134581414668`}, \
{-0.017276371247722678`, -0.17100055158460373`, -1.623985853639961}}], 
   Line3DBox[{{-0.0027936947582416355`, 
    0.1727590269940048, -1.0460134581414668`}, {0.017276371247722678`, 
    0.17100055158460373`, -1.623985853639961}}], 
   Line3DBox[{{
    0.032793694758241634`, -0.16964097300599518`, -1.0460134581414668`}, {
    0.01272362875227732, -0.17139944841539625`, -1.623985853639961}}], 
   Line3DBox[{{-0.01272362875227732, 
    0.17139944841539625`, -1.623985853639961}, {-0.012348454858434483`, 
    0.17141165556230184`, -1.6388619523983357`}}], 
   Line3DBox[{{-0.017276371247722678`, -0.17100055158460373`, \
-1.623985853639961}, {-0.017647951630203114`, -0.17094733049468194`, \
-1.6388619523983357`}}], 
   Line3DBox[{{0.017276371247722678`, 
    0.17100055158460373`, -1.623985853639961}, {0.017647951630203114`, 
    0.17094733049468194`, -1.6388619523983357`}}], 
   Line3DBox[{{
    0.01272362875227732, -0.17139944841539625`, -1.623985853639961}, {
    0.012348454858434483`, -0.17141165556230184`, -1.6388619523983357`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.00014356399652567858`, 0.25, -7.968298282804857*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    0.00014356399652567858`, -0.25, -7.968298282835187*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -2.829083735211914*^-18}, {0., 2.829083735211914*^-18, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 4.148162542856875*^-21}, {0., 1., 
       0.}, {-4.148162542856875*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9940631337344655, -0.1088048075684806, 0.}, {0.1088048075684806, 
      0.9940631337344655, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.876511489120555*^-23, -1.8049223764084106`*^-19, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.829083735211914*^-18}, {0., 2.829083735211914*^-18, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 4.148162542856875*^-21}, {0., 1., 
       0.}, {-4.148162542856875*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9940631337344655, -0.1088048075684806, 0.}, {0.1088048075684806, 
      0.9940631337344655, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.021501714731650117`, 
    0.19884100250621467`, -0.4192275323145006}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.829083735211914*^-18}, {0., 2.829083735211914*^-18, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 4.148162542856875*^-21}, {0., 1., 
       0.}, {-4.148162542856875*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9940631337344655, -0.1088048075684806, 0.}, {0.1088048075684806, 
      0.9940631337344655, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.021501714731650117`, -0.19884100250621467`, -0.4192275323145006}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        2.9427325886722452`*^-18}, {0., -2.9427325886722452`*^-18, 1.}}, {0., 
        0., 0.}}], {{{1., 0., -8.953585229249072*^-21}, {0., 1., 0.}, {
       8.953585229249072*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9917044073657286, 0.12853936522088877`, 0.}, {-0.12853936522088877`, 
      0.9917044073657286, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    2.1437648964895632`*^-23, -8.644076211747095*^-20, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.9427325886722452`*^-18}, {
        0., -2.9427325886722452`*^-18, 1.}}, {0., 0., 0.}}], {{{1., 
       0., -8.953585229249072*^-21}, {0., 1., 0.}, {8.953585229249072*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9917044073657286, 0.12853936522088877`, 
      0.}, {-0.12853936522088877`, 0.9917044073657286, 0.}, {0., 0., 1.}}, {
      0., 0., 0.}}], {0.017392739720158097`, 
    0.13891674500354714`, -0.6960621853090289}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 2.9427325886722452`*^-18}, {
        0., -2.9427325886722452`*^-18, 1.}}, {0., 0., 0.}}], {{{1., 
       0., -8.953585229249072*^-21}, {0., 1., 0.}, {8.953585229249072*^-21, 
       0., 1.}}, {0., 0., 0.}}], {{{0.9917044073657286, 0.12853936522088877`, 
      0.}, {-0.12853936522088877`, 0.9917044073657286, 0.}, {0., 0., 1.}}, {
      0., 0., 0.}}], {-0.017392739720158097`, -0.13891674500354714`, \
-0.6960621853090289}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -3.617059877428487*^-18}, {0., 3.617059877428487*^-18, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 2.9556115976717245`*^-21}, {0., 1., 
       0.}, {-2.9556115976717245`*^-21, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9943749051746085, -0.10591764706123533`, 0.}, {0.10591764706123533`, 
      0.9943749051746085, 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-3.6913634289793824`*^-25, 
    4.936982002748541*^-19, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 1.117689255830045*^-18}, {
        0., -1.117689255830045*^-18, 1.}}, {0., 0., 0.}}], {{{1., 
       0., -2.9457498297375913`*^-22}, {0., 1., 0.}, {
       2.9457498297375913`*^-22, 0., 1.}}, {0., 0., 0.}}], {{{
      0.9998802162879199, 0.015477502253997166`, 0.}, {-0.015477502253997166`,
       0.9998802162879199, 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.7382155400388228`*^-25, -1.5983514381690875`*^-20, \
-1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, 0}]], "Output",
 CellChangeTimes->{3.459872753068269*^9, 3.4832950628568907`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#19", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-19]]", "Input"],

Cell[BoxData["3.3254040859981333`"], "Output",
 CellChangeTimes->{3.404735877835278*^9, 3.411511424262044*^9, 
  3.411564231894125*^9, 3.411565285653473*^9, 3.4115689922111*^9, 
  3.415473829157428*^9, 3.4155059006479683`*^9, 3.415556392236446*^9, 
  3.4156408320484343`*^9, 3.459802018426879*^9, 3.459872753091745*^9, 
  3.483295062915618*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "19"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0.08078213504089587`", "0", "0", "0", 
     RowBox[{"-", "0.5840626343481391`"}]},
    {"\<\"Mass U\"\>", "0", 
     RowBox[{"-", "0.09889476549796015`"}], "0", "0", "0", 
     "0.70113810731319`"},
    {"\<\"Mass 2\"\>", "0", "0.022370284007728294`", "0", "0", "0", 
     RowBox[{"-", "0.25356048679121473`"}]},
    {"\<\"optic\"\>", "0", 
     RowBox[{"-", "0.0008443661732807706`"}], "0", "0", "0", 
     RowBox[{"-", "0.29355783522895235`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735877856386*^9, 3.4115114242775593`*^9, 
  3.411564231917363*^9, 3.411565285852714*^9, 3.411568992249844*^9, 
  3.415473829355543*^9, 3.415505908522067*^9, 3.415556392325158*^9, 
  3.415640832069818*^9, 3.459802018447856*^9, 3.459872753115591*^9, 
  3.4832950629645042`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 19\>\"", ",", " ", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "19"}], "]"}], "]"}], ",", " ", 
     RowBox[{"-", "0.2"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0", ",", "  ", 
       RowBox[{"-", "0.25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278489328*^9, 3.390980073122484*^9, {3.39098082172258*^9, 
   3.390980826718862*^9}, {3.483299173032613*^9, 3.4832991820234327`*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{1.6727812443926358`*^-19, 0.25, 0.004486633061334279}, {
    1.1400113207422128`*^-17, 0.07358786295331594, -0.408558432463791}}], 
   Line3DBox[{{-1.6727812443926358`*^-19, -0.25, -0.004486792427299563}, \
{-1.1309255941700725`*^-17, -0.10518546786191092`, -0.4295369021226927}}], 
   Line3DBox[{{-0.0029999999999999745`, 
    0.18446194182939685`, -0.4095751120449975}, {-0.003000000000000004, 
    0.07895455411369892, -0.7030539021990155}}], 
   Line3DBox[{{-0.0030000000000000256`, -0.21602249556164502`, \
-0.42883596350418934`}, {-0.002999999999999996, -0.039867550792631344`, \
-0.6862816815461309}}], 
   Line3DBox[{{0.0030000000000000256`, 
    0.18446194182939685`, -0.4095751120449975}, {0.002999999999999996, 
    0.07895455411369892, -0.7030539021990155}}], 
   Line3DBox[{{
    0.0029999999999999745`, -0.21602249556164502`, -0.42883596350418934`}, {
    0.003000000000000004, -0.039867550792631344`, -0.6862816815461309}}], 
   Line3DBox[{{-0.0030000000000000135`, 
    0.16231059042853074`, -0.6848965157753852}, {-0.003000000000000266, 
    0.17113393053609385`, -1.0178669806626652`}}], 
   Line3DBox[{{-0.0029999999999999866`, -0.12360874939576823`, \
-0.707167734302867}, {-0.002999999999999733, -0.18081303006373092`, \
-1.0357302649224367`}}], 
   Line3DBox[{{0.0029999999999999866`, 
    0.16231059042853074`, -0.6848965157753852}, {0.002999999999999734, 
    0.17113393053609385`, -1.0178669806626652`}}], 
   Line3DBox[{{
    0.0030000000000000135`, -0.12360874939576823`, -0.707167734302867}, {
    0.003000000000000267, -0.18081303006373092`, -1.0357302649224367`}}], 
   Line3DBox[{{-0.015000000000000258`, 
    0.16636076046086803`, -1.0224628488358622`}, {-0.015000000000000258`, 
    0.166870585551448, -1.03732277716332}}], 
   Line3DBox[{{-0.014999999999999741`, -0.17559905596756556`, \
-1.039819229456026}, {-0.014999999999999741`, -0.175529414448552, \
-1.0547041391196137`}}], 
   Line3DBox[{{0.014999999999999741`, 
    0.1663607604608681, -1.0224628488358622`}, {0.014999999999999741`, 
    0.16687058555144804`, -1.03732277716332}}], 
   Line3DBox[{{
    0.015000000000000258`, -0.1755990559675655, -1.039819229456026}, {
    0.015000000000000258`, -0.17552941444855194`, -1.0547041391196137`}}], 
   Line3DBox[{{-0.015000000000000258`, 
    0.166870585551448, -1.03732277716332}, {-0.015000000000000171`, 
    0.17121416506552373`, -1.6139432032721373`}}], 
   Line3DBox[{{-0.014999999999999741`, -0.175529414448552, \
-1.0547041391196137`}, {-0.014999999999999828`, -0.17118583493447626`, \
-1.6340285040077847`}}], 
   Line3DBox[{{0.014999999999999741`, 
    0.16687058555144804`, -1.03732277716332}, {0.014999999999999828`, 
    0.17121416506552375`, -1.6139432032721373`}}], 
   Line3DBox[{{
    0.015000000000000258`, -0.17552941444855194`, -1.0547041391196137`}, {
    0.015000000000000171`, -0.17118583493447623`, -1.6340285040077847`}}], 
   Line3DBox[{{-0.015000000000000171`, 
    0.17121416506552373`, -1.6139432032721373`}, {-0.01500000000000017, 
    0.17124184416616642`, -1.6288113739230967`}}], 
   Line3DBox[{{-0.014999999999999828`, -0.17118583493447626`, \
-1.6340285040077847`}, {-0.01499999999999983, -0.1705681906973253, \
-1.6489026672268778`}}], 
   Line3DBox[{{0.014999999999999828`, 
    0.17121416506552375`, -1.6139432032721373`}, {0.01499999999999983, 
    0.17124184416616645`, -1.6288113739230967`}}], 
   Line3DBox[{{
    0.015000000000000171`, -0.17118583493447623`, -1.6340285040077847`}, {
    0.01500000000000017, -0.17056819069732526`, -1.6489026672268778`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    1.6727812443926358`*^-19, 0.25, 0.004486633061334279}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-1.6727812443926358`*^-19, -0.25, -0.004486792427299563}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9931851711957048, -0.11654705366056478`}, {0., 0.11654705366056478`,
         0.9931851711957048}}, {0., 0., 0.}}], {{{1., 0., 
       1.851571033480883*^-32}, {0., 1., 0.}, {-1.851571033480883*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 1.2702884174930079`*^-16, 
      0.}, {-1.2702884174930079`*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {2.465101388606762*^-34, -0.016156427008179177`, \
-0.416000079279518}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9931851711957048, -0.11654705366056478`}, {0., 
        0.11654705366056478`, 0.9931851711957048}}, {0., 0., 0.}}], {{{1., 0.,
        1.851571033480883*^-32}, {0., 1., 0.}, {-1.851571033480883*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 1.2702884174930079`*^-16, 
      0.}, {-1.2702884174930079`*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {2.527272815664113*^-17, 
    0.18446194182939685`, -0.4095751120449975}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9931851711957048, -0.11654705366056478`}, {0., 
        0.11654705366056478`, 0.9931851711957048}}, {0., 0., 0.}}], {{{1., 0.,
        1.851571033480883*^-32}, {0., 1., 0.}, {-1.851571033480883*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 1.2702884174930079`*^-16, 
      0.}, {-1.2702884174930079`*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.5177164322902947`*^-17, -0.21602249556164502`, \
-0.42883596350418934`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9901842075527522, 0.1397685054407045}, {0., -0.1397685054407045, 
        0.9901842075527522}}, {0., 0., 0.}}], {{{1., 0., 
       3.827809884699374*^-32}, {0., 1., 0.}, {-3.827809884699374*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -6.600004685089143*^-17, 0.}, {
      6.600004685089143*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.5784826190872952`*^-34, 
    0.01977895309959203, -0.6929997458713233}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9901842075527522, 0.1397685054407045}, {
        0., -0.1397685054407045, 0.9901842075527522}}, {0., 0., 0.}}], {{{1., 
       0., 3.827809884699374*^-32}, {0., 1., 0.}, {-3.827809884699374*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -6.600004685089143*^-17, 0.}, {
      6.600004685089143*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.3152821504898078`*^-17, 
    0.16231059042853074`, -0.6848965157753852}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9901842075527522, 0.1397685054407045}, {
        0., -0.1397685054407045, 0.9901842075527522}}, {0., 0., 0.}}], {{{1., 
       0., 3.827809884699374*^-32}, {0., 1., 0.}, {-3.827809884699374*^-32, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -6.600004685089143*^-17, 0.}, {
      6.600004685089143*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.3209321845989315`*^-17, -0.12360874939576823`, -0.707167734302867}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9987144171391168, -0.050690363960759016`}, {0., 
        0.050690363960759016`, 0.9987144171391168}}, {0., 0., 0.}}], {{{1., 
       0., 5.619477793819198*^-34}, {0., 1., 0.}, {-5.619477793819198*^-34, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -1.5142948952253794`*^-15, 0.}, {
      1.5142948952253794`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    9.651412121291667*^-36, -0.004474056801545659, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.998276970979824, -0.058677842592818316`}, {0., 
        0.058677842592818316`, 0.998276970979824}}, {0., 0., 0.}}], {{{1., 0.,
        1.8232448179009282`*^-33}, {0., 1., 0.}, {-1.8232448179009282`*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -9.96901934239655*^-16, 0.}, {
      9.96901934239655*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    4.1209482477711017`*^-35, 0.00016887323465615415`, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-3, 0, -0.25}]], "Output",
 CellChangeTimes->{
  3.459872753456922*^9, 3.483295063441674*^9, {3.483299174156248*^9, 
   3.483299182828168*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#20", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-20]]", "Input"],

Cell[BoxData["3.4189284636027493`"], "Output",
 CellChangeTimes->{3.404735878411355*^9, 3.4115114248262997`*^9, 
  3.411564232553895*^9, 3.411565286319941*^9, 3.411568993009276*^9, 
  3.415473830081956*^9, 3.415505909369532*^9, 3.415556393207712*^9, 
  3.415640832618195*^9, 3.459802018800227*^9, 3.459872753516753*^9, 
  3.483295063567696*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "20"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0.64508254471999`", "0", "0", "0", 
     RowBox[{"-", "0.021860313105720106`"}], "0"},
    {"\<\"Mass U\"\>", 
     RowBox[{"-", "0.6774601255245466`"}], "0", "0", "0", 
     RowBox[{"-", "0.3126185182593524`"}], "0"},
    {"\<\"Mass 2\"\>", "0.10474421679727862`", "0", "0", "0", 
     "0.12497360541691702`", "0"},
    {"\<\"optic\"\>", 
     RowBox[{"-", "0.003845588349654743`"}], "0", "0", "0", 
     RowBox[{"-", "0.01017526515434965`"}], "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735878437231*^9, 3.411511424848709*^9, 
  3.4115642325757723`*^9, 3.411565286521504*^9, 3.411568993036914*^9, 
  3.415473830221826*^9, 3.415505909405343*^9, 3.415556393300621*^9, 
  3.4156408326397123`*^9, 3.459802018818331*^9, 3.45987275353996*^9, 
  3.483295063616679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 20\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "20"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278555296*^9, 3.3909800765299063`*^9, {3.39098083585817*^9, 
   3.390980839183413*^9}, {3.483299189168751*^9, 3.483299191199538*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-0.0018556375058390927`, 
    0.25, -7.968298282823696*^-8}, {-0.1290299245723997, 
    0.09, -0.4190685492637036}}], 
   Line3DBox[{{-0.0018556375058390927`, -0.25, -7.968298282816337*^-8}, \
{-0.1290299245723997, -0.09, -0.4190685492637036}}], 
   Line3DBox[{{-0.12728300996279915`, 0.2, -0.4192351421754086}, {
    0.13239262935088444`, 0.06, -0.6944935868275073}}], 
   Line3DBox[{{-0.12728300996279915`, -0.2, -0.4192351421754086}, {
    0.13239262935088444`, -0.06, -0.6944935868275073}}], 
   Line3DBox[{{-0.12128306730750252`, 0.2, -0.41926137446756384`}, {
    0.1383809055303192, 0.06, -0.6948684846786808}}], 
   Line3DBox[{{-0.12128306730750252`, -0.2, -0.41926137446756384`}, {
    0.1383809055303192, -0.06, -0.6948684846786808}}], 
   Line3DBox[{{0.13031080797882055`, 
    0.14, -0.6957438092656657}, {-0.02412810709109566, 
    0.1762, -1.0268665818559886`}}], 
   Line3DBox[{{
    0.13031080797882055`, -0.14, -0.6957438092656657}, {-0.02412810709109566, \
-0.1762, -1.0268665818559886`}}], 
   Line3DBox[{{0.1362990841582553, 
    0.14, -0.6961187071168392}, {-0.018129981201770007`, 
    0.1762, -1.0267166291441046`}}], 
   Line3DBox[{{
    0.1362990841582553, -0.14, -0.6961187071168392}, {-0.018129981201770007`, \
-0.1762, -1.0267166291441046`}}], 
   Line3DBox[{{-0.036015692986029225`, 
    0.1712, -1.031513135247806}, {-0.03552826294470564, 
    0.1712, -1.046385782603903}}], 
   Line3DBox[{{-0.036015692986029225`, -0.1712, -1.031513135247806}, \
{-0.03552826294470564, -0.1712, -1.046385782603903}}], 
   Line3DBox[{{-0.00602506353940096, 
    0.1712, -1.0307633716883864`}, {-0.005528262944705639, 
    0.1712, -1.0456411336790308`}}], 
   Line3DBox[{{-0.00602506353940096, -0.1712, -1.0307633716883864`}, \
{-0.005528262944705639, -0.1712, -1.0456411336790308`}}], 
   Line3DBox[{{-0.03552826294470564, 
    0.1712, -1.046385782603903}, {-0.014617449920899896`, 
    0.1712, -1.6239579241983126`}}], 
   Line3DBox[{{-0.03552826294470564, -0.1712, -1.046385782603903}, \
{-0.014617449920899896`, -0.1712, -1.6239579241983126`}}], 
   Line3DBox[{{-0.005528262944705639, 0.1712, -1.0456411336790308`}, {
    0.015382550079100103`, 0.1712, -1.6240137830816093`}}], 
   Line3DBox[{{-0.005528262944705639, -0.1712, -1.0456411336790308`}, {
    0.015382550079100103`, -0.1712, -1.6240137830816093`}}], 
   Line3DBox[{{-0.014617449920899896`, 
    0.1712, -1.6239579241983126`}, {-0.014236676194453374`, 
    0.1712, -1.6388314206969248`}}], 
   Line3DBox[{{-0.014617449920899896`, -0.1712, -1.6239579241983126`}, \
{-0.014236676194453374`, -0.1712, -1.6388314206969248`}}], 
   Line3DBox[{{0.015382550079100103`, 0.1712, -1.6240137830816093`}, {
    0.015763261683955487`, 0.1712, -1.6388924722457106`}}], 
   Line3DBox[{{0.015382550079100103`, -0.1712, -1.6240137830816093`}, {
    0.015763261683955487`, -0.1712, -1.6388924722457106`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.0018556375058390927`, 0.25, -7.968298282823696*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-0.0018556375058390927`, -0.25, -7.968298282816337*^-8}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        5.782431251649448*^-38}, {0., -5.782431251649448*^-38, 1.}}, {0., 0., 
        0.}}], {{{0.9999904425494426, 0., 0.004372048692544368}, {0., 1., 
       0.}, {-0.004372048692544368, 0., 0.9999904425494426}}, {0., 0., 
       0.}}], {{{1., 2.216521477723243*^-22, 0.}, {-2.216521477723243*^-22, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.12901650894399802`, -6.288591550031302*^-39, \
-0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 5.782431251649448*^-38}, {0., -5.782431251649448*^-38, 
        1.}}, {0., 0., 0.}}], {{{0.9999904425494426, 0., 
       0.004372048692544368}, {0., 1., 0.}, {-0.004372048692544368, 0., 
       0.9999904425494426}}, {0., 0., 0.}}], {{{1., 2.216521477723243*^-22, 
      0.}, {-2.216521477723243*^-22, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.12428303863515083`, 0.2, -0.4192482583214862}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 5.782431251649448*^-38}, {0., -5.782431251649448*^-38, 
        1.}}, {0., 0., 0.}}], {{{0.9999904425494426, 0., 
       0.004372048692544368}, {0., 1., 0.}, {-0.004372048692544368, 0., 
       0.9999904425494426}}, {0., 0., 0.}}], {{{1., 2.216521477723243*^-22, 
      0.}, {-2.216521477723243*^-22, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-0.12428303863515083`, -0.2, -0.4192482583214862}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -2.1199962313952248`*^-37}, {0., 2.1199962313952248`*^-37, 1.}}, {
        0., 0., 0.}}], {{{0.99804602990579, 0., 0.06248297519557502}, {0., 1.,
        0.}, {-0.06248297519557502, 0., 0.99804602990579}}, {0., 0., 
       0.}}], {{{1., -5.230391324469975*^-22, 0.}, {5.230391324469975*^-22, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {0.13549202510490932`, 
    2.02965910289153*^-39, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.1199962313952248`*^-37}, {0., 
        2.1199962313952248`*^-37, 1.}}, {0., 0., 0.}}], {{{0.99804602990579, 
       0., 0.06248297519557502}, {0., 1., 0.}, {-0.06248297519557502, 0., 
       0.99804602990579}}, {0., 0., 0.}}], {{{1., -5.230391324469975*^-22, 
      0.}, {5.230391324469975*^-22, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.13330494606853793`, 0.14, -0.6959312581912525}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -2.1199962313952248`*^-37}, {0., 
        2.1199962313952248`*^-37, 1.}}, {0., 0., 0.}}], {{{0.99804602990579, 
       0., 0.06248297519557502}, {0., 1., 0.}, {-0.06248297519557502, 0., 
       0.99804602990579}}, {0., 0., 0.}}], {{{1., -5.230391324469975*^-22, 
      0.}, {5.230391324469975*^-22, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    0.13330494606853793`, -0.14, -0.6959312581912525}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.621041600295839*^-19}, {
        0., -7.621041600295839*^-19, 1.}}, {0., 0., 0.}}], {{{
       0.9996876482209421, 0., -0.024992118647322984`}, {0., 1., 0.}, {
       0.024992118647322984`, 0., 0.9996876482209421}}, {0., 0., 0.}}], {{{1.,
       1.0880357077769599`*^-21, 0.}, {-1.0880357077769599`*^-21, 1., 0.}, {
      0., 0., 1.}}, {0., 0., 
      0.}}], {-0.020948843359455724`, -1.7990754561447158`*^-39, \
-1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -5.604407429275801*^-36}, {0., 5.604407429275801*^-36, 1.}}, {0., 
        0., 0.}}], {{{0.9999979292802954, 0., 0.0020350516261949327`}, {0., 
       1., 0.}, {-0.0020350516261949327`, 0., 0.9999979292802954}}, {0., 0., 
       0.}}], {{{1., -1.220251395226877*^-22, 0.}, {1.220251395226877*^-22, 
      1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {0.0007691176699309486, 
    1.0504795790398866`*^-40, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{0, -1, -0.25}]], "Output",
 CellChangeTimes->{3.4598727538951683`*^9, 3.483295064060009*^9, 
  3.483299192520986*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#21", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-21]]", "Input"],

Cell[BoxData["3.7603586098010178`"], "Output",
 CellChangeTimes->{3.404735878942134*^9, 3.411511425367812*^9, 
  3.4115642330898123`*^9, 3.411565286886651*^9, 3.4115689938474617`*^9, 
  3.415473830899755*^9, 3.415505910247542*^9, 3.4155563942175827`*^9, 
  3.415640833142953*^9, 3.4598020191956*^9, 3.459872753918441*^9, 
  3.483295064119138*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "21"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", 
     RowBox[{"-", "0.5397856163100005`"}], "0", "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0.8271663496485162`", "0", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", 
     RowBox[{"-", "0.0845110693729886`"}], "0", "0", "0"},
    {"\<\"optic\"\>", "0", "0", 
     RowBox[{"-", "0.1314731820084057`"}], "0", "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.40473587896312*^9, 3.411511425391995*^9, 
  3.411564233111907*^9, 3.411565287153132*^9, 3.411568993868916*^9, 
  3.415473830984466*^9, 3.41550591029556*^9, 3.415556394288499*^9, 
  3.415640833164229*^9, 3.459802019213168*^9, 3.4598727539416533`*^9, 
  3.483295064167811*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 21\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "21"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278639551*^9, 3.3909800810556173`*^9, {3.3909808462756023`*^9, 
   3.390980853200426*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-1.8750505107100636`*^-19, 0.25, 
    0.10746319244930214`}, {-1.2815001713811932`*^-17, 
    0.09000000000000025, -0.311111455328734}}], 
   Line3DBox[{{1.8750505107100636`*^-19, -0.25, 0.10746319244930216`}, {
    1.2815001713811932`*^-17, -0.08999999999999975, -0.3111114553287338}}], 
   Line3DBox[{{-0.0030000000000000287`, 
    0.19999999999999996`, -0.5834868922775824}, {-0.003000000000000013, 
    0.059999999999999616`, -0.8601175973046765}}], 
   Line3DBox[{{-0.0029999999999999714`, -0.20000000000000007`, \
-0.5834868922775824}, {-0.002999999999999987, -0.06000000000000038, \
-0.860117597304677}}], 
   Line3DBox[{{0.0029999999999999714`, 
    0.19999999999999996`, -0.5834868922775824}, {0.002999999999999987, 
    0.059999999999999616`, -0.8601175973046765}}], 
   Line3DBox[{{
    0.0030000000000000287`, -0.20000000000000007`, -0.5834868922775824}, {
    0.003000000000000013, -0.06000000000000038, -0.860117597304677}}], 
   Line3DBox[{{-0.0030000000000000304`, 
    0.13999999999999885`, -0.6804147725073232}, {-0.0030000000000000642`, 
    0.17620000000000016`, -1.0098871394739939`}}], 
   Line3DBox[{{-0.0029999999999999697`, -0.14000000000000118`, \
-0.6804147725073209}, {-0.002999999999999936, -0.17619999999999983`, \
-1.0098871394739917`}}], 
   Line3DBox[{{0.0029999999999999697`, 
    0.13999999999999885`, -0.6804147725073232}, {0.002999999999999936, 
    0.17620000000000016`, -1.0098871394739939`}}], 
   Line3DBox[{{
    0.0030000000000000304`, -0.14000000000000118`, -0.6804147725073209}, {
    0.0030000000000000642`, -0.17619999999999983`, -1.0098871394739917`}}], 
   Line3DBox[{{-0.015000000000000062`, 
    0.1712000000000001, -1.0142351455494765`}, {-0.01500000000000006, 
    0.17120000000000007`, -1.0290510981185153`}}], 
   Line3DBox[{{-0.014999999999999937`, -0.17119999999999988`, \
-1.0142351455494742`}, {-0.014999999999999939`, -0.1711999999999999, \
-1.0290510981185133`}}], 
   Line3DBox[{{0.014999999999999937`, 
    0.17120000000000013`, -1.0142351455494765`}, {0.014999999999999939`, 
    0.1712000000000001, -1.0290510981185153`}}], 
   Line3DBox[{{
    0.015000000000000062`, -0.17119999999999985`, -1.0142351455494742`}, {
    0.01500000000000006, -0.17119999999999988`, -1.0290510981185133`}}], 
   Line3DBox[{{-0.01500000000000006, 
    0.17120000000000007`, -1.0290510981185153`}, {-0.014999999999999951`, 
    0.17120000000000002`, -1.5977513633866358`}}], 
   Line3DBox[{{-0.014999999999999939`, -0.1711999999999999, \
-1.0290510981185133`}, {-0.015000000000000048`, -0.17119999999999996`, \
-1.5977513633866334`}}], 
   Line3DBox[{{0.014999999999999939`, 
    0.1712000000000001, -1.0290510981185153`}, {0.015000000000000048`, 
    0.1712, -1.5977513633866358`}}], 
   Line3DBox[{{
    0.01500000000000006, -0.17119999999999988`, -1.0290510981185133`}, {
    0.014999999999999951`, -0.1712, -1.5977513633866334`}}], 
   Line3DBox[{{-0.014999999999999951`, 
    0.17120000000000002`, -1.5977513633866358`}, {-0.01499999999999995, 
    0.17119999999999996`, -1.6125673159966556`}}], 
   Line3DBox[{{-0.015000000000000048`, -0.17119999999999996`, \
-1.5977513633866334`}, {-0.01500000000000005, -0.17120000000000002`, \
-1.6125673159966534`}}], 
   Line3DBox[{{0.015000000000000048`, 0.1712, -1.5977513633866358`}, {
    0.01500000000000005, 0.17119999999999996`, -1.6125673159966556`}}], 
   Line3DBox[{{0.014999999999999951`, -0.1712, -1.5977513633866334`}, {
    0.01499999999999995, -0.17120000000000002`, -1.6125673159966534`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-1.8750505107100636`*^-19, 0.25, 0.10746319244930214`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    1.8750505107100636`*^-19, -0.25, 0.10746319244930216`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        1.150072002128038*^-15}, {0., -1.150072002128038*^-15, 1.}}, {0., 0., 
        0.}}], {{{1., 0., 2.8616940302870814`*^-33}, {0., 1., 
       0.}, {-2.8616940302870814`*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.423889079312437*^-16, 0.}, {1.423889079312437*^-16, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {-6.6453712110905*^-36, 
    2.5432896458539667`*^-16, -0.308042956017518}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.150072002128038*^-15}, {0., -1.150072002128038*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 2.8616940302870814`*^-33}, {0., 1., 
       0.}, {-2.8616940302870814`*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.423889079312437*^-16, 0.}, {1.423889079312437*^-16, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {-2.855768871107181*^-17, 
    0.19999999999999996`, -0.5834868922775824}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 1.150072002128038*^-15}, {0., -1.150072002128038*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 2.8616940302870814`*^-33}, {0., 1., 
       0.}, {-2.8616940302870814`*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -1.423889079312437*^-16, 0.}, {1.423889079312437*^-16, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    2.8557688711071895`*^-17, -0.20000000000000007`, -0.5834868922775824}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -4.356536656216574*^-15}, {0., 4.356536656216574*^-15, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 4.107416849518557*^-33}, {0., 1., 
       0.}, {-4.107416849518557*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.1528611500111375`*^-16, 0.}, {2.1528611500111375`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    6.301923921237361*^-36, -3.866477701868453*^-16, -0.8584330158010265}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.356536656216574*^-15}, {0., 4.356536656216574*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 4.107416849518557*^-33}, {0., 1., 
       0.}, {-4.107416849518557*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.1528611500111375`*^-16, 0.}, {2.1528611500111375`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {-3.052717576055681*^-17, 
    0.13999999999999885`, -0.6804147725073232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -4.356536656216574*^-15}, {0., 4.356536656216574*^-15, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 4.107416849518557*^-33}, {0., 1., 
       0.}, {-4.107416849518557*^-33, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.1528611500111375`*^-16, 0.}, {2.1528611500111375`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    3.052717576055714*^-17, -0.14000000000000118`, -0.6804147725073209}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 5.881319139599854*^-15}, {
        0., -5.881319139599854*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       1.1756225849842122`*^-34}, {0., 1., 0.}, {-1.1756225849842122`*^-34, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -3.649669233648108*^-16, 0.}, {
      3.649669233648108*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.944551028675744*^-37, 
    1.0218611859526419`*^-16, -1.0170974440312022`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., 7.054160639635967*^-15}, {
        0., -7.054160639635967*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       2.2509418800388914`*^-34}, {0., 1., 0.}, {-2.2509418800388914`*^-34, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 2.9737068439159124`*^-16, 
      0.}, {-2.9737068439159124`*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {3.164132037647033*^-38, -3.0582911162453433`*^-19, \
-1.6097050175149277`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872754285091*^9, 3.483295064628108*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#22", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-22]]", "Input"],

Cell[BoxData["5.099378599770439`"], "Output",
 CellChangeTimes->{3.404735879524032*^9, 3.411511425943492*^9, 
  3.41156423368186*^9, 3.4115652875076437`*^9, 3.411568994629903*^9, 
  3.415473831744793*^9, 3.4155059110519943`*^9, 3.415556395110395*^9, 
  3.4156408338648*^9, 3.45980201961406*^9, 3.459872754308331*^9, 
  3.4832950647534323`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "22"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", 
     RowBox[{"-", "0.09087144558893662`"}], "0", "0", "0", 
     RowBox[{"-", "0.9668633926886961`"}]},
    {"\<\"Mass U\"\>", "0", "0.08440829926711166`", "0", "0", "0", 
     "0.22220901900014436`"},
    {"\<\"Mass 2\"\>", "0", 
     RowBox[{"-", "0.0052103464531741`"}], "0", "0", "0", 
     RowBox[{"-", "0.011081677914951944`"}]},
    {"\<\"optic\"\>", "0", "0", "0", "0", "0", 
     RowBox[{"-", "0.01630928053033985`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735879550501*^9, 3.411511425960904*^9, 
  3.411564233705262*^9, 3.4115652877078743`*^9, 3.4115689946574497`*^9, 
  3.415473831825726*^9, 3.415505911104804*^9, 3.415556395195558*^9, 
  3.415640833899477*^9, 3.459802019630604*^9, 3.459872754334543*^9, 
  3.483295064800564*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 22\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "22"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278705916*^9, 3.390980083108987*^9, {3.390980859963587*^9, 
   3.390980863352069*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{8.318130434827789*^-20, 0.25, 0.024428098400189512`}, {
    5.6163012255151924`*^-18, 0.10708651419147376`, -0.401716105026214}}], 
   Line3DBox[{{-8.318130434827789*^-20, -0.25, -0.024428257766155165`}, \
{-5.5418057192338176`*^-18, -0.06955859016308862, -0.4363066688777294}}], 
   Line3DBox[{{-0.002999999999999987, 
    0.22641719206186386`, -0.4386967119514662}, {-0.0030000000000000057`, 
    0.042984256481635806`, -0.6973482946184639}}], 
   Line3DBox[{{-0.003000000000000013, -0.18882817582313005`, \
-0.3996380441427248}, {-0.0029999999999999944`, -0.07689725858616517, \
-0.692017033506062}}], 
   Line3DBox[{{0.003000000000000013, 
    0.22641719206186386`, -0.4386967119514662}, {0.0029999999999999944`, 
    0.042984256481635806`, -0.6973482946184639}}], 
   Line3DBox[{{
    0.002999999999999987, -0.18882817582313005`, -0.3996380441427248}, {
    0.0030000000000000057`, -0.07689725858616517, -0.692017033506062}}], 
   Line3DBox[{{-0.003000000000000014, 
    0.12304915401576566`, -0.6976669396490592}, {-0.0030000000000000703`, 
    0.1772256560895057, -1.0263988530475991`}}], 
   Line3DBox[{{-0.002999999999999986, -0.1570845847939991, \
-0.6944513834201796}, {-0.00299999999999993, -0.17517347839117864`, \
-1.0271798890676176`}}], 
   Line3DBox[{{0.002999999999999986, 
    0.12304915401576566`, -0.6976669396490592}, {0.00299999999999993, 
    0.1772256560895057, -1.0263988530475991`}}], 
   Line3DBox[{{
    0.003000000000000014, -0.1570845847939991, -0.6944513834201796}, {
    0.0030000000000000703`, -0.17517347839117864`, -1.0271798890676176`}}], 
   Line3DBox[{{-0.015000000000000067`, 
    0.1722353050025499, -1.0307579301129137`}, {-0.015000000000000067`, 
    0.17222573364731253`, -1.0456328752735118`}}], 
   Line3DBox[{{-0.014999999999999932`, -0.17016385403884143`, \
-1.0315168027952475`}, {-0.014999999999999932`, -0.17017426635268745`, \
-1.0463940410094221`}}], 
   Line3DBox[{{0.014999999999999932`, 
    0.17223530500254994`, -1.0307579301129137`}, {0.014999999999999932`, 
    0.17222573364731253`, -1.0456328752735118`}}], 
   Line3DBox[{{
    0.015000000000000067`, -0.1701638540388414, -1.0315168027952475`}, {
    0.015000000000000067`, -0.17017426635268745`, -1.0463940410094221`}}], 
   Line3DBox[{{-0.015000000000000067`, 
    0.17222573364731253`, -1.0456328752735118`}, {-0.01500000000000001, 
    0.17119802835347317`, -1.6234285700907494`}}], 
   Line3DBox[{{-0.014999999999999932`, -0.17017426635268745`, \
-1.0463940410094221`}, {-0.014999999999999989`, -0.1712019716465268, \
-1.6245431371891725`}}], 
   Line3DBox[{{0.014999999999999932`, 
    0.17222573364731253`, -1.0456328752735118`}, {0.014999999999999989`, 
    0.17119802835347317`, -1.6234285700907494`}}], 
   Line3DBox[{{
    0.015000000000000067`, -0.17017426635268745`, -1.0463940410094221`}, {
    0.01500000000000001, -0.1712019716465268, -1.6245431371891725`}}], 
   Line3DBox[{{-0.01500000000000001, 
    0.17119802835347317`, -1.6234285700907494`}, {-0.01500000000000001, 
    0.17119143396467787`, -1.6383035083962385`}}], 
   Line3DBox[{{-0.014999999999999989`, -0.1712019716465268, \
-1.6245431371891725`}, {-0.014999999999999989`, -0.17120674451939719`, \
-1.6394203659464477`}}], 
   Line3DBox[{{0.014999999999999989`, 
    0.17119802835347317`, -1.6234285700907494`}, {0.014999999999999989`, 
    0.17119143396467787`, -1.6383035083962385`}}], 
   Line3DBox[{{
    0.01500000000000001, -0.1712019716465268, -1.6245431371891725`}, {
    0.01500000000000001, -0.17120674451939719`, -1.6394203659464477`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    8.318130434827789*^-20, 0.25, 0.024428098400189512`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-8.318130434827789*^-20, -0.25, -0.024428257766155165`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.98136169085868, -0.19216979917508537`}, {0., 0.19216979917508537`, 
        0.98136169085868}}, {0., 0., 0.}}], {{{1., 0., 
       9.06084292559602*^-33}, {0., 1., 0.}, {-9.06084292559602*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.31668054742827*^-17, 
      0.}, {-6.31668054742827*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-2.5631126271852188`*^-36, 
    0.018174289117787325`, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.98136169085868, -0.19216979917508537`}, {0., 
        0.19216979917508537`, 0.98136169085868}}, {0., 0., 0.}}], {{{1., 0., 
       9.06084292559602*^-33}, {0., 1., 0.}, {-9.06084292559602*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.31668054742827*^-17, 
      0.}, {-6.31668054742827*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.298381608312496*^-17, 0.22641719206186386`, -0.4386967119514662}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.98136169085868, -0.19216979917508537`}, {0., 
        0.19216979917508537`, 0.98136169085868}}, {0., 0., 0.}}], {{{1., 0., 
       9.06084292559602*^-33}, {0., 1., 0.}, {-9.06084292559602*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 6.31668054742827*^-17, 
      0.}, {-6.31668054742827*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.2905461577076497`*^-17, -0.18882817582313005`, \
-0.3996380441427248}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9990126255650081, 0.04442717593668161}, {0., -0.04442717593668161, 
        0.9990126255650081}}, {0., 0., 0.}}], {{{1., 0., 
       7.681721649182574*^-33}, {0., 1., 0.}, {-7.681721649182574*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -9.212311385063793*^-17, 0.}, {
      9.212311385063793*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    9.273897156711236*^-36, -0.016881659853422333`, -0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9990126255650081, 0.04442717593668161}, {
        0., -0.04442717593668161, 0.9990126255650081}}, {0., 0., 0.}}], {{{1.,
        0., 7.681721649182574*^-33}, {0., 1., 0.}, {-7.681721649182574*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -9.212311385063793*^-17, 0.}, {
      9.212311385063793*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.3683863460923284`*^-17, 
    0.12304915401576566`, -0.6976669396490592}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9990126255650081, 0.04442717593668161}, {
        0., -0.04442717593668161, 0.9990126255650081}}, {0., 0., 0.}}], {{{1.,
        0., 7.681721649182574*^-33}, {0., 1., 0.}, {-7.681721649182574*^-33, 
       0., 1.}}, {0., 0., 0.}}], {{{1., -9.212311385063793*^-17, 0.}, {
      9.212311385063793*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.3708931180132851`*^-17, -0.1570845847939991, -0.6944513834201796}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9999975439292972, -0.002216333768497793}, {0., 0.002216333768497793,
         0.9999975439292972}}, {0., 0., 0.}}], {{{1., 0., 
       8.541299425838068*^-34}, {0., 1., 0.}, {-8.541299425838068*^-34, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -3.987390451726745*^-16, 0.}, {
      3.987390451726745*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-6.428738917458832*^-35, 
    0.00104206929063482, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9999946801520885, -0.003261850321873121}, {0., 0.003261850321873121,
         0.9999946801520885}}, {0., 0., 0.}}], {{{1., 0., 
       7.009494617369984*^-34}, {0., 1., 0.}, {-7.009494617369984*^-34, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -5.827982011373851*^-17, 0.}, {
      5.827982011373851*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    6.12310066354794*^-35, -0.00001699166658358796, -1.6359996539166088`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872754677397*^9, 3.483295065278685*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#23", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-23]]", "Input"],

Cell[BoxData["9.002271709544296`"], "Output",
 CellChangeTimes->{3.40473588005599*^9, 3.411511426481065*^9, 
  3.411564234214073*^9, 3.411565288142659*^9, 3.411568995513441*^9, 
  3.415473832521497*^9, 3.415505911943104*^9, 3.4155563960990057`*^9, 
  3.41564083447044*^9, 3.4598020201322308`*^9, 3.459872754733803*^9, 
  3.483295065339053*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "23"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", 
     RowBox[{"-", "0.0036632930750396236`"}], "0", "0", "0"},
    {"\<\"Mass U\"\>", "0", "0", "0.0649154361713474`", "0", "0", "0"},
    {"\<\"Mass 2\"\>", "0", "0", 
     RowBox[{"-", "0.7216808827013997`"}], "0", "0", "0"},
    {"\<\"optic\"\>", "0", "0", "0.6891656331926735`", "0", "0", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.404735880078897*^9, 3.411511426497704*^9, 
  3.4115642342379293`*^9, 3.411565288306719*^9, 3.411568995542378*^9, 
  3.4154738325882196`*^9, 3.415505911999284*^9, 3.415556396148232*^9, 
  3.415640834499475*^9, 3.459802020156146*^9, 3.459872754757243*^9, 
  3.48329506538835*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 23\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "23"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.3909112787725573`*^9, 3.39098008562107*^9, {3.390980251846231*^9, 
   3.390980257565917*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{2.5315397301851046`*^-18, 0.25, 0.0007292273765760945}, {
    1.73017664300786*^-16, 0.08999999999999997, -0.4183359199757262}}], 
   Line3DBox[{{-2.5315397301851046`*^-18, -0.25, 
    0.0007292273765762826}, {-1.73017664300786*^-16, -0.09000000000000002, \
-0.418335919975726}}], 
   Line3DBox[{{-0.0029999999999996163`, 
    0.19999999999999996`, -0.43215172555997927`}, {-0.0029999999999999393`, 
    0.05999999999999996, -0.7076674146092428}}], 
   Line3DBox[{{-0.003000000000000384, -0.20000000000000007`, \
-0.4321517255599795}, {-0.0030000000000000608`, -0.06000000000000003, \
-0.707667414609243}}], 
   Line3DBox[{{0.003000000000000384, 
    0.19999999999999996`, -0.43215172555997927`}, {0.0030000000000000608`, 
    0.059999999999999956`, -0.7076674146092428}}], 
   Line3DBox[{{
    0.0029999999999996163`, -0.20000000000000007`, -0.4321517255599795}, {
    0.0029999999999999393`, -0.06000000000000004, -0.707667414609243}}], 
   Line3DBox[{{-0.0029999999999998617`, 
    0.13999999999999974`, -0.5528086525682552}, {-0.003000000000000017, 
    0.17620000000000005`, -0.8824531768083105}}], 
   Line3DBox[{{-0.0030000000000001384`, -0.1400000000000003, \
-0.5528086525682552}, {-0.002999999999999983, -0.17619999999999994`, \
-0.8824531768083107}}], 
   Line3DBox[{{0.0030000000000001384`, 
    0.1399999999999997, -0.5528086525682552}, {0.002999999999999983, 
    0.17620000000000005`, -0.8824531768083105}}], 
   Line3DBox[{{
    0.0029999999999998617`, -0.14000000000000032`, -0.5528086525682552}, {
    0.003000000000000017, -0.17619999999999994`, -0.8824531768083107}}], 
   Line3DBox[{{-0.015000000000000015`, 
    0.17120000000000005`, -0.8868011828837931}, {-0.01500000000000001, 
    0.17120000000000005`, -0.9034842059299446}}], 
   Line3DBox[{{-0.014999999999999984`, -0.17119999999999994`, \
-0.8868011828837933}, {-0.014999999999999989`, -0.17119999999999994`, \
-0.9034842059299447}}], 
   Line3DBox[{{0.014999999999999984`, 
    0.17120000000000005`, -0.8868011828837931}, {0.014999999999999989`, 
    0.17120000000000005`, -0.9034842059299446}}], 
   Line3DBox[{{
    0.015000000000000015`, -0.17119999999999994`, -0.8868011828837933}, {
    0.01500000000000001, -0.17119999999999994`, -0.9034842059299447}}], 
   Line3DBox[{{-0.01500000000000001, 
    0.17120000000000005`, -0.9034842059299446}, {-0.01499999999999965, 
    0.17120000000000005`, -1.7600120559497379`}}], 
   Line3DBox[{{-0.014999999999999989`, -0.17119999999999994`, \
-0.9034842059299447}, {-0.015000000000000348`, -0.17119999999999994`, \
-1.7600120559497379`}}], 
   Line3DBox[{{0.014999999999999989`, 
    0.17120000000000005`, -0.9034842059299446}, {0.015000000000000348`, 
    0.1712, -1.7600120559497379`}}], 
   Line3DBox[{{
    0.01500000000000001, -0.17119999999999994`, -0.9034842059299447}, {
    0.01499999999999965, -0.1712, -1.7600120559497379`}}], 
   Line3DBox[{{-0.01499999999999965, 
    0.17120000000000005`, -1.7600120559497379`}, {-0.014999999999999644`, 
    0.17120000000000005`, -1.7766950790368703`}}], 
   Line3DBox[{{-0.015000000000000348`, -0.17119999999999994`, \
-1.7600120559497379`}, {-0.015000000000000355`, -0.17119999999999994`, \
-1.7766950790368703`}}], 
   Line3DBox[{{0.015000000000000348`, 0.1712, -1.7600120559497379`}, {
    0.015000000000000355`, 0.1712, -1.7766950790368703`}}], 
   Line3DBox[{{0.01499999999999965, -0.1712, -1.7600120559497379`}, {
    0.014999999999999644`, -0.1712, -1.7766950790368703`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    2.5315397301851046`*^-18, 0.25, 0.0007292273765760945}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-2.5315397301851046`*^-18, -0.25, 0.0007292273765762826}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 1., 
        9.359548768905257*^-16}, {0., -9.359548768905257*^-16, 1.}}, {0., 0., 
        0.}}], {{{1., 0., 1.2275288270190122`*^-31}, {0., 1., 
       0.}, {-1.2275288270190122`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      1.9224184922309555`*^-15, 0.}, {-1.9224184922309555`*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-8.407076095035997*^-36, -2.3972315396018248`*^-17, \
-0.4152674206645102}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 9.359548768905257*^-16}, {0., -9.359548768905257*^-16, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.2275288270190122`*^-31}, {0., 1., 
       0.}, {-1.2275288270190122`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      1.9224184922309555`*^-15, 0.}, {-1.9224184922309555`*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {3.8348217774228613`*^-16, 
    0.19999999999999996`, -0.43215172555997927`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., 9.359548768905257*^-16}, {0., -9.359548768905257*^-16, 
        1.}}, {0., 0., 0.}}], {{{1., 0., 1.2275288270190122`*^-31}, {0., 1., 
       0.}, {-1.2275288270190122`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      1.9224184922309555`*^-15, 0.}, {-1.9224184922309555`*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 
      0.}}], {-3.8348217774228623`*^-16, -0.20000000000000007`, \
-0.4321517255599795}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        1., -1.5743884423392152`*^-15}, {0., 1.5743884423392152`*^-15, 1.}}, {
        0., 0., 0.}}], {{{1., 0., 1.2151128339167992`*^-31}, {0., 1., 
       0.}, {-1.2151128339167992`*^-31, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      1.0087570096167365`*^-15, 0.}, {-1.0087570096167365`*^-15, 1., 0.}, {0.,
       0., 1.}}, {0., 0., 0.}}], {
    6.048736932758877*^-36, -4.023550798853669*^-17, -0.7059828331055926}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.5743884423392152`*^-15}, {0., 
        1.5743884423392152`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       1.2151128339167992`*^-31}, {0., 1., 0.}, {-1.2151128339167992`*^-31, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.0087570096167365`*^-15, 
      0.}, {-1.0087570096167365`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {1.383714381589905*^-16, 
    0.13999999999999974`, -0.5528086525682552}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 1., -1.5743884423392152`*^-15}, {0., 
        1.5743884423392152`*^-15, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       1.2151128339167992`*^-31}, {0., 1., 0.}, {-1.2151128339167992`*^-31, 
       0., 1.}}, {0., 0., 0.}}], {{{1., 1.0087570096167365`*^-15, 
      0.}, {-1.0087570096167365`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.3837143815899094`*^-16, -0.1400000000000003, \
-0.5528086525682552}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 1., -3.51118046098709*^-16}, {
        0., 3.51118046098709*^-16, 1.}}, {0., 0., 0.}}], {{{1., 0., 
       9.415131934891543*^-33}, {0., 1., 0.}, {-9.415131934891543*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -9.495942614722897*^-17, 0.}, {
      9.495942614722897*^-17, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.8878165028754715`*^-36, 5.3404126050258366`*^-17, -0.88966348136552}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        1., -2.978893075501496*^-16}, {0., 2.978893075501496*^-16, 1.}}, {0., 
        0., 0.}}], {{{1., 0., 9.186552153597365*^-33}, {0., 1., 
       0.}, {-9.186552153597365*^-33, 0., 1.}}, {0., 0., 0.}}], {{{1., 
      2.076318474326447*^-15, 0.}, {-2.076318474326447*^-15, 1., 0.}, {0., 0.,
       1.}}, {0., 0., 0.}}], {6.39571383041266*^-37, 
    2.606250693644517*^-17, -1.7738327805551435`}]},
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-1, 0, -0.25}]], "Output",
 CellChangeTimes->{3.459872755092718*^9, 3.483295065847999*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#24", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-24]]", "Input"],

Cell[BoxData["12.874339204336874`"], "Output",
 CellChangeTimes->{3.404735880665831*^9, 3.4115114270442533`*^9, 
  3.41156423479325*^9, 3.411565288660474*^9, 3.411568996318293*^9, 
  3.415473833343259*^9, 3.4155059127853613`*^9, 3.4155563971299467`*^9, 
  3.415640835212562*^9, 3.459802020535028*^9, 3.459872755115744*^9, 
  3.483295065972994*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pretty", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"e2ni", ".", 
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "24"}], "]"}], "]"}]}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "4"}]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
    {"\<\"Mass N\"\>", "0", "0", "0", "0", "0", "0.0005428212040812971`"},
    {"\<\"Mass U\"\>", "0", "0.0006931417513066855`", "0", "0", "0", 
     RowBox[{"-", "0.02544475289606192`"}]},
    {"\<\"Mass 2\"\>", "0", 
     RowBox[{"-", "0.0003658685423049888`"}], "0", "0", "0", 
     "0.7224073717236102`"},
    {"\<\"optic\"\>", "0", "0", "0", "0", "0", 
     RowBox[{"-", "0.6909987299862748`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4047358806918383`*^9, 3.4115114270595217`*^9, 
  3.411564234815374*^9, 3.4115652888763533`*^9, 3.411568996343701*^9, 
  3.415473833401903*^9, 3.4155059128373547`*^9, 3.415556397173423*^9, 
  3.415640835252317*^9, 3.4598020205519133`*^9, 3.459872755139184*^9, 
  3.4832950660210133`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoWithStatus", "[", 
  RowBox[{"\"\<Plotting stage 2 mode 24\>\"", ",", 
   RowBox[{"eigenplot", "[", 
    RowBox[{
     RowBox[{"eigenvectors2", "[", 
      RowBox[{"[", 
       RowBox[{"-", "24"}], "]"}], "]"}], ",", 
     RowBox[{"-", ".2"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "0", ",", 
       RowBox[{"-", ".25"}]}], "}"}], ",", " ", "floatmatrix2"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.390911278839479*^9, 3.390980088704258*^9, {3.3909808779401083`*^9, 
   3.390980881232645*^9}}],

Cell[BoxData[
 Graphics3DBox[{Point3DBox[{0.2, 0.5, 0}], Point3DBox[{0.2, -0.5, 0}], 
   Point3DBox[{-0.2, 0.5, 0}], Point3DBox[{-0.2, -0.5, 0}], 
   Point3DBox[{0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{0.2, -0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, 0.5, -1.8090229393459556`}], 
   Point3DBox[{-0.2, -0.5, -1.8090229393459556`}], 
   Line3DBox[{{-3.3740072818023717`*^-19, 
    0.25, -9.546635532814592*^-6}, {-2.3059511492920518`*^-17, 
    0.09000068599935923, -0.4190783493543054}}], 
   Line3DBox[{{3.3740072818023717`*^-19, -0.25, 9.387269567159042*^-6}, {
    2.3059682200194822`*^-17, -0.08999931293988325, -0.41905880779099686`}}], 
   Line3DBox[{{-0.003000000000000052, 
    0.20000069629310696`, -0.41898950327663764`}, {-0.0030000000000000642`, 
    0.05986916744389217, -0.6943789698450171}}], 
   Line3DBox[{{-0.002999999999999948, -0.19999935774701158`, \
-0.41946556131432416`}, {-0.002999999999999936, -0.06012927871438135, \
-0.6949896412787124}}], 
   Line3DBox[{{0.002999999999999948, 
    0.20000069629310696`, -0.41898950327663764`}, {0.002999999999999936, 
    0.059869167443892174`, -0.6943789698450171}}], 
   Line3DBox[{{
    0.003000000000000052, -0.19999935774701158`, -0.41946556131432416`}, {
    0.0030000000000000642`, -0.06012927871438134, -0.6949896412787124}}], 
   Line3DBox[{{-0.0030000000000001427`, 
    0.14000808944766868`, -0.7214739285073704}, {-0.0029999999999997225`, 
    0.17547542711321848`, -1.0522336369652636`}}], 
   Line3DBox[{{-0.0029999999999998574`, -0.14025417707682422`, \
-0.6706503628015843}, {-0.0030000000000002746`, -0.17325281011389929`, \
-1.001495322443917}}], 
   Line3DBox[{{0.0029999999999998574`, 
    0.1400080894476687, -0.7214739285073704}, {0.0030000000000002776`, 
    0.17547542711321848`, -1.0522336369652636`}}], 
   Line3DBox[{{
    0.0030000000000001427`, -0.1402541770768242, -0.6706503628015843}, {
    0.0029999999999997255`, -0.17325281011389929`, -1.001495322443917}}], 
   Line3DBox[{{-0.01499999999999973, 
    0.16990150064916018`, -1.0558164432125654`}, {-0.014999999999999734`, 
    0.17109019364979722`, -1.0704387798835395`}}], 
   Line3DBox[{{-0.015000000000000267`, -0.1689309296191858, \
-1.006517921952324}, {-0.015000000000000265`, -0.17130980635020276`, \
-1.0215881363993942`}}], 
   Line3DBox[{{0.015000000000000268`, 
    0.16990150064916013`, -1.0558164432125654`}, {0.015000000000000265`, 
    0.1710901936497972, -1.0704387798835395`}}], 
   Line3DBox[{{
    0.014999999999999732`, -0.16893092961918585`, -1.006517921952324}, {
    0.014999999999999734`, -0.1713098063502028, -1.0215881363993942`}}], 
   Line3DBox[{{-0.014999999999999734`, 
    0.17109019364979722`, -1.0704387798835395`}, {-0.015000000000000048`, 
    0.1710271090175633, -1.6006359637909746`}}], 
   Line3DBox[{{-0.015000000000000265`, -0.17130980635020276`, \
-1.0215881363993942`}, {-0.014999999999999951`, -0.1713728909824367, \
-1.6473357434889473`}}], 
   Line3DBox[{{0.015000000000000265`, 
    0.1710901936497972, -1.0704387798835395`}, {0.014999999999999951`, 
    0.1710271090175633, -1.6006359637909746`}}], 
   Line3DBox[{{
    0.014999999999999734`, -0.1713098063502028, -1.0215881363993942`}, {
    0.015000000000000048`, -0.1713728909824367, -1.6473357434889473`}}], 
   Line3DBox[{{-0.015000000000000048`, 
    0.1710271090175633, -1.6006359637909746`}, {-0.015000000000000053`, 
    0.1699618588120313, -1.6152501074542642`}}], 
   Line3DBox[{{-0.014999999999999951`, -0.1713728909824367, \
-1.6473357434889473`}, {-0.014999999999999946`, -0.16917356417746343`, \
-1.6624192167710246`}}], 
   Line3DBox[{{0.014999999999999951`, 
    0.1710271090175633, -1.6006359637909746`}, {0.014999999999999946`, 
    0.1699618588120313, -1.6152501074542642`}}], 
   Line3DBox[{{
    0.015000000000000048`, -0.1713728909824367, -1.6473357434889473`}, {
    0.015000000000000053`, -0.16917356417746343`, -1.6624192167710246`}}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
      0}}], {-3.3740072818023717`*^-19, 0.25, -9.546635532814592*^-6}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1, 0, 
        0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0,
        1}}, {0, 0, 0}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], {
    3.3740072818023717`*^-19, -0.25, 9.387269567159042*^-6}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9999999941069028, 0.00010856424060299955`}, {
        0., -0.00010856424060299955`, 0.9999999941069028}}, {0., 0., 
        0.}}], {{{1., 0., 6.599112141349043*^-32}, {0., 1., 
       0.}, {-6.599112141349043*^-32, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.5621774424944575`*^-16, 0.}, {2.5621774424944575`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {-1.3940783906629972`*^-36, 
    1.019659035503839*^-6, -0.41600007927951815`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999999941069028, 0.00010856424060299955`}, {
        0., -0.00010856424060299955`, 0.9999999941069028}}, {0., 0., 
        0.}}], {{{1., 0., 6.599112141349043*^-32}, {0., 1., 
       0.}, {-6.599112141349043*^-32, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.5621774424944575`*^-16, 0.}, {2.5621774424944575`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {-5.213407591727602*^-17, 
    0.20000069629310696`, -0.41898950327663764`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999999941069028, 0.00010856424060299955`}, {
        0., -0.00010856424060299955`, 0.9999999941069028}}, {0., 0., 
        0.}}], {{{1., 0., 6.599112141349043*^-32}, {0., 1., 
       0.}, {-6.599112141349043*^-32, 0., 1.}}, {0., 0., 0.}}], {{{
      1., -2.5621774424944575`*^-16, 0.}, {2.5621774424944575`*^-16, 1., 
      0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    5.213425546749086*^-17, -0.19999935774701158`, -0.41946556131432416`}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[{
        Polygon3DBox[{{-0.065, 0.25, -0.042}, {-0.065, 0.25, 0.042}, {0.065, 
         0.25, 0.042}, {0.065, 0.25, -0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {0.065, -0.25, -0.042}, {
         0.065, -0.25, 0.042}, {-0.065, -0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, 0.042}, {0.065, -0.25, 0.042}, {0.065, 
         0.25, 0.042}, {-0.065, 0.25, 0.042}}], 
        Polygon3DBox[{{-0.065, -0.25, -0.042}, {-0.065, 0.25, -0.042}, {0.065,
          0.25, -0.042}, {0.065, -0.25, -0.042}}]}, {{{1., 0., 0.}, {0., 
        0.9999870513189459, -0.00508892861412744}, {0., 0.00508892861412744, 
        0.9999870513189459}}, {0., 0., 0.}}], {{{1., 0., 
       5.886594769252226*^-32}, {0., 1., 0.}, {-5.886594769252226*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -1.0686981815348002`*^-15, 0.}, {
      1.0686981815348002`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.3282214067331134`*^-35, -0.0001386283502613371, \
-0.6929997458713232}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999870513189459, -0.00508892861412744}, {0., 
        0.00508892861412744, 0.9999870513189459}}, {0., 0., 0.}}], {{{1., 0., 
       5.886594769252226*^-32}, {0., 1., 0.}, {-5.886594769252226*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -1.0686981815348002`*^-15, 0.}, {
      1.0686981815348002`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {-1.429168175048219*^-16, 
    0.14000808944766868`, -0.7214739285073704}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       CuboidBox[{-0.015, -0.015, -0.015}, {0.015, 0.015, 0.015}], {{{1., 0., 
        0.}, {0., 0.9999870513189459, -0.00508892861412744}, {0., 
        0.00508892861412744, 0.9999870513189459}}, {0., 0., 0.}}], {{{1., 0., 
       5.886594769252226*^-32}, {0., 1., 0.}, {-5.886594769252226*^-32, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -1.0686981815348002`*^-15, 0.}, {
      1.0686981815348002`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    1.4288350717493172`*^-16, -0.14025417707682422`, -0.6706503628015843}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 0.9895806958771787, 
        0.14397932611051795`}, {0., -0.14397932611051795`, 
        0.9895806958771787}}, {0., 0., 0.}}], {{{1., 0., 
       6.20060544458111*^-33}, {0., 1., 0.}, {-6.20060544458111*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., 1.5828587390612146`*^-15, 
      0.}, {-1.5828587390612146`*^-15, 1., 0.}, {0., 0., 1.}}, {0., 0., 
      0.}}], {1.4014570893323455`*^-34, 
    0.00007317370846099777, -1.0339996579058}], 
   GeometricTransformation3DBox[
    GeometricTransformation3DBox[
     GeometricTransformation3DBox[
      GeometricTransformation3DBox[
       GeometricTransformation3DBox[{
         Polygon3DBox[{{0.16167960777017612`, 0.05253288904374107, -0.1}, {
          0.16167960777017612`, 0.05253288904374107, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.13753288904374109`, 0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, 0.09992349288972044, -0.1}, {
          0.13753288904374109`, 0.09992349288972044, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.09992349288972044, 0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, 0.13753288904374109`, -0.1}, {
          0.09992349288972044, 0.13753288904374109`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, 0.1}, {
          0.05253288904374107, 0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, 0.16167960777017612`, -0.1}, {
           0.05253288904374107, 0.16167960777017612`, 0.1}, {0, 0.17, 0.1}, {
           0, 0.17, -0.1}}], 
         Polygon3DBox[{{0, 0.17, -0.1}, {0, 0.17, 0.1}, {-0.05253288904374107,
            0.16167960777017612`, 0.1}, {-0.05253288904374107, 
           0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, 
          0.16167960777017612`, -0.1}, {-0.05253288904374107, 
          0.16167960777017612`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.09992349288972044, 
          0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, 
          0.13753288904374109`, -0.1}, {-0.09992349288972044, 
          0.13753288904374109`, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.13753288904374109`, 
          0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, 
          0.09992349288972044, -0.1}, {-0.13753288904374109`, 
          0.09992349288972044, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, 0.1}, {-0.16167960777017612`, 
          0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, 
           0.05253288904374107, -0.1}, {-0.16167960777017612`, 
           0.05253288904374107, 0.1}, {-0.17, 0, 0.1}, {-0.17, 0, -0.1}}], 
         Polygon3DBox[{{-0.17, 0, -0.1}, {-0.17, 0, 
            0.1}, {-0.16167960777017612`, -0.05253288904374107, 
           0.1}, {-0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{-0.16167960777017612`, -0.05253288904374107, -0.1}, \
{-0.16167960777017612`, -0.05253288904374107, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{-0.13753288904374109`, -0.09992349288972044, -0.1}, \
{-0.13753288904374109`, -0.09992349288972044, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{-0.09992349288972044, -0.13753288904374109`, -0.1}, \
{-0.09992349288972044, -0.13753288904374109`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, 
          0.1}, {-0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{-0.05253288904374107, -0.16167960777017612`, -0.1}, \
{-0.05253288904374107, -0.16167960777017612`, 0.1}, {0, -0.17, 0.1}, {
           0, -0.17, -0.1}}], 
         Polygon3DBox[{{0, -0.17, -0.1}, {0, -0.17, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, 0.1}, {
           0.05253288904374107, -0.16167960777017612`, -0.1}}], 
         Polygon3DBox[{{0.05253288904374107, -0.16167960777017612`, -0.1}, {
          0.05253288904374107, -0.16167960777017612`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.09992349288972044, -0.13753288904374109`, -0.1}}], 
         Polygon3DBox[{{0.09992349288972044, -0.13753288904374109`, -0.1}, {
          0.09992349288972044, -0.13753288904374109`, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.13753288904374109`, -0.09992349288972044, -0.1}}], 
         Polygon3DBox[{{0.13753288904374109`, -0.09992349288972044, -0.1}, {
          0.13753288904374109`, -0.09992349288972044, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, 0.1}, {
          0.16167960777017612`, -0.05253288904374107, -0.1}}], 
         Polygon3DBox[{{0.16167960777017612`, -0.05253288904374107, -0.1}, {
           0.16167960777017612`, -0.05253288904374107, 0.1}, {0.17, 0, 0.1}, {
           0.17, 0, -0.1}}], 
         Polygon3DBox[{{0.17, 0, -0.1}, {0.17, 0, 0.1}, {0.16167960777017612`,
            0.05253288904374107, 0.1}, {0.16167960777017612`, 
           0.05253288904374107, -0.1}}]}, {{{0, 0, 1}, {0, 1, 0}, {-1, 0, 
         0}}, {0, 0, 0}}], {{{1., 0., 0.}, {0., 
        0.9904656045253936, -0.13776024917278087`}, {0., 0.13776024917278087`,
         0.9904656045253936}}, {0., 0., 0.}}], {{{1., 0., 
       6.210601220835582*^-33}, {0., 1., 0.}, {-6.210601220835582*^-33, 0., 
       1.}}, {0., 0., 0.}}], {{{1., -3.160856295896381*^-16, 0.}, {
      3.160856295896381*^-16, 1., 0.}, {0., 0., 1.}}, {0., 0., 0.}}], {
    3.9768493025333295`*^-35, -1.636347656293961*^-7, -1.6359996539166088`}]},
  
  PlotRange->{{-0.30000000000000004`, 0.30000000000000004`}, {-0.5, 
    0.5}, {-1.9090229393459557`, 0}},
  ViewPoint->{-3, 0, -0.25}]], "Output",
 CellChangeTimes->{3.4598727554898243`*^9, 3.48329506649977*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Structure displacement to optic displacement transfer function plots\
\>", "Subsection",
 CellChangeTimes->{{3.4832946459177637`*^9, 3.483294660590148*^9}, {
  3.483294746950395*^9, 3.4832947527030478`*^9}, {3.4832998646976233`*^9, 
  3.483299885122538*^9}}],

Cell[CellGroupData[{

Cell["x", "Subsubsection"],

Cell[CellGroupData[{

Cell["x to x", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportxinput,opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746633154*^9, 3.478377746644853*^9}, {
   3.478377780747471*^9, 3.4783777807927094`*^9}, 3.478439358850165*^9, 
   3.47843940462948*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c41f8Xt4lEZmZaUqHMr5UjihIlJJVQskoSslJJpZSRyAiFRISUEZJz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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466778520212*^9, 3.478439485430641*^9, 
  3.478527704184457*^9, 3.483295071105425*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to y", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportxinput,opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746662045*^9, 3.4783777466787443`*^9}, {
   3.478377780860149*^9, 3.478377780914689*^9}, 3.478439359606676*^9, 
   3.4784394055404*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWHc81t8XR0WiQkYpK5LxPJ5JeHAbRkMljW+RhIYkKcoIUUIlMiOUSvYm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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466783632835*^9, 3.478439490391252*^9, 
  3.4785277101240463`*^9, 3.48329507767308*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to z", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportxinput,opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746687168*^9, 3.478377746696575*^9}, {
   3.478377780965199*^9, 3.478377781010839*^9}, 3.478439360191482*^9, 
   3.478439406294216*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c8le8bx7MrDXskq6FwOAvHKDcySlQoSUWiSJKQlSJKqRApK1EZWZmJ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466788320264*^9, 3.478439493669572*^9, 
  3.4785277151841373`*^9, 3.483295083231571*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportxinput,opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746713162*^9, 3.4783777467310867`*^9}, {
   3.478377781058949*^9, 3.478377781110216*^9}, 3.478439360686646*^9, 
   3.4784394068681717`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWHc8ld8fR6JUsoWGEWW7z/NcQjlIRBGKVFZFtlQKRWlJZZRsGZWQMrPJ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -30.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4784394972174683`*^9, 3.478527719623373*^9, 
  3.48329508814959*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmnc41+/3x6WkhKRoyCj7PcyElEMos0GDRGiojJI0JDtUtopKslc+CNm8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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -22.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.478439407136755*^9, 3.478439418355668*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmnc41+/3x6WkhKRoyCj7PcyElEMos0GDRGiojJI0JDtUtopKslc+CNm8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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -22.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.478439497336631*^9, 3.478527719737*^9, 
  3.4832950882681723`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportxinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774674713*^9, 3.478377746763092*^9}, {
   3.478377781159789*^9, 3.478377781209103*^9}, 3.478439361147902*^9, 
   3.47843942300064*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8Fe4XtguhRERGFBKiUkY5kiINo0IqfKNBkpAVUUkqpZBNVpQtVOa5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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466797325183*^9, 3.478439500542678*^9, 
  3.478527723713172*^9, 3.4832950926164083`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportxinput,opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746779937*^9, 3.478377746797263*^9}, {
   3.478377781260631*^9, 3.478377781310965*^9}, 3.478439361575379*^9, 
   3.478439438896866*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWnc81e8XR1JSUlFamiJ3X+uiPCgjKZL1laiMkFDJKtmlRJEWSSSyyZY8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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466802132057*^9, 3.47843950471726*^9, 
  3.478527728953517*^9, 3.483295098354396*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y", "Subsection"],

Cell[CellGroupData[{

Cell["y to x", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyinput,opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746813946*^9, 3.478377746830666*^9}, {
   3.478377781359817*^9, 3.478377781410695*^9}, 3.478439362013962*^9, 
   3.478439439616886*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81d8bR8qWRLJXX/Ne7rCVE8muEJKKMgohSUklo2FlZCYNJJWVvXOO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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246680707001*^9, 3.478439509128048*^9, 
  3.478527734701577*^9, 3.483295104710516*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to y", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyinput,opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746847114*^9, 3.478377746863484*^9}, {
   3.478377781461542*^9, 3.478377781510157*^9}, 3.4784393624750443`*^9, 
   3.478439440235651*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c81d8bt/ee2aOBjMy+RXmQlVFSJCmKUioUKlIyKpWRKEX2imSTfT5G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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466810917551*^9, 3.478439513159577*^9, 
  3.478527739226475*^9, 3.4832951102153177`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to z", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyinput,opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746880033*^9, 3.478377746897133*^9}, {
   3.478377781560615*^9, 3.478377781610815*^9}, 3.4784393629588757`*^9, 
   3.4784394407419643`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fx9EOUWaSqIy7uMaVBgeJQiUNQkmpUMk3EhoUSouMCNlS9hbC
eZOQ7D2z97xamn7n95fH83E/znnv83pLnb1qfJ6Lg4Pj3HIOjv//fX9aqm9p
aQ5Htb3QumurANu/swydF+fwY0NJUVcbBbj/VL9gen4OS+LyFoeLCqBf5BjY
OTCHubmnlyzPK0DDxgq97PdzeOySuZi6lQJ8brHLuPBgDi+4eOosmCrAL/2c
u7Xr5rD8xbnHevsVQGmH3vbwzbP4iJKHfrCMAmjg9X2xG6bxjuBddr7d8sCI
fh1pTJ3EI0E33Q8FyENATIJPsME4lrATpFvoykOQsf64rs4o5g22irkxwwAX
iwLDKMth/P27IneePwNOJ0udsTMZxvKv/DfxP2OAzq+HjqzDw7h0lY6mrS8D
+F+YhX3SGMbObA4QfcyAN82/x35sHsZXLB7bXvZiQIe+hqdRzxB+OP2zZ9iZ
AWo73xdwnhzCw/eMxXnNGfBTqFbG2ngQ399ceBW2MODMmr5Hx/UHcYvOjoCO
zQyo+jM/q6s9iAdWc+rMbWLAiyHBtxSlQSz5zfaAqCg5L9NCb279IK7SWOdt
ys8AZ8Ppi26NA3hb8e9pXw4GfL3HnfjMaADbj9OqC/voYOG8mffe/gH8ffqh
VmQvHcptFf5z1BzA4jrVze7ddAgyOrrzBHMAK76T3qHeTgdlifCPm/gH8M0H
lq7RdXS4VkCdTKjvxxnLKt4uL6bD/NwBWvGhfqx5IP+9xAs6FPFfVdip14/r
E+51Dj+nwwPFIOVc1I8vDHinvwmkg4Tj592pzH68lvXQm+JHB4Pv1wwjNvTj
oSO/WHz36XDw547uXyl9+OPy7VrnHelQuKHH8mbRZ+zeYnmR25AOR47J2Dim
fsZ7kqaybx2gw/hzB4dLkZ9xbsRSx6QuHYQ2rrhr7vEZR97me1CsRQeHLfKx
u3U+49SgQKvdO+ggQ/cY/v2pF0seCpryk6JD4L7ttre6e/CQ26dKvS80SEjZ
1KrwqQc/+z2i8WeOBoUCAlpDhT3Yz/+hRPI0DQYHODfqh/Vg7ajpoh8jNGDe
6asSOdmD76v69RzooEFdXphcdls3PhfhW1r4jny/OSDoQkU3zl/xr2tNPg2+
ez3kEMvrxttCAhOO5NBg81GXDo/n3XhiY1B1dQoNLs8d9zl0rBuPJ+scsIyg
wRq59eMTjV24y9v07MwtGoj7rT4WUdqFczvpUrku5P7vS9goswvHCRR/vuZE
A9Py2ZC3z7rw/qAAx/pLxJ8zNXreh7vww1W8livNaKAT+uC1ZG0nvjX3V0Je
hXzP4S7QUtSJRUcOWakqkPsvOrs/SOnEm9fnsBWoNAhknTeZfdyJbcWtzL5t
If40aq8q0u/EZVovqovW0sB97b8LJlUd+Oq+4LsVPVQwq9kkIFnQgS+enYjk
a6eCiu9OPJ7YgTMD/73f20iFyfXXRdwed+DoxJGddh+ocGLjdOXLQx3YnEPs
z4sUKih2r3E6jzowvfpb/rYEKvBEyErKMzswd/3pywFRVCiVPOeC13dgu49X
1osEUIEu1yU32NKO70/9Y724ToVVkz9akj6047CFQ/Ob7akwmCx01zGvHVdU
5izcvECFEIUjnctftOOi/Inc/BNU4NpR9VDWvB2v1i7xXFChQu/iCGveoB3z
a+LnizQq5BcuG8zf047Nh6qtS7dS4YoG2qUv0Y4fU1UFHvNRoWNf3uTlgTas
Euto5DhCgexVLcGspjb8r/1a0IouCvh+ZGv/K2vDFqHVj2h1FNh7kBHuF9+G
Y7eoBK/NpYAEn4Ge6fM2bKKlu5D8mgKLDTZfJO+34aNhddMZoRRIOxZvkHWx
DYvV6P6KuEmBh8JlP9xM23BBmH/ZyUsUsO7oi9t7oA1zi4V8kDCjgEbY38M8
u9qwzN/LTR/1KLDRYtOfFmob7o1vuq2gQoGvm3e+idjUhk/vcDXduIUCdX0n
jl3gacP95zK7tFZTIDHGiUPhbytOj+radWhODrzOBaT8mGnFzmH7ysqb5cBS
OsMUPrfidS+Fpv/kyMGusdrlD+tb8fTBvbXLAuRAMHEq4wi0YsE84SAbWzmY
s1tzSiyzFWcrLbGb1OSgmi67ZiimFZstnknl+SML8bM6uckBrfjuIl+2XpIs
uGectXLybMVU9i+mGU0WzK558Ko7teLMG3FffL9KA0slsmDF+VYcqm8Sd+OJ
DPB/f3e+7ngrrnRUvu93XBam3nauD9Ftxad4JDpuv5OFCtcfxZY7WvHNtPir
b5dkIWa3kJ2cXCv2L5qtLVKSg1t/lYTZoq24hqm9/YC5HJzARmUFa1rxUsvA
XMUtOVC8a29/71cLDjYr/E8hVA74n/S9C5lqwZklIqcPZsrBbLDRmtSeFnxw
/Om0V4Uc1MSUniirbcGyDkO85zvlIClFKb69pAXfkHuafGJSDnzexrGn01uw
W5br2sSfcnCxTBBxxbTgcT5nz9BVFNCt9X4iEtCCo93/e2AqSIHtHd876Z4t
mCXhs8QjSQGuoYuy2k4teLM0xLVRKTAw0+Fkcr4Fzzo+i68n+YXFA2WXT7Rg
7yz+fl4NCkQue8d3T68Fm11eXhmnS4Fb6+inQtRasNOi/ZqYQxQw3xiRlEJp
weJ3I8UETlBAVMF9Xzt3C9a0vRVy7xwFvu+cD5j+04wtCq5OBdhSoFXHqp9z
thk7m+AjGlcpkHO4iSHS14yDr5+LeuxEgQCzvTfpDc1YTLBpwMOVAg7nc6q0
Spvx0/Jut213KHDYQVrYJKsZf5J9t8PlHgV47q/KvBvUjA0umnXvf0SByWcu
/4K9m3HAvm8CNU8p8DF8wiDFuRlf+KLH4PenwJsEs9DSi8045u7BRZEgCtzP
/DTaZtqMQxV0OEaDST8U7VGZPtCMd2hN+N8i/bO3MvUu5+5mzO56W9obToGt
TRL1wvRm7BO//z/uSApw9PqJ0zc349r2paOroinweYzDTmtdM94Qs+lLUwwF
ihf+e3tiqQlXLezIvBpHgZd/B5dfnm/C7RbWtZ/jKeC2+pjx3YEmbOBcc14q
gQKmAh+igpuacBqDz02N9PMOCdWZ5PdN+PjzPTPb31BAmPJ6V2lOE379K/zB
GOGvyqI+ba+a8Ko31EWPRAo0aTxsnQpuwvy2o61swpkHfm3l9GnCRoHD0buS
KPDs2CUHYdcmvJam+d6csL1lTzHNrgmnRjf4HydsaHeQW8u8Cd/zqDWUI0y7
XmJ6wrAJC9WqSLaQ89Z6KCRcUm/CPG+lt58kPP4o+ouHfBN+Dpyn3hJ7Kp6v
1wre0oRFgu68myX2v4q+55vM34RNHH3Fl4h/XslfuoGzCTdPSBwYf0WBs3nW
lLaFRrx7tuJbIomHZmmr89RQI/Zar1G2l8RrS41uOUdrI/7olaeWS+L5r+3t
euGKRlwvxF/7N4oCPQNylrS3jfhBa2+3OMlH4XRoiuabRuy/WyVx/UsKhP5Y
++t4aCN+2mpk2U3y6cJ1S+/So0ZsdJiT1zWEAid4Z4I8bjbiCwnv4yZIPaiI
nh58frkRqwUlfaMFUGDDtnqF5FONGN2ZyNLwo0C9WmZ1K2rEMjMO1+t9KEC1
rb+ZoNCIlb8Z/PnlReopdIZ+Y0sjvp27Ye+oB+mvj9yf9fgascfqra6+tyiw
5xfFT3SpAe8cptycv0GBF9T9mhOzDVilaKJqtSMFvphdYBd8bsBH1aVcm69Q
IOld7FHzkgbMu/r29ytnKbByGpbT0xrwui8XjitbUMBKvC/3T0QDtrscxht8
nAJFhn8v1D5twELCihv8SH+K3t4kGnm7Af/aUmQpTOa5Y+rOj/ZXGvDuC2sb
tiIyv3tN3NCpBuwSc3ooUZUC3hpBPf17GvCHnLn737ZRoN8+62kmvQELZzv5
hm8k9kc1aNwTb8Byhy5S7qyjQEj97JwxTwPGVc/QfS4KjCxt1NZbrMfHMi+s
e/FNDl6eORE/3l6PlfiEW/zH5MC4NGDlo7f1uHez+o8DHXKwZmu9DS2kHnd9
eGD7pFIO4B73pxrnenzqt1encK4c3BjSY9ifqMfH7Zz/BETLgbyOlx+faj3e
m9yT+PShHAzHAztDqB43Ne+0trkqB+Er/h41/laHbRlHPDWPkPsu7Mz70lKH
9z1YDCxlyMHqyuuiz3PqsEV0ZP1HLjnAslluqkF12E9oj0x4jSw4+8z2tDvW
4aZ7URFpnrLAmKAi16N1WPfqxZ/fBWVh+MDFGDHlOnx4+PQaVyUZCEuKW1a0
oQ6fpX7TqFSRgSPc/edPLdRiKen9qyM3ysLqy+JV/xprcUFxn6TQY1koqTGl
RmfW4sMRbTdb2mThOuP5Ey3/WnxznmNbL58c0H0bZwcdavHKxODiLHU5GJrl
PeJlVItVeRsYG6zlIOywfrY0sxar3RyqEPeWA6OM+0KVfLUYpVm2ycTKwar1
72/YzNUQPc9YLlAkByX/LXWuqa/BG6KsBtzJ++vUtHtPcloNjj3zKrd/XA4G
A3M4Zq/UYNbmDoFyks/Qr/Nn/Q7WYJUbX0yKyftudJzxgcmowbxp6Q9jFMg8
E0546Dj9CV/SDniWYkgBpxuDU4I1n7DVucy0lUQ/UDskDuUlf8I2Y+hlzgVS
36EhG37afcJ1nJIGhmR+H/rV7BSm/wkfvJpXYPSQAivM+dt3Uz9hdZVmkb5A
ClwTfxh+Z6Ia8/8dky0h8+NglNv25TbVOMv7ztdDn8j7kLtsVcOBaix2lbp3
uokCbZ+eTITTqvGYdMzFw0QvnVmMTFOe+4hbxn48chwn9h15r3bO+SNOoh3a
eouLCgUXDTcpmH7EV1Zx7QpcTYV/t1v//tr5EZe/eqPtuY4KPkljZQF/q/By
39iIrxup8HIZz8Eyrypc9vVK414FKgxsfK7ge6EKawosZesTvSfDlNhgtr8K
s7yO/VDZSYUMC2Y7m7sKi7x3Pv9Wmwrvc49ZSQVW4uww8b2PjxH9ejHiukdM
BeY9KbBrpRMVFO7ImBp6VuAYUxvelzeo4BSUvkv0fAUOmQl33XKT2AelS+ly
FXjanC92/i4VNoiNPuxL/4Ctj3yp/OBLBRPm1cvJ/h9wbQ5Losmf2Ku7eOiG
4wfs92h/dF0Qsc9xrSDfjg940clue2gYFXbWyEdqlJRjs25vU7dXVLgz+NZj
bXQ5/jV28ei6N1QoW9Q813a3HOtpZm4JSqKCofRROft95fi27ljl9XQqnLlz
Iyui5j1e7d296nk+FV4FcTy3TXuPNawljN8VEv+SHt5gPXuPTfZwWbcUEX/a
w/fUHn2PL/4ny+gDEl8mVPzpKsNoXdY/0yoqVPrHOaDCMny8ZdfWPdVUWPnl
vti90DIsw8enzF9DBc/cg/arTMswdVBF5nE9sU9YUVR/RxkeMi9coUT2AQ4X
wbInwmXYpXqu5mMT8WdXt9CG1lJ8q7R48lMrFYrDS/CxnFJc4OAprUr2iT9/
YmxDAkvx1+dy/P4dVHDFNsXixqXY/t2TF6LdRK9LGl60VCzFLe3bl3TIPvL9
rsL6WP5SXNy38bVVL/FH57u1bD3g8AqZbZf6qJD9qnOdXRrgAw1rY0z6qbCw
sjg/5SlgSoZvtvIAFZg20WfnLgM+n/J0+xLhqx89eZQMAVd0iRYUDFIhjXox
j6xd+NrOHYrnhqgw/Vj/zNu1gK8Yxuj9Jnyiy1zwazPGw0znzLvDVGh+udXG
NQDjE08nN38nbGQ58e6fEca8r8dZpiNUqJPK4PPiw5jLPSf8NWGDYedza+pK
8Bu6++QQ4aoE9be+T0qwwMOJXJ5RKujaLucWNCjBNM27D6UIv6d9Oh26pgRr
xLLG/8+as/5ZElXF+Ni+AgNewiUZpivj7xfjqbHqbf8/b4/jFjPKvmJs0eLa
Gku4gDWamrasGNN+Hi40IKy6mMKpUlaE4zaf2tJL7M0pdDxe4FGEL1dr6pwg
rHh7V6IGKsLXJNgn84i/aYjz7/u/77Adh/fdPyQ+dK4qowNF77Cq4cdqWcKJ
5b7xdW7vsEltpNIOEk+ZB8cXj+58h3eL7o2hkPjHHxA37PxRiI9wGIz//UwF
KZ6hqNN5hZhb2R6ySP4i6xK/DDkVYv7i+Qpdkl9xfwc9W+VCfPLuZ7f8LiqE
Ht0RPssuwOojeTtXdlIhqKNc+6d9ATZ6yP9MntTThvDHwXcYBTiQmyWyopkK
fqeMJ5dN5+PmFsad9Aayb0pu1HiYlI9f+VTvoNVR4dFgn/8623y8PXD/9euf
qLD6VcJIoGw+fjNWsfkxqX/vi1d2bhx9iz8KypbbkH3WY/pX/7Zzb3H+wAqb
yyWk/9NKVRKl3uIrhTUOD0l/3fzPx0e+Pw+fDCyxtcijwqLy4Z7syDzMKF1+
qi+TCs7fhZg7T+Xh2U2yvtypVPiS3+NZsikPp3ZuMul8TQWHm3Hte7tyMVXd
9C+KpcIlDkX3Qya52HVwTiftOTlvVMd0pUgu5shmGGEyX7xqTRVL2nLwYvFq
8z0PqMCfc3mtc3AOFnQsnhBwJ/MmzGOIcSIHR6S671F0poLc3aCiEaEc/CvR
/frNyyTfF988j2jNxsL35B1brEg9HSqyP/48GysF66qLkP25RqVBj/d4NvYt
s60XOkAF003Dkh8Es7HB3pDp57uoMMy5+PNWSxZmH5m6bEgl9o9zN6sEEc77
ztsmQoW/dVtSpo9m4Yog76VkMt8f5Sp7xwtk4UZafiH/JNHLL/VOWzRnYlXp
hemZGgrE3jPfIRiYiSc1hcYDiH6Vt73KX2OciR32ohi520Q/Hvac8NyQiYcN
9LeaaJN9SjWkbHdTBjbpMMPrZuSgSTw5/It/Bm6NERC6cILss8uwU/KRDLzV
QFi1yEQapiaaDp5bn4F3Kn5f9t8lst9F1x5UjU3Hz69HfrFbQ/Sb/belV1Lp
uNWeZr2J7ENbdm/OEopJw4LPDa/IpFNAbfU+a2/JNBzLtDpGGyPvb+tl4W9R
qdia98iaM8JUsIkNqrLekoqzDBPkniFSL1eL3FoiU7DAmdw4W2sqvNgzTNeR
SMGd/rn05fepkLmGpy87IhmbLeNekiTzfjDOfG/gyySstsw1co70wy8Hz29c
4kn47VTf1tOLVBDQSH59LTwRv31/70vXehrodPziNg57gx8le6t1atPgFU9Y
C/+LBFx9Y5dGXgwNSjpL73uIJOBI2rbwzAIatCVMqM0Hv8JVXvs+iDfRYKXW
zoj65/HYK4R5ln8FHSTWWR1GQvH4JXXrrLAkHXZ0+3CmB8Vh9a956wP20MHo
TUa2hGAcDnJZJzBnRgeb6x3nfQNj8bqTFjb4Jh08tDlE/22IxcaHtb/WRNEh
lE+u+kpADGanfN6mUUWHrJ7Dt3rXx+D0AJv+7u90qE68IX/QPxrL9P+4/Uae
AYPOUf1F/NHYpkbU2vw6A7498JU+KRmFj3qu1t7SwQCZrZ8fqm2JxO6UPc8j
POXhRBFjVkQiAvssfPgeKMOE+yduG/8Qf4n5a/Q/nDwpD2/na/LaNoVj2/LI
v/21DLIPiW/KEwvDfJqhxS/cGCAqfdn9+cZQ3E0NNTJADDiA3w05ib7ADjQn
X/31DHA7yb3/mEgIXiYZtjV3ig5JX8xSlIWDscSWO06jn+jQ/TSJX0DoOZZc
HW+nm0GHOy2WN3SlgzDvlGe6RSgdJDcJfXZlBeJjUqHMUC86lFlV66TuC8CM
U5SLvv/RwfqNe3L/cX+cN7B4c8KSDivnVDYIXniGKRtHxOwOk3hfamH7Tvvi
repucr2IDh3eiU8sGI/xv68SK/9spYO4gKDZ+4MP8Y+NLR02QnQ4E31Hlmr/
APcX5IvqrabDROHRsh9pnti38/6/5XM0+Nb3e07aygXvVD8fkVlCgzu/Gh59
iXHCHM1izJIsUg9CCdKlgw74UVTRppIEGsgHReflV53FLdsu/LT2Jd8HPO94
HXQC35hSfs2+SwOvhdd8rpYaeHbKNm7PdRqIKVwZybE6gcwyJ9rqzWhw6yyP
Oko/iyzVdC58M6SBHePsqniGHTqINq0I1KBB/MDKOtXnTkhD2K21ZQsNxCsV
lW2PuaAz3CPh6nw0CEyxeBEucAtdr+L+Gv+XCqW7TypyfLyLvBWjfya0UeFW
2uy50DeeqL/7PGcR0S9qUl7BSj7eyGyIV7SA6KWvgRs/frr4ADm17eHZROZl
xsr039Z6D9FuwffWNAcqXHbVkf8n8xjlXtMUGzhIBdnpzjMhK58ih3vxzFfS
pB9PXw1kjvoi1kjhiravZL+04RoaPvsM1TxMVwvLowB968Fbmcb+aEig9T+L
MxR41B0idEc7ACWkvYo42SQH40GDafpKgcjDvyLGa0QGdA8x9otsDUK7Vs0h
1XA5iF/lMjC0/jmSvBxVuEmHAlylZW4ZnMGoT1jCbCSW6GU3XsHb7GC0S+H6
D/ERCpQom6YeGAhBZkXNzetFyfs4E6sr3PgCPf2T6uilRQW3hJm+QQhFaSdq
Q1zIvOmwVHNNzwhDJ95Ne+TeI+/9Rs8Nt6LDkdBW00OnI8j72VSbvP/ZS6T+
X+o1tVyijx6L7hPyiED+Off+1RO9Z7Tv3OeBq5FI/IPo0GPyXqf+S72RZhmF
UBP7T8E8FVZY3PIplo1GULk+LJiTBjn5Uq1xUdFIQPXUmSNkPm24dtnewS8G
+d/u8vrCoEFp3fp3J1bFIk9bo0mB3TRwoL1dpe4ei66cyTB9oEeDumHOmDVX
49B6ieSTqadpECyk0SDIjkNOl5vtrOxocFrXbWmLYzwySzes9iP1NvN64ZTq
jVdIfjpg9vEjcn+H/FOtn6/Q5Mbq1fZBpP7WXCoyvJmAQg2qIr9E0IDn0pDY
OffX6IP+QOaKDBq0hG/Rt+d8g3ZwXfgvMp8GL2vMXV093yDO89vsvgANaPIt
7X4PEtGe/U6Cww000GeXBxX5JaOVkouDerPEv62c5ZXrU1CJEmpjfKNBl7H6
l6bAFBRK7emZ/E0D25zcIxMhqUj4MiVpgfSjz42EdcLR6Wg7bRvjshQdhv7t
Ld/RkYmkPFY6qx+kg67IoLn6xiw0lWOlfcSYzBsFjy/aZllo76GvEkdM6HDt
TNHWQz1ZyPzeiWYRKzpwlancte7PRsoPzUKbHOkg5S2t4T+ei4wez01eDaaD
V8T71mBKHlrwkvF4EEaH8VyrKy/t8pBk3auxgEg6ZIxGvHw9nYdOVqidv59A
B839wr+L59+il5zrR8dy6WDJvSp/crEADT71pFY30SEhn/twOKsQ5R7Wfs/V
RofZ8/yjBtcKUceWp6PKnWT+wUbB1KlC5KQmdNijjw4vr9Mdrn5+hxZdv/0s
J/Ozo++I3Nf3xeisWpqI0DIGSD49geM5StCtkS6foRUMuLjL/MRx9RLkFLZt
S8pqBnwPsvbKyytBUcp5K+nrGCCof6PfJREj+T2lWeOiDJAzO1RzpxLQT+M9
hucYDKjJaBBpHwHUKJJX163AAIdVR88pLC9FG8KXbA4rMeBtjsmvPs1StMLi
3ga5HQzQ5bOS0yosRT0Z5tbRmgywLnf0WpZahoJWRx3JNWZAjHzoHp+AciRY
c+t5vCMD9HeVgm12ORpIFHIrIO/T130TOgYt5ajSe1XixxsM2H9q58F1wh/Q
XcmvP7pvMmD+ceepoNAPyGZw+6cqTwZoTmx0j46uQPwCepsqAhgw+VVr2b3S
CnRyTP2gfxADgjjsHpwbrEAX2pMWTYLJeyVS6CezvRLlOhdBeygDnumaRae8
rkQd28wZMdEM6I8LK81Pq0KrRNWizVMZ8Ci9bF9YfRVSu4TDP6cxQOXd5Meb
81Wo1NeL71QGA3yadjVpKH1EC1x+Jw2zGcDk7B4sz/2IKM8UtL/mM6CLZ9nF
hLaP6Oa/kE/GhQzwEqVNPfjxEVU0WBalvGNAh8LNL/o7q1HOyZtVxiUM8Di9
aXljUTXqeZjKvPieAVS7vT5ZvdUo7yvXy+hyBrRcv8QT9K8aicQaHm39QPL1
9J2gieYn1Dc4EsSsYkDDO3Pp3vefkEbH2pHUGgZs2fhSd6K6Bv34t18FtzCg
LGCzj+JUDXo0M1ib0ErywxP10ZW7Fomsvvn4YRsDkpZiDNca1iLW9jhTTaIP
VEZfG9NqaxFbf9uta90MaLOkBDnO1CKTemEXpR4GuHYmtb7jrUOec2vOzBAu
qUk1NTxUh2QpIq1HP5P8ZWefvlJfhwLD5x0H+0l+6Kzo3Lk6dPbbBrbLAAOe
JuQN/OWrR03/TYmuHWRAU2iBta9RPdLLT9onPsSA6wK7E9oc6lEls1QtgrDo
06IxCf96tHbvTJboMANOeWC79MZ61ALzIkuEOX5ppvxg1yN31u552xEGNO4c
+L5lTQOy0wul1hOO/R4jorOxAZ0UiC2WH2WAU/ZZNRtKA7qB56N8CO9z2Hby
yc4GpGUmXNVDWJgx7JpxoAEZvYqk08ZI/UzEh7WcbEDOLLlyR8IFCeffLdo2
IM9wc+88wo/OyfSIuzWgjGXfL3whbCE59kfzUQMKKGiwpI4zgNH7evP5sAbk
WDZxwZzwv1Absj81oMrTto73CTecoFimFjagkv1wK5lwjMCke2N1Awq+9MSt
mvC1hqTob10N6LZOrfUQYZ2nl0o3TjUgCdSn/J2wkD59UP03uU/mST/XBANG
V85wneVuRP4cStZrCOe/T912f1MjCnyUnv9/fuhhr5NEa0Q3xOM7lhE2U1c4
X7e7EZnnXsc/yHn0X3PeCwaNyOKZve0I4b95GQnCFo1IeveX5hrCdY7/Ve66
3Iii3O78TSUcxVQaP32rEV2XZY/4EHaYWVjt+YScf6LM9xRh7aRsyuuXjajp
ON9vGmGBi076n1LIeduXFL6SeA1vY12aK2pEJb6rWf+PZ17/t8cCtY1ocFZI
8BphU7MbteYzjWhJ2iSkneSHIqI26/63EekNlFreJfyreXFdPG8TeiSeaSBN
OOKgm9E0owktq21abUHyb79293/8GoSzFGTmSL1oVv72VznUhA4OSXDeJjyo
ebv5ln0Tqn7/t/chqbfpWJGcx7eb0OMd+cwNhL8vzwoKe9KEbodmjQeTeuX+
OHo8P6kJNZWsGg8m9axyxKjjy2gT4g5p577TxwCN7Ml8ru9N6A+cUP/+/34Q
8g5dv6IZ8Y+I218lfKqzwExhWzP62zrCsO1lgM3uY7s1lJrRzcHxc9Okn65F
zG46qNWMzlX0/7xO+NaSzx9zo2bk9bd5bBXh+1bbeu0sm1GB/ua78aQ/n70v
Lna1b0ZaXYo+hwiHSZtG+txuRglS9XprCMc/WLgT8qQZ+Tsfzu7oYkD6xBPL
hPBmxLXP4Fkp4UIDWc3cJHJ/lnrqR8LlqaWS5QWEP4hQFwnX8VlwNlc1o/PR
LzuPk/M6/vs+MNDejDokUypmCA82PyubH21Gg39kZmqJfdMsWtzSt2Z0UfS9
5mri7/eQD57rVrSgbANDSk7f//vV0nqzYAt6PD6eP0/it9bilw59WwvymZxf
N07yIVgSJL1bqQXta9TPayH1IiGpsFJfqwVJUbrurZ0l+b/3cdTUqAVdvRO/
sOIbif/wucqLli3oduLWhz7/SPx1/712tm9BBf3LjBu55WH/mxc+3rdb0PRe
l7yNW+TBeK2ybdCTFuRiMKjRskceLC7XHogLb0ERHXtGEq7Kw4W6i9SspBZ0
MC4+J69bHhyYXNylBS1oNt31yFgGE9wCXk7VV5H7VqnZnzeWB6+vqjWf21tQ
5MUzAWb6DPA90ZgyM0rsc+wdnRGkw4v8S0//fGtB9o1frlrb0yBObKU994pW
9PnYwBfdo3RIuxV9SEywFXUfF01ikX0v//MuBcq2VmR2N0HwZgXZdzRb+dSU
WlG5BitioZcONbFX53W1WpGs2/StyWk6tC1f23jcqBV5Vumvzyb7YP+F+Exr
y1aUobJRZO1fOkxWaQQ42reif4pnr7E5yD5I7bx273Yr4i1J7FtN9APHU8ej
/k9akS23qU0+4bVzvCrR4a0oRvzjBV3CgkfeCKYntSIf0YzyIU6Sj2ztb8UF
rUjv5TZ69hId5IR6W2uqWhH1pe212j90ULpxI6+7vRU9e3Xoos5POuzpXB8y
OUp+b2pL3v6NDnq7U278/NaK1q16M+08TwfjCF3T1SvakPRVxzxNom8slvrV
RATb0AStf4X3CB0c3gv9UlFqQ1Xxj/6700GHv0tcN3y029ABqTMujxvo8GjP
/Jdu4zZkPbD2GruSDqKuvQ4K59qQQ2px/OsSOrzKrZ6559iGjHeah8bmEPsW
3tq1ebahDAP6h+ZEOoD8qzFKUBtyWa61mkL0XNdr94GGnDbUH11W1+9J9vPh
y6e3f2hDY9FWW1Zcp8M3SbPuG61taLrzU36tNR3undIz/TTShprl5FqWkXzy
h6m0SnxvQxcvqzefIftmRJuU8bWV7ejncNynBxQ6UAX46j8ItyM4JHb8Nz/J
9+E/Bhtl25GA3880HqJ/9z2ZqLq8ox25pKSpl7TQoKmqbR/otaNt3oyFx2k0
OLOivEzAtB3NzOmM/3An+l0rE120aUcr9ijccNGhgdudyKJCl3akc1iz0HyB
CqvfPd657mE7KrjivXf4ChWe/3DJswptRxaT6gVvOCmwVeWCcm5iO9ryVC+1
ah3Z7xyOZqwubEdXFR+bXC6ngnqqJsOiuh3tHZYYcZalQfUEIym9qx2d6m2o
Gr5EA1OZTbLLptpRu//H/arRNBg5uzr+xO92JDFfpehbTYNrUd8kk7g7kIja
mVcbid7n6BmM+LupA52zWWuZw0OHp6INYkfoHSgXH6x+IksHsePFIfF7OtCW
hzkCV0n8XvsnCS4adqCPtfbeU8fooFIX4m9wqgMdfnaj4ZIN6Y+13uuirnQg
5tX9cciNDof1rj1euN2B6nm83eMf0aHH03K1rm8Hur/6cn11KB3swNA7NLID
tc2xjDpfE32/U9ZdE3egUk+97zKldNjgLPgnsL4DaXb56jyvoUNUFqfrWF8H
omx/p2TYTgf63Oy3XfMdSIvjIpgN0KGQ1nPNl6MTrZIZC66dJPVt83FugL8T
DRRm2qd/oUNLfN5lllQnkuntPbWG9MfcZv8LPVqdiPerAP9ebjLfze4MKRh3
onKqxjv5DaT/Qi6d8TzbiXpUZfyTiD4PaTbtbbvWiVDcFsVCCQZs59c1o3p2
IhdFOYcz2xmQZajcfjuwE/VmfrOOojAAPZQ81hjXiQYvL9i7yBM9/4G3cXtO
JwpNSNw1TfS7Gdfvgy7lnWjuiQL8UmXAmMZ49aeWTvT+zgGNuF1EH91s1dsy
0okq+I4rDaszgCu/rPzat07kcIbnwDui7/2+pmtVrOhCvLsuG0jvZYC4YkTJ
RuEupLJKfrnEPqInrzzafUWmC634Q90crcuAHUk38kG1C3H7Oi/E65H3ZdSa
JajXRerP1HT7fqKfqmjXjE90Ib7CuzxihI2SFtKene9CKeLSgz7ke+EnBVN1
Tl1odFbhhzU5r/eKhxyvVxfy5tgxG6VD3rfDeucNArtQrULDMTltBtgprot9
GNuF1keJtY9rEH0u0Pq5MrML5R5LpVQS/75/Dd+0srQL/eDy8o1lMaCo7ayp
TkMXWpxOKjxC9p17+ZTn9/q6EP9MeXOULHm/w+YbYbYLha5v/6lH4s936+26
pb9dqPz3kNMsyVfbqTsG6rzdKF7EtVuI7F8v0T6fm+LdaLwz6yfPVzqcleL5
UEDrRvNcnVV1n8m8XNbMubirG0ndv6fz4T3Z/4ZDNVT1u5FWRbji/mg65FSc
uel0shupDXOEnL1KB7c3svlZNt3opOLMnJgMHbQezX6dv9GNjN/M2EMsDVZf
zlVUeNCNJJWSzh+KpkDdwVv2V4K7UUqkkdychxIEKexNTn7Vje4HpHbwkP4x
W792fCKnG4kmcSneKKOD5JeG7XLl3SgjuVT7sDDRjy0hVheau5HXi+0VlywY
kJJ3OjJ+sBslZzz56xfGAMcX0t2D7G4keOLT2FwzA3a5TYtIcfagUr91xnFr
5YHDIvuYJX8PEnux3k9LUx6ebNGq65bvQeG6s92/U8n7y7maW0yjB2Vsqxa8
NCEPokN1eqYHe9B9+JEsS1OAz+XPvYItetC/zH2MmBsK8CrBorTlUg+ye6uv
VdOuAJd9tv3bcLMH9Zuf/TOoyAQlu8ldRx71oFO3q9d8r2fCokHmDb/QHpSm
3jEf+YQJJQyXnNo3PUjBcu+PHfJM8OJDbO78HvT+tya/KQcT9Nkr5PUrexC/
c7dL1wcF4G+usfNp60HJnqoyQeEK0J4T+LpipAeVizJtlW4qQGSw2fDybz3o
hZ0z64SVAli7SEntXd6LdrfL3+MzVACq2fipuwK9qAL/TJPdpQDzu9PD8NZe
lHy0qLGeqgB5m53b/yr2IlHBXbdvbFYg+m6P4B6tXhT1eVE8b70CaA8sO+Jm
1Iss0ekM9VUKsOZ99dN8y140Wv42oOmvPDTE+1d/t+9FV4UNd+l+k4fg+6ar
WHd6UWhXb7rjjDxs1R/1yHzZiz5pHdv0qE8exmmpxXPJvahyVPK6bqc8pPE6
/WK860VGcreQVbM87GrkdErq7EVvMrkX3ark4ajp5otxwp+R2VOBms258iDM
fsb1XPozcr7nWJqRIQ8dD5dH3lf5jLbca9tmmiIPp99Ntdgaf0ZryyP2N8bJ
g41EoTbT9zO6r7Vnxd8AeaC+ZXyWiviMXn0zeY195WHmcIyrQMpntN6+q9zl
kTxcu+uT8f3jZ+S2fXTF+7vycGv4hETxij5UdZX7hx3RYxq3qwvSBPvQpbWW
E4F28sAprHE8elsf2nWG71TEeXm4ryf9xFOrD0l4lBzXNSd6r/+F7HWjPnSv
urm/77g8cLvyvL9g2Ye2b9g8c9BIHp4lffl54HYfErOwmg3VIfW49+Lz3U/6
0O1iEz8HDXkQ6uliMsL70JqhnT941OQhjLfsIn9BHzo9ImPkTSV6MYG1jKuq
D2X8zj9vsk0etqDEyC9tfYivbe+l7k3yEO/wrLXtax+6e/NBdx/Rn9nL76kN
c/Yjj3XKtUeWyYNg4+6Vp9b0IwmHk7dMfzGg3TY95pBoP/p1x+PoH7K/qKna
Xq3c0o84PQOl7hE9Hca1TV1Tth8Z/us+d6WR7JfhwR2Kqv3IzcNzlUIBA4ov
GiUkqfcjPh/rtd3JRJ+prHXatq8fmYuGbQuOYIAHR7nWS8N+JHOEsgv5MmCg
5jaf0LF+FChfU556m+xnoTt6n5r3o1sGXSbpl8g8Pc9OWnmuHy1daRVbbsqA
FUrJLu52/egRZcz9JJmvF/5Z6y7+14/Cv5aKalMZUFktIfifaz/iWf3WRo6P
AXIhHQMTHv3ooT7cViP67tG5gPSzPv0oSHjpwA7ynk4pGN7u9utHoYtVp5Ri
6GD4Z4XBsZB+5PWLSq+7RPRwFRatjSTnw+/m69J04HvuOrovoR8pZ8xn0kto
4GClnFOS2o9EFC9fEV+kQhNj5u6O3H50IuLFPUFNKij/SjicUdSPZg/pG5++
R4OgijObKeX9aEdn+MMzHHT4HiA2FfOpH2GBcNbkYTqYWLbkizX3I51JMpqJ
Xsin+d4P7OpHm65rXM14S/TIot4xnsF+FPfnx7fdRH/fLOfc6j3Rj3rzlt9a
SfS1xL9h9Wh2P7o8U1KZLsYA2FF18t1P8v/1cW9uqTDg3H/J19s4BxCrl//h
HgMGrEz29WevGUDV0h7H71oyIHH4v1SeDQOI/6uAQ+5/DDCUOP5RVmwA3c5V
iZa7x4A5E7UR7a0DyImluVHUnwEB/ps4T1MHkDudMyU7kgGsT//EXZUGkKnK
CS0pkv+O5YNqQbsG0He125rueQxw0/hwLF17AL05qKU1CgzY7PLGoVp/AHUI
KOyzqyb2Zj5+MmI8gCy+OEdsIvP87JT9Gw7zATTJ/eL5KrLfrZA2Lt90bgBZ
58MXNbL/vjnN6le9NIDq/5w+mU/2M4MXon+OOA6gZVbLnjwh+9ls42+RKzcH
UNO3K8mFX8h+yt2n7OM5gOK3KZ3UXWSA8r6yw3GPB1CIy7NmxT/k/bzz6lJJ
4ABKbd2y8s4SA1zyfR50hg+gwq6AZ1Quedi0cCnua9wAirpyqpy1XB5KaIcx
X8oAEor7+eLlCnmwOq/UTc0ZQK57JYLNVsrD8iihH/uKBtD1zsAsW8KvOxY3
WJUPoNgDz6TLyPf6G3rkb9UMIHa/u6wZOW/GAOuHtAygnNH3EdLkvmfesRey
egbQyNO/SULEHiXsfa92eAA5JiaIif5mQOuiTeT49ADSK3cOE/5O7FUyLFz2
bQC5FL9J/TbHALHLCm0Sf4k/2U67A0l8il9tWNi5YhCJn1/3qJzsv2f6vvEe
5x1E73XlzY62MmDZxk6Kg9AgSpb6++pnFQMSjIv2Pd48iGK+/6CZFzLgwJMo
qwTpQbQxdSf6/Ybs1x/u3S5lDKJ9/xwXaEFEjy2dD+1hDaLZhF8x827E3p0H
cn+oD6L8kUGnCnMGtFyjN27QHUT+JQHKiqQeb6TwzTAODSLFOyPtiWR/Extd
WH3gxCB6yTkg4Un2o6ItbdutTw8i2DxszrWDDpYnCzTdLwyidUObi9d+ogJX
4EuLMPtBZHCNipIHafCqxt0l13kQPRhVC7tP9Mv+leeCGu4MIid/tfPP1zJg
EulmTN0fRJfbDm1qPM6Ap66UmpV+gwhbvTjf9Yzos2yecamQQbTK9fjF3lIG
NE3PLVOPGkR12vs1uKcZcF2meYvp60Hk1nb8s9Z6ohfO5O12TCfxurCVlakk
D+9CQ0183xL7ffdHyhwh71HzLcdEPIja35+zU75C5rHu3uS++kGEnuamxkXJ
g56HTOWv9kGktKVbOjhPHiYL1gwJ9Q8im9DKRf0aeVBgNIgZzg8i5Q8DgoFf
5cF+Z3Rwz49B5KE6oyOzUgHS9jlsuLI0iD4m6ujwiigA/TT/Wt91Q+jI8Q+i
AjvI++9n9LOePoQe8+ZVafynALbhktfPqAwhValjn97fUYA3r+fn53cPIfvL
MR9nHiuALDwbX28whIxO6z7XfaUA29kN7Udth5B2Yfk1nxYFOPc3+uiwwxD6
a1Um+LZPAWLX/Ffv5DKEHH6c3ZA8qQBSW9dXPn8whFItG4xnlhRA4uiRvPZX
QyjkBu9HbkEmiOY2BpkPDqGtuDZTTY0JJqUx/NMTQ2jUXDDCbg8Tgmv/e3KL
PUT2fRvvx5pMEBpd7xXBMYzSd/s3h+9nwgYRY8c+iWGU1CT6asmECUe2bZ27
KjOM+hz3zWSZM+GZwoIdh/ww+k0XjzaxZALf/oCzUurDyNZrQsT5AhN4XJuO
nDMfRtfjYROPExMMvGNrv5wdRk8NryUcvsGER/7XDnjZDaMJo7PN3m5MWJO0
QeuV6zBSOGh+odqDCSu7jZljIcPI+4DsVC7Rc/vGtqbciBpGly/e3vTMj+i5
Lwuyq1+T8zzNdpwKYMIynsAtlLxhtL7+pUBDCBM41JvXXWoZRneydbBwLBPu
5tV0RPQMI5UkFcfCeCZwMStiG4aHkcTOfp5Dr8n/bytQVf02jLysDWR1Usj5
L7M4bP8Oo5nqOaWENCYsF06pDl8xgrJ0r+z8kUHsWxN1mlN4BMUZHPhnncuE
B/deyKlIjKCuNZo8d98yYfUf/4ULMiMIiclnPypgwto5r/s1qiMouM1m5fli
Jjy2uWO0pDGCuv3cc1UwidfgDTElvRH0UduKcx6YwNtqlxZiMoKcU/qmZcqZ
4HvI2qXacgTpfXaRifnAhHVVp7T/XhxBczrr5JdXMsFPy4SH6TCCJg4fkT5c
xQT+d0ZtZ11G0MY51413PzLBX0U/+rnHCIrat5IztJrkN22vXZXPCBLx1St4
/okJgbLqKr+fjSDFw67LnGuYIBij+o8ROoKO+/rcVatlwnMxZtWZmBF06ZhM
Vjdh4SBKQGDiCGpesJk+VUfqiXebRUXmCKqsDzUrJizyQFzmZ8EIGosV+vqD
8AsO4Xla2Qja0SXjzE30uqgbX+Hp6hH03vmu+Tfye+iX1V7+TeT8k5ubsgiL
XeE6VN41guz8V6drEg4f/S3yY3AE7cfpluHkfvEz3wYoUyMozfxLewmx92Xn
bLLFlxGk6Uu9lUD82Xx0/Lrfb/L9wekVB4m/kWT2ly0bRW4KnGdTSHwkdLvX
fOMeRSeVnb2LK5gQhVuaZQVH0UWTFFUXEm/JnXURZuKjqM7WvKKplAkxWZUX
n24fRX5H92WVljBhK71UEeijaECKj7LjHRPiXhX+XlAZRfvp/lZbSf63b8n5
IK0+ijS4b2baZzHh1YtUP9N9o2jzoyJtrlQmyGx4ffLxwVEkNFWmVJTAhITH
0dtKjo8i02TT0v+imCC7Imxm/tQoql/BMTcRzIQ3dwLfbrswio66R51qI/0g
t/jk7gn7UXRNgXtjJemXxP/uGzx0HkX3k+sogteYQJ1yFyq6M4qKbeZfZpD+
TLZ27Zu9P4rWZtNryvWYQP98LVHKbxQdedcwFy7DhFSTy47HQkbRoa0WI49G
FEC+8bz6g6hRpB/+rYK9XAHS9S1XFb4eRdhGKXR0RB6Y5aaN0+mjqOPH8PfK
WQXIUDcO35I/inj6PQ9tZTFB8a3BeWMYRT0FziVFp5mQxdyn4F01isqajvpF
3CH7W5LGz7cNo8jcwzCt+AUTsrepvZ/sGEXbv6px8aUzQSVC8enmgVEU6JlW
mVTGBOVrd1dSJ0bR2YXRPexm8v96je6q7FHUp3fWLnOI3Ccu9VP75ygKcf10
Vm2BCUy2w7XDnGPI3LXXuGSJCQoVMGW+Zgzpr//gcIVHEeTD+c/brB9DW/RX
7b0gSlK5L8PkrtQYmip9cChYXhFoYhyNTylj6MWm/W8X1BSBOndYP0xxDA3z
ME6NaCuCXOjcnmytMVTVp+FacFwRts/Ibx2xGkPBew/H/7uhCNvK7oSzbcfQ
jpDrxv/cFWFrSJ3gv//GUNPnxK6aB4ogqWW/SuTeGHL7ERcyHKwI4s9Tp/fH
jqGzhuc3H8pWBAF1+tuUwTHEsTNNrHxUETZsuMUsmBxDLpyet2unFYF/7FPi
h4UxVDr2qOH9giKs87/08jPXONKZUHrm9k8R1o4k3eXfNo5+fz7ktV1ICbie
Ugydzo0jpruwzARSgoUemYHdw+Po04zNs86nSuDrda6weGoclSREVEkHKAGF
Hh2IvoyjzX9C+C4HK8GZmxt193JNoNQF9wNjkUpQt5EnWV9yAslJXEgJT1eC
xBNsp5MWE0hk478VAg3k+4Z3q2+0TKC5XUMGNbzKUPfeiJlVPomkYytTLrgr
Q3JHnklbzSQCx2uy/J7K4DMj7v6rZRJ1bIhpy7uvDNoiE7XaI5PoquGb2d9P
lSHP7u6l5hVTiPORaOn5l8oQuT4r4avuFPq9Qfdwcb4y2FsKbN7xcYrMi4I9
0XPKwPu7dU1R7TSyLFpM5DBRgfuDcv7HW6eR88uX2qMnVYCj+qboXM80umYh
yqy2UIGFF1KyW6en0V+FCe6nZ1WgQ/WKjs/aGVQko9X874oKxF9b7n5MbwYd
i3MoCfBSgd2TSl+nYQbZ6D+ycs5QgZxG75v3q2aQuJHAc+lsFZAv6OCSbJhB
DeN8w025KiDpc2f90b4ZtCjPTJF9pwIrZarlC/7OkHn//Vj+BxVosrKy9d41
i24dlNMz7VIB206/z5tzZlGjXOKWkBUsOCO+U8j/3Sxqni4qrlzFAlPLQYPl
72fR2l0OjqvWsmD/iErBZOMsau+Y3Ry1jgUy7M7At3Oz6Jt6WPSCCAsGV28/
cIQ2h+p/JM4GUllgoZaf7RU7h465z3vkH2LBsZtWkz8S55D2uaHoSSMWGJSs
lbqUOYfCL4gnix1lwS6dU75HYA79pzhs5WTCAlEjLluJz3PosNtPP94zLJhU
luHr4ZlHz8cNzzU4sOC1gUP59f3zKFa9gcf8GQvK4zrvexjOI507vWvOBbCg
/7f2gcdG8yiqgZd+MYgFYilCddGm8+i40Zngcy9Y8ITnXfsnm3n075lpNzWa
BQ61K6akHs4ja65K27408rv01VT603nUcuBrQFQGCxJvd1zd4T+Pvp7qOW2W
RfxlJH81DJ1H0oc4zXAuC477Gv27kTiPDDx4p7SLWHBttADupc6j3yVVqKWY
Bb4a2zyfZs6jZGW3FZaYBVWz31bFFZDznDvlzpQR/w+Hr6/7OI966v4ocVex
4MTr5S0dteT3bLb72Y8scFy6EjzUOI+mXgv7ZFazICVdc9PPznmU8ufVW1Yt
OW9VUu+yz/PoU2K1oV0dC0YsBaLXDc6jhzrrXJ7Xs0CCf3T79sl5dHvpmEZd
I7nP5vCY/Ow8snBib+tuYoEJ5CfuXJhH79wlVXqbWfDM4bH84V/zSGMin4Zb
WZBa9XX+5L95Mh/vy0e2saBa8nS2NRcbOZx64u/QzoJljUw1t7Vs1CLhbzbT
wQJJStgvr3VshNPmw4I7WbDn7rJivw1slPQ7eZbZxYKTnZfdw4TZKFLo2Jt3
hJ0V27ReibFR1s9FXtVuFgQ8RMszJNjopvOcSRTh9IE3FYVb2YjL72r6d8I1
Ozc8/CDDRkJ7VjB297Bg3P+mQQOVjU4frGm7RHj55DBvtzwbmVbaRz4gLKV9
qGFEiY1C7LpPPyWsEfY2YF6VjZ7+e915k7DZguTx37sIn+PPOULYWf+RyErE
Rrm3PR15CQfGfunk38tGcyeCXFPJ/Rm/LF5u0iP+PLZaUvi/PcYVp2UM2OgE
Yzt/IPFnh6BM49QhNlL+qm05SPyPbfXem2nMRiIPRW5uIMwTMpLrfIKNBETW
aUqReN0w3Se3x4yNmqZuH+Yh8Rzc+CqM8zQbLVtir2wk8TfsXs5bacVGUjmh
1y+3sODtS2v3J+fZ6MWKksP/z9/W0+XsI7Zs1H/vbt9Gkt+nW7Zbi1xhI+aq
nQvbSP4X+z3behzYKE8lpvRrDQvOxQ7tj3Vio7fXfNrvk3qqO7f33UUXNuLf
cnKyuZIFO6XjGIxbbPQpZVdGSzkL4ke5ohfc2WirdtQrj1IWrHtzdkO+Jxu9
sSkrqyX17Wpb5nX7ARvJzsRszChgwTB16w/tx2y02DJtvJH0x6Hpu7ar/dho
V2PA7x/pLChIHeiuDWCjmb66J6pJLNh+VetQYDAbKbwy5C6MY4EfMwZMw9hI
62HgsjMvWfCLzaEsEclGOztS3H8HsuB89plXQzFsVJPwaa/RIxY0OIFI4is2
slue8W+tOwt2q0o+sk9kIx6vsuLs/1iQ8MP9j3IqG3EblOQEWbGAv6DP/mcG
Gxnt5My7f5AFN93QQEkOG608W3rXVZkFo7ujjnrls5GZz+Oj2/hYYPT334cD
RWz05yRaM9SiAu9KTqvxARuxzXikfuiogIxHSVLLezYqLeL79c5bBfy1JDaH
VbKRqi/f73S2CvzhuuNn+YmN0lRSX4dRWHChvJdTup6N0tUvHFEn87DRW91p
somN7gudS5W0J/2iFzGa3sZG3ds1vN7eJ/av/mt6vYv4c/+ELw5nwfpqi0+7
PrPR0Mxu951kXt16XKTOMchGJs3ulRUlLBgzFM/4MMJG4005/s1kPhivu7X1
8QQbFdoXDCeTepXz371KmM1Gfk9kj/h9JfVtHO7a/ZWNvn5RODq8xIJ/Ar+n
ohfZaI/mdEjUWlVoDi5soHEsoD+0FRbBEqqgYSq2l71sASUsO7hsXlYV3mx0
y81btYDebWe9n2Gqwp2XO8O0+BbQlb3Krr+0VIEam3/ORGIB6eutyhe1UoXn
50TbxLcuoHKZB7ctbVSBQ9pl/6D0ApISjE93u6oKra93MK4wFpBW9O9Pu26r
gkdq3vd7exZQ+Es9U7kQVTKfac9CNReQKG/Chv4IVQiJiKJk6CygzdAk5hav
CmlPfSx6/xcbA+T8TPI/7Vz6JVyxNsDcbVrCN13yP0Uq0pIByjbAOS7+jex9
8j9fR4uRx/c2wPKuRSVWv/I/YKbvYORJN8D+Jrq+bMPyP2y2cPK4TjfACZ8u
WIPH8j+UZ7olhlM3wCCPF4uwz/I/Axn5UgtdN8BPb+nwCuDyP05FhmjGbzfA
rC+NvL8A8z9xAIPYJZQ3wGWw1FMpQvM/7xqgcm/ZN8C+kT+d+kXzPytLd5tc
3TfAGHOq5stJ8z/kYgrcRuE3wMw1gHluUfM/DZRz2xLpN8A0uyufs2DzP6qw
5z6K+DfAAsaC6j1/8z+bwjzbABc4wJ/bMIFSvPM/1pMDQVFSOMDZBo2uezb0
P7ZZqeoBxDjAEs0Q9AMm9T9VBtpgf5Y5wH07wv7VKfY/zeeShqlvOsB2/Q0H
VBz3P2JpAIcENDvAoWeH1Bsj+D8o5ImxUwQ8wJFBzIwZJfk/9cr6mb7NPMAP
b6tCwxX6P5lexAqwhz3Av0S4vbYa+z+Jqnx/x08+wP5tXzZWDvw/YqncfYgJ
P8ACB9KZK/38P0X5IDrovj/AN0hywkoA/j/ljcBSikFAwPvcrOgV8v4/ujn4
sNqcQMBEbMiQTfb+P/VQFgtynkDAjvvjOIX6/j9hxShiCaBAwCIaG4n0Av8/
wO85BzijQMBIV4kp0xP/P9Mrdi2VqUDAldFlapA1/z/xBo7tTrZAwC/GHuwK
ef8/fxELVcDPQMB4VTqUQn3/P9hgslRX0UDAwuRVPHqB/z80bL5R7tJAwFYD
jYzpif8/DKARRBzWQMB8QPssyJr/P/fy/Ql43EDAybrXbYW8/z8h1KwdL+lA
wBJK8xW9wP8/ZM4a9cXqQMBc2Q6+9MT/PwRXH8pc7EDA8PdFDmTN/z9Q/vds
iu9AwBY1tK5C3v8/AlM6luX1QMBgxM9WeuL/P0l/r1p890DAqVPr/rHm/z9P
sNIcE/lAwDxyIk8h7/8/2p4umkD8QMCGAT73WPP/P5ALbVXX/UDA0JBZn5D3
/z974mQObv9AwBogdUfI+/8/kPMYxQQBQcBjr5Dv////PycLjHmbAkHArS3k
FA==
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -30.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466815232053*^9, 3.4784395179002867`*^9, 
  3.478527744580017*^9, 3.4832951162915497`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyinput,opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746913471*^9, 3.478377746930922*^9}, {
   3.4783777816603737`*^9, 3.478377781710813*^9}, 3.47843936340908*^9, 
   3.478439441259446*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmXc81d8fx4mkUBIhUWlYd7j3ujLKyS6UUSRklL1SVGZRkhJlJCOSlMgq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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466819426744*^9, 3.47843952258252*^9, 
  3.478527750541658*^9, 3.48329512288519*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportyinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777469474287`*^9, 3.478377746963317*^9}, {
   3.478377781760839*^9, 3.478377781813466*^9}, 3.478439363859208*^9, 
   3.478439441754499*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWXc8lt8bRlGSkpmRUcl4p9dWOekbyqaSJCohEppGylYkuySFEJHsTc6x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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466823897972*^9, 3.478439526498692*^9, 
  3.478527756193668*^9, 3.483295129378489*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyinput,opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746981037*^9, 3.4783777469976397`*^9}, {
   3.478377781861001*^9, 3.4783777819111643`*^9}, 3.478439364263809*^9, 
   3.478439442249517*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81P8fN4rIOKKQREqISENlvCQrqWR/S2koUkmSFEmiCImMzIiIbLJ5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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668273345203`*^9, 3.47843953003332*^9, 
  3.478527761401968*^9, 3.483295135126253*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z", "Subsubsection"],

Cell[CellGroupData[{

Cell["z to x", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportzinput,opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777470144176`*^9, 3.478377747030521*^9}, {
   3.478377781967656*^9, 3.47837778201213*^9}, 3.478439364702929*^9, 
   3.478439442722149*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fx21KysjOSIW43OEaUY4kCkmShMwy4ouUjCSh0kBGSSgimxBC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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668324134912`*^9, 3.478439534800036*^9, 
  3.478527767202735*^9, 3.483295141581698*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to y", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportzinput,opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747047474*^9, 3.478377747064941*^9}, {
   3.4783777820621862`*^9, 3.478377782117507*^9}, 3.4784393651302958`*^9, 
   3.4784394432282543`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c8198Xx0MZKURGGS3jM3w+dknyrigllSiphLIl+UaFhJISRWZ2VDSM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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466843582295*^9, 3.478439539122445*^9, 
  3.478527780168879*^9, 3.4832951559119062`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to z", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportzinput,opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747080618*^9, 3.478377747097636*^9}, {
   3.478377782166779*^9, 3.4783777822124434`*^9}, 3.47843936555762*^9, 
   3.4784394437569933`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c81e8Xt2fKjMzIXsnKqA4SwjciEkJERkVUUpE2ZZUVUUQUmSH7+RjZ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668461984663`*^9, 3.478439542345305*^9, 
  3.478527784299974*^9, 3.483295160477086*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportzinput,opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777471144238`*^9, 3.4783777471308613`*^9}, {
   3.478377782262466*^9, 3.478377782312475*^9}, 3.478439366097721*^9, 
   3.478439444274682*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c8198Xx9OgIjMkERIqJaXCZ7w/RZFRspIkhZKsJKMkJLSUMrNnw8iW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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -55.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466849640353*^9, 3.478439547508819*^9, 
  3.4785277968210917`*^9, 3.483295174497652*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportzinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747147533*^9, 3.478377747164796*^9}, {
   3.4783777823640633`*^9, 3.4783777824130087`*^9}, 3.478439366547752*^9, 
   3.4784394448259172`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81d8fx40iKaRkRVbWvdd1cSXKsWUkSUhDkqgkkYzIykiSmdBQCQlJ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466853766217*^9, 3.478439551611762*^9, 
  3.4785278017363234`*^9, 3.483295179978508*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportzinput,opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777471815157`*^9, 3.478377747197897*^9}, {
   3.478377782462984*^9, 3.478377782514411*^9}, 3.478439366976221*^9, 
   3.478439445377042*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81f8XxwtRmSVbRnHv5ZpJSfKpKOVLiUglGkIlhOxEmSmyk4hIycje
nLeZvffee6VCSn7v31/38Xy8zv289zmvI3zbUvsuzbZt247u3rbt/7/lhsJD
W1tL8N1wL/W+KQWJrMpr2K0vwZo8nzXnPwryeqWeP7+8BF1D1Y5MmKdFjEh3
ZpZgvsxeXoheAqkX2QT3jCzB9Kbxl32Yk3V8tmn1LkGrbNkRBfw95rl3D6ta
l4DHuUpnc4cEsniW3qtUtwQvVvIKv2Nu5qlSyyxfgtDQmcKmTQo6lN6bJVa0
BP1XK2V6sR5ybkk4JmsJGGifCxdifXWINoAzZQmOvacpT8N8xZ7778uPS8Dt
P6+fgDmPRfIebTT+voHgWCRm3oRTnY5hS/Bp69OtQMwuJ/RUlv2XoPbtrXYv
zIPt99NMvJcg/S4Psxce76T50/0DT5fAQEOu3RHzB9qQFzoOS5Dl7ThhguPp
Ij+v1VgtwY3JeIoB5ruHio1P3lsC3QvI6BLmqpqWlpxbS3Ba9P7Lc/j/lFuT
ypLXlsDBNT7xONbnA1h5eP9bAiaj3DJRzBfIIl6vVZbAfOnPOU4cn1ai8INe
CY/3JugLK9b36mnefHIYs9uCHx1mm4VbDT8klmDOVZhmmU4CtXvYKd4XXYI/
aacPjmE+wu/3aXj/EqzK1I2P/qWgN5nv913hXALyr4ngLswb6lnuDSxLECx9
9kg9ZoPR6kUVhiVgnuivQ5hLHAeuF2wtAnh/XIrF3xPas1Its74INTQhzYlY
d/9Mf+TT8iJcvhlARGMeJfji9s8sgiJjUGwQZtUuabaQkUUoMHRe9cK8k/7q
rFvrIljRbDhYYr4f9fDKWu0iaNw0SriDuf7ws4qH5YtQJ+1ZdQWzVH2Y7Hjh
Irw3uLlAweMH3EmKvpa1CPSfPgwSWF/eAMaW5EUIuevZKYdZO6jdQe3jIrxW
/ZRpfZeCssRmJoqjFuHE3c9RfFjnLN3UPhy2CPwxGVFjtBLIQX8v+uK/CJ1z
B6Rosd67RJIU9l4E2x05I6t/KEjJ+/jb8KeLsHDdznsWc5SAFgOLwyKYpVwW
HMT8L9vY1sNqEaIvSia2YL6p6TiyYbYIyqy7RCsxi7h8KJy6ugjUz/orSZi9
2HMphtqL8N8gs9esMX4/X+pC29UXQYEx3ysI6+qnh2n+U1mEZDfLQk/MST0/
LUuPL8IZ2909R/B8mR7tGjh6eBF0Z9HVXPx/i50C6qkSi6DKmUFjhOOb3x/K
FRFdBF4f5Wu7cfyho2oikfsXQY5FeUYV69q3DqlYcuDx5Qe+HMFs7bf/tgrz
IowX7bpOwRyUvdOda8ci3Lqd+5sHc+bQj/dzfxdAglzrxYi5fddQCfxcAIVF
CZrNDQr6KVc7EDy/ACcNmh4sYt5nmP3XdHwBsgtcHlPx/A77xPAp9S8A3D3t
YkcjgS5n+CmytS+A6k6uE2U43rbf7up43QKcKUgzzMQcQn/bIa98AfL+kpRU
cHyWjGb4y8IF2Ncn9SAU6+3XFHJuZi7A4eA+Xa//j+9xsONw0gL8oaGTsscs
3/N778DbBTgv5Jugj1nBOXm7IPcCnBVefXv1NwXpfwwX+sG6AIPdSzzZ2/D5
Nz0jvjEsgI35zGgs5je/HxpGbs1DdX1IIBnH5x+8+sRybR6+RqvY3bmN74em
6juVpXmgPDIN0ca8YS9dyDU1D/Si1o0/13F++cDbOzc4Dy1av/LGMCvW7/gN
nfMQGhb2SBDHX1td5gppnIdY25ILpVh3Euo/YlY1DzaGq8t/b1HQW/Vvukol
85An6FXzfYuKCmwzbNly5mHu3CvWVzi+NzoqeDwFc/BBJ2fMG9U+GXkf5yGt
d1vTvf+P/8Om5WXUPGw072LRx3x8v9HyzdB50NNKexCMv2+gps4q/2oeQv6c
Vj+MdZdH8lK7POchwFZe7QDmd5FCmgMu88C5uSjJhrmoktE83XYeOIT/KzyG
59O/tPrC03weikI48+bWKOgvz2jiVeN56G6ebyTh7/OrNlRLGsxD9MrUVBXW
lSzyprZfnoeBE2NPJv5RkcGbOPrO/+ahKuhWUSzWXcr8Rb+o4P0y2HhTgPV3
846qrsfn4TGJNFhzk4KKOe/e0Zabh96aZc17OH7wpNYzEnUeRB5UXtTD/O/+
8diNA/Nw8DCHogpmgVASauSdB/HdNUwymJVhz9CHvfNwqjn9Gz/mMk626O2M
8zDzvIr1IB7vrAXLjZu085D6bsztLB6vtpKJH/7MgQFziObkKgVp7mfs2/9z
DhoGCjfaMDfb7nrrMj8Hgw/pLjdtUtHleoarfeNz0Pr6AsdXrHcfpOdWHJiD
pJMSm/FYN3Cm63rTMQex/AdiAjAPt9KErTXMgbfpcX57HG8svl1Xr2oOagaa
gjOMcD5w32LPLpmDSPntRpew/qBns5U9dw5W1byMlDEvyvwNtP46B4nCv89T
MVv7bGi1fJqDC14BoSZG/6+H66wyMXPQl3eznw7rTkfXGv3fzEHPaVfekb9U
9M//16uF13PAUN2+Vov52eQPDQ3fOZDimw+o/UVB9MorjEnuc2CXO/QjB7Nv
6HLtLqc5+HVc2ssbxzMtLPqaWc8B6e8l+wCsv1ZdOPftPtYZOc1qDfH7fzfH
QLqD1+ttcEMFx7/5MVPlcX0Oxs+9CNDB8fz/TXuO6czBl1juewTmmA+Tqqc1
5kDw/i6qE/6/yMY4bazqHLzYxVk7+YeKPl0aK9tSmoPRR5HmTZjFE0fcDeXn
wHDo4UIu5tRtwyeLJefgUfm7sz0/sV/QH9ziI83ByV3pgRWYc772lzgJ4P30
iKj4ilmRoe9JD+cc0BwqWNbH/y8x7FFSYMXzK3494on1SubOgl9bs/Bo/NW7
65jbHzTlWI3MgmFgw/QOzCvkslST+Fl4bcoDuj8oSDLmU7S2+CzwTKS6jXzH
47+7mNp1YBbGFB/X1WBWeLNWbMA3C4WP+jbSMSuHvG8YYZ+Fq/0rvHPXcH18
rTZgwjQLMq+YGJ5hXf3l0vwc3Sz8PaPLWIj1iz7hf602Z4DJyWsmbA3fNw+C
afXXDJjpGr98gfVrblN8zosz8PduDK8R1m+6BFC3Tc2AmLDDiZ34e3cdjh73
HJqBjG2HXi0t43prO6S+u3sGiDhd1InZysr7WkDzDHy2z+pfWKUiO3Pp+/tq
ZkDLxqg5HuvOZl2OEaUz8H73thQ/zG7GT30FCvD3p9hqwnG8101yRFzGDGwP
yGG5ivWXBk2fKUkzEGWWfzfwKgUF6tvnpcTNgItGWJ895rDLgtWH3s3Az8+t
coaY32l968oNmQFOVgarlSUK+qBhOaX0agbCAkqfdGP+fI5rrdRzBk7o1/HV
/sLnrQr0aq4z8FY3WTke65knTTnr7WbgTFLod1/MeUqspEuWM8D6mrxqieNL
FHLlO03x/JMc/lzGesVhozPXb86Ak+RRbUXMtTIMusP6MzDNNOMriLlZ4qvx
3UszkE9v8YEOcwfliu3s+RkwOXL6b+dPKuoV2XpueXoGgv9df9y4SEHDQp+C
fyrOQHhH6NgOfQqa5L8Y5yg3A/1jBTXhWJ/jXsv4R52B0VIWVRfMy/velz0X
mYHdPRrRNzGvsqm17tyP9QyNblXMf5mWRl5xzIADy8B3Cubtu8K/72WZgaFn
PbNMmJm2T7Ht35qGP8+sndoXsB/c9Bf6sDYNDdpFbHmYuX4fkSEvT4NOW71n
JGb+X4NE8vQ0kLxnlFr1KOjAd6+LsiPTwOcg2cH1g4ooC1JGOT3T4HDtc/3q
ChVJzXRaHG+dhtd/Trx3xvGHJ1xdUe00JC+fcTHEfGyE5H+mfBpab55wX5jH
93mgMaq2cBrKrXczPcL/V+2xS7mYheOFW8/Q43j1DoHi9uRp6PAIvyiJda2W
qvqrH6dBpSW22Q7/X6/Bon8wahoujcs06GO+XsM5fydsGnKOeyQoYr5ZWfJn
2n8arq7N+ljpUpBJqQmjhfc0JIy3XHP/TkXmxSx8P55OQ0r7mWQ5rD/KzxF3
cJiGOf2uT2iOguyyDRU3rbBeo9IYi9klnV792b1pWOJWHfi5jPNfSupVhtvT
8IF/NeUO1r0T9e69vDYNXfJBzBGX8X3++M9hj8402O38viGC9aDYBJ+w/6ZB
Kn313g7MejKi6o4q0yDR8nHoKI7nhThGg+PTINzV+RDN4nqleaBBWW4aKj/Z
pURh/tAf4y9MnYZb3RVR35aoyOSBoBbdwWn4HqHelqxDQeIbUXumeKehT9JR
3x7riz78bTV7p2G3ruQ8G/5/BldkSPLuaaDsylBfmMHrS+DRC6CZBiGdB841
mBXl33BZb0xBeJmA60fM/8o5ey6vTEHekzWGpEUqKtMOfXt0dgr6ol+uG2Dd
a4TdgHd0Ci5czbFUwKxuFbR/s2cKnIQ6c9kxs2yxDQ21TAHb8ufmxWkKan0V
EFNWMwVkvvdVgtr4PfOz3P5YOgWNGeY28Vi/lvTyoE/+FLgG1v91xSygyDhx
P30KZoku3auYR6t9EzQTp0DA44yrHOaEKzvNZGKn4OlBg/k7l3B+mvQSY4+Y
gnUzCaWpKZxvaT2Su32m4CG/8+G3mHOCaCwK3abg5d+auzaYnYTdpaMdpoD5
RbOxBmbltK1lN6spEFG8ISuKmYZwzbhjNgWE8oHey1q4H2v4a3P25hQ4/8mU
7ZykoBcGzvJi+lPQM/bLOBXzhbnfq4xaUyBv+sLYCzO7k0Peohrez4GDMoaY
u3euObYQU9BS9fLzzCz2K+GPj2cdnQLLBENxZqzfJP38GyY9BTHf7+mPT+B6
lm1d4kiegpK0c5cKMU+rfH9qIDgFZTT2SzMXKCi51fIUwTUFfgsOH8ywbnVr
keYA6xQsJpI3lDEfXjavoGPA85G1nIyZoaJ11znPqX+TIGJtoKyC/1/EfF+t
dnUSaillu3gwu72b3pmyOAntTC882XC8KtW0NmByEibbfJ0fjOP+q2DCz3pw
Enp3pG2kTlNR/TljTd3OSdDd/vgGB9Zfd42yKDROwqvwEGsNrF82udXMWzUJ
OdUiJ7g0KYj711DgZvEkjFR/8g4ao6D+54Y6w9mTQHvD18EEc8zegX3lKZNg
V+InrYjZOPZ658ePk3CqyjmZGTNFpjfcJ2oSVMi/zytq4P63RP/qg9BJWCHC
7jNjTtPs4r3wahIYj1O1hv/7f3+g2y/jOQmJ7tM6V0dxPX3QHsX+ZBKq+mkS
qZj//tY2WrWdhHvSdGWbIxTkwaU1Wmg8CbF39ijHYg7RVp8+qzoJ9NPJlyeG
8X6x9J/PUpoEysHXC3mYx2ofJgnLT0LY6fCLLzEfUgm0+Cs6CT6/ph8ewnxt
60DzPYFJyOJ7J7YDs3thlmwX5yQYhCikdA3heiHX/TOdYRKOlHMxumBeX7qn
J7htEpQ68sc1MQsm/8l9uT4Bbs3snoKYz5q94tlYngDx5z1zy4O4fxMRdDad
mQDT6q/cZZjDhtP620cm4KzS0eZjo7h+vTutfLp3AgKqx9+CGq4v+u3vv7Zi
fvH65GEcz8xhsn1/3QS003j0hY9Q0eGWtdsvyieAT4rft30A+/1XvhVrhRPw
aFelTjxmj/N8pLtZE+DfqjJqgzl5R4p3a/IEnLtx7LAK5vZS5Rni4wSkv87t
tThLQX+eNKunRE2ARuxd4ZF+nB9WfzD7+E+A7w5rblfM1hmelr+8JuDKVGdJ
3BAVRVhwtdx+OgFLTjWcvFifnlQMOWE1AaIH3Xiy+3C+6XLn/XFpAvas7hOe
7qWg1GB2l5vqE5Cspn0qC3PHxY8DDacnoGhvrG7EABX9ZTxKHD8+AbW0NX9u
YBapro75LDcB8qEK3Fw4XsPjGg2nxARc1PssM9pDQTYn5+88F5kAmtNq9CmY
y/JYyYYcE7AqrD11CvOsbaxPHfMERHJ+yr1/moL2yMrNKtBPwPykdl5HN75f
CxX/Jfwbh27mXW32fdhPJeqlsK+Ng5mYgp0Z1n3uTrO4L43DxY80D2Uxpwk7
WS1OjUPjgcb9G104Pwwwtl4fHgfaV7tfPOmloq2IKLma7nF4qXlNZfYkBZH0
pEOPtIwD8xdD5QzMF/aWrsbVjMOdbb++O2K2a9TW31M2DhNu6TdOYY5+MZ7v
WjAO7Mr9Fp87cf46a8c3nzEO3N99xC0xL9DsfHI1aRxYfzJGyWNWcqaePPxu
HMRy3saXduD3d7Q4NjZkHM5e7FHwxuz34wIt66txqP7N/kwDc8bXYWMXz3HY
K7nNbQ/m3gfWVTNPxiGi/6mKZBcV0VDoKFfsxqHHYzL8bTsFiY2H+lZY4PX4
0aUbYtaKIc/Jmo5D3u01lwOYHQzyNd4bjUOG4fU/E20UZJgkfPP+lXEIUSxl
i8esuuFrI38Rj+80a+3dgf38+RWvbWrj4LVPniSIdbY3197WKY/D/Wx20f5W
7I8my1LCjoyDzNO5yjeY++WppbekxgGYCiSutON65hHcLkEaB5+f++fYsP65
7c/U2v5x0OKZ8S9qoyL/A8Z/yjjG4fkip9msIs4nj+pZ/JnHIS1y5roQ1q+h
wweu7hiHDom7GX+bKegka5S8yOYYRM/mXn/WSkUkwx3nl36OwT2hZ+pWWGdK
eWhQMD8G5DhrdzHMK386LD3Hx0A0218gqIWKutWVn2v1j4GayGjp2yYKKolI
CONrH4PHvyeachQoKH6a5ctk3Riwtvu+scD84qh9cXr5GDhIkD+VNuL87zXU
7FKIv+90dnq9iYr0OtTG1TLHIHGhc0IK60oiaWt7k8Zg4ZDY9HgD9nM23IyD
H8bAjHmjd7ORinaWuQkkvh2DuCQPk0TMi2wzsrZBY1CiaGVNh+PbjS6dIV6M
Qd6fPzV59RRUkJqvv/sZHn87bbY55phNYfMOR6zzrR0Swuyl8eJpzKMxkM7f
ON1WR0HmkStBD+6NAYvSw3FPzArHyvO3Xx0DLeX/umdqcb33oTbUa40B/X0N
sUjMdF3Bw+HnxsBlOHWnRu3/+2djBimFMTjo8NgyuYaCzNJ26F7jGoPkZ1rf
TKvxe9h6aCbKOgYa6vcec2A+fKHTeZker8f/fVLZNwraNp/wwWt1FN7F9SXz
YX5DPrec0TEKBZRLc98qKcjVLo3WtWEUZNhtyx5hNq7k5jpfOQptjgO8fJhl
7sycGMoaBbWC1f/MKyiIM+PSpS/Jo3DNv+/APsx/txUYP44fhbTHFvaF5RRU
Hf3CjzFkFP7S0YTtxJy6sBLd6TcKZzREDFPLcH1Rup4R+3wU/v08GaOD2cmv
vNLcGevixtfXS7Ef6KX2HLUZBd33yQ0MVJz/xULmaR7g8ZLHPiWJU5CEw9+t
htuj0L1mv34B895vxuwR10bB5+/UoieioN8cDSRj7VEwq6qYbAWcj3YNvdBV
H4XcLhqZOsDz+7u8ePb0KDjUxAw+xCyzTKOjoDgKd/Ivh7hQ8P6M7csVOzQK
qrr8HpIlVLSti8THJz4Kvpf0G8uKqcisVuEp04FRCPPuvnSTjM+nWH1skwfP
p+/OgeBifL7pBmpLe0ZB+Z12jmsRFcXEWyQN7xqFh+eibrQUYT/xxo21dfso
0HIXfLDEbOUXZFP+ewQkbGd2yxdSUZdrfFfW9xG4N02u4hbF/sw653jCzAjs
ieRm0CugooS71e/DR0ZAbLE1YiKfiliu9tL69oyAb4zWddcCnA815k2dWkbA
Zp+5KA/mQeJf3YOaEQhWFLySmY/3U45N5kbpCMS2OSxpYObkPbxOpI8AceP0
Rdc8fB+YzxrIJo6Aio2gBcqhoslt+uhA7AhoufgeT8mloOwpZ58dgSMweWf6
S08O7pf6Xs2v+oyA3o7mZQvMHo3vtabdRiAptjaYFvN8aXpWj8MICF7LDArP
pqDL2eXcdVYj4BitOy+Ouehzh0uR2QhQ88zfF2dh//duajjl5gjMnfmXU7of
9xMBv1Xf649ALjdiGsmkoJ/PGBNfa41AWpyHuF86FRnY7Wd+dm4ErkmbNm/H
esU96Uc2J0dAp5KHn44f35cbpzqMFUbgCU/bkGAGvn9aOsf0ZEZAgOndcEo6
vr8qd6PUKCNga64qczz9//nffvsxoRE4q3Kt4VsaBdWL+94V5x6Bna8cOphS
qUhOILKGj20ELj3/LKPDQ0Fv96RIMu8cgS2lWdN7X7F/3gGB/7aGQezMrMSP
VOzP15t/La0NA8MVLQUXzK1zo1dHloYhht63wJEL9x9DP4tbp4ahebcO/8sU
3O+00h+oGBqGX+ss3mZfqGh3FbdXdtcw2MalM0QkY/+QLz6b0DQMM7tUJvUS
qWh56Ty1+MIwNNR6P9OMoaIiNkvpY2rDIDWV+cwnDvdnsiFy2cQwHDY5a7sT
s7Z2/lFZhWE4rykR6/0B5x+bweMpMsPQ4v2NgR7zTDDtSTGxYUjQfvXr324K
ysqiqH4UHgZdqTjnbbHYL3donhPmHYYcvlBPlxgK+m/VWiNq7zCkFkj1VUZS
ESfXGy0exmHgPZNNJ4t59Gjx5VDaYdj727dpLhr3q+kV6QfWhyCjoDHSGPPK
CksB78wQRPqZh/RHUZDv4atle3uHoOq/u7k6mIXs4mp31w2Bhz85VI0e9zO5
C600RUOwq9rwcGw4FWn+Ptq3kTwEHSKVTPSYxxWfja1EDcGYurlQAh3OLy71
c7P+Q3Dh94u4t2+xfynh/Dn6dAjexLg98aPF9W/r5t9eqyEYbr+T+ySCgohT
SXRtt4bgVY/J3MIbCup89oupTnsITHaCwg3MDysIjnKVIbA5Zx9VF47zNf2L
/YWHh4D+naDt7iAqilRrF80UHYJDKvQRJoFUdMhXQCqJcwg4bUzzS19TUXWt
2ZE4hiEo02D+7hxKQUZMmcqR64MwWGLx0zaAilY1N88GzwxC16Ov25o3yfj+
q1306x2E8TRW5ZxgCjrYEnjled0ghKO8PfsxF+ztN3IuGgRWqYszz4Io6NJl
kplNyiAcU3YrmwrEfjLUyupB9CCcWJp58NiPily7ChzuBAzCjLtIquwGGXHw
7HC/7jYIypk5BNtrnI8EpT4cVx2EJ85R+169wv5Lwm38T90AfAubiNX2oaDi
h7XzP4oGoDmT7niCN37PX/f9mksZAH+5q5/XvbBfXDbcHIseAJ3Q9cnzmN0P
Je7oDxgAH52aHxGeuB+y/cHc7jYA33/410174PqQfYKz/tEAvKIXf3AE85k1
b4GK2wOgMnyg6dlz7F8UWklFOgOQ4GzgeGWejGyc+KWzVAfgCfG1i+sZBe0u
MjmaLD8Az2X4Ht90p6DYzTQinjQAX6aJu0yOVKRA/FF7xzUA9I50LQtPKajJ
7YxWyM4B4L+r63MIs0lZgP7L3/3w2+Pgmxg77J9pe296zPZD0K3W1dwnFBR8
RuSeS18/KB4LSFh3wf13Ml+HdF0/XNI48ZGMuYCd/dRYQT8szVht13XG/frI
dh71t/1w9ptn8RdH7MfO/fbY9O2Hn5GBe9scKGhX2vJymmM/+E0lf/1tj+uP
61A119V+KPbXTjplh/3eROfhunP9UMkl9O/2YwrS12iMcVXoBxN/c/dntthP
ZFYyHaL0g/y+I9IxNhT0lLfYYYKrH5zEhJw1+skoyD1r/A1DP+Q5LfYVmuF6
MZ2kpbHWB/vfVK4uWOH5Xowr2prsAxtbPmY6zI05bymZnX3ww675Sf5d/F73
B4WYVPXB8TqGC+IWeP4evtt4c/og9NDyPcWHeL/n3cwbPvbBIx8ax3PmFLRf
x6HbLbQPytbO2Fx+gNdTYKl62LMPjh2f1jK8j9cjbJo2ZdsHIZe4TTZayUjf
x5A/0rgPvjHfCH1ghtezpOtz4XIf2NOLSV6+QUVuepo/t6v2Aa2fE42VCd7/
YtWb2XJ9MExa2Tp4Ha9HRKne7CCeT9rgxQfGeD1+cgr87H2wjZZjfUafihpX
xOObaPqg6YuX7I3b+DyuHmB7vtIL+sf0az7q4feFeFyOjPbCHmkuvTM38XlQ
9kzPtPTCq9TDn+SNcD0L2Hk5qrQXzthPmx40xOtZ3QKt9F74Ted68N8lKlK9
sUali+2F/Yc2d69dx+dTsRie+7oXKKmP2vuv4fVQJ2kfuPUCeT23H67i8wka
sBSw6gV+z2TOGH0KCvrd3tdi1Atyfm+uLvyH13OzXs3zYi/0fPbeSlGnooJv
5ZkKRC/srv16U1oXn49UoeC8VC+4WfO20F7G6wnN8Hsv0AtUy8fG1kVk9Otv
4po2Sy+M9XykO1VIRjuNY+/Q/+sBZ41eNQstvJ66N035Cz0wKbP6rD2PjGQO
vT7+cKAHpLLqZTY08flEeH8SasC6miP7iZNUpL/tKXt7UQ8E6IVpDSlTkbmp
3VPv5B5gzDRckVXH+b/x4Zziux5gcsrV41aiomD5u1cW/Xqg7HGk+fF0Mkp4
Z1Ae69wDD80e6ZzD/XAB7WVp3Qc90PqZ5c2KKl7P/f8id17vAZ/ii5rXjuD7
1nKaoUi9B77xNvweSCKjVQVFG0vFHjjcPHm5G/dzu2Jkhw6I98AbNuT6iMDr
YRD7r5OnB4bVHu2lV8bnYyGU67urB1T1ds6HKuH1dHAdPPG7GzS+O0wKHcfn
o8QasDzdDSe9/XsSjuHziaP/E9fdDVnT+ZFk3E883f3P5Ep1N9zhL31zm4L7
m3o+dqH8bvDq95GTk8d+2v8YTCd2g2mCpWmJHAWxal15kP62G+6viViqHsL5
bs9jLie/btguysFfKUNBlW1B5addusHX76rSSWncH4SmWTI+7IaPFlXxjQJU
5Hylka/9RjekMz/YJipBQXo889/eXcC66ikpf+xnZft22d4luqHi84FfWTxU
xBRFFpKS6YZspuI+Dew3Jw3P1K8KdYOJ3E6NCwFkVCp0xwH2dMPzS38M370i
o3ejbiI+NN1gqfETRv3IyC4+ulnrRxeISBYw2Qjh+mBS5MIz3gXPhQ5N6fmQ
kQSllzLa3gXatjON7dgvMcyutX+p7AJ6Z/muNV5835I43G1yuuCwQdEvNux3
ih7KSSp96gIa56i9QE9F4dKXeujedMHJ5k65dlcysv5u4dng0wWHfqS18LJT
kEbmS9kwxy4Qo5b/2LGHgsiPvwwY3u+CK5+YE8dYsF86Wu1Lvt4F8QGbh0zs
yGhgfUJ++b8u4HmbP2uN/UdeAe1onlIXuBkyKR3Yid+Pi7C/u2QX+LEPvocd
uB4rE4rqAl3wiKcw/Dyu5+e23Zjcy9oF3pqJ+rb3yehAmVNQ31YndIluneL/
R0bdZ3JmzUc6wTktO8J3nYwyGdrD5Fs7QSgv7dt/RmTkX/P99L+yTtiUX4p2
XiEjFU3JyID4TpjaNujVPkdGAqz/qemHdsK+5WNvP3WIo/Vmsx9CXp0Q7/Nj
+P44GaVejv8vw7QTTBhWKbQ4H/tylq056XcChW77qG4XGRl3D8WpnO+EpJ3V
L1VxPlR+u3mRSbETLki3cBfVkxGPAd/fdnE8337dJnKmOPq5/9jnKL5OKHwZ
dqcfyKhxSO+yCVMnRCcEWjjFi6PEWNtt0psdILtIMxkbKY487gQlry10gJH8
oL/pRzIyEk3TR4Md8GvyDKtFBBkpTjXQ+TZ1gKFC4EaEnTjalziXdgl1wKg9
w/YvDmS0dH/XDd70Dpis/zoTXktCtRLkXWOxHdDOmFDomUhC8Yuq2UlBHWB3
e+8jRXsSepp2+5bt8w44kuBXupVBQtes3ZhP2HYATb4bmzP2I/KHo/N33O0A
htfrTqTHJMS2Wni3UbcDmgvuWnzyIKO53J494Wc74Ikm83mvSxRU5bhWbHS0
Azrrd7knXBVDscc57lMoHbD58qdLRokYctk8xPmduwNs7v71XJIVQ3qgVZa/
qwPUXYNuX2/H78fdwuLZRjs8rlf56/6CitheDhWGz7WD3yNf/ZMzZLQYprUr
pb8dbjLO9p03xf4+tlSvrKEdjMITapJwfv2SfCi+q6QdNqQbVTLOUJBPbtz3
+a/t0PKi6hmB84dp2T6CJrYdco56isRI4X6qwfMlV1A7ZHg32N7A/ZpI92qP
xPN28FL83Zu/g4poxkzJp23bcb0poC/hoKCRhW7bK3fbgc9P6c8ffP/R+vky
c7120EpyDAy0JqNo2kLWZ2rtoHm8ek+ZORm5sEjcCFdoh96JFGEH7Aev80R9
SRZrBw8mnUzB2/g8RVjWS3nbQdp7236DH2TELf30TBdjO8zOJ5hs4fu5emw5
aP5vG3wVtSpnmyWjDtVbw9sX26Aksqkkq14cZV1sleQaagMhWeudsv9h/3BN
xVmiuQ0k71uEkgbIyOpuVvWp0jaQ0juztKuHjC5aiXJeyWgDUtkBp612MpJy
DrtjHtcGoxVeW4OKZMTkxZDuHtIG63ab9bL4/s6+dvgX5tkG9X99a6RryKgm
cua/ZLs2sGvS19KuJKPPCdciSk3bIPdz3wenUjLySq+b7NRvgxPd/9F9Ksbv
pUjp8Pz5NtgIdfl54L04UvmW4r79eBtYxnEuTwji990q0MQp0QZ5T+/oyGeQ
0baBAH6J/W0g0h/OeYabjAantt0/xdIG5+aa0vy/kFHxyqNcva1WOHOFQykn
AefLzVE68+VWsDvev9r9gYycdl7Wdh9phcKAhLFf0divsFe+D2tthbdXVvYw
RZLRUYEjC0nlrXDt9K9w3nAy+inH7dP5sRXqXlkI7sf5uFXZt2MurBX+CDKY
suL8m35+48B2n1b4t1bwatWLjCyM+oup91sBdQpwxOB8Of0i5oebVCu8CbQY
V3tIRlWhe06FCbaCpKDF72ozMvoY88w/ia0V+IVLO48ak9HtHGOxzpUWeOZn
uNh7jYz6RyhG1NwWcFvIPM+tRkYF8xHJJz+3gMXHRZ+ZU2QUsbZ7QzeiBUJW
tC69VyIjBxoXtQcvWkBa74CMwlEy0mNeCHFzboFNAdVrT/eIo8PchqOh5i2w
Y6VZjCGMhPYebJJOutECf3Q+mZ8hkdGy5Mkn6EIL8EtNy10TIqMmhfTaDqIF
nl6lP32el4zE7zU5J0i3gGPdP/krK2LIK2JBwl4Qx9vH0AYzkZHShlgA91Yz
2O7RimH4R0JvxM+dnFnE7HN90GyVhH5cM/meP9gMr8QdDvguktAFP48PLxqb
QWZbecqdSRL6UvhB53pJMyi/fnr8xwAJ0c8jOolUzEtJy7IdJHSLfyj7b1Qz
6ENO3/fPYqhIY9Ok4VUzuNR51saWkRD3Ez7u6CfNsHr041z9ARKySTlWY/Gw
GSJFPh6xTSWhxoErTsSNZvCtgpHEOBISZ7Gjsmk2w/jYpwFjGhLyVA7pH1Zq
hj/Xz4xaviShYYuMV+kSzWBzuV9q5CkJKb1vVn7G3wzuOSLun/tFUXjT4pI2
UzMMNJ42e2JMQhNbPKfV1ptgsGNm52NdEnp3Uy9+uqsJXF8dGbT6Koq0S4Po
X+Q2gQ+1LZrxMAntOtBkRg1vgvK38V4awiSEnjHW1ds1AeUne6/1JAXZj6lJ
Wug1QbKGSktJEwVJqXoEsB5pgmVmRyP7AVE0Ho++p3E0wawafbVFqSiK3LGp
o/2rEeJC9mTfj8XjmRzL+dHeCHZHHy/LTYqgnd8ec4dmNUL8okbBA+w3gJzh
dCSkEYbf8S1f5RJFdj6L/V02jTAkpEtJrhdBkjPihKNOI0j/to8/ZiCCxs+b
xvLKNYJJ8l02BoeD6O2XONqivY3gqLe7OAHzJcbhuzdWGkBb9P2v9ut4PHP+
6n8tDfC1flovsU4EldTri8ekN8BTx+rMOg5R9Fgy9OWpwAa48Nb6t5KmKJLw
b1kctWqApV8CX90cRdHYIvMlD60GWD96JUonWhS9vaieKSrTAPBngG0HRRRp
pXlxfGNtANG+L4o8qdjf7Cm3N1uqB/8jeQcbv4uikkdbPbua6iHEo/BXGQMJ
2bYeV0pKrYf1TmnSuKcooso5RGv410NR6IdHC5IkNBqctW3xYT0k9ij0FCqT
UMTP5dsBmvVQYZae4Z2Hx9OVrJSRrIfBKF6fNgMSKuZM8LWZr4MXUS5W4rhe
2tqPzu2rrwOWnjNxIrpiSLxb4EJOUh1UMGsaBPiT0IjC9bQrfnVwapSuMowW
v4+I8L2/79fB3v0Xz4Xg+3hho832rXodCNUVvn3DRUI7rrN1HRevg7ttIpPT
QiRUVKhxbGBXHdDcOEj7AkjImt830nWmFqxul15grSYhzfdOInRmtcBY9KZq
DL+noGxahubztWCbEFRWfIWEOutezkRSa0ElUNK29AcJ3VyPTpVbqoHjkwtK
jVt4/pfKFe7Y1eD+dKirmoOM8k01+KT1a6DCafvmKH7//550bG4cqwGOGmp8
7JwYUgkxHK7iqwHbLP5zSSJk5PNlqixosxpae1SWX/wUQw3I6qPhUDV8u7E/
a0GSjPZ2/fYWL62GxtvFfDcPkdGVhWf3Vz9Uw9K+xOWsIzhf0zJplnlUg/Lj
t5cWcL0Z4QmV9jepBkf2z89Sd4ojkozA3mvnqmHum0g7kwoZpRnIdH1nrAZx
JbkTVeq4X7LOzy9e+Ab7PB/PLuSRkKLv6Xe+Td+gaevlMSFtMnJ9X+eqm/4N
5nwfvTHdL47Ksy/fEg7+BqdoW5OFruL+qn5AZcH2G9ywk/3tZkBGGqMmpHy9
b3BNM+CXP0kcBa4v7fRU+AYbtxoUXBvwfrI4zmnxfoNbhR6HxEzIiE+UppH/
bxV8KeZy+icljm4e90ubHqiC+BT2zWO43n+8tC84C6rgUL9NmvJhXD9Nox67
xVYB9eV3fc9+EpJ2JelrPK+Ckq8mZUeOiSPbkK+K3HerYODFv2kve3weXxT2
j5+tAqUz53llnPB5oNKtr5Qq6LhEIetMkZBKl/qo8+4qaCaf/HD1tDjyWWir
UJuvhLMq7mL17mTUQHvjE3tjJbRNsxhU4fy7l3fSd+hrJVDjVshBuH5dkbE0
TwqshL38YbODuH94d3b9gr1NJVyZY9+6oSGORgzcZVV0K8HnpH/y+BoJkWx2
72M9WgkPXT/+scD18Vi9VLRySQWoiyvvfIjrp+tortvumAoIE8z+o479adn6
yTud7hWwc2uxhg/XWwbW2jMf7lSARsbX8/XXxJGGqA7F4kwFnM57dC8M1+fA
4/27FckVMHxCIGF+Nxl1Xrq7sGNXBSBuqdyBWLzfZotNLbPlYCOVpmcRR0Y3
Xe0zourL4WVFOM9HVrzfIdtC76WWA9WUfZnuNt7vL7728q/LIfIV23D7JzKS
Lt17bbt1OXQ9FOqcZycj265IpQadcqjpqg5dMhZH+QsighHy5ZA5FnLWlxPv
N23q9rtc5fBE9GgeXQruH3iPjsv8LoOodwqnfmI/4iODqv72lsGaiJye9lcy
+hYYZ0UUlMGkgO96h5k4ov/hxfssogykWBysInA/rXr5fkWFQxl0mH1n+oT9
zfNsTQsG/TJ4Uyr/+2Mm3i9OWW71o2Wg+jp/xRT7oW0O+8pecpaBtprdI/ts
vL+KfRx7O0ohjX7bQeZc7H8iS+ByVilUyn0IMDcXR3//xt4LDy6F57g7NMnD
ftLQExeWUtB58/zZH8yOYFbMr10KV58MnHLPJ6M8IQ1TI9lSeLzRLbeGedVd
es8HtlJ4vYPp4I0CMpIf21s4voSAVt1GL0YU75fqqjG5CcEASxL3OtYzP/aw
3E9FkKfu9UGikIxW6Ivzkl8hsNA6LauFWcYs5vaSOQLZvreOtzFb1jxnOqSB
IH8ydOzLfXGUKm6aY0tFMF+2/OsS1uf91G/m7kbQvs2Nz+qeONLrvb7vZxtA
8VCh1v/Ha3t3wMwxCKA2+CTvV8xaRjOF/7QAxN5lkulMxVGjcBqrBysAe9KO
7BG8nv/G7e7saiyBepoHgQaYqxNO5Pq/LAHImLEqw/tx9h4d477/SqCto6Zi
L+Zyap1hxK4SoPCPf9fA+3tyMTBDoLoYXF7ErUwbiaOSNH36eK9i0C4w+BmN
/ZKSjeA1sTPFIH9FoqTBAN8f+cmUVNpiMFDs/qyOz/PIevL2w2VFcMXWPpAR
n3dWgY1uvlsRvDjzssjoijiSfaKYqEwUQXnaEQ0lfH9Sie2b5ZuFsO86yMnp
iCMJmmqt80WF8OSFnpM8FxklVvjHNzoVguAyxw0q9r8kb911nWOFkCatoab0
mYziz/Nr9KwVwLwz/zsq9sPCTGPvDXMK4LBr0ELgWXEU3Zj4Y8y2ALibLaLe
4/fEH2ildk+uABwUXy16nRRHETpHIxe/58P8nQED1RPiiJPz36JNWj5Y6iae
SsTvOaS74vRvi3xQthVeTwrD+T3SL8xVMh8MTHLlrA6Jo4Ab2rO083kgfIFF
0OcPCTEJ8Sj7fskDrR8jZoEvyejF6FAgy708uKjxaaIa55udHxMmgsl58OFx
T2sl7h89TR8e45nMhdB3i7vV+MURjfjhV9HxuSBYYJi6zYWM3OY3hg/eyQXG
peez8jg//kstPZwonAtOtdV9sdg/Oj/y8ZEazoGf1M+rXTtwPy93sT8zOgdM
KTJDv3C+tlvlkDl2IwdS9zxf77hJRj/y+p+X8OWA7s7S/AvYf1s5x3Wp9GaD
cq7U3uUSElo8cZ9a8yYbnkTkCY3jfurBNtmnF65kQ6BUh+Qsrkfrk6r69FzZ
kNE1GU/9REIeDfqyJZ1ZQFU8G02Nxv1xlvluu7AseK1d/beGgvPrW7cxSb0s
2D6w01VTgIwo7iFFExxZsHQ1d3B5L74fpp9DozoyQUWv/8RlaxI6eaHIQjc0
E3hFB2g5fpNQ/eFmNWbdTNBlnjl2apaE9PnGhSr3ZYJ3X1jTYA8JjW9f/+3S
ngFfz3WDrRwJWU0zth0OyYBj/9l1bgqQ0GajYPK8TgZYH1qECxQx9CJbzjOe
PQPYXM6f53UnIc53aoYGbelQkn20IesWCX14dv3ovuB00OoUPL1NiYSk7lmy
1WungzVDpoQIMwkVXHw+83xvOni639v9rUkUnT0SXna8NQ1KZWmfddmLolb+
pMgfgWkgY3vL4P6gCDKiBdukS2nw0v9pTn+/MJqbadW8sycNLHPvn325IIIW
Yxo0j3z4CoL2icI3fEQRvcWvrY/CX2FuNlqiR0sUCR7fn8ERmwoMWk3mWmQS
Uth5xthTKBXULtN4tgxQkFaHOeev9ynQ10jwXN8phsw+hFQbC6bAP4X+pC8S
YsjNssipPToZBPbZ/LunIYbeKI1LqAokQwoHF1OymRhK38U0lBmVBLfOWXJq
0pFRbadc4MH9ScD++by2dYQYGo27rhL87gs0W8MAwn5mw+r5Lxr+L3D1XtW0
B+7X2JWTPllHJoLu1d9V6/g+STC2XR3lTQRpp90/1HE/qNq9waj99jPo91HI
bHMkZPDxQEkpz2f4QWfylAfXU1trdSvZiE/AvHx7qwHXw5eE9YFY7k+wx6DP
VB/7sY9Mb9vZ3iSAW33ErFIRGZX0lHq5cSWAzl/V5h/4vXYmzCgsh30Eup6K
LFZVMlq02TNnxPkRPp1j1TcYJyP6U8eimkLjIcsktaLhljgSYLl1keCIh3Mm
l1U/3cP9cJ/P9q8hcdB8fYE/dyfez89pmQL74sBeK0uFtI+CzB533/UP/gAS
Js/Y2fF7dju9jfvf3g9Qd/td/yrOBxGslNqHQbGQ1BDZVHyYgjL6L7oM7IkF
Kk9+Pg9BQbWJ9lKagTEQ//PBCGuGOBq1ez9cxBYDIfzrefsR9nPe/qJXhd7D
FOfIrTEDCiIdGPRVEIyGXY/WYy1MKEivSHKRSyAKlDIDfBosKchL74n2Gv87
uH6qqZTGkYJyl+tzOvki4WX8/si74+K4H+fny+F9C7vdmpt/v6AgblHzp6E8
EaC5St2Bgimo79UXNnaOUPjo9PDgh2wKcm03sj8rGgLE5GT5uWIKEuLjGHSU
DwbeDPmFngoKKrtVq5pyJgg23ONcbUSoyPjz06Rh3UAIKmVVQ20URL90eO8+
k9dgdLE0nqsP79+D9u/+8/5QeeEG1/pFCgpZV4ZfTK+gmDd1NHiGgro9E18a
SPoBY/P5MhYVKuJn33etXNMXVtQkDNrWKOhmjCtZ3MIb4t0mMgb/UVC85MzP
1/6e4PWlOntghxiaKdApW0t9DiLPUw5dukZFUudKAgyb3AG8rlp+cKeg8S+X
Cl4MPYUwRjub6LtUZF5J0tUXcgG+QuvPj4TF0K+hP0uitxwgmcfm8ymcD1w3
ml/8iLWFMpPLlozSYoieI0G0dNQK1wOQbZYXQ/uNVt32q92H2nu5pWR3PF5I
TE5e9W2QUxK+EuxFRa5Bod2fQvSgPVBzccOPijxWPrE6GilDz+Y1UoOWGFox
pldJCT5BpE+bmQdcEUO80g8nsm7pEVxNZy5cMRRDLreZThBfbxM9r6PDyHfF
0H3J2wzxkveJi8F0ubTmYkjib58ZXacVUdt4fnTJWgzFj9A3Hgm1JcCyUOe7
oxji/yYrd++yAyGYqiNVv0RBwckGbyLZXQixgVKf/Xg/dwd5bza0PiVeZz5o
LwsQQ6XHr8puq3EnLvYA7y16PH7q4p2Iz8+JD5whkS7vxZCCsEfYIR9P4mTT
zeKNT2LoZzBPTZ2pN9G6UhVVNUhFafRf/xir+RLFX/YaHS8UQ+aOqlL/SH7E
rpH/jrdViSHyfM/NcPpXRP1vUZBXxfnD0DJYZtKfKNlz/vyzKTHUZEYzNn77
NfF4/u7LRDEJJHFA0yVdO5BIEnl3bQG/5xd94Ryup4OIINVoA6H7VDQdMpqq
fiiY4Fx/WBPNTUFnL0ie4zoQQkQGD484i+L9YHAYGdsTSuxPLtyVYiOGaErL
nNK2hxG3bof2HAkVQzedmPc9+R5GPP0XJ17DI4ZK5PRTzo+EE7V54d4ezfj+
LXw4y9nyhqD2OLytrhBDTgkLQ6MogjAqFfx6gxBD3UYKjl/T3hJit84ZXugW
Q0d4nu91iYkkHp6gFh29JIZCWhuSzr1+R7D4kgN516hoxY/7DIdbFDEtrmes
tCyGtM7cGRyxjCayBmsjFHC+TfmXYp9q9J6wvnef1+2fGNph4OJTTI4hfnsL
m13B9TsrT7gj7n0McctgQms3kzi6w/FN+AVXLHEj8/eumL3iaK+1uYVVQCzh
ojvCLMAjjkob9xTqMXwgDE0v5/sIiiMrai7DiacfCP/GXcFjouJI0Mfg8sG1
D0SHzicXWQnsF8e3x+6yjCMWiuKSZeLFUBiHcvO+73GEFnXx0v/7McOzTluC
NvEEsIn8XCJwP2qfI0X9FU9M3mKOi8N+auHTyo0j9h+J3B+bq9EghrK6pV6d
+o3ZQXmPNT5/l10PijScEwilse3mX3C/o6r4ae7KZgKx8N2j7TLOv0wPxnjv
PP1EWKqb/a1Wl0DtkYLqFts/EzfF4kOSLkigd/XXHR2ffybuMAk9iZ0WQ8ab
4Z89diQSlGzW9st6Eogq1d4V4J1IcBosalc+E0crhmwMkbu+ELJajvLuvuKo
IEDjSILfF+J2/NSv06/Fkfr3ipCigCSC5UkBS18U3r8D2yu+7UkmYBoWMuLF
Ua/2iR+twcmE3q3YzOAkcfThueOBQY4U4lj0fqv3ZHF0Lyv70kx4CuFxvrCz
Ffe7MhPf3X7ypBKktsUO9iPYb3FIpW1FphLZ38+4Pv0mjtDZ+0O7Bb4STmEs
oW8acX9qn8DCGfOVOPnL1hM6xBHl8vdotj1phNyeP20xPhLopXnAEU7tNOK9
h/DKrpcSaNlDspEvOI14/vv6SMCcOLocVXdXuD2NAG5vhbUVcZSXfW+TxJFO
VHpRTrhaiyP+RoZQCb10wlYxlvWekzhym/wocSg8nXCOmXH69k4Cjf1TqTja
nU78Kq9+vydGAp3lGr1+gieDiNO1qxLnoaIv0m4/Tl/LIHLylw4IRYojlnMC
fuciM4h9DI9uRMSJI+ubRQcu9GcQnuz+akdlqajT4VqBzv5MokU4fEE5TQIp
Bq5fumqYSRjbbci1nKKi6MSwGcP3mYT+GSOji+pURFN22N14OJNglznQW5Iv
gUx6W7nvC2cR66fyDuRdp6LaFas0y9tZhOHnSxe3QAJJMbKeexyXRVS8ERDk
KZdAQQdThpzGs4hSwzbJ3fZUtHr8P3s30WxCxGhWUGM7FV27PMPiZZJNHGma
Zu5ipKISc+8Ev0/ZxJUlATWOECoS9hRVDpzOJv5YxDysFcb5Oaq8I0wshxhY
CGWJ+IzzS/ath+/u5xDlXdebT2ZSkUbjFt2HpBzigfFPgcMlON9NRr37NJ9D
BEiN/nCooaJ9W8cPp0jmEpoFWgWcHVTkwNVbl2GRS7w/NKfIMUJF/dIOd/K+
5hKX993v73SiopPnOP8UL+cSjLvvWVzdoKL4m1lB5bJ5BPfqw105DBJop6O2
eI11HkFV/cc4uiSBzAOXSxsz8wiNlGOeZSsSqDnR/2r7zzyibcvI54acBDpc
JvG9Rz6f4J6/lzg8TEVvemt9huzyiX3Odp5afyTQ3xUzoYncfKJvT8+dfSYS
yIiRIW92PZ9Y4S+n43aUQAl5jBcj5QsIt1dDVUz4vi3eZZv8z7qAUNSsUzfC
9+MIO8eTv6kFRKKUjvb5HAnkinj2pcwVEP0p5+dEoyVQ1UOBpBuUQoJJ7uuq
1rQEYuY7eJrlbiFBVr2xZbJDEl2uJveUxBYSZlb7lZjZJdG7xxJWloOFxP0p
zoff/5NE4wdkGYT4iojwK4+6njpIImqzfHTzlSKii8xzmemrJLJ+oiiPWwSi
Mznj1NwvSVQgTtTLthQRhW7SdcvXpRBNt8qdUeZiovWvs8/APml03vPcRpB6
MVGTSTMhPCuNXh/SDFTxxvz+1OF7SVKoe+gS5Wd5MfF0IeKoloQUEnqlB/Hb
Sgj9xPJ8NglJZKp4XU/3RAnx48sj5ktxkih1ymhhh1MJsaVNv3HHThKthhh7
5OSUEHu+7/e8LSeJlE/f4zP9UULIc+yI/XBIEnkuPczgkgHigl+U5QiXJKp/
Z32+2hyIttfMrKbbJNE+dfthh0QggjxL4k6wSiCDNWd7sUkgTrfS/yzvlkDa
2icZHu5BxGm/7z1l3yTQ6ucy7UppRNymfzuhkCeBIrZUo/dfQMSXb6ZffiZK
ICW9bzOPzRFx8Gv4VgV+38PJ5+UbXyDirYAb04vXEsiDtt6NlIiInxvbdV5q
SiLKtQv1rt8QseVxamPoIp5fWjNX1wQiuGa/DOukU5EVg84dabpS4nnpFau9
phJon2FHqveBUqLr1MOjZh+oKDfrysbQyVLijaQBTZOuBLrG2HtGwaiUyIhh
k+rXlED/bhkEvn5SSuys+R2idRbnF9ZblFMFpUTV1yKpCwoSaPbumE1Edylx
3+BqZ7WsBPIvugvfV0sJQy2/U/5UCXSIfXq3OkcZoah2YeGNqATquHdf74Nc
GbGdUUiazgK/LzQfu3GpjDB8OOb8gFcC8XNZLmhblRHCrCPkamMqQg+/KyT5
lxEdIWWHBNkkkHGFjQdtShlh/XDYbtNGEu3kW226XldGXOqRCBbRp6LkRw58
WTNlBP/rqAZuGgmkVb1hwrSznPAq4Vk016KiHwJPMoxJ5UQe06GlUg0qCnu8
tVmkWk5kSqn4eP+iIsV69/Mcd8qJH5zT0bTukmjwAF3oQ/dyYrtOYUn3AhU9
c/QarnxfTjAHv7KQnaUiUvNOCYGScqKuX2fu0yTOdyQ/e7t+/D1TdgM/X0lk
8YS5vHGjnNgc2Xb9s58k2tsewELmqSAerGwIpvdTUY743mtPj1YQj/1flgX2
4HznHvKxS7eCKDRMZ66UpKJ/XZzfpW0rCIfDrS/etFFRrFSEkk9QBeGnFt9R
hP2NumIpupdZQRz3iRMobKCin2dmVP9rryB+2Um8bK7F+frSnhqJXxXE6K6E
f3++UdG5G8c0WTgriWcnetcZ3kuiFbNbLUtHKgm5W1WqgWVU9M7WV7flSiXB
oWpGa4Xfy1m39J4Mh0rC/UHApE0xFS379dwIiagk3GRqjm0rpKK34dtHHxdU
Ekw/i4Kj8qhINU7M5EpfJVGdXHvivxycvwocLXj3VxGz7Gr7O/B9PF0Vu/Ln
RBWx0/uGQNpXKppvqbEbMKwidugcZ4tIwfl0hudpTEwVYcFtFRWUSEWzP0/R
PiutIrL/R6GVx0P9dWGVbKUiIpUt28wwxsyQFk4SLaRSoUiJlAg/WZKkpFJJ
pLQRKRJFSSJLp1JE9n1fsy8zwyBt733/fD73fu899yzPec58RmGNRcIzGt4W
OHHFsfsrmDxaP7cgkYaGC28tMJlXBKVHl49s+qCFAzLvb6qpFEH7n1mj4L9U
0l+6l4qYFEH/mdQve+NpuEFb7N7g0SLgRDz8ZvWLin3rmCtLLxdBkeqLgtEY
GkaYHoh/8awIiuE0b+tDkg+WwSrhxUUQO7Q9omGKir0HU5I9BovAMVc273mZ
Foa7VGvuFisG3YBkzchoGur7zL5i0opB1GrIOrNKC7vPK+tKmRfDl43792XV
aGFY2PYcvlsxLP70SnJqnIp697wMGm4Uw+7FET65ETTsfPLgY3ZaMbz2zVm8
/yYNr6V/MnlQUQwfRISL/9ygITt36FsApxhQWqyZM0TF9q+SFgclvoHGNv3b
0R1aGFq9rtqQ+Q1m8o8ekbpGQ8aclu7Ct99gdBo+sS7RsHnhvGNJ9d/gFt3t
q2gI6ZeytOEr09+gvkZ0xY9gMv+o7PFwkS2ByeiY5JkxLWzUDpjYvrYEhFsp
zqMdVAxe/8RP80AJjG85tudOEA01t5T+Eg8oAZpJ9daQc0Q/WE4EjT8sgfnX
fHmzrUSv2K8QrMorgWFf+2SPszSknjAOzWgrgUCrA19cA2hY6+O68PbfEih4
tmnWlfTTcxeiInwUSoE6k/DAuInoqRu5UtYbS0HF7lNL0j8trL7Xc0/foRR6
o/QWhBC9cPbpglVywaVA8/H0jPIl9fiK9fhXQimUBjrsT/KhYWWurWrbZ3Ke
j0t8njcNFZbHmA6WfAeuqrxB60kafrq1KlRn+Du8bxujLCHYaWHcN/8FZVDF
HT1u6kZD4cuKCz7RyqAp4+LF7uV0TPn32FzMvAyenu+Wvb6Cjub+q8Mt3cpA
pT399kgJFcd5TysehJXB708/VXRdaHjLTU2i50UZNKp+TTutSEd23zNLWlkZ
yJYNBmcfI/46RLl9arQMXLaWjv92pqF/U0pdrng5jDqnrDQmeOUeTRlBejlY
3hOevkbm3YLvL23MLcrhbyPVrZbw42FT7Qe33cvheHbLKQWC5+Grltbwcji7
uvRydSEVk9YyV6mml8N4kSBzkxYdt755Y3+ygpwXe6uhik7HIU3d+Lfj5fAo
Srl5vwMNbyRldf1ZXAFX2DvyUg+T/FHUX23KqIB4tc21fw/RsPp+jlP4rgpw
zL4uvYdgn6Xrk+o9K+BEzie3ZHsayt7I65ePrAAVH4vKvwdp+F7IkHLsdQVU
F0ivsSL44PkPJ9KrKiCyMyoszY6GArMbX0xzK4B2Y2z2wgY6Vq3tmlIQrYRj
184O/jagY8LUY5nNyyth6HTYy9Q8Knq/OULGrEpITztatIRgE8/V+8PWVsJp
v7Ae7/00XKbV6/9qWyWw9P9ltL6n4sDg0we1+yvhs82XDG3SH3KSjubOuFRC
w+6c+eHWpL4c1VpXnqkEwdljfSNWNLRT7P+98VolJH4GuzPZVNRqe7bq6INK
OOxVrftiH+Hj+8cNr6ZUwqujMuELCd58w/Xj8uFKUPh1FiMtaVh+6r+idW5V
EHXEelPyDhrGMZgD9meroG3w4asFBHuO8kQuhlVB3TFhtgfpP5tS3lCexVRB
jGnrp2ozGi495r299EUVrL9je0CP4N7Vuq7jeVVwd/X01H2it7M6+deXllWB
dVDl7T/baHglNuvFmrYqkPP+t0nzBRVtDviV2Y5Wwctljh1XnelIkdEfC/pT
BUXHSx00ttJwtmZm0VPxahi/GMu9voWG3yNytItXVUOf8h2/cVMaxu44s2tE
qxokpqOnLQl2F1v/3xLDajiue1HtWTIVNxb9imRbVMOdMJ3e5SY07N4YWHPW
vRqEjzl/6jQmfJ4gk3k9sBr01DQyLQieEsy4/SCsGn6NzU/N20TDBd/69mWn
VEPvxv9y75F5Yhntgl5RTjXEJI60CxGseGOFTH1xNcA+LeO7ZD6hjr+d7m0g
96dqZIkRzN69q3GirxpS6xtFLIHw/5uh7LlT1fBm49ZvaEj6m/Sl+xLzayDt
jKP+1zN0tPRTOKMoVQNSS3iL4wxI/jXlHNBeTdbnbH21iODj6/euN2TWAId2
X6cjkI5esWMrdhjVQODucL3x9YRf/oX+tt1VA9srWZS0R1S87LC67cShGvDQ
m3BRITjic36+v3sNLN9go7d5HemHqjaPQgNr4KC20753a8k8cIV37m5YDVy7
VGZLIzh9MOxQ0sMaoChnHInXJ/Vhpr7xbUoNHO8wCltGcOHLj4qFOTVweFM6
Q/AKHcsX282pKa4B42d364XW0LDxv6muroYa0LLlml34//9TayI+cfrIfoOV
1//oEv/r0p7849eALn9tSYDu/+vrkNMqqVp4elp5axCbhmJ2s5s1V9fCmf1Z
y+cTLFVwW3U9sxYe3lGXDWfRUF5RW2i7US2MX9qfIUcwJfhbn82uWljSwXRO
ZZL+0+tYdOxQLYjINNdsJNjQ9O8zX/daUBqo7/O/Q8WtyfdCLwXWwqfAe6BA
sKUYy+V2WC2YhH8tKbhDRzu3sm1PHtYC907fZDODhs7lx6gZKbUQy6mN336b
ip6MuQs+5tSCT66mpjrBZ27FDFcU18IfgZUPuQ/oGDKp9729oRYiC5UwjqyH
W1W9GO2rhSFJo753xN572a43fvNrgZ7vuUQgmo5P5ITcF8yvA9U7MUaWmjRM
OxtvISdVByrH8t2XEn2V3b5Om7K6Dqq25bhciqfjp411i/WZdeD399LYZbL+
PcGDY2pUB1f9Q1lpBNcLilXt21UH6gUrOloI7nR++trpUB3EBXwvkaYTvVJs
eOuUex08sA+2T0mmI5/a5BUcWAd9rj/+KyDrAjdO7YkMq4OPg4VybG0Sj3Fx
dvzDOtC1XRtXSLDU7mSp9JQ60LJYXn6K+Ef+zSZ+fk4diN4532lC5nMN6ba6
78V1sC7YIwGI/5l+flktDXUQtO3wfWfy/g1NEneH+urg1JjlbOY9Km5Z/8Lv
J78OPvvRqw3yST3EmtqIzK+HqnfCiQySb3b/OvVlpOrhT6qp6H6Sv84OAcvV
VtfDlfj1za0bCF99lp5lM+sh4+VWed3vdPzzb65f6KZ6oE7l1oaS+r62gTPR
YlkPnLwrvBnCJ7L+bZ7ajvVAF1HzMSZ8l/i2ZDT4VD0IGq1VjNlD7OW9O1F/
sR6MV5/Yt9WW6Ht6Yj/ldj38e1r6Ia+YijtcbzkFPq2HnedmLfhC2tj8LKir
MrMeAh+LM1qJvjje62av8qUeHtvdEkyLpCFf8UCLX109KL3qTMxMIfr84Bab
0h/1cG5q3r7rRA8vecCuk5+qB2ZLwnQ96Z+x9UqWXkINMNF+VX78gCZSly6u
+LKsAc7aL30XqaeF2Tt/my1XbwD3DL3gO0JaaBI2WOy2pgFWHXl42/sA6X/F
9Sa4pQH4v2VUj5H+dXh+4aelNg2Qn6oU9eYyHUeNXsOx4w2QNyfsYZIEHc+c
e5T3/nQD7F0tS1loTkGR3OtrF11tAO7Rl9em11HwzvTpLIf7DaDhYOuUlKqO
ymxn1tvnDVBdOZT17L4GvvLc80rkfQPoZTRvNWJR0ODlRi27kgb4d2IVvjtL
wZJBrZT05gY4L36Kdfs5BW3UVqjPG26AhOM3dwkUU/DHEZGnVr8a4GYX31pr
EwW94viKKQsa4duWKy6KYxQUaO2O/bOiEZIvuO4ofa2FN2Qr5XZrNsJmt4pV
8wSpKLcv/+7TDY2QsuG5f7YHBZ9FpkjNmDfCv+j+tP++ayG7/G6k2cFGKIrY
ztgrTcVPYpcWxZ1shAVzRN1T6rVw5xav67zARrju7Zb/VY6KrRcPiZiGNwLl
c+AGw5VUPIHml+4/aoRx0YoEoVVUnP69du5oWiNs8Yo4p0twyFr1oI0fGsHv
2lh9C9kv6Sv1O6qiEVS0n+sKExyXMce/v6MRvjz4efwTOV9zfIy/jtMI7ZRM
iWXLqfie1uoVLtAEryuTxUVlSD0c/zbetaQJ+AqV5QadWlj7NMtNV6kJXGV/
e3ZJUPFI15PBUJ0mqH4Url++iOi5VZHOrUZNkGKt4uiygIpnD5zr0bZsAp7D
hGumMBXF7roevnikCb4urv3BPE7BuzU2bfVeTXB9//Ugu38UVFlieoB6sQlM
3//yjq7QwgxzVkNgVBPYOQ3XFfIpCFcV91Y9IfZM+vQHcij4/Yt4lUpmEyjZ
F3a576Tggbm/dpwubALak6dTZ7dRsN9woKS0tgkMzP1vP2qnoHdA3RaFH00g
NTG5YLyBgnOzPxV68Ztg+kvFjuZKCt6cTDf6Or8ZOuwubTzwjYIrdWILli9r
hnbLm4XHPlIw5eS19SfVmmHex6dhs9kULOxz0pXa0gwWUVNhV5IoeK2Y5mVp
1Qyrryaw5GIpuCuFlxZxtBmadB4dl4mi4LKwnOFy72b4vr/c0TOUgm0nz2uI
hzSDzfPW7KWBFHy6c8tRs6hm8C1rfG9qq4UndBYlXE1ohkuT+x53O1KQsbSu
veh1M5h4rfVq2EfBqcmHK4Q+NkPf2oW+SaYUzKs/YrO5shmSF21fpqxHweBs
yp3gjmaAQU2ahZQWbn3AqcKxZlhnczNWYwkFF599t+jfn2Yoa1rGFpnVwPqD
58wMxFsgKbCeR+vSwBgwCQ1Y2QJ64PqxpVADjygt/JJDa4Fd7/q8P4pooMa8
mjkz61pg9R3bV3KBGjjWe99Qb3sL/KfWuWL/Dg3M/Ho4wHt/Cwhquwl9XayB
Z5LVszOOt0C8+W4J0UwaGl0bm+T4tYBvQ/QgS4WGIm5vdbSvtMAFkQ7Z5zKq
WL7jrPvJ6BZ419gS4iWqjre1jVNTE1vgsd7+zcovyPwvITYwmNkCrwXmp2os
0ETFiUoVjcIWUDu6VFSQ3N9Xe9fBuaYFZtccTTh2XgNfZNk/etrdAj5Xkobc
UzTw1D3Vlm5uCxwIf+clUq6B686MyCjNaQUlYRc77ogGCti92XtoSSs0qHWL
S53UwK8GZyJjFVohOjPRqEyRgmEKRuUt9FZIb12zSnwNBS3niCyQM2wFq0x/
wZNmFJTtKd9is6MV1p3I27HOnoLthXdCou1aQVNcX/g14YfEJLuPta6t4CT7
pVDgPAXdQlf/lQxohR+8te07b1KQeWJo3e5rrTAaXnz890stnDF77Xfzfitc
eTFP3ymVggVapzPLksn5og0G+0k+hiwG7oLsVrh1WZCdXkjB7dz59O1FrRBo
7uOn9kMLl9R8PxFa3wpvwg42vm+hYENm1LOvP1oh1bd16GofBR9FH+gV5LfC
kzNnpPpF6Oh0WknJWLANbm3Y5DE2S0HO+vQHH5Tb4PeVRwcHxKmYtcq34Y9O
G0SIHbaqDaAQ/bdBaoNRG/gerXdIU6Dipq55u8/sagN3mstyTQ0qin4uuZF9
qA02p9T077tDwcqnkSVT7m1gpbO5y1ufitGXbYR1z7VB92fHPVs3UtHuuMLm
UzfaYIPRn0sNLyiovL3v/OuYNvA75eh35BQdB2gv88dT22AvwyDrfi4F08S9
Z7Vy2yC7S9Cw/CCZf8bXrXEraYMFTlHpC8PouK5qjndKUxsUlAnUpbhSUeBN
8auBgTaIMwF1Fy8qfr19c1Rtpg0cZOm1Yv5UDPO1oh4VbocXnz9uvBVExT02
q449WdYO86euFcwMkXrmRsy9o9oOghmxMywuBRuvCj66zG4HrfOahx1vUfGh
8um1p43bQWHtlZ1niL6wzx2udbFsh4dKDrXBRA8r7j3kaevQDpKuop4BolTs
GalesMOzHQ6GiL3f3kbHpEumzwyD2mFsutPVsJeOx+Xfb2KEt8NF9+Eq2jAd
qe+02pVi22Gk0kNXmcx3ozsf+y990Q6rX9r4zPtExVcDUtLzc9tBWDb3R18R
Fb0uhL6a+tYO/94MnKgoI/OB3G+zgcZ2cNOe21shro3TGR79Tf3t8AhcRT4Z
kn5g1hNcOtUOXsw3DU0rtPFsr5V8/vwO8Hom19j3g4qGgSU5aVIdYGntdnXV
CBXnLDPcF7+6A+reP5b8j0fFwrTXnEhmBwhcHV7eP0PmgS2qYReNOmBwVvhi
pBPRv5331H12dcBH2XcToVu1cYH/ws/Ohzogb7rmg504mQ8lztvbuHfAtItt
ZoeNNkakTPzcFtgBpUtYWoYraWhpfOzO+rAOUC/VfcIg/CHd2szQetgBiw+1
DN4g+rXR2+K7fEoHiAafEHch+v6B+KdjS3I6oLNrg1YTmX/sknTnzS3ugJPe
mw31o7RRAZ4/mqjvgLj/8qrn51Cxu2Hluh8/OqDhcsCXATK/P/WMqKuf7ACF
buao2XttfCMYrN87pxNeKBzYWRdA9GjVeqGDop3ATf6rmtGijb6x/Jq6JZ3w
sTyh/2EcDRtc0h9byHbC9UVFp+dk0VBfz8WjSKETXv+kf2yvJPbNXW2wUb0T
pN3TmE+VGfirvFUsh94Je7Y0z1+5ShPtHkY36uh1goTerF25FQPzj+1KSjHo
hMPmFbZJmZoozxbzXm3SCVHpmYllXlp4XqDQKMa8E8p/pezK/6eFXd8DF0vv
7YQPditMz+Rq4qb7a9pu2HbCO41gmDBm4NOj3BQhx05Iqnra8qWUhvOZqaeD
TnRC9p2nryIbtdH5r5PpzH+dMPgjImNPDBWLSuSl/vPvBH5voWjaFBU17jZ2
DZ7vhIcWjklLiR655ngr/UhoJyhvp3/ZdJqKw9rmgS03O0HgAUW0mE1F89/z
zfbe7QRfXbu3/oOkfos/yJY9Iv50C/XZRvhv8R3/PpOkTmA99VbolKagpwMr
s+BlJ2gsSJNWBg2s1hq9sOYtuc+pNSnZTx1Zs0k7X+V1QlDTN5FbqRp4++vh
VZTCTli433LU4oIGTt2SG35c2gmbnh/UO12khdaHarPlajph6Whw+IYbFMym
hV+Oaib3m28ObJCioNzMlr0LuztBtKmg63IJBQMK5yhfGuwEvUCnl9ROCsr/
7TWI5xL7DKz/7Z+gIK4p3p/7sxOeh4dkHSb6xvG/VJ/6OV2wO6RJOiOIjkKp
4ZFc0S4Q2GL8+t4KKj7v/e/lQskuOG6asMKZzF/m8vu+qct1wRxHiy3ecXQc
t9b/sUm5C+5utuuXIf66Fblijj21CwQ5N1UZcRTULf270p/ZBeMaJcd2ZNKx
UbBb//a6LnBI/CembEzmQcMve9M3dcGT/qHSPjLPrDqd7FmyvQtstzc/iU0j
9r6+HvbDsgsoZRoTUWZEzw27JwvYdkFL/tu4kxkUnK9qWbjCsQva54qImFpQ
Mdlet1PPtQsG/349IZlJQbN7sr93n+oC6rhzSS9ZH6v6JXMyoAvsknuLfAmO
WNDBCr3YBW81PX+H7aAiy+TTzifXu+DrirLgY68pWH8u0bUgirwvrF/OdDsV
T2eHXml62AWjotLKfVuouILn+mTySRekGdbeFTShYgFt54fFL7rgsbWkWKwR
FR2OMluomV2w6Vntq+cGVBSMk542yeuC05+Ktq9eS8VnjTOSDoVdUDH+OcLk
PumHkq30s9+7ILU1WiKQ6LFRsw/b79Z2wdNthenv1Ym9lxKcM1q7IJ3eOe6v
SEXmh0vBZb1d8MxYw/OILBXrZo4/GhjpAq/Uv/wjD+l4mmn+fh6f+OeXacSO
+UT/u2nXy//pgpQjZ1ZLkH6ZnyjJWzu/G/YMzj96dpSChzv44vvEu+FTf5iP
TQcF5y1vonhKd4NDXFW2fQUFkyzzTK6v6oZDFJ7uOWUKbguLc0hS7YZFK9/q
WyVTcORLcOBHrW4oFx1uWBFB9Oq/o/dbdbth4Wm1lppGDWSu3fZ22oCc/+dB
ncRuCtZ6aVZJmnbDxM2xDZHXNdDvxeJRLYtucLmdLBcxpoFyfTyRbVbdMNMj
VRE7XwPzFOpVnOy7wWznnh8fFDTw0P6cjUHO3bAuS0ZqxTI1nBsVY/fAvRsq
Txp/9f+ijonfg06/9e2GJVazS778UMetQo63K891g41f3ZF/5ho4BKavhi93
g5LGHh1FBgVv+FO+C93sBtnPFV/dSX0w3iwcULrbDa7mX/o/R1OwemR8nkFc
N6huoXMSV1PQR61GweZZN6xYOW8jj9Sb7OGs9afSuyFH/8pkI5kXcu/ftw5/
R+6H+DGNCxS0rzl76vmHbjjf7tB8Upf0I/HDNwuLuuHrz4QXMiT/npoap3ZU
dEOfwU99V1Ft3HJerWi2oRvaX6hqFPpRcShHtEe6sxtyHcx+7GFpY9jEyF/G
QDckBh9IiI2lorZWpZw5pxt0Rvh+culUdF8bH9063Q2sBcmF3i7amGbiKXny
H9kfYev+hPTX0d0bw/8I9UDOlkq3ea1k3rJfIha+qAcsNDzS1u2kotuJzkvy
y3qg/72WzUM7Kqb6vpqTvqoHPA3fL6cL0nAo+HwgqPaA+BWHD9K+VKTe3PWz
QrMHIk9sOtBF+p/LQ0Wfw+weeH8uN0EynNTnMw6Hs74HTh23p7PYNFTHiAEJ
sx6I3dkhtGc7DVW4lQ17XHrgbuBW9ZunaOj4J35Pr2cPrLVZ1mIZSMME0f8q
vE/3gKvVntHeyzRUUpYounOlB4Soku7n7tNQfs/urIbEHrijHr6mMI+Gsm+r
btt2k/X2O/WSf2ho/fHxkpHBHuit/rAzw4mB0WX/hZ3l9sAPl+pfQf/RsL7J
SET8J3lfNNXj1FJNlO6TCIkV6IXDf/RWq52n4V5e1z8tkV74/jgwfERJE2//
fR1QsLgXKs0pW0UpmlgjFjxtIdMLYTs25EowNFFSxvJUh3wvvPgtfEtojSYu
9K/e7WjbC9c0Lq3WcdNEAYOaRa61vWCeQKub+10TL2R9b4xt7YXJH0X/yVZr
4lzG14TK3l7A6in1+waaGPz8g9u80V7Q7MwrV2rXxHmrc/T0+L2g5Rwus6xX
E4VE4+znLPsB253jMoN+aaJ43Ym0u9Y/4MEN6rmbGlood3KuRWHzD2Bd733R
fpbM+7E6N1Z19QHFrkzBUZKOLK8LQtTBPrBp8J/pWkZH5paqID1uH4irhEbs
W0FHBtfTa+ecfog8yPulrEJHTZNX1heU+qEv684dL106qozSlX849IP2lYW2
663puNRA892L7n6YWGBy1PQeHSUlzzJyhvpht9m7DYYxdFzSX/r8C68fDozv
O8iKp+OiSNeY9rkDsHY2Plo6mY5iP1IuLFk9AIKqs8nv39Fx7g2KubfjAPTq
HcoIq6cjr1Wta33vAOyxa4v2ltTG8BDH9/nDA7B602HfLmltpGjGR8HEANyk
j53oOEfHwppWt4+zA9Dj8bzk7UptPByw3NR47iBEPJUxWaWojeXLF6ZuVxyE
6DlvLz3X0sbnVlzv/XaDcNts2V4Pov82/9WyaHEchJHknAA008bOxBPqB10H
4XpopHHnOiYG7Hgm0OE1CI92RzcctNTGZfyepsNnBkGmc1nnVkMmZsQovum+
MAjPtApbOoGJOzYfDHO6OgiK5dR4AzttHBi+f7QvYhDyT2/PtzFmYkhUveHx
e4NQ8OFsXskRYm9lrohf7SBMRW+s+XBWG3/7zXTNtAxCVL6713SQNt5V0M09
00PO32EWqnWRvMc97eQ53iDsSry76s5Vbdwg/rj60pIhcOpXXG4ZrY2NmW2p
wrJDsPBodHTgfW08ZSd36arCEJSbXIlcP1cbFwla2y9QH4Kli8yWV8ZpY0pq
1Job9CHILbBRmk7QRpntl2Numw+BVZPGtZB0bczgfvJZtncIGB/zNzzN0EaL
+/8s7tkOwX4XjYBPb7UxZOD0nJgTZJ2bFj+bq42KEW+bV3kNQZiD8yVrLybm
ruG9ifMfgtBsOydU10arDvoNpQtDIKSSI775izbyLrs6PwkdgtNnPqTsLybx
pieDasQQPIXB5pOlJN71vbLP7g6BX8yGuPPl2lgYqMTTiBsCxe/xM5FVxH+q
9qUpSUPQyhrsf1xL/Pf9wVPNtCFo11Vyf9VA/OfdEJj2dgjOX+dcz2/WRuZK
KWtG/hBwzmtX2hoTf37excgoHIK85UY6BReYmNqYZV3/fQhuJmcJy/dqY+jo
yqDZ2iH42LDhZ1IIE4/OvZgk3zYEO+3Pi6QNaeMmmcGyTT+GIGSL8p2JUaLn
NXfynUeHoC3VUWI0lIm/N75deZ0/BPLfktT2XGNi074Vm9P/DMH7cYmAd9eZ
mHXigmvN/GFovx8R/HNWG6OC+m9Niw/DkZLvkT7hTPS8veP9imXD8Ln7+eEc
AQZSC5aLOqkNw+3qJ1958xgoXBPECKUPg/1L/ubw+Qzs7f9h/UJvGFQbXUxk
7zDx42+zoErDYbCjqYRK+2njI4mMpEnTYZgR/sWxFWNggJpsuezOYXDVTVs/
uYCBNuvP8TdYD8NTB53318UZqLurd6XDoWHovP3VTXkxAyWPbt986dgw7Mk5
/OpKDBPH/V+5PvcYBtu6n1qUa9r4PXxZVJnfMEg+v/ShaykDnz85+54bNAxi
Uf2bfaQZeDm7u0s6dBiOCkX+E5ZhoGPZVtF1EcPgFvlu/L4sAzd2pzHs7w2D
xP2b0jQ5Bq6alrIJjh8GWe1H++bFauPsgoCgpORheMe/GFeVyMQGxa6kklfD
EM6onexNYmKm7pbysexhuDqxreSYIgMjt7/kS34chhMWBf8mlRjofmjpqjXf
hiFKO8j9xgttNPP232xbNQy49OZicVUGalztcA1qGgatnm1Dd9UYOP+RSdST
rmFo3XLxt5IGA7szUt8XDQ5Dkrzged5LJn4okuge5g7DBw+tYhaNgTGtfqJL
ZoehpkIkOFeTgf7cNgZ77ghUGH3ctfATyX+hzTY2YiNwn7Vl883XTGStSAk6
KzkCI4dN51roMHAJY8mzeLkR2Hjg46NqJgNHN/uWFyqPgPoTX28rNgNL9rfy
B6gjYHwx52KTLgOfuW9aJc4agVXCNd9t1zAw5GLyZp31I2C9Y9muNn0GOtxb
5LbPeASOM5vE7dcx0PCld5S/2QiswW/B798xccWn5vexe0ZgXuWmWsdsJs7U
b+z+aDsCIk41k2t6tLFuOEm0z3EEVqpM79u/kYEZAuI6Ym4jECQUblhvxMCb
0qds6N4jsHXmPydLMs+5UZuCLM+OgOkao+KyzQzcBvDMN2QEjrkmn9hqykC1
vYnlD8JGIDct33pjHhPnuSyYKrg9ArqqTu7rtzGwM/C/VT0xI0APjIkRzmdi
/q2GzcKJI5CvEOJLM2fgg2cGbrSXI2Dgnr69iKz75T2J2vl2BF57mjbWzGHg
3irR3FP5IwBz+//c2MVARp9H990vI5Co5PluriUDxX/VieaVjYCEQGGO7x6S
j90akfvqRmB3Ytf+qr0MFCgJkB1vHQGxb34HaWTe9X9dHhfaOwK/T9PdN5B6
4d1TUlceIecXXC4U/sBEt/PeabkTI7Ds6L4K3QMM/HGsSHffrxEImOCeumHL
QPudcvljc0ch82vvmvoCJjbqndwcKjYKrc9KRcaXMNBSHkuVJEfhQNX9OZGH
GFg6f+me3OWjsOalqWffYQZuHj3avFdpFBSM+vavP8LAgtpshzGNURh9lfHp
piMD9fMWDF5hjML4Uon0HqJ/Xj+x91TSH4WDD1VV1jgTvrj+evo9jMJFIRf1
a8fIvO0lGLR3yyjgrOyH1uMMlD9gLTRmMQp2rnkDTSsZeNco5cYVq1F4dzrC
nypP8pHyR0rJfhQeXxTaVu3GwGtLdsW8PzoKvfOWB612Z6Bn2sMcxZBRUF2j
stv5FAPXDzEnR3AU2jpyDLmBDMysuhRwuXgUHOULbUyCGEjPaZyrWDkK8Zx6
p2+PmfgsnnYtp4H4B1TOcS8wUDH0nMSejlGoz/invP0iA4XUSug5f0ZB68iS
f0WhDDwvvirLcv4YnDo3G6BzjYE/Jz0MRhaOQc35lOr46wz0av1UeElqDJRr
M+xkbjBw5LO0ucLKMbhfwUhtJfnrnHq8Jnv1GJzfYHNeKYKBHbdyD1jSxuDP
uPuh95GE/84s6h5mjkGCodm1o1EMrHZwcLm0bgwUbglkadxhoPm2TI78pjHY
ZrxpdHYrA78whE9nbxsD9RPjS223M9FQ9sC/3bvHQEIrzNz1IQOz/724PGwz
Bo9KDT8vf8RAZv8/8UuHx8BtrPTYoccMTC23vCN/fAyU6JW3UxIZqJKVuDLb
Ywyeet+6NU7y51HszJPdfmPwmeaq5vhdB2UvmdGGz43BrovnrdfXEn5ze5QR
cpnc5/tyjqu8Dort5a6VDyfvixH+3EDqLWT95o/v7oyBoE123FI6A/8o3926
O3YMuDuL89826qCv2FDF0NMx8Fb9saoqjIEc7gbrkBdk/cTlZ8KrmOjSdLN9
VeYY3C088W0Ref/hlWulI3PH4KJBFJbcJf461G0m+JnYT201lHvAwF0J14P9
SsZgscEaY6UYBm79wc4ZqhqD8Eut5vxYwu8a7eMHm8ZgY4W9lT3pp2tcr6hV
dY6Bw/6zTnrEH2rcpqh342NQWnHzxqqnJD/ZF0uo02MQz1ASPkP8I+2nOefR
3zEYf/8xriSJgYJ/zrmHiI/DMt5b5s7nDPwNGonTUuOQZmyKl1IYOBFc1XJi
5Th87Fb4/DaVgUNfzki2rx6HBc2n+R0vCJ+LqGzbTRsH6py0McE0BjablQUV
MscBK21oqukMrAr3zVqzjuDkvVHnSL0VVymMphiNgy11ctrmNQNR6ttq+W3j
kDgQUvbkKIm3tdeByF3jQNt0si7wDQNfPVgRKWgzDicW/l5/PZOByW2FRX6H
xuFo59GXn0n9xSm6/x1yHge6GL0qJouBdvrZb0ISxiGotsHTr4DwWYDD0PTz
cbjygpJ17AMDzQrElFxfj8OjZ6JJ+5CB6zYfDN+N43Dvxu171E8kv64IfSks
GgfdyCePJT4zkFKS/mtNxTiYJYYfmSJYdtdcF/n2cRgINV2U84XUd1RqXOSP
cahasGEm+ivRE/V76wVHxyHs3vl7XkUM/Cv7d+HpyXGwvHDmq4IbC6dsnxkP
/xqHHJE0nvI3Bvru1DBIn8MBH8W7ZkKk3nmcs43H53NgbZKDYEkJ6be3qk4p
i3IgKq9f+EEp8T9LbXHrQg5IZU0t8CZ84Fx3JuXOEg60VT4eZpaRePhWmOyU
4sC3UZb9nUsstJdV6RKR5cDW2v9UPpUzsCnn9NlPKziQMxKx5HIF8Y9tmcxZ
BXLe7qeBWyoZWPlb6Y3uag547xRyEqoi8YLSwWQqB5YsLg44W034tEvh0hE6
B265pz1k1ZD4BXsrrmRy4Oz9bokBgrO/rLK+uZYDSyX/a9pax0D2MS/eVgMO
9N/jS/MJfiVSdGOuEQeu1Xace1RP+q+ZZ6HPVg4Ed0s8G2hgYOGTpsvnzTkQ
u3VrfXQj6We/Nm27vosDbp0mvkZNpP72vFgQvZcDR2LzfQYIlnshXR5vwwGZ
NRS8QfhKTzAoItWOA14X12+ntTBwj92AZdZhDjxf+Z5ZHE74NnO39EcnDtyR
uvbevpWBYQtzG0qPc2C0tc6fR3Cyk8qDejcORMv3KAa3EX7Ku2HX5cmBd4+b
7om3E/9KTcuPeHPgS+PUt9sE/3U73DV1mgNfX118KNNB7Pny7cmcQOIvK4dL
do0sXLOK5bzwArEvunHHIsKHe31iNGQuceBtzNHvIZ3EnrL5w0pXOVBe6S0z
QdbDVD1eat7gwMK31p6Hu4j+C2z0WBPJgetVZp++Evy1zoi56Q4HLnKnB9S7
iT1aqZPm9zngnL3200WC/12Semcdy4ETl2S76gnfrGwP9D/ymAOPZOJ9VMdZ
qK/Xv/5kIgfkfjpK+PYwcF/4rr9+z4n9KinG76IJ//flYPBLYu9nn8OzZD3c
cPXFG685YOr6y5jVS/g2Oszk3lsOuKbV7jw3y8LiMb7wkxwOVJw89TCSrPea
Hip5mc+Bfcfy414TfpsTVxyW/ZEDSmJ272vJuvy0zs7PXzhw2VrqaddcNq7b
+VCi/BsHhiyem/PJfqtngrWNZRwoOLmu5DfBp/6djO6p4sDm/YcKTITZGGHd
YDNWx4FhmFgSI8bGF+kbV/xs4kClm8elbrK/WDilbV47eb9U/bIKct+PQ0vj
F3UT/xBef0Hw3OyzR5b3caCn6ysn6P/2LOlTURki/hAY695G8LrjO/vpYxwQ
VfSMmEvOs8bs52t5HKCdofwtIP7wllV22zzFgZ2l92xdCI7wvE7fOcuB/dYa
diIEvyye5Oz/y4FlWkNXH5J4lCjav3Gay4UL104dUya473SRj4cQFwK2m3jE
kHjOq2LonxHjQvqHB5MCt0n/pjyYDVnEBSdlxdxjJD82XJiXf1OSC2ZdOo/v
KbJxf5Nb0INlXGgR1Lk4Q/LPV6feKFGOC0MaNuspBN+6CoKv5Mn3i3YsdljN
xvSu5K/vlbkgc7LzhDXJ74HIALNKKhcUeoz3rW8m/D/UK95C58Lvd9HcRaSe
lDZZVP5gcuF4uVLNd1KPhg/e3eLocSH1Biv3FKnXAzzFfb/WcSGDF/V95gq5
f/s1GSHgQpethw9NnY1RCRNNS4y5EC22xKWS8MerWbuYFVu44AJexyTJ+nfL
r/ZqZlxQSl7lo0fsWyOlVjVswYWkZbmVW78zMKHukvFrSy6UKTLp2wj/Lbz7
462vFRdGcjR8NIoZ6GdjorHhABeq5+aZ9hL+7V6e+GCOPRfmOjjMTVBgo3mL
oHiRAxf+bRvd0kr01LsYp6Cwo1wwNJ9eoE76gbJ9IXe3C/Ffz5yzf8j+Gwoq
TjInudCmaeC+NJuBM50X61s9uTD5eeRzKtF7jgk9WxO8uYAjoaW75dhY7mic
e+w0F94qJ/zVJvpyreoTLa2zXPjlqVVkJM3Gp31z43lBXPDTMCm6QfrvouQj
ktkXufBjrNEmLY7oYZdPIYFXuHB6WYiDE+n3vVTl6U3XuXC5pjDvoRAbLUYu
uIjc5EJ7t579XsJXOS+7WspuceFRfuL5Pb9ZqOJhZBEVzYWXyXYBHwj/32Q8
RpsHXMg+/XHvOj8GznIFWPKPiD0p/0ZTTjLw6JvDiT2PubDsyk+xOqJ/K71R
5nkiF66+4WbsFyV6U0/xmvtzLqgr/hzo2cLApOmg36yXXEj+8Hq7fI02Lsnp
cP/5igs0zan3acnaGHAGugoyucCNOxyoKUTyeX3cnpBsLthqH1p64KM27vrz
98u2PC6ccck74fGKjrkF9vqLkQs7kn60mIRrodr5gpTaz1y4PrvX+Jw4HSON
5Fc9KCLnL+fmaQVq4++5524eKuWCvYfI94whbXQubJujWsEFjtz31bVknq26
ZOA9VM2Fo7sP/haq08YNW2L70uu5sGl5mcY/C2K/yB8bn2YuhGwxv2DMY6FE
iV3punYu3Dfe38D0ZuDZ63kGAt3kvvYDO+4TfdxvvvLVlx9cMBD4czaI6FfL
RWeVrw9yYRe/zU2H6M38ipbbu0a5MK+g824f0UcakeuFl3G5cKg+NruY6JEo
y4f+LZNcMqU9/D1N8uvv0l/D8TPk+6Qjqr6H2Xi87oC9828uVJQ2Gj4i9VAT
/b6SJsCDMDuOxDpSf4Y2csbceTy4+XlbrTvhh+TlZ95mCfPAzXq8d8sQA8/F
rH1gtJgHUR8zWhf8ZODgwfsLhZfyoHHLzPB8AR3cq/Dz3PdlPFh8JEfqs5AO
UhOyHa3leSCi6S/3cKkO3nGUrV+pzIPHpj3ur0l9Caie3tqtygN+U11ploIO
nuhreP+MwgMx0+dFl1V1sO7ZGq2TWjyYP637nw5NBze63I1j6vCg9YOsTQ5D
B1Oo0xIzbB48GPVyWTpI9OSIVUi+Pvn+zylvuzEyX7zMmgrewANH9v1xBR6b
9DNaxP2NPIgLu5snROy/GxtHebWZB00NScHeZjqYIC31+etWHhzWPqOSs0sH
026E2rWZ8+C4d8Onnn06+H7+H/7ELh7YJ9q18w/o4JfA/26K7eNBp/vGBs4h
HWw9eeDTmoM8uJGYtzfJRQcHfpTbWjjw4MCfuPRXy3Vx4qAx3+koDz6/2sAQ
P6WDf+vehQe48KB/45mIRD+i9y00NW6d5IGKMmex1lkdXPY1/mPyfzxQ+LrF
/+l5HVQ2lLb94EP88an18d81OkjPujpJlAKkPukTsNmgg2vpf2+MBPJA2FXu
GmuvLm5O8lKfF8yDmK8vt4xH6uAu+X5cfpkHdr8uLRY9rIt20bYHGNd4YL6J
QzV5oIPHF1VOmIbzINZRVd7+kQ56X9584+AtHpzcsDfTNUEHg/5mq3lH80BC
ZZm9e5IOXvPVwmsPSLxl31xyTtHB6LHH+x8/Ivtz/q4qcNbFBOdlE+8SeKBv
UNGkn6GDL9uvhZUnkXg9zC9YmqWD2Vb/VH+k8ODJugVRP3J0sLD81IdfaTww
maI9S8vXwUrTARvJNzxY/3fb7GFvHWwpsONpvONB7dbneepfdLBPr+o65PKA
NXDVrLFYB3lpJqpWH3hwUIpavyNZF/+qvS9w+8yDhfPO5ihX6qBoHN3mYhEP
KsYuSubX6KCUzBPu/VIe3FqW4L+rQQcVb8pcf1XBA88dpSptzTqoKRymUlTD
A6OguLIA1EX9IIGCtgaSD5aUqNrbOrh52tt6soUH4s1rcux+6OBOj0GOWCcP
9j7nOVYO6OCB/oPXlHp5oL2pFAxHdND5UPVq/QESn8lNvknjOujVYJpvMcKD
//pUtEUndPDczlyroxwe1FwBjvVz4t8ibU7AJA8MCnZ/KPhJ6geeXr01Q+pv
hMme90oH49/Jrn7+m+SvRfbh3W908IX2jbwPAhMwHjVy6vk8JmY/m2NVLzgB
K1iLqWNCTPys4Ds+IjIBz9R37KKLMbH87lDoPPEJmLZLmXdCnInNiw8py0lM
gLldDfXIfD3su1KTy5CeAB9Xn7dfvuog99+WfVuWT4Bi6aaeSXE9/O2XN3Zw
1QT41U4+CZXUQxEOI9RbiZx35JrfPjJvSh1PVLquOgFGwa5vh+T0UKFzee5j
ygSoZxhqJq3SQ6pN+N5srQlY7838/EaNiXqVc8fKdSbgu9PX3lIKEzdt9bvy
Q3cC0lMOBHdqMtEChxV/r52A4/0P0rnaTDygf/i9pOEEWB4cvcYh/j/6qnYP
ZdMEGPuqLvxF/F8QCbGzJhPQJ+QjcHeDHsqeSukr3TYBNYaUg+nrmei1V5oR
u2MCGiPZ/EBDJn7XPe/vvnsCmi9O920zYqKazPAn2DcBgcZ2sHQzE8/P7Fso
sX8CVB3GxZpNib+acF+33QQEl/bue7SNiexcWtybwxPACVquedicieEx0QMh
ThMQPiZzX2EnEwcC5zCtjk/AUg/j1ZRDerjpkFuAuhuJR8JCp7t7mfhwY0Ph
jMcE/Hf+VsNOaybO/Ro8ZBA0AQbqQTErjjDR7tkoa/FF4o/A8fXfnJiYFWoT
2HmZxEefWeZ9jMz3ZvQlF8MnIFLKbeCLGxMrK5t0i2Mn4N+E08guPybGtTAu
WOZNgLVkVvuSMCbO5D0sWY0TcOGu+kwkea/lIyEp/mcSX+XrOoxIJgo5tCbd
LZ2Ad2NvYFs0E937rnxvbZ4ARr/uVpd4JhYX8aTT2km+HfdIGk1govLzg4eC
uifAjnPrgWciE89eK07e1TcBomWJFN4zJta5snhKQxPw6VxQz5GDTKTveLR+
YnQCRlMjNLkvmBhKF71UyJ0A/Y/UFPd0JnYv9i6/w5+A2e7F9UOvmbiB2y5z
7OcExJ0Ufns0k4nR1dsc9P9MwB6rkI6Z+3rIeZOZIjpnEqQsimKtc5i4/Y7C
ZLPgJLDmHX5VnsvEJ77XDF6ITEJz3dkrmwuY+Nuafzlw4STsvmcV9/wUE63W
Hq60WDIJZ73bozQ/M/GVXOlyRalJsGUYVj36wkSx37qOXJlJOFJ3bZ9AABOd
2uJffFoxCVrqC8qDSphYULBgKkphEtabr7oz9p2JsvG+cHT1JBzXOWGyIFMP
vS50heqpT8LTqAGdnBCSb0fMq4Vpk2BSem4tu5bk2+Z3K5rokyDt+zD6UT3J
N1XloynMSXBMNN0yc52JTUI30gL0JkHkX0zw4XAm8qSfVKxdNwn7/COyliqs
QTHVHM60wSRcXefjptrJxNXsCokso0ngCK6bcb9D/Gf8g+ltMgkOk1kV9b1M
3Gf5aw9z2yQcWj27hN5P4usg4cMxn4RNgZukl2ivwSue6tFpuyZhkYPix6Zh
JsYHGbxz2ztJ4h2tSx9jYk74nkaqzSR8ldmg2qWzBqtjXX4O2E6CSsuyo7U8
Jg6/CJJ7dmgS7sSN+S5LZqJg3p31Rx0nYZXtWkG/aSauKk21W31sEgLE4y3f
kfjrNX8M7DpB3lcc6y1E4r9zsOFRnPskhJ1Py9tL4n98ZvTDQa9JWLfTUCvh
DROnBi2qIG0SIKN8WLyRiYt/OvH+vJ6EYsdUqr06CzVEApbmvSX3bTUdiaWw
0Egmkn0mh9i7Z87fVhoLD6g926efPwl76I8cVtBZeEo333cKJ+FWfJ/sfgYL
wzbX3M0snISM+1dUo5ksfLpnMNureBLKdtq9/UT8lX/kXxPj+yTM/hSpfnt7
Ddb/J/1rrGIS8tYl2G1by8Kx87SVL2smYfH7hxUX17NQOMLIwLVhEu6atRS9
5DBRMc7antIyCQs0dSqngIVr004G9bdPgr/Y/ssKfFKP+RfjE7snwXTnqr3H
NrMwpCW9W2loEiQkUo/VbWVh7NCXeZ2jk1Disej6AjMWZv1sUXnEnYSszZXL
jHawcEBG5Jjcz0lwb1c7mbKbhXPU5UMbf0/Ct4q4de17WCinx34eLcCHlD2y
vhJWLDTbe3hYUoQPke8vb/A9wEInR9+FVQv48KLDuOSZHQvPeoVp3VzMh3rB
/aWN9iy8cyHBYsdSPqjuXWok6sDCtIhsjwUyfHCwn/swC9dgUVx5xDc5Pry1
b7p5/CgLO9N6X1+R58Mm51Ve2lVr8Gf+bLWJMh8man3wiwsLJcuWTM5T48Oq
x4wnPfIs/H5r/YalVD7EqRqe4zatwcs2ziHKdD5cT1YcTvVk4Ub5yO86TD6M
TjiyhE+x8GdPrpSRHh/k5UV+OPiwMON5n92udXwwD1P75Um+d/OQSDxkyAdR
j79Xpc+wUE13w6j7Jj54CjLOu58l9s06654z5cNCtuOPr+dY+AAjA29s58Pv
IZ0vi9gs3HM570uMBR9+Wjxe4KzHwoXm/eIvLPlwwuNF3vdLLPwqIWmVa8UH
kz2SE5Ik3ucbNjwqOcAH3b+7lhv8WYPrYo/1NdmT969wSS0LY+HkkVv0wSN8
mAxs8H8+Rx9fauT7zjjzwe/Ow13OJN7OY/0Fwq58iIgovMkW1kfFTElhGQ8+
LI00bVwZzcJmf4Odaqf4sF3Kcb/HPRbehuN3df34oLCh1ebjAxZazI/q2BzA
Bz1/rblrJPVRuDRffW8QH47UL2jYY8lCjBjwcLzIh6iX0vszH7PwjNXSbK8r
fFiWnXxQ8CkL2SsNBYKv82EgaEvfniSSz13Ht0be5AMtSXYyIZmFDicLGtPv
8qFtKPUJvGTh1hCXnyPP+GD60NjzVBYL526/bfQ7lQ+fp2Djh2wW5i7+cHXB
Kz6E6Ufenj3JQu+6wSq5TD4wFZqu7stnIf2hlBw1mw9XTM7Oj//AQumMD+uO
FfNB2Mg04UsxC7s7pM92DfDBI6C/43czC2MSNxZyRvjwvJby06iNhVaurgsF
uHzYM3I17XIHC79NYYz8Tz5Q37znLOpl4Stxt3xb0Sm4zXUZlBtlYeD6T3/r
KFPQlcqyUfpH6utEz1Sc1hTY+pwTuB6ij2H3BcdddKbA+s22Ist5bIyZNu34
oz8FO9+dErooTOZrteMNRRumILnH6+0DUTa+2He1InLjFDwfcNWIuKmPmSEp
Rbabp+BkuqxMDrIw703pB9WtUyAyGyvUuZiNhd0j78bNpqBv58WbUxJs/C6x
6FXOzimI3qNbuVCKjbUbtZMv7pkC93drvikvY2Orx674HdZT4LhMOEBflo29
j/67J2M7BZGwoW+HHBtHym5FdNlPQfgfx4bueH2c/P0mNPXIFFQaLV+qlKiP
v2l1532cpyA1zvkTPUkfBW2nTsMJEhxX6+Z4ZTYuvCbzn6j7FPS/ezmcqcJG
qRx9l5r/piBM1TynWI2NKwf2O8T6EH94vTFu1WCjikzA/mP+UyDmbHV9nMpG
TdOY3TqBUzBU9DJirhYb2T75236dJ/Z21mjP72bh+qftRl9CpoCtrxLyUUEf
N9X8W3szdAqmWTdk1rHYuH2uEnN/2BQ4nbeQNddlo6XOJurqiCkoSC8/VJOv
jwcOOyqPRk1B7rl57EMjLDxyM0Tu3d0pwgfsmPPr2XiiIFHywsMp4GBwXKQB
G71Gv4qZxU2By3Zzg1tk/j6zcmCu9JMpOC39bjjDiI3BZqK/2pOm4EvSCd3P
xmy8doY6kZxC3uP0xFKkXB9vPTcb9kqbAnlFa8meLWx80OjWsyFjCsr1zZN4
29iYIBzeIpQ1BTr5/n/nmLMxRS+9pjJnCtbqveYKzGFjxtHK0gf5UyCbt/KP
wi425tzmfnb6OAVv8w8+pVuyET9L5tG/TEFrioeEwV42FvNYmTPFU6C7O2uz
mRUbK5X2vfj0ncTvdZjhfhs2Nu7yfRpGOkXF6KF/zgfY2Bl0N8aqdgqixmOv
eNuxcSAt+7Zi4xTcdLnecMGejZy2prChlinI8NP5fG4pG2cW/grJ7JgCj/td
B+1G9FFgw8rAcz3EXy9c/ZOd2CjiauCztZ/kg9z0cKYzG5c8sD8pOTwFq/9K
anw8zkbZb0FHW8emIOuTHL3sBBsVZ+IPJvGmYBnr+N9GNzZqqH/a5zk1BWd8
re73urORYdWzY93sFFi13Kjs+P/va5cETQX/TkHRouA5w6psNMxUNSyfMw15
e220hHzYaNpjqndv/jRctsv9KkDyyULyOP2I6DT8tEm3XaDJRiujq2qa4tOw
6Pa+UdUANtp7pshPLZkG8xXcYQUGG53jSpeh1DRc2eYjuy6Ijb5/xIX3rpyG
mQKdMzsuslGhx1jNQ3EatiaFBgZfIv4u9je5pjINXfpztry7wsblt39cRM1p
8Oy8qaUYxsY8ar6AlsE0FDwP2jt+m41OSyYUthpNA9zQiVK+y0bxKQ1wNJkG
/h3hh/vuszGrxd7+3LZpGAlycAt9SOz7eDvw/o5psPCpEzsuvRaFn5XEZO6e
ho17U/XbSPxfhQnkVeybhuDH7FiFBDbaeOm1DO0n71v77vAVxlqcY+M2O99+
GiqT0+0vJpH8MkhYrnSEfB+3JkZUdy1arm7U3+A8DduWnc+t01uLv0QW2Vif
mIa9tlHGwocJP40Z+3m5T8PmV888t6az0bzWP/qG1zREx46z/V+zkZ+T/jbZ
dxoSQzUj7pN4P4r7Ufv5zDQMXV2h1vyWxOPSisn2c9NQHv9mj1g2G8dP7F46
GzwN2QnnZKkn2Xhv1xWm9JVpMLSY6d7vwcaNevm7GdenYaBcOvN+ARsHV0x4
mt2cBvXtm1Z9QzbemkOJcI6ahlGPJVYzn9i4rt8+/cLdaWixUj1Dt1yLPd9v
l8c8nAYJKlPfqoiNYRklo+/ipsHhhftz77OET+4JiNc8mYaQBeIqT86xsS1Q
T3Ps2TRE3Od6VJ1n42VHNzPRF9OQdG8bu8VuLdK3JZxQeUXe56GUZVDNxgZ6
41XInIZHZdV+rrVsPC+16PmB7Gm4eZlVHXqV5O+scbFP3jScuNbv9bWRjVUd
/v0ROA3/a7jMw2powzCekCWiTUmSJBXaNMs5p3rShkhIhKxRlihRlrJUQknS
pkjaVJS0oJ0HoShlSZtSvqQSpVJnP9/8+V4z88773Pfvvq+Z6h8dOcMtpnj6
1UOZnMoxqLFoPTcz0hS1sn8sfFPF6Fmsfcvhmyke91u/V1Q/BlNM5Zsz/jPF
WdP1Og90jsEDz/Y1m/tN8dnQDqmQH2OQ8i6S+OLPwv1NMfOSe5n96xr8Aw6w
cObTtxZlv8cgNZlzr/ou0xdpUju+/B2D4ZL22RP/meKeUPLM339jsFhYxZ7u
zcKpXp6J0/hj4Oi4ZNI2nikWbkwtWyQeg6pgbwwRmKIru6nFSpoLXebeC8yu
sHCCphx/uwwXRG8P1FafZOGDiTazT03lguuUN7wJ0gRu+nWKjpHjQtE6UDCc
QKC4/uHmhwpcuJG8cPwWGQIzn/zwezuLC27RxTVBkwlclzgn7ocaF8pyo0+a
JrCQG7j+sdQ8Lnxsa+trmEZgiselz3MWcOFA7adxA8+ZfvHf/27BIi7s8Rze
oiFPoHfEqheLF3NBW2joaK5IYFOKfskyQy68OzY6z1WZQMvHsnmcZVy4cMO9
5rQKgVlV/RnWFBeoRq5yaA3TT19rb6/mcOFK18qSojkEfpOOvLLNmtmPilUZ
mUeg3ayjQW4ruNCn+F5eQYvAXL0Npw6t5oLg/cReQ20Cz65T8vB34sLME/aG
h3QJnJsUb3XLjQvRMKzZYUTghfxTrDQPLtw//3uyyITA/sqtRtmHuEw/JNTN
Jggs/6WuUXaMC7y9CbwNLAK1JSKllye4sF3HZbsXh8BwhW+y7/y5sFYhOPmK
OYHbWCm8lmAuKJl2vXq5nMAXa4IGv1/iwjd576xv1gTq73L72XeFCydsrQ8J
bAmMOmbTPnSNC4fL9siprCSQf3FhAz+aC5JGzSgTewL33JSpkY7ngvq4uFGH
NQS+ffDzxdRELoS7aPJdxhFo8ryqRCGZCy19l07TUSxM+HwvTy2dC4/Wm+pe
m0igVE9YplYWFx5caHlQVsvwKDiUpJ/DhV1LDmk0bCKwXs4h1iSPC+Uqi94N
uBBIaxmEsx9xIXN28hHfzyxMJmYEWxVz4fjeyrfa2wmcvGrwlH05F7ojpTVg
J+Ov6wfvDcgFd+qz05bdBDZ6FXhsreTC+3WOnsfcCLQIjt6xp4p5/t9D7TOq
BGbEHXc+WMMFsfOYbaYHgXL3ndf41HNhtfXoIPUfC/0qSOvTn7lguDwwp+UQ
ge31KuygJi6Mtxo1HTnM+N3FNQr7yvBWrp4y3Zvxe6x5UVQHFxrPxj+YtZBA
ZdkyjZtdXFh0NKTTcBGBARqJyqk9XHDoSOOt1COwy/jMtPv9XFAo6GT5nCRw
je2O8QWDXKj71ad25TSBj1yAXzLChQK5Wx1pAQSqe2r+fc7lgkr5gMr26Wy8
cG5cT7WQ4TX1glrDeQKdMl42NE/ggaaqqGdiCIGlJek1nZN5EF/J0tW4RKBW
bcjL3mk8uLttngMZSmBYh3vp35k88DlSsHntFQKHhlfk85R48PRr4PhNlgRu
naSXNW42Dw5EjNQYa7DxhdrUO1Pm8mAKy7I19jrDj8GvWPn5PDiy1vTsg2gC
ry+vCZ+9kAcecpmxGY0stHuatuyrLg86NTsDi28QKGT7tyQt4cHqoLnd2QkE
FhRtCNxtxIN662jTO7cI3G+qr6ttyoP/BjmHo24TqJE/rq6b4kFPyPLIkDsE
fl7a7HuPw4Ot357dPpnCnP9+nron8KD/sHuF7TI2Wi66/NLAmgepqYknd9wl
cDRt58G/djy4/bbMuoBkY44mJf/IngcPZs0sWebK8HxbrthvLQ/MuyCVzCZQ
Va17B2sDD16XaP9S3UXg+7iKiUJnHrgdbb0/5yGTT8XYnKdbeFD0qc9pVTIL
2ZGeToHbeZD+vldtcB+Bg9Ns+Na7ebDy0KLbQ48YvkLnpMjs4wH7p9GrricE
usoMr6jezwN9+9qo1wxPCsFv/1zx5MEyVdMsDXs2VklSYtd68yBR0bqytJzA
5CGJ0ZZzPPA0fpcTWMn0pVdj45xgHozuzsvZ5MzGaf25Z9sv8qB6W7X/qs2M
P/svLkwJ44HiQiW5TW8JPPlje41bBONPy+eqPls2GuwhjulE8eBM4p4E+j3D
X/s0td5YHqjNj9R4v4qNN7d1YXYCDwxkXzapfWT6tqnM48htxo8Sva+ynwmU
cY6WM07hgbi6uUbYwPTRh4OPh9N5UHev7/7vRgJ91lq5Psniwbgnvn7tzQTq
vps9/lQOD469izKsa2Xys+LvPU4eD+yiN3x51kZgTGXVOnEhD3zXNh7M+0ag
/fLkMSziwZe31r+TO5m+eHoiKbiMBwoT0Ej6GBufsB1t7Z7xQP7caFngDwI9
i3T6J7/kQVXZsck+Pxm+TcVR717zwES/bN2Xk2xsymtgRbxlzs+J0rZKIjBi
6YOOde95MP/C0/TiADba3L9wSfEjD1Ki/UJNBpi+03E1+NLAg6NPDUmFdALz
0pY1xDfzQDqTdd/lOwvdNWUDtrXxYE9rv4n0PyaPt79raXTyoKk7dfjvKIEf
Z5dWd3TxwOVsr+6uy2y8HHfdO62HBxo3e5Z/4DP9o3hAxb2fmed4eh0KCRy5
ZvlUd5AHQoPdSoYRbLw/TXXfr2EejB0rLL4jReKu0AHZ3DEeUL8sla5JkzhL
5k2Bt4AHsgbSKkeKCKwJStqyTMKDNTOaio7HsjFI4is1Ks2HNV3lL10nk0gH
OGQWy/Dhd5lOLKeCwD9c7bX+U/mgNovXzZ5GYrqvcMRcjg9F+Rs69ORI3Dr0
6ZaUAh/mv46rVp1J4gyvbKuXynyolnbdOsbw5556Y2bjbD6IpHlNM94w/jcE
t/fN5cPSBZFX6VkkKk7xzhHPZ95vqfJznSqJB81cTyvo8CHWOfSHSy2Bz71W
rtTR54NylmBPoDqJqmmms9gGfCjtvx6SoEHikS+aXQ4mfKgRTonL1yTx1ZTp
BbtJPsiND4mp1iJR3Zx3zpfNB8/YqYGd2iT6eP9wCLXgw0bj8XaXn7CxOu3D
nNtWfGj4Xqgtr0eiZmNFb54dH0aFMtGq7QSemHq/qNKe2W/sJW3UweTbPC6k
aS0f+KZ0WAbTb9pHg5z6N/CBqzgrwcuYRP/0I/OlNvOhl3743K+b8bdx64Di
Nj4UHhn2KKpko67siopFOxl9nD6WPqZIPGex7ArHjQ+5hlt4NSwSvxydt8XR
g1lPHNDp4pC49K7sIrdDfAjqemwtMCfxQtPYiJ8XH3L4lY4KliS2yHa9CDvG
6Km9aLWeFYnGUB+ZdIIPjqsj5Y4z/XbZp3xHgT8fLL762GcRbGy/m7Xk9Tlm
nofxLYdXkkg0x/Cbg/mw6/u2mAv2JIZPC6z6fYkPG0KX9xBf2fgfHI4bF85c
zzvWmL+WRPaxLXuVI/lwLnd4V9U6EiMzbE30Yvgg6Qload9A4s9mYynzeD6c
MFls828jiRbTNd6vS+RD3D+lJNnNJMZYTk3cm8wH56+Lup71sPHXsdEDJ9P5
8ObAgBa9jUSrzO9UeBYfHm6TXrt2O4m3j0d7tRbzgef0bVfGPhKdZvxrP9XM
h5GygcdOfiQ+symueKImAEeFaxlpN0jc23mTE6IhAHJd5eeYBBInnz1T4qQl
AK/b4Eorc/CB2i5KS0cA/FdrAxYs5eCGIqvHg3oCiNYg1fbfIXHMaeGyZ0sF
sMjt+nCYEQcTByflXzUWwAa7gzPs00hcfrXPwJUQwFYvGR77LonderU5+iwB
2HtLn9pBcvDK64f6PDMB1O96cF/9HolGblFZbywFIMAXPtOzSWyQHNeJsxFA
ZH21oTiHxNOJm9P3rhRAueniN/ZJbJzHYmstWyOAuSnvL3/LI7GyQT153DoB
JAX90q4vIPGAj2RuvZMAHjprJv6z5qDcjO+3kjYza0gwy39CYmF25ezD2wSw
sMy2OKWYRJeVmTc4OwUw87K5XlQpiamBntFN7gKQ/LH85fOUxBUajvKZBwXQ
+ivrXoIjB/tLja/5HmH0SZQNdnpBIjkyGqbgJ4Cyt9zBZa9JbI1sntx5SgBt
oT6q2lUknl9afvHhGQF4akcRSm9JXPg2acLZQAFcZoI7oYbEt+6BQWtCBDDS
obp+pJZEr/F7peaECuBzwvYJn4NIVEq2O9sbLoDsN0Lrzx9ILDHTExZFCiDB
cp1B5ScSdzTLnr4YI4DzT7a8TLtM4ni/P2Mb4wUQtmhqZJs7B7MUPvguSBRA
y3r3/OhmEh0eFg7/vSMAGd7fY8GtJA6tjjuKaQJQupK75FgbiTd6Tg5EZApg
QnhK655vJJqFbDu8PVsAQUF+hFUMiZ3zLX4tfsjMOyKoN44j8eJTzQP8AgEM
qEg1ex7n4OJt439WPWF4eLp8vNYJDtaP/dh7o1QAilqOj2f2kugbU/V931PG
/90h+lK/SFQzzt5l+kIAToUOcQP9DK+1V9ulXwvAnyjktv9heD3IfIFWC0BV
vnD9+0ESp0xyarlTKwAjemdKxRCJuWmEy5EPAriL27p7gznoZKn6xaxBAJv9
+7QTR0nkfuU7yTYLoPvON5crXCYvp9o+NH8VQE5LbvBpPpOnWeiY1SEAt9rd
dw8ImXwWpNb6dQmgVG+J6+erHAx3DFlt28PkR5RSu0KKwi+X7Vd8HxDAc+fR
DwsnUOi/cOmrvGEBNH17+VpJhkLNFzOsz40JQOvWk4Lxkyl8tWMIHQQCeGDU
HDs0hcKDgs8W6hIBFHZS3p2yFM6ILyrvkxZCoEXL8vrpFD4yvckukRGCvHrt
1GczKNzyIaD40lQhXDdVe/dAnkLx4Z3kJjkhuGgo+Y4bz8E99O8r8gpCoC/t
OhmoTOFraf/OGmUhTN/3cZ+7CoX6tZOpy7OFcJWvuHr1bAojbsSFW88VguE5
StdoDoVDu7W/izWFkK5rK1KaS+GmJQVUqbYQ/q7peekbz8HSUbjqqysEnY4V
19o1KdR4XvvdaIkQxnqOSRU2kBh0ZRvdbygE1qTBj3qPONjt3Hs1c5kQlpZH
5obrUGiveeK/PZQQAjZPPPtFhYO5fRNYGhwhuMWfe9xQwkGFx1ERzRZCiLPU
DSkt46DfOc2uGCshbLOYrTzPgMKWVbmsdXZC0Pi7z3H4O4mgZHZN1l4I3qa8
5TCfg+nt1V2vHYQwseFtZM0yCiff28wOWi+Ez/rTpPIJCj2P/bhm7iyE36NV
HrEUhfXmx35wXYRgZjL05hSLQtPJ4ziPXIVwaKQ3QP0dB+M/RkR67RLCAsmr
o1bmFO7yuM/p9hBCnvpH0dTlFFYa09dTDglhSPYNPWBFoa7wVberlxA+BO7x
/GRDYfhrJzPVY0KYpf4wvsiOwsHIzuuf/Jj10tSjVwQkbtzm9TPitBCSIs+0
nrOnsHihyMz+rBB+js0ccltDofpgWNTEICHsy8p9/raNg+dLVXswRAhPPIqn
LFlHYdeFDPOAUCGcmNM2deYGClc6mkZTV4XwRebPhBEnCnNmv+gZihTC186a
7DcMfzO7HC1yY4RwqfXdjeypFB7PbYs+EC+EnPv8qjtbKGw6eahXO1EIi1Sn
ZwZvo9DMmmfRcUcIfTa6Zz22U5g8/VLMrTQhqPw8sXb1TgonNCn1bcpkeFnX
oWK4m8L9qamgkC2EUxt8WxTcKKzxNIqtzRXCnwaLuNG9FBpRT/suFwhBs41e
3eJOYcy4NZY2T4RwuieCV7GfQu675lhJCTNfhXZKykEKXeM8fpVWCIF6/P7f
8XkUPt/1z9LvuRD4UgqRLvMp1FkcHGf8SggXzhUvMFtAYdi/mf39VUIId5YX
GfpQ+OdZ0vKsGoaXxLhgxeMUbghbcsOtXggVnLjxY74UPtlY2q/xWQitKqpn
Wk5QqDZvpVVLoxAKs7UGK05ReLa34UZsqxC6vCtcU/wp/F7o9nvdNyFMDr/t
d9yIQruzf62m/cfkU5JjVX+Eg/dXnot/0y0EPS+jgNWBFMopTv8T1CeE/dPd
6gyCKfRpu2lt8UcIRde76sbRTH9k6ibw/jI8vGra8+8ihWyfJ38e/RPC65Pq
LjtVzTDJzMbGmycEn2vObWVhFEpP+piwWCSE7Rmb5O+EUzjp8vFZ9DgRHGxf
aZ8dQeG0KSrRNhNFEIQyAUWRjN9hJTPWTxGBUmp8xssoivlfdg3fPl0ECkNq
tpu1zVAtXDz5oLwIAhYPJrxbxeR5ekqIn7IIZjUlCH7GU7ggwlo6eLYIJnzy
rPjPgeF7RvfZa3NFYHdUTV7qNoWOKny3YXMRdC/Rctr5gMKN8YkdkuUi4Ou2
qh96SKHLbNg+zU4EW+XyNBqSObj9Zmezqr0Igq1OJwYVUrhnzoVNC9eKIERt
v7KdrRl6JOp8Mt4ggtgDGeNuFjF5nVvtaLFJBHoHdty/W0Lh0aRDNfZbRfC3
JWdNfhmFfvPkVm3eIQLVGT9v5Xgz/Zuc98ptD3P/z9ozVc8oPD/fycrbXQTK
Jfr4kvH/Quq/pwEHRVCz3D7220sKQxfEc0KPiGBxprOtr7MZRqSzi2N9RNC8
dnf06BsKoxa2mab6icD79O7yvwEU3sg4l597mtHn6bqT02soTFykZVB2VgQz
Xx3uVH1PYUpW5f03QSKwHN1so11PYYaex6LPF0Vgs0w5xfAjhXmLczR/RzDr
a8tW2n2h8KUhqTjvDqOHc5HDsXYKq/Kari1OE0HFeo3zZzuY/Bj7T6MzRTA4
Nywn9DvDyzKcuP6hCDbubxi+001h66M9QdsLRXBrkvD5zVsUdhATJQeKRDB7
xwcVq9Nm+ONJpr9fmQgODFDdeXco7KPsuUHPRODL3m1W84fCgeL+49deikCr
YI5l4yCFI6xrf2+9EcHZHfMsvg8xeSw1PpL1jtEj/TD5e4RCEedz36M6EUw6
w7p/4aIZSlf4eTz/xPBVd7J6KJtCGYvZXbWNIoC3d0XTBRTKPivb1dLKzLNk
oCMQzHCm5Y627m8i0FeZ76VYwPD4XGrr8H8iYMXlRhmMo1HNKu2L5KcICluk
9rLG0zjvpa3TtH4RrDduMbSZSKO2TU+d6qAIRivZo2sn0aj3KmzNwhERRH+y
K9oyhUYDu6XVxlwR3Buaq7PxKYUmb+psLYQiWApGO1uEHKRW+rywlxJDStiH
5IEkMwwzkR2QnyCGR+bjo3bL09iunj6neZIYMqt22K5SpNF4kvnKZFkxHNmw
wqQr3Qwv/G047jFDDPnXtiapqtDY2HokxUBRDDf/TLSRmk2j/utJ7//NEsMX
YvGPn2o0nslL5periWHzz7rAOnUa62+yFl3QEMPGb/q1GR+YfIV8dFqtJYZD
mP0gSZNGP69D5xV0xDDO57fZRS0aq7dMeNCsJ4bGjp07NB+ZobrN7ebkpWI4
pau/1lmHRi8DUma/sRg4PpO3visywxeqdSaGhBhWlS37GV9ihsrj9+8cpcVg
ZGfzRnYJjft/S4VXmInh9yszs+GlNJY1JhRfsBRDxHFxToshjXIvTH6sthFD
s2F0TX4Xhbtz3skrrhRD9tLpX2f5meGjuL0WLavF8IDl/yOSoFHKsmpwdKsY
prhLrTYwp9FJf/fcpzvEcOuOssNEhp8MJf6qkD1imGmWdsO73gx54ii/Ne7M
vKtOLO6yonFN7+I0xYNi+Jo/48g7GxoToq45G50Sw0hCneP+NTT2B+gGjQWI
oWeZwVnHtTRaejzPfXpeDCU6TvdefzPD6PVbW0MuiGG7zuj7uRto7OYMT3K4
zJz/v/1/J2ykkaUTbqoULoZB+a4Z/c40hs9cuLv1mhjK9wbpf9pM4zd+xdXU
aDEkcZ0KDvaaocmPTaUHboihfr7SpOtyNIbUDXQb3RLD59CjV5c0mmFTyWVF
bpIYJgVKDnvtpHFx+nzLZ6lisJ1i4rtpN41nI0o9L2aIoSX0/klzNxo/nHRK
cLgvhn/+Vie19zH8uvW/UsoVQ/UtzeOyHjS+pTTmpT0WQ8HxkF3NB2kUfM3p
UR4SwwSZtkd2oTTaeFZFOoyKwflKhIz7FRojBP/RIXwxEMcHnEKu0tgUJuko
F4shymji7fRrNGqpzQkdkZbA38VfOl9ep9HzHmm8ZJIEKtBd679oGh/TG5rd
ZCVwM7BcfmgljeI3hwNvzZDAiH5b3Px4GlduDtX7pCiB7pjaM0YONEZ1p3+Y
qioBrz9R/J2JNLb64ikrdQko7l6mcy6JmWfi1/mnNSWwPDdfKsKJxiMxY9X5
2hJIsdgwZZ2JORYvUPTp1ZWA9Bo36xpGb+lCA7X5SyWwZW5qtiCD8d/K/oWL
sQQ8Ct+/ULtHY+yHfQcjCQlkvR33hZVNo+Frjf6ppyQQ2S3zT7eWxpPO7Bir
MxLo5Ba8XlFH44suZ7PTgRKYvz0vxv0DjZvGXw3vDZVAiUnmwvQGGpOjskzn
R0gg5sW9WwVhNPbOr/zqEiWBKSM6WZ3NNAZYCpZU3ZTAFVlz9XntNL6um9Ug
SZLACao1eCmj14ydJmeoNAmU5ysFuX6n0eWPw0KvTAmMtT0y9O+iMfXMgdqM
bAmMnvnYnNDN8DotxLf9oQRsV/mcL+6hkUxMnjvrkQS+28YvaOyj8fzi8lcO
xRKY0bbIKSXAHKtLGw+HlEugINlXYUIqjQr2w8oVKIG7NzdxTf7S6Nos93Sk
UgKNmQWWyxm9Mvbruy+plsAC2dKPO7NoHByzldtbKwHlmNO5EWM0si/tfnLr
gwQIJzlfl1BzDJ51ZsenBkbPxrLn7wQ01tyNl5FtkUB44Xa7PhGNs4hHuVbt
Eihbkf9mshQLd1XWbTr9XQIG5f/sYv3N8Z7TL3F+twQ0rAVFhWfMcei7TGZv
nwReu/OpvTIsNPPRcpw/wMwXxs4JmszCi+MsxlyGJfCOYs1NmcrC+sgtdyLH
mPdNHDV/+Izpd03fFVUCCejKPPjXJsdCt4eRAxKJBHwi5mwXzmTh/30IEDI=

     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -25.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466864957922*^9, 3.478439555279995*^9, 
  3.4785278142369967`*^9, 3.483295193777122*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw", "Subsubsection"],

Cell[CellGroupData[{

Cell["yaw to x", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyawinput,opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747213866*^9, 3.478377747231146*^9}, {
   3.478377782563344*^9, 3.478377782614772*^9}, 3.478439367391523*^9, 
   3.478439445916901*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWXk4lV8XJUNFpkxFZCiZyb33vbhykFKGQkhUlEQSkgrpl1SiZKaQpGQm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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668701597567`*^9, 3.4784395595523863`*^9, 
  3.4785278192057543`*^9, 3.483295199296899*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to y", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyawinput,opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777472482967`*^9, 3.478377747264744*^9}, {
   3.478377782663492*^9, 3.478377782715198*^9}, 3.478439367863937*^9, 
   3.478439446434376*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmXc81d8fx2mgrBChkAYq4y4zObi3ZDWIpFBSIuErFUIo0rJTEikje2dz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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466875049713*^9, 3.478439562502277*^9, 
  3.478527824159316*^9, 3.4832952047640467`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to z", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportyawinput,opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747282455*^9, 3.478377747298711*^9}, {
   3.478377782763011*^9, 3.478377782815172*^9}, 3.478439368268825*^9, 
   3.4784394469742117`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmXc41V8cx5FRUSQrK6VsmSninntxySoJSUbDSElCoZCEkEhIQjZlhexw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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -55.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466880963873*^9, 3.47843956630342*^9, 
  3.4785278300668793`*^9, 3.483295211328289*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to yaw", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportyawinput,opticyawoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747315681*^9, 3.4783777473321447`*^9}, {
   3.4783777828634043`*^9, 3.478377782913505*^9}, 3.47843936869659*^9, 
   3.478439447525621*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc81d8fx4lQMhINMktGhERFeQtRoi8qCSEpJSGUlTJLyV7ZZGUWIftc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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466883980711*^9, 3.4784395692051477`*^9, 
  3.478527833722913*^9, 3.4832952153943777`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportyawinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747348585*^9, 3.478377747364773*^9}, {
   3.4783777829637327`*^9, 3.4783777830139933`*^9}, 3.478439369123975*^9, 
   3.478439448088316*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWXc8le8blrKSkZCV0FCEnPc9FOVBpCRJha+MSkayIrOUHZIQIe1EZjZZ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -30.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246688807664*^9, 3.478439572601288*^9, 
  3.478527837537532*^9, 3.483295219606083*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to roll", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportyawinput,opticrolloutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747382025*^9, 3.478377747398735*^9}, {
   3.478377783064495*^9, 3.4783777831158953`*^9}, 3.478439369551487*^9, 
   3.4784394486619596`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc4l98bx5FVJArZq5QQn2FlnUKUKBRJRqS0SCiUvVJCVpKZyB7JXufY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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246689209197*^9, 3.478439576602054*^9, 
  3.478527843415103*^9, 3.483295226041643*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch", "Subsubsection"],

Cell[CellGroupData[{

Cell["pitch to x", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticxoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747415605*^9, 3.478377747431857*^9}, {
   3.478377783164138*^9, 3.478377783214637*^9}, 3.478439369978833*^9, 
   3.478439449303227*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81f8Xx133mpdwjQpJlESyJetdUoRKSBqolJCkKKNF34YiuyQNRZSZ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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668926913147`*^9, 3.478439579969301*^9, 
  3.478527847624425*^9, 3.483295230699665*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to y", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticyoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747448872*^9, 3.478377747464966*^9}, {
   3.478377783265456*^9, 3.478377783314869*^9}, 3.478439370385262*^9, 
   3.478439449899227*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWHc81d8fRqJIRUbISGla9173XiP3SIVQoZSopJKU5FsKkaSSysiIJCtS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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466893169702*^9, 3.478439584040698*^9, 
  3.478527853531859*^9, 3.483295237243079*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to z", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticzoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747481554*^9, 3.4783777474986877`*^9}, {
   3.478377783365024*^9, 3.478377783415765*^9}, 3.478439370800365*^9, 
   3.478439451912611*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8198XNkpFMkIhQkWZn2l8lGtlZIQilaiQSJKU0bJTtIyo8BUiZI+s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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466893726523*^9, 3.4784395873797083`*^9, 
  3.478527858601152*^9, 3.48329524282969*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to yaw", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticyawoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747515319*^9, 3.4783777475324507`*^9}, {
   3.478377783465704*^9, 3.478377783515093*^9}, 3.478439371272708*^9, 
   3.478439451959631*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWHc8V98fpkSyImSU1SCz8bn3Y+WgjIRQJEKDlJAvyohSIgpFSogokb1l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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466894206287*^9, 3.478439590876416*^9, 
  3.478527863097582*^9, 3.483295247761827*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747549424*^9, 3.4783777475657187`*^9}, {
   3.478377783565462*^9, 3.4783777836155653`*^9}, 3.478439371700444*^9, 
   3.478439452010869*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c81d8bd3Htca89MkJF2UmFnJSVKAmJjG9mhYSEFg1R9t4kIZEt+xwj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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466894766156*^9, 3.478439594166936*^9, 
  3.478527867103322*^9, 3.483295252224069*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to roll", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportpitchinput,opticrolloutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747582581*^9, 3.478377747599025*^9}, {
   3.4783777836658583`*^9, 3.478377783717371*^9}, 3.47843937221796*^9, 
   3.478439452059874*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWnc81t8ftVpKMgsZSVrGM8ljXEWZpRRJIqKQVWSVEQ1lZcQ3IiRC9sjK
vfbee89EhIeUFH7395fXeT2ez+fe9/t9zvuccsjMXteCiYGBgcTCwPD/n5XG
h0a3thbhdLGgo940GYn9omo7ry1Csz9z8y1fyehZoGbR/NIiHHm4rK+OsWap
Y1j/+CKMy7vxlzZFRm18NWq5lYtQLC3GV3iCjEa6rLNuP1+EnVF/vL8Ok9G6
Zt7j5r2L8HFrynvzbjIiyaqJRQsuwFjW110nqshICXKMJnDOw+MrHCA6howk
45JjdU98hzTDD2LvXcgoND7JL0JrBuY9O/K+X4eMwnU1Z86pTsOrrCL33oqQ
katRkfY7kylIrKpYmlsgIeO0Qzetr07BeZWeORaMVddfOFJ1pqDTrPF5wR8k
tO8/w6hGpSn4/JME0J4joY+df7/9FpyCP1KjShO+kVCfppLvxaFJGH30ym7i
GAmdkqssYrw2CX+raibVt5GQkN/J5qaLk9BA9Ae9qZWEWHrDxiLVJ6HNMU3X
1hYSanMy3yF1ahIu0lOlOppIyDJrm57h/kn4+eNprpY6EvrvqPpSTvcEpFT0
UWIRCf3haRY3152Avr/G3UIzSejmrtGXepoTsN9+OcMzg4Tq/i0tnDuDP799
bNYqHX9/kvvzcdIE/Hdx6pZiGj5ftpHaIscEfCXOSuxLIiFn7fk77u3jUL+/
gmkwhoR++uxOeXVxHNqEN1sy+ZOQkbMgm4/6OHwY4UhqeEFCVVbS9xyVx2H7
z/ykV34kFH7xspw+YRzqGTZ48z0jIbJQdL3AvnG4TJUM539MQveLTnxPah2D
GcfDm3ucSWhpUePklwtjUHjJOOaAKQmV7rOXllMbg6sC19hqTEjoOTGcnA/G
oIbgUuc9Y1w/xxH5dMIYHPeQuFR1nYS0ft3XjuEcg2La9x5d0Seh839kB9c/
jUIrJ9WGg1okVMw5ZPKwdARG3yasiZBJ6NIVcUvH9BEor5CcEkgkoZnXDg53
Y0dgRNbM4G9pEuLh2/b4uvcITDebiKmSICEHYakEedURKLb8+IWSOAmJS3hP
/W0chlY6HfWpB0go7KyY1aPBISj9PIdvz18iSvok0C3dOARNb6YIf1sjomIu
rtOTxUNwm+Kq9JdfRDQxzsinGTUEOXXushguExHBc7Ru/7UhmCuucv3yLBG1
FEQdy+0ZhGmPkySO9eDfFwwNv10zCH2OaR/60ElEv568YOAvGIT3PELp/O1E
JHjZtc/79SC8Hv3TYqmRiGwW9fwuXBmEz4ralxTKiWjXMY6Z2fYBOJnIOyOe
SkQHg3deiSkfgE5s+QTeZPz+X1vwYvYAfC2lILb+nogMqhYiP78agHlPxh/F
xuD73GxSe6ozAFWbuWq0X+H71FbmngIDcJeepH53AD6vVInwvNQArMh80nzh
BRGt/kv5rbt3AHK2317n8CEi1TfPk0Wa+2HAn6B31ffx8xm8uLpK+6HIvrjl
cjt83jvOXs8/9UP1MP+Nj9ZEFEa1uLrg3w8Dj8CfJDN8//YzO0o1++GcsrYa
10V8/1M0R3taPyxrlIs/o4XvF0ccFT3RD8XjVm5cOofvYyfy+cWufvjc7qEf
iwIRebFu3r5a1wdbo5lzXI8QkWGTAJdIUR+UkdrfXiVMRJQgOTiT0gfr/usz
GuUjou8cD/a7+/fBmLiC3fZsRFTdGVp55lEfnGG8ZzWwnYjiXmfZ77btg+Em
Cg4MDESkzzdf+/ZCH8zevDBjQicg4uAuJwvQB+mGT/b4zRLQnpijIlKEPrhd
i5SqNk5A08Znm36J9MEfGy+iQ/oIqFzklivkwO9fY2fWbyWgtxPeYn5MffBF
26lHj6sJyDkxtu3iSi8MytVY+1tMQJdulz7im+qFAuYaAsmZBCRxbODYRFcv
zG1faLn+noB2fP/dlVrdC8s9d7ycfk1AE2k8jx0LeuEBLYIx43MCKrUlSyok
98L9V9+vazgTUKT0pX6W/3rhtYdpbdK3COg+3e5ps18v9PP96NmuTUDauQHE
CLdemJPVcC6HSEBHH6QOG1v3wp9XUhm39hIQk2zdi6PXe6HcT1KGU6k0Gl77
Sl3S6oU9u7qe8XBJo8Ji5olChV6YX/lmV+5BSRT66FDQY0l8n8F7XYdkpJGt
EqBpCvXCLNN98VoV0kid4cY0J3svNJBx1XdmJSDRCvfQwa0eWHKwY9P1KAFt
+P6nlLjUA4ffc3lFKhJQ39mC7zbjPfCjwFlGdR0Cyt3RFUHt6IGHwwyURm4Q
UFA9/cxmRQ8cqXH7dsSagCz92RdrcnugeCH3uQQnAlI5LxkdnNgDzy1zW37y
ICAhdi01g9c90JimPO/zlIDW2ixXRJ71QPVV02ndAALqDH32bta5B7o+uyam
GEpAGVcStXLu9MD8vtd3rkUS0Aveit/uBj3w2oOpm4XRBGTeN/peRaMHfnsx
PWD+joCUojZ09tB6oNw2fU3zBALiMxL413WiB4Z8bOgvSCSgn4JyH2MEeqCZ
+OScfhIBtYzqX7m9pwfe4hGhyyYTUEq8E4P0RjdscOBXUcX4ya3QT79/dMOP
7DxW1/DvmxzJMkAj3XDgaFDQafw82rdmlhet3VA40P9dchwBcafMZV1C3fB9
mOs5Bny+RetdN/izu2F0wl+1a/g+DRJHd03Gd8M+vqffp54QUOKCan5aaDes
VdKX+GhHQF5ZZqZOvt3wGeEQi6QqARne92ZTdOqG2mIhmWI+0ohKiS3aZtEN
Z6IP/NE+QUD7fpVYtOh1w7amjZEbeQQ097mfI/JcN2wsUPn59yAR1bj9/mIi
2w11/wpe5cf6Ey/PY33sWDc8pQFWUkVJ6NEGiZd+oBsutDSwboVivsGLFUW7
uqFBo+DCjAURER/b2fmsd0H9V/PTeeeJaF/AaEnkXBfcTxQg+SgR0ULExV3p
Q12wv8SlpZZMRE3x5foVzV3QaErQqvgkEaV+IiX2lnVBsy3BC7exPvh9fk+f
z+yCwqr+PxREiOhOBTdgiu+CiU3L3VMCRHSu+WnA/tAueIPlbp/oASIS6/vV
L+HbBXWFlvlbuImIafLO0TNOXbCZtGVdz0FE4z/6nK5adEGNWx80tvYSUSxz
CbuPWhd8OMR5Z3gXER2Q9jrbu7sLjnZlvruE9eSX3FLo/L9OCIyeZC1sEFC3
qukY40InVDt4SM/nLwGFGqo8lGjrhMunBzw9fxGQg0Ve3enyTjjOZKg8tkJA
Og5HeK/mdEIDuvbYCaxHe57tyH4c3gmve0VcspsjoO+vXDcjnnbCqJyJ3psz
BFQfPav1ybkTCj/a5yf9lYCeZTdO9xh0Qpvqh4cvj+D5LVWgzGvg95vTTsUN
YL7Upj9mlO+E/VzlCUU9BMQwHHxQQrATPiqInlRoIaCRbwzWp/d2wjWhcRRV
T0Bflu991t/qgLbB37M/VWF925hgsVnqgKaKDOesIQG577yi+3i8A+rcWYmt
LyIgA67qdxEdHZCpwIYL5hKQrJDMj7TKDshx51GOQjoB8R5PppXndUA7ZVI0
Ec/7T/IBv54PHfBMxHeuF7EE1KH0onsuogMyxJ84fTyCgLI11kUZ/TpgvdBD
NTrm76srdx143Tqgaxbds8CHgOxMhr6ctO6Awf65fMouWO+sz+8+fb0DXl2b
41LGenHyQZmBvnYHvD+7h1/tOgGxeksn3VXsgHKG6YYZGgQ08zJuxVuqA2ri
et2lEFDNa47TEcIdsFftYHUqHwF9iPMJStvXAbN3vHf3n5NGT9JWBhFjB/Rb
0CP/85RGZgXmx3uW22E/w6OxzRgppFze7Tw32Q5/ZsHhZzZSSLjpXBVDdzuM
nu07fOi+NNrs+czBW9MOE01PqD6ZkUZD48dMTn5uh5dMiv/yCRBQ8fybT8of
26F65Qhd7BQBvfnNuq73ph3CV7yyt7E+ujI9Urv7sh3q+dQ1dJoRkD7bj3Dv
h+1Q+m39oJ8jAVEOGE+8tsHvMxVcpeD6cB5ulU670Q6VQ7wfaAcT0JKksge6
0A4lqNoeIlg/Wk9lN3SDdsi6TX1k7gMBnbBqfZgk3Q5fngKFKVl4nt78kHAR
boevfdxtg/D+Gq/fPaLG3g5rPda+F1cSkML68eADW21QMU2OS6OJgP47oa48
u9AGk5ntY893EdCK4W160UgbfDucZd4/SECpJQmXr5e1wT6KV18J3q/b5xGL
REYbdLdh7T+6RECmB0fz/8W0wfHG72HnMD8OeAgciPVog10L63mfGYnoqVL4
0JhCG5Qzt7T+y0NEY3Y5gdkSbdA6ju/8f/xEpPCuTcnnYBvcMaIiwob9wdct
vjNqa61wUCC+zO8oESGf3Y1Nzq2wQCjgKJMsEblMqkna6bfCZDIfQzSNiKRU
nwSzy7TC+I2tGX6sP9HbNi7rrrbAA3ICsEuViJz9FoZ6HVtglLan6flLRCQ5
ewK4XW6BRSIzVgpXiGhK4048P7kFBjsWiPBfJaJLu8csbiw3w1FGEZVEIyKS
CGpfmHBohmmMz0uY7xDR5ALbpScXm2Hm7u4lVysiitLRzD1CaIYJb3VI43eJ
aAdHpYvlYhMUsDnoGuCA/VRYHsOCbRM0zy8hGrgR0ZufS2bB55tg98zKAYeH
RHRRT7KaINkE2z1yqj08iOgLb9ILx/lGGHkm5NHDx0T035tIzj/WjbBDrmfH
Duz3zr9zF2OxbIDR9z4S/SOIKDSfeUebRgMcMrncsBlJRD2NAbPRJxvgqn3N
QZs3RHRzLTaDvFgPRS009SlvicjpUuWpW8718NyGeb5HPBEV3dEWkDaoh1Ea
K1/KE4ho06N7Y12uHvaddKAyJGJ9Tv1WEbpRB5l3iZTYJBHRW+Y95yue1MHf
dPq/bWlYb/leSwfdroO8kzrGwp+ISJwgxGmoXgcvjldlktOJKMuI0EvfXQer
KndfPZ9JRJX5V0wPhdXC/yiGzOdysf+7E/PAO74G0qoVnPWKiUjaU9xA27cG
btsy6hQtwecNz6QdsKiBTtdLcucw3kTlW5nHaqB+kCOnwxci4uSffjGaWQ0V
eKq/qCAiukqwt0kLqYYdm93pPzB+e27tgotjNfQMzFAKw/5c3JGVm122GuZb
hWu0VxCRXJNUrFJZFczIERLkqyYiz4nP3qxxVVBvliIdh3HFmvKtnsdVsO0A
01fRGiLSPnL5mN3ZKijuQqYK1BJRiPwQK+1oFTwnL9f4CuOeSxY/tu2qgmHs
Mv8Y63D9PV1yYpoqoc/a7UO9GH8IZ3htlVEJ9zpHscnX4/unvnChvqqEtw7B
J1EYO/VGKzRfroSX9/ltajXg/vwQE35DrYSBnEqrMRhvMmcwWuyvhJZHmEzm
MPbDEvhvoAIKDK7buuI8Uhvy3gEUV0B+utzhLxhvX3nG7/OmAnJNuhr8w1j1
inVVlWsFXEk0ZJRpIiLf/PN2OwwqoAg1fp81xhW8xAOashUwq13M9T+MGVy5
KwJ4K+BGbsOxcoxB/++7ravlcF+lO+cUxp60QR7O7nJoVsItxtiM5ze6DF7J
K4eKF8y1DmD871+8VWRYOcw25H5wHGOa8VOugfvl0Es5PoCCsRu0/HJQtxyy
/dR4JIdxoYj2HRNiObyxtSVxCuNfj6U5EvaVwzIh/WcEjKmTnCVTiwj+Tra1
E8XYSfWX+dFWBP9RJ+rZMM790L/XOgNBidLch8v4fMvbvxR+CkSwYkTKog1j
gmWc2aINghzkTotkjO3rffeQtBEcuCF73QXjjBN3CpxOInit/ruIMsbz/po3
P7MiyJxz5RUjxvoD17l/dkI44fDKuwTXs/OtqKVbKISP9M/V2GJ80WS2ZPMi
hC8VHpMPYNxyKIv9CTuEkju8I4txv7SmnG/taimD2/t8yq5gXJek+DkooAzu
ehx2bxr3/5wVy25urTL4X7C6sz3GlScbjd/sKoOsRj5Bi3h+yrIMtic++wK1
EvLnO/G8KTgKGx4/+wVOG4jFy2JcRJ1Oz2D+AoU5zp0NwfOaV+yoV+RdCiMc
xRmO4HkmetBSlEApZAhUumZche8LGDcqN0rgbp13RwIqiSilKiixxb0EplgY
aVf+ny/P9dYuy5VAtLsrtRHzKVHjoHb/72J4aWM3Zin2Vy0pK5NOxVA0kkIJ
wXw8GOKgZkUuhotvvQpMSrHeXZaNXqAXQZd/FkxCmL/hfVVn/tgVQX57qajb
hZi/0f4RnpJF8Hjz0rbFAiIKvqH7nXm+EEYtSDjfyieilxOjIXutCuFO243g
3TlEtPND0tewo4XQdtzJSyEL75c7tnJ805+h4x/1X5cziMh7fn3s8K3P8ODr
uwrSOH9vZpRTUg59hvEm65MLOH8/vOfnJzVWANcPrWQHfCCiNbLOUG5sAZwc
OTy6Dfth5188BLkbBfCg2PrZq3FEtFI45FsmUABXCoMveeB87vDwfa/KQD6s
W2iacYwiorsMRK8LV/Phv5ApIRiGnzetarB9fz5kukz9wYfz+5NmA2JZTx58
8C54Sxrn9315NqzOEXnwoL00w5/nWJ+ivCcl9fNgLBc/011fIjr2OLz0K08e
5D5hz+Puift35+PrmO5cKLNHoGA/3h/KF0rt9F7nwg1+DhaSI/bXlDY1Nr1c
WBiWnZpjg/O+wJRINXcupO4c0PbAfn2Kce3Po64cKF8bKGV7A59/ZncnJTwH
+nVei7uE999Gi/Cn+cs58Cl/iMaMBq53PvlpIlcO3K5//r9ORSLifatmbNSZ
DYddNUpfSBNRgs91We6wbHieeuMrWQjvXyv7fU262bCU87mm5U4iKtbxnfXl
zIbCbxfmHmH/e04mskK+IwvqCM2fsinHfvFgWvRKSBbseDhzsArnYRNm6JR2
KQueciNdsFuSRHOzHedvcWTB0+O8TWvYDy3ENZ+XSciENzRfmDF0Yv9ht7r1
4VAmvF0q7LCbhYiE5QVzeOIzYLDtu5J7x4jo1M6z5k9FMmCZJTPcdQ7zsduG
d/VdOrxeUJLhbEJElgnhdebC6VA2Iej6MWc8L/al7l2xn+DIYNwuJn+8bxWm
JFSFPkGJ9KSB2Fgiyt61ZzQ3Jg2umIhl3s/G+/z9dZWwt6mwqPJIBKGHiNYd
fFeZDqZCbcrhPVUzRMSllJZ8PzoFKhnum1j+i/3D7s5rE/wpMKby7zGJfSSk
2re+WzfqIxweVb/AJE5CRh9Ey8r5PsKnBcE+6kok5HRf04H4JhkSmmtdLhiS
UAC4Lxp/IBnm9eXn2D4ioQ97orr2/ZcEn3Hr7ExOIaGy/vJn3vuTYLmDzzPn
JRLqSZo9tRTxAd55YAnZy8howZFjzoT3A7Rk5XLqFiGj7aflYlpfJ8K0lGJO
+3oSEtprqgN4EqGtaAvflSgSkh30Y8wMfw/7mE2/s7iT0MWPWblC3O9h+uGr
b0xNScjyQZ9FUFgCbPX3jTI/T0LeZxgObHImwP0iyfWPFEjoDfuxBtvQeDjF
wLRWJklCOUM6j4Y54uHaSNPh1yIk1JDiInU+JA6+FNS894abhCac342V7ouD
vjk0qu8uElp9HnTkmsg7GAr7LA9uYb0tlVzYLxQDG5nL/pbNEdEzfQ/d3wff
QtOusW7/CSL6vNRU0CMQDYcUDYtf9uN8d8TG6zXfG7hDMm2gBevhYGDqPi6e
11BS72GNN+a3Z5eJy7kj4fDPUY60x5i/IgI8I27UMHj+sYeCRAjef6YNquln
Q2GcS+/CXcxP849eaWN6IdDx3ZHAY9ifbV+kcHLffgV92eSaVe/j+brbRQ+a
D4JHA/+qvr2N9W1NCa7uCYRclrbGDIZE1Pc0JcBI0h/+im97Q9bG+sjFbVh5
/gV8wcbXNq6A/UGc59ETds8hjLZrD8X5OFFy9ueroKcwpCYxMGQ/Ec0WX674
neELaZ7sbkVbBCSlXhZs3PoY8jrUOzJOENBU6qXil6Ne0FGY6wkF+32banE9
A5FHcEAykrrNg4BWR/8uHjF1hVPvpJ/sHZZGnuttL1finWBrSudZPRHMJ56k
I+UTDnDf9HNjbX8CEjT55S2oZg2zbZLen0X4feFxBYV1ZjD0POlzyiQBeYa+
7ksO14epgxzWtE0CerKczO5mogRvavodfciF9635dpX0MEWwcJ3Vh4DzPb+0
7dc8U33QtqLTakwhokdmexRBphn4XDu7nHKaiKwlzXYkSlqD2PjYk97nMV/+
DVqy9DiAv8oFcdIGuB7j21tkXjsB01/dKsumuH61RLLVFVeguTdp4uf///3y
k9F/0VyPAE/gzozrWA/L5a8RGeofg6652s5mH/y+jIVbbz76gsMpJ0j7XmJ9
OPQkguT3FMynU8aP437/DOOrb7zzHFyT+3xH6T/sV7dn/jVXewFe3VrX8nxH
RDZuqlKb4v6A61tYGgXvj6Pz/TcjtwcCM8dnItPYz04Y24cRpoPA269Rau+x
f221ZJqcMnsFDpSt8Qvh/S4hev5Rtm4IqPTv+8ON9eHlYCSP55lQ4Cn1opbF
i4RmwicyNElhIJE17McCzvfnLkiq7xcNB2cESd9GsV4n7nAdn+R4DVZrReeu
PCUipvIK9yzGCJDduOGsi/3/TXc2bg96BLCcMzyWjfdVGdkgXWM8ErwNj2s+
/BHX60fCOd72/4D+lTNCjHg/uif9GJ1Ab8DD+47npvA+7TM55ZaZFQXmb7+U
EvpMRDJ8vpyP4qLBpPHv28P4PuEdzWnqr96C2KrndUpluL/+B87yeMeAKJ3t
ynrYH6RvprtkmLwDaoNx+e3Yb2wzeuT35WgcKA0406iG/Ute4aHu9+/iQP/X
Qspr7Idu8dQeerk/HlgZvJz7gv0a530bO4fgeOAlpsJe3Yr718JRor8jAQiH
BAumt+N9dfLzDkWvBHBtRIDPtRP7qSnG+F3274Hms7N8X7D+RvAotXHT34Mf
fj8TDPqIyPic+5awYyKYeCD6oxfrgbhLgdTJ1UQwmOv1VX6QiH4kL9+QcfkA
suaGNJ4O4fP1SQWe/vMBKC5xZOYN43nZdbdU+2ESMPsk+6xhBPtlWvLc1Y0k
cC0gRqR2lIj23J3kv+WVDO4bVeWkjhFRV7Swph3jR8D2Okz/wTje503X3dx8
P4KDtQt7jmJ9Mt+I/PhkWwq4Y1FTBjE+KdXVG/w8BSzu/6wIJnE9jfftiN6V
CryaVFU/YFwcrC2T5J8KOPYVP6Bj7IP8LLLZ0sDzK1k3Dk8RkSa9Krw0OA1w
p52xp2HMKcpYVcvxCXjrzzLLYDygq7jSEfYJ7N2zfo0H4wRfN9ERnnQAHapD
e/HzrPLyL81GpoOhBrWshxgTvtK9f/JlgNhZ41AGjNd4pLK2ojOA7TPHFXN8
XnTOepRVKBPYXfEyT8b383NJ2ssblwl+sV1Wr8H3P3aFHruPIwvwya7h0ExE
ATbBMry6WcB9iuF7CK7f0hPJFoGwLJD8wv8CDdf3SkyjxaGuLKB5ONu0APej
MN9qQ5wnG8jzbBGZB/C8tux4LaGfDcySfCwFcT+9pz9IkCKzwXd6jSwj7vfk
pkqVbF82UCxaOZeK5+Hc/onrinw5wOrOr0guPC+p0t4rZwxzwKdRxTuyLUS0
V13IXz06B5TSdzKz4/m7f7NU9MJQDoiN8YkM/X9eczUsviyYCzYkaucKsf+l
haxdumacCyA/YHX5v79NiZg1fpcLOColmiDmA1MF5bH5WC4QGVNX8MX+9PZA
xwHrQ3nA/PfQl3SsBw3LDln2ZnmgcPvxQfEU7I92s6s/eJ8HYmXS/Ftx3g49
nD7qPpUHDvnfTvDC+fyXvJaL95F80N8d2cuI/aLhldm9z27nA8NIFys2zPcy
m+dJ/sn5YDa7RlfelYgOPT2iFDKTDwLOvOlYtsT+MqayO+J4ATAsTFZW0Sei
mXxT27fWBeAP1ynLV0o4r7ZssSSkFYB/sfSQEuzXsqZj3ibPF4CvItE3jBYJ
iHtLnpIu+RlkTmoc+PyagFz3DzTm2H0GiemHT/45QkBD0q63CjM/g5KSlcMe
bQSkrM7798vSZ3BN4PxnBW6sTzfzQiuJheDroqJ5EsD+3E33RP39QjBxk8+Z
6SbWz5Cl8pbcQuAYH961052I2lKCrnX9LAT3Y1kEV4KJiFIhQe+nFoEnddbh
fxOw/xpo8Bt1LgJfWh2EJ3Jxfly2FPn6uQgcSvj1Wgz3x2T3jsLva0XgTLAq
0///Py6pcLdONLUYtBabu0jg+Vqw2Detdb8YPB2u/eqG9dYT8XGnzxWDbYW9
nTIbRFRjK5R241gJyNX7ebR9OwmxCRw+s9eiBPQtaLZvspPQ2wcSDvYjJWCT
tV7v3CESmhIl7hARKAVGdeyBTsdJ6GQbNbbtaikIEUgLNSGSUPEJ0ERsLwVR
Igf5niuTUN/opWM/K7+Atif/QrOMSEgkUB8mMpSBvS3xSqa3SOgO7bq+nmIZ
sPV8zbxqRUK/ws2fFBSUgQUPk/R2ZxLi1nQZc02BwFvNP+NjMAkdM7zQ5FmL
wAS1SLUFklBTVtv+3q8IWBATMvurSchhx+Vb0izl4MuSa/JCIwl9zru6Pqpc
Dlo47z5W7iOhc+ymx04Xl4OEp7yvx+gk9N1i0vFNXzkwPLbxPHyNhIJKLSD9
VzngCpyocdgioW4ra/0EcgU4nDUQUsJGRq5oPn79UgWQlp1Rk+Mho4P77X/o
OlQAhYKfvJsHyci8yvEJc3oFcChoFwiQJKOdAr9arzdWgD9DEav3Zcjo0z1X
gbzZCtCjdDJ9GJDRxbr123t2VoIJYt3urxpktCLkkWMuXgn+65j2/niFjCIe
bG2UqlaCLzLuFRdvkhGt6bEGz61KINofPshlS0YjoiyvbR9Xgj+EuAL5h2Tk
4/ZsrPpdJfDYuCxL9Ccj8badEkJllWDk2z29VzFk1CDu7+I8VAkKDIKzdXLJ
yM6DrbJlvRJ4H0hq2N9CRpxdwXuP8lWB8p1HKsXoZFRwgtPQS7YKnJVtGT4l
RkGGj8M/9OpVgbdy006ZvhS02ctLl3aqAseUCFzHuigoXuqNgl9oFbg+mLr/
ymkK0qSVI6vcKsC8/nNCbZOMfp6dVdXqqgJXWA58Ue0io9hLHPUSq1WA7cwu
m/v5ZKR+Q+78Xt5qwGpy2oT+loyWLU3bF2WqwQ5GSSZXPzJ66/RCr/1qNdCJ
uJhX6UxG57yz+3Ncq8FI25Q4+x0yWvLvvxH+phpESD3W7TMgo6hIxokHxdVA
upHBtUqLjFTfH799dbAaCJOOKobg+v9X7GbHL1gDrom80mc7TkbKs3xecXE1
wCXgyOAuBjL6/vM0s095DVjaOFjN+YuEwhmsn9+aqAGbKRVm++axX9lfHCwu
Vgv6T2QyvOklYT2b4Np5thbwl3feWGsiIQVp1v9mLWrBmoi60ko5Cb06Zxj3
KbkWNHecoCumkhBN10csqK4WnHRqGlGIwfy6kfrRfrYWXKqwjJLC8x5k1SFx
ibUOzAyV3avG/ujUg/Us0sk6wPZi5n24Hc4L3qJUbu06IBV7Z/Lv//NRgGbR
qk0dqH77bnxThYRk/ruv2BtYB8q3X/40d5SExt5HlRdm1IHbpbsIDswk9DKz
4mxUax24H+3t7Yr3A6Xke/3DpTqg3bNqGGlFRCM1nBducNSDbUfZqpU58b7r
oHUokeoBx7ncx/ZY30kjZvoil+vBDq3WTqMfRDQ0+3KA0akeiI/aS5nhPPNs
Ncd4Mrwe1O2eUewjkBCBcXCiKr8e0Ky5SmTUSGhgD/OdpJ56YPVk8X7sNRJ6
cuDk3PPf9UDxjWWJItYDKbHL9lYHGkCCZXp9M9aDPumHK5pyDeCOkYBynQ8J
+ci/d5EwbACbm/zKjwNJSEKt8S/bwwbQ8EXaiBqJ85/uitdidAMYKq+I5ojD
+cxYgKW9tAHMfdwwPPWRhE5Yq/jlDDcAKKNjUZVJQl0P7u4J32wAzGKDTI0F
WG8CS7ivKjeCkT+qT19UklDHf5P/nTJtBKfsG7mu47z4KHG3IL9PI5gXulQx
+P+/nym5fmS4shH0xQxxsvaTkHutb0rZVCNQFvRKqRomIbHONMm4bU2Ao1gt
S32ChFy//6XeUmsCAXcTzcq+k5Aw39tzsw1NwN3jJ6nsDwlVhAr6EeeagJL4
S5P9GyRkvuddvdvuZsDsfmhIF89n6la8Nqt2Mzh1QnHZeTsZabsdDtK1aQZH
U7SVzHaR0eJyYmtUQDNgX7isTt1DRpTpZN2Tzc2gIznrbQQHGfWYHA93/NEM
VDnfpopzk5Fbf2p3CVsLMPrmy5TAS0ZlTekG2hdagJnFNcINAczP3Fxj29YW
cP4S6+mfhzE/JKhx+YstYMLt2uyPI2QUmFQwvsHeCpav6AX2HCWjjjdF5kEX
WwG0PpXx4CQZPeCST+pxaAWp0hu+ElgfDwSWfhMKaQUp6jM7OqXI6IY3tM5s
bwV6g1duLhLJiGFd+dNveiuw4nikbEEmo3a58V/Cu9oAzwul6QYKGTnlmp2y
PN4G8jk6yRayZHTW4fC1ALk2YOZR+PbNKTLilZxyy9Jow/qwpf1FjoyKkixK
1qzawGXp22/a5cno5S3xoYPubeB89PcP5QpkZCTy7Z/yyzaw/ebb/neKZCQ5
nCxoEdUGTu7taL2rREabbyyVXqS2getyfPuPYP1o0z9ukl7cBkI0DAiNGMdz
ffdqb2gDGj+aA28ok9H9ttS41YE2YJc/GzKIsWrg3XK+uTag/2wtUPU0GfFo
Skwo/m0DlCexKBLj6e0/mMx2twONft4rXRgXVqYffibQDqzIBKM/GL/wtlNN
PdkO3v1Z79x2howMFaUtWuTbwfJ3geg1/LnE+uLTZa12ILEj934bxhsFWUm8
Ru2gnKfyjz/GLY73amk27WAmizHlOMbvCKQZ40ftoEV4uTkZn8/hx/JO34B2
YCol/pQF4zOpuceT37aDy9tcchXx/bjuOGk2fmoHr5T+bVzE9Zg6TL27WNoO
xJldkTyuV8HYqj9XcztY+zLA+BfX93lMwSfZ4XYw/8/itj+NjAwMXZqv/2gH
zDPtQrO4P8f3n1rw2mgHMgHJney4f+uda3sT2TqAaViZ/zrub9OrIuk6wQ7w
utgu4D2JjGLOu1+cl+wAFb+8iCwEvL9Y5e/tU+oAN1+KFXPjeVKu/RtCudAB
rv2U3tGE9ZzjSWmOgXEH8EgQOCssTkYTyh6dj+w6AFfGDzdGUTKaT9if5+/R
AaoUJVMKBMnoF0tOeFRABxiBL1TmD+D5u6P9ICW6A9gQVmSDuchod/20XmFq
B2At/9v8HPsB3pOPZWqLOsBWrTlTIeafSKDA/p66DmAfJcX3ZxPry2L+76ne
DnDsrPzkfrw/KJcu9q1MdwBP+Wd1LXMkpJT7vZDpVwdg1x+uLBklIXWep284
tnUCR7qu64V2EtJ1EXYX4e4ER3KG3D5gv3Ojv8hQ+nAn6NBXvKuSQkKW8lfk
lUidgEaOH9b1J6H7MQsC5093Aj/Zz2wXTLA+bfn9u36xEwRH6HuewH7umenh
YWuTTnAb7LWdFCaiV5VfvrjZdYKDmdcuLJ8koagjBrF+Hp3A+7Puh16st4nP
lz0jAzrBxf3n5GU+kFDmbIBJUnQnkHxyeL9FLfZ7WkeV81M7we+gSu06rGdV
6eUiVUWdIDL/FrUb61cLuxFjZ10n4DumoDOG69V379f4eG8nINL39BcI4350
vqpYmsbnm/hHHZHG/aCefL+12gn01whsOUr/57+JuSB3Fzg816Kgd42MWI3W
VSUOd4HVGy557hZkxF0WfkSe1AVSwvLzGe/hefKpnza42AVGI1k0Ap9hvZu6
VXvHpAv8c+UNzXtFRkrnNpOd7bpAlMKxrCdRZKTLSrYKD+gCsy4ssVrpZOQe
+nautQ4/75mbqW8bnr8E+6Vzp7vBVX+ds1/ZKaiHhbVd72I3WN/FVVexn4LG
bidmm5t0A94/DL4xwhS0eqL/vo9HN2htJicYSVOQUO6Z1S9F3WDvW9soFx0K
OsYz3N1U1w0mN3aLF12lIJKLS8Fgbzcort/tdPAmBanJf3L5s9oNYvtL9pje
oyCHSp51CqkHcLzsTCiPoKCNLSYXvzM9oMNxn1hbPAW9VFhaGdTtAcIOF37d
SaegA27DDtK3esC6P23wfREFfchv+OHj2AMUTXuLPtTg9y1/tu7x7QFrdmd9
32C/hqQ+fDse3gO8a3TyiyYp6PzdUHOPxB7A9WIqV/8nBQ0ke4235fUARq+7
9pPbqchyysZYrLoHTJyp+7znIBWtihgOunT3AN4uIfUZChX53FAzaPzaA26p
inPcvExF+6Io3UK/esC+CMZzVx9SUUzPId3723uB9a/zuyYLqOgEF3trNW8v
6BFZefaNIoMKdf5p8R3tBde2739YIiWDzgbM1tnI9gIN7zZtn2Iq6qjrOYvU
eoG9nZmPxRMqurmtqoLLoBekr3UtnDKloh+ns8Edy17wzcfeWE+Nitw9Y0uL
XXvBQPOZ76skKtpZ4i+390Uv8Cx/7KggSkWvf7sWmL7pBeyb7NMHuKlIlHKb
nJ/SC+oDI4PHd1BRlsPlrJ3FvcCMfcj6yAYFKaYrSxo19ILJNKGbr1coqGFW
MjVzoBds43/19fd3CjIQFzjKPNcLTJp/NBzC9fxqtjNR/28vOBTc10gfpKD7
71ZFUnf3gfyo/z6f76YghqGJmA2BPjBV0uUv0kpB/HpfIhMV+sD1Img0W0lB
ySGp3GvafSCnYU6ruoyCKC2RIVo3+oBw1OjYBO6vjtp9/2WPPrB3SSm0PIuC
nsgd9VKGfYAUTWwyiKMgTmfuf2GtfYA9hxTl+5aC3uUwun0b7QMj60P55f9R
UPHJoftBDP3goTN7i1UIBS0KhtweOt0PgqKvq3Bif//I0HNSWrcfvDD9w+np
RUGskXdv+pr1A60Yd8GvDylIbN85wxO+/aAw1ZMrygnnA6a/512r+gGZf/Ld
RQsK+qY009DY1Q+QUNIhNVMKcnrYrSb8tR98bu+pFblBQcE/M0/XbBsAGuR7
JbZXKOggMaaMj3cAZNYVkvswX1JtX8rbig+Aq0sXNri0KKhq2pzKrTYA4tj1
Kr8p4/mvO3lfV38AtJ78Ud8mT0EXU5czXlkMAO8lf243GQriDSiaa3EaAOtP
32f2ESho2Nb7GNuTAfD9YqHx9AkKStRRs9AKGwBySd5akTjfWBP3JrxIGADL
+WLRI4IU9OtntMD28gEw7UG4uLiXgkp7zAxU2waAcoZYWdB2CvIpPP7aZ3QA
pIcJbrPbwP4oaqkdLQyAkw5ujXdWyIj90ee9WxsD4IHeDnatGey3bnhqKbIN
gl1UWnr3IM4z4Kzfw4ODwF/vsUZaMxmZHdpTXXRyEHxa1ZI7+4WMjjF3Mq7R
BoGo0enBzhQyWph6oySjOQjcJp5MbYSQUV7NzYdO1waB3dOBjTOOWL8+Hi3M
sRwED9TqioXVyej0y4WfSy6DIP7pBFsezrM7bfKJ0s8HAaNoPnT6TUQt5x/Z
2UYMghj3iganJZxvpFXS0j4MAqP2FmPV//sLDtaZ2bxB0PmOpKiH9VVkpU3s
WNUgcI/5+y0mFPuVrkjT252DYKQ+qNXxE863BcaxiRODoBE+EY8pJyPH/44M
TtAHwYHfvb9edeL86j6//xDjEPj9iT9UchLru1HuFZN9Q4D6Tu4dI86bNYru
ITHCQ2DwVh///+sZIHy6ZVBqCAyZTS1+3klBuow7d/MrDYFAU6FODi6sd5Mt
agbnh8AbnU7RhIMUNFL1+kmE0RCoXD8f/uwI1r8ko/Kuu0Pg+IewNz2SFGTj
d3iT8+EQ4Ht7eCuRivXQ+jvt0ssh8LatlZVRkYLKJF3zmj8OgUMh6vtDNTGf
2AF9d+EQuLbt+aGBizjP0rdJadYOAYn6Z3E9+hTUmxeWXPN1CPBe5z7IYkZB
sRGGUyyrQ6AUScgq3aEgc9dDh1RYhkFlPYkKbChoST4zCooOA8M9TkuxDyio
QNC5d4M4DAai+0UY3DHfthS4FU4PA31f528SnhR0Zpz5kvvFYXCEXNl42IeC
dlU2BBaaDAOX+c3s8acU1JYY0vDLbhiosTRRTV9QUMQzgx1Uz2Fg/nUu7E0A
BRlZCqs6Bg4D3gHD6kfBFCSqOe2d/XYYKCge3/ET833mZPqXxbRhoGybua8/
jIIy2JzWJUuGQUb588hv4ZivizRZm4ZhkPWIHhGFMa2d0Sm1fxiM9EjJNODv
M+TWZc3MDIO/a/bu5/D7a8KDf4ivDYOIIGvtDFsKCnDWP2GxYwSEhd7aTSgk
o8sGgnfe844AAw2v+m13qIiX/orp9ZERMHygY8eZdQrqe8ES+4wyAgYt3ojV
T1NQtKirnKvKCAhS5bm2OkpBxiVzXVa6I2BxjRboOExBIldMHK6bjgDOrxsC
C0MUNDnfsfu8wwjwiEsedcefJz09l6zkNQKu+wzfTRuhIEuh4jOEoBHQRtva
f3aMgk58lhw5FDMCHHdVc4pPUNAPnXg3rk8joFEsPF9uCuv1Y7+sX/UjQLGL
yF0/g/WX/5/WTN8IiHx27bPMHAX9zrH/1v9tBFSqKsgV/sD9m9IX+rJtFMwZ
M2ktLlOQkkdDUQb3KHiyLvTk/SoFMfIq6cUdHgWCl23CLdco6JnakQDf06PA
KnxV9cQmBamP/Xf0wcVRIDcSsnaCkYp2u+2pvG0yCg7+iilSZaGiV6krfzQ8
RoFZ1LJ9JysV6arceS0fMApei91v0t1LRTxDAwTJ6FHwKsrfhoGTivqcLjQJ
pY6CU7k1i1M8VBTFVnFnX9EoSHgst8XKT0VGSVRmprpRECxX+NVLiIqEQUrs
Ss8omPZOM79ymIomeg/Svn4dBb5FGZMxx6go0eFVd8/PUXCiT1HCVYqKcll8
Tk0xjgHzNdZtO6lUxN0uv/3GrjEgmM552kuBipxjVju7942BtyNV+ofPUlGv
VWb8hQNjIDbveaKBDhWdkrGyrxUeA+1boVsF1/H5mA4rKh8dA44f+J+S7lLR
35Yh1iKpMeB3tuSxsxc+b3REH1FmDFSfbX3bFU1FX+5cTEpVHAM/WrQfeNRR
kRCF1enw2THw3T1BY5e4DPJmqDr9VnsM/BsR2z1oLYPGmzzYea6MgcL4iMfL
NVR05o3scOD1MfDVpfuSgie+nwU9dfutMXApoVxAQIuKtpHSXL2sx4Cu+3yv
xiEqur1pfm7t3hgI5KxtOPKPgmobhLjvuY2Bp35l21X7sb+L7Buf9cb1oLHX
7vyM99Ot0EwzP3wemYn3+zF/5qS1PQaDx0BPQb7lLzsK0v63TetK5Bgo4+8h
Rp3F/KuDB5pjx8BITZvUPW4KYn/tNn02aQysmJ5mVcH66WBKzitLHwPHduf6
LpvhfC3547Fs/hgYmwu/WIT9Nnk9SSerdAwINan/Dgoko/Cam4LHq8ZAUb/t
w99lON+E8s/FN46Bii1H7w99ZHTVpKuQv3MM7Pn9lX1kGufNk0HPwgbGQJzi
iRtdP8iIf03typ4JXD/9kFMqi2T0sIpR9OnsGJjlrRmtnCMjoc0pxTj6GFiK
NL0mMUFGSLbuWsmfMaBdSbkl0U5Gt+6lPehhHAfPHP+TF8kno+1pQSH0XePA
+qHtRKYvGaVM3UvfwzkOksdTvrntJCNtIb36o/zjIPscNcr6BBktXj319Yzo
ONg77umS856MQkMEGI1PjAO+6YPKIeNkRG3cPOhGGged5lk/4/dg/WCZOBVO
GwclA7fGaFIU5K5UfSXzzDjY8XFf8j6s54KuHx0aNMcBu7hO5hb2IyjbP+Cr
7jiQyRB4wO9CQWZzdh8Zro8DOGMgu/clBW07olslcGscvIsy+6QTTUEfjalj
MnfHQbnH79vENArS+u/Av0uO42BDcXn/EvZjC+1/99s+HAdz1gWlRbUURD5b
ofPeH98nJMp6FetNj+eHu2Vh44C8KZMeNU9BroV+z/ujxwF1d/p/eb/x/jmp
A9k/4fosXSD57KEiUwvS4Im8cdCy9JT1Ai8Vsbzj+X22dBxkOa1UQWEq0uQc
knrUNA4kPH8E5BGpqHvNMnZmfhwIm4UeC9KlIleSdjHz6jjQNPPcUjCkIn4b
6R6hjXGg2hB96Av2yzdHV9n02CbAdPxFY0UHKpqv9vEol5wAH7aafH39qYgp
7K1RlN0E2PjhZ1JSSkUfmrxc850nwA8VCYNHFVSkvv1WeJvnBCi2KWA5gfkX
6Ha8aXvwBAiKUC+90ElFB24WyDtmTgDreMey9hkqkpZs49demgDxfP37AIcM
spOLixj6PQF2Sc6sVPHIoIyzDpy2WxPg2zfx+NP8MkjCeB9r0N5JQOPdshE5
LINOBF/80yoxCf4qLaW447wgRm/rvWw1CU7dKMlv05NBB/Lbw69PTAI/8rsK
wXAZxKDYufdu1xS4xZmkmckiix4XNPXFDE2BZIaueY2dsoiJUJPQNjUFogZS
k8d3yyLmw0UyMqtTIMwy5PVOLlm0fdc7Y0ber8Cs6eNz6iFZxNZtnRF59Su4
LKKYz60oi/htmS5UDXwFPE/+lBx1lEWUGGKg4Pg0GAj6z3iiTxYtD4mPy0/N
gLHvUCgl7BRqqbxIyKn6DniffKy9R5FDbH+7d5U2z4P63ZrfGnrkkFV/8Ihg
3gJg+O/7yGVTGrp5UI4npGQBvE6JTta9RUMGJhNaLJULIFb/wZmLFjSk/pVS
9L19AcxdkJpQs6IhcXp/2OfFBdAO5uyO3aOhiZ1iGpdOLgKT8kef0rxpyOhU
Ye6ThEWw2HtrJCaWhq48NP3+O2URMGi+cLCPoyGtMtZDd7MXwS37XHWQQEM0
1RtBl9AiIF86mtP/gYYOXGSyEhpZBHpO93LWPtHQd7I4+9CeJRA5IXGov5iG
krUcqh6oL4FTb857TXfRUNX7/mfe2ktAtLA2OLSHhsb+ntHwv7gEzhbwE+X7
aIj/E09LnMES2LDcGHg8SEMBe0p6Gy2XgH9vSOTEOA19NBeL6rFZwv1L2XSY
pKHq0kCjcYclcFJq8PzfKRratLk5/st1CdxRIZxmnqEhh+Ztc4deLIFWTeOg
4R/4eUfs0yUCl4DiQMEF9UUaSvHos5cNWQJ9Qps8GUu4PpJpP7XfLIGqjRiS
9QoN6QVd3HRJWQLWJWqJcWs0dH+6CPmkL4H5w2GJo39oKEjpsG9g9hLQ3Kvu
fOAvDdUtrO54X7QELJU52503cL10ojla6peATnBu8RijPNJPZunqa8bPy/uQ
MsMkjxy3bCMm25fAXiffrBlmefQpU1ngT/8SKOP7Rm/dJo/qdqQOM48sAf0k
5TcF2+XRVxOuuL0TS4DNKJkYvkMeCe2bFhP7vgTEEmXHSbvkEc1S55vUwhJQ
Ix04s4LxVVSYIre8BBZ/5ImnsMojpwOiNqq/lkBFALf4ld3y6JWDv5TO+hK4
NjvdtoJxet3PpWubS2Bucivr+R551CBinGvORAdNulXq7GzyaNq19oH9djow
PvWc8yXGzO2EU+6sdMAl3e31G2OR41HrT/bSAfiYtqa/Vx4pPGb+EsxJB1ty
bwaSMb7Wb+MVxUsHjpWVLrMYOxN7Tn/gpwOBD208AuzyKPQFYMkSooOTH1Ln
5THOHP9YUyxKBy2XRI5oYdwkx/miWpwOyiuu9KphPBPyUKvtBB0ouv/dScSY
5fsU26AUHehX6Kdtw/jQmQttX0l0EE1Z+K8Kv08p6nPokgwdvGemh9pgbLgs
oveXRgfKbFSlf/j8zpov928HdJD+DAnfxzgsYaV/nwod3OCq+68J1yNr3eit
gBodPNu5fWIXxk26NcbiWnTgKaux/Riunyy3ePvcBTqIyk+9IIvrndD9VCVb
lw5Wpns+HsX92BP5Nd9Znw7yLceWfuH+uRicPaZgSAc//DpqE3B/J/g+RDEa
0wE/x/TLY7j/2oMsbLWmdOAeyqTxFM/H57fmXgEWdHBm++GCfDxPosZV9EtW
dGCew3OwYIuGAoXFzPfb0kFQ8Fc1Hzx/a2O+PUMOdNB7j8mRB8/nrYRJ9QQn
Oli8tiBujee55ZZKyR1XOshKquVzX6UhuSPvJSUf0QGRZM2otExDidNMccte
dHB/6d+19AUa2vvRjLPQlw5exzgIlH2nITeriicez+ngS6zrVfNpGpo6Ifr7
jD8diK+6FYRgvl6Yf2y1M5gOZrL5qylDNFSUPj7YHEoH/aIa/2Qx/8XsT18I
i6ADTpv7N71baSiYEI8MouiA93Cjx1wtDa3TGchCsbh/S/uNtSENWeTe/DAZ
TwfnyKrVt/NpqM0J7U/5gL//oc70WwoNycuIvLRLoQPqRI2y/lsaSvrt9Y+c
TgcKbrmvN/xpCHtduz9ZdHCYI4lU4EJDD93BeFkeHZydCOq1v0FD0/LvLj8p
pANZUj4cO0VDFzc2qzVK6aArMLfuzqYcKikzPsWO6CBD9J6Dip0cEvcuS+2q
pIOrtu08bRlyKOS0kGBULR00F2kJB/DT0D8mz2CTRlwvzdP7gC4N3a4aZjzS
SgejuvNyqa401P5U0el7B66HIumSfgQNKajFTGf20IFGo7VQQQY+/84NgwcD
uF9VOdeeV9IQR4NRI22EDq5PXy1o6KahR/6ligwTdMDKkpp4CNf/m/bBrOqv
dHDZbv3C2k8a0t37SNR/lg7I2dMlUVhvjoXI7+Cl00Fl3LOdXAJ4vnWj3QZ/
0kHSD4M2krg82uT6Oxe3RgfTralcRQR51BlR3HaSYRkAJj3Pc6qYPwb8KnTm
ZTA3xN9897w8+sjnnl+wYxnkXLlkQ9WXR55v5aJOsy+D7QoWzwduy6MTCYW3
rgotA7GwsMMST+XR61sHeg6KLgNRSSN15QB5xHDEVX3iyDJQ8/jEfjxMHnUn
y0raSi6DQA/S7ydx8sg7veCXj8IySFeIiPhUJI/1++SrN8rLYIA3V1EayaPI
mHfHs1SXgTRfk314jTzKCPQzGtZeBkP9lKdsnfJoyNawQvbGMrgzq9w3+V0e
yUltBs57LIM/nx594t2vgJYzzh7Rh8vA3rrSXva2AtoULy6zqVwGGrfj2Uas
FdCud1IGvrXLwJ2B3cfDXgGJBO/3z2pdBsUXFluSXRWQjv3sEuvYMnBpswrN
fKmAPkkHlkKGFdAcnTiVna6ALLK6Lh8/swLuCQ7XWSwpoLIQELN+dgUwjZFq
JH8qoAOOqdONGitAdYaLeeW3AmqiervZXVoBjNy19x5sKSBKycl3uTdXQA3L
7xfX9yoiphqf74peKyBIqb+y4KQiejdIeKxbugKO2+rzz5srov7tgRkPZX6C
EdNxanOHIuJs3veTWXwVsDeELYu/U0Ie8hWb3cd/gYlnj/eedgTIeYNtx5WD
v0Fw2ZEeZn5lFH/neZfA4TXwraJxMNdbGc9zUwDfkT/gS5OJvN6UMmK3TztT
ybMONt5fWHqpfBpB1cIvBfx/wfyLIvTr/Wm0aWsio7/3HwiLys2+zXAGMe3o
eHNy4x+QYRS4WmF4Bsmq36/QZNgErw/8Ng0rPYP+Dn2a4VneBC/sduzK3a+C
VG3qXp3/tQkSOhWTNPhUUNDfyVNP1zeB+6z26TF+FSTKL/DiJ9MWENjacmAT
UkHqV18c7+TaAseXWT7fEVNBr9strF9Rt8ByWO+oAFEFSdcIzbO6bQFlB6MC
H00V5KpHCz/jsQUW6R+5+LRVUMWUnoL74y0w6Cpkn3leBekzBwbMvtgCV5oC
RYYuqqBHyn8l6qK2wKbRF1vqVRVUX9xr+7R0C5BP6uV+u6WCODVXeL6gLcB2
Wvmnh4UKMurfW/azagvcnHAhc99RQUu/z+41b94CO851f1K2VkG81LyMMyNb
YJu9r/8bBxV0s6pV331iC7xvZ4PS91VQyuW5zezpLfDEeXWp2lEFKdwX1Tm0
uAUKM6d0lp1V0DNGpd8GK1ug69LSIz9XFdT26tq7V7+3QMMl049C7iqIX+SB
Wt3fLcCYJdeR91AF3cp8tbi1tQV0rB+ua3qooP8BVP9XQw==
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466895240679*^9, 3.478439598855193*^9, 
  3.478527872246492*^9, 3.483295257912038*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll", "Subsubsection"],

Cell[CellGroupData[{

Cell["roll to x", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportrollinput,opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747615584*^9, 3.478377747632732*^9}, {
   3.478377783765902*^9, 3.478377783817721*^9}, 3.4784393726902533`*^9, 
   3.478439452110503*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHc81d8fx0OSUSQSIqsk6y6uiCMKSYVKktVACflK2WVVWkZkRkj2yiY5
x957b66RnYiU4nd+f3k8H/fez+ec93q93oRv3te3oN+xYwcP444d//9baSo8
ur39HabQX+5qOEtEYutyOo82vsN795hKSjE/e6NdvLD8HYb5ZARkYtYufRDc
P/4dvlF+yvIWcxtvjWZu5XdY1nPmpCHmkS7rbMvn36G3f9vjcS0i+qOd59W8
9zu8EtC1PK1JRMa0uiV1pu9wZ+a3jB7MZS7D10u2l+Avt6uGNZi9knfJJy0v
QZWDq46fMO/edW3Os2MJXvKJbriJ+UD5P31K6BI87efY2a9BRCSqpliUwBI8
73Ytp+gMEenfIKnf516CE2DhagJmh1cCN9X3LEF1yvZEAObc0dUP838XYeKm
QJYlZopfLP/JoUUorP14z37Mcv2/OYcjF+Gjm/xNlqeJSMEtne7wwUXIuXlV
97caERl+ChNaZV+EEfKGnuOYnVu9QS3TIvQWl3tbj7lY9JrH/V8LcDNu3CgC
s2IT42/YswDdSh+7UTErCZgtm79bgOcp1V22p4hIBe4bjedcgO23Ez6XAyKq
OMARQ8e6AA88LfuYhFnDbq+JOcMC3JL+/OgN5vMCrIMCP+ehQc7jMkPMxm47
e8O75yFfiXr7ogoRuVJ/tfiHz8Oc4+sj+zAXZA2VuQrOQ6v24buqJ/F5mAY9
+g/MQ4GPSmIimMtM+08qsM9DpqmFYgbM1Xt6Sta256D49rNHNUpE1HWvtcB+
fA5+55WX1ca8Il6RaZkwB/8Tt3LQViQi6dikGP3jc/BXb2mLlALOx/uLmb0i
c3B/ULMqC2aF8F9fjfnnoMld0otvVCI6Hag5bMk2B5/o8b6Pw2zk+Y3fbWkW
CgTLVO3H/MxcPOJjzizcazs+912OiMaEkoJ/Ks7Cd6KEuadkIpo+dPGjC3kW
lpCbc00wzx/8lbMlOQsb3rDryGFe59Ds2C0wC+MEHnybIBERG903DoHtGfjf
yJEKFcwnxo/6n6mcgQMdivVzBCJ6G5foF3puBpYuDnPxyRCRAeGItov6DFzZ
/HPsmzQR8cGPrMZKM/AR68ivXMzxQ7H+wpIz0LhIo0oHcw5PVEg6ywzkSUpm
dZMioo43AbEV9d/gu1HRlfrjRLTf1bloSfMbrD9OPygtTkR9u3+5tINvcFYj
yPLHUSJ6H/ZQKY/6DR68Xxydh1ks36HMRfwbvCaWwaaImbJsU7WT6Rt80dw8
rHqEiC5b3mjjq5mGavBli7IoEYXoa89onJ6Gzl+EC5YFiah079DZvJPT0Mgg
yzID80SDbZqw3DQ8eyq/9C5mknqQ3d8j05CPi2YwLoD7l9z38zPTNJS+9pTc
dIiI9nBb0gk0TsF3b7h3B/LhfPR68a3qTUH+2NOpjdxElBm8391cewqmnxrp
ccPcffHTcLPaFPxiJh0iiVmsri42mTwFWQyWv77gwvVcxC5uyj0FJTnrilT3
E9F2RDS5vm8Ssn9cigrnwP1jXKzzwWwSkumX5eZYiMg0Tdjc+uokPBRiPeGN
+fSfFw/kLk7CQpXWRT7MHOFGkY0qkzCJVZnrLDMRJXdufvslMAmPqpF9oplw
fLVVfHSHJuDi/sniIztx/Z2oLKa7NgHJOconU/4SkKCfZHOT7gScV9auOY55
Z2/wWJjWBEzI7XdP2ySgNsfbTDIKE3AyUOlO6h8CupPNeMWIZwLOSs0yxGwQ
ULi41nJONw2Kmb6INPpJQL+5m4/e1qfB/c8/a/PNE5A58+jLK9o0eOXuFS3P
OQKq+7u8pKFGg7lt7PJTs/j3E1yFEiQaVD3j1ps2Q0AKn401v++jwRzTQzOS
0wT0SGfByrV9HJqWtbf9HCOgEbDVeK9+HFLibZ9rYdYgcxBMysdhVJb/jqhR
AjrAR9kAn8chjfhc+uQIAeV/c/NjDBqHznGl3PcHCeinN2tKoO44LCpQ5Ajp
JiDjRwJ7vLUwP799qaOLgKruyv73QHUcGqejw+yYQ3QvnTAgjMPt/0rVfTsI
iCwYVc/PMQ4ZtVrUjFsJyKH4+Fxi6xiMtvxKgnUEtPz9rOTXC2Ow8d3EaekS
AirluC97QnMMDiTUkU4XE9BzYgg5H4zBu8VfNK4V4fg/GFHKIIzBL2Cs3qOA
gM6tO+hEc47BDNATmpVDQOd/Uwf/pI/CLeJmcXYqAU0qek+sRI9C8SEpwaQU
AnJ1b5qf8x+FG/LGICqZgJK3zf8O2I9Cg4HWCPdEnM9dLwW+UEahK9xuFokn
oBLOITO30hF46EN75Fo4AeldPnrnQcYIDL/Z1FMZRkAz7+zt78WMQGbbHhAQ
SkDcvIxe1z1HoFDNT1uBEAKyPywTr3R6BMqpuWxxBxDQUSnPyc3GYbjvWe9x
W18C+mrbsLBaOgwZHgpH7fYhoMtZXGvzGcOQtUr1XqwXAXmRUhiHAoahtOXG
fNVjAhpS6DhaemkYqjflxow6E1DwGbG77oND8NCYSck5GwJKTOfvlm0cgiPx
Eoue1vj8+/efmigZgvLvW+9n3yEg2jgdr3bkEJThfvLt320CIjwereO5NgRP
vHDeuGBCQKeneiiNWkOwauT17kvXCchQpyX2scIQVLjdr6t7jYCe8H11nuIZ
glMFTNNyVwiopSDyWG7PIIyfN7iYrIOfL/A2xLJmECad/GHwnzYBrfu+2MFX
MAi9NetFSVoEJHDJuc/z3SDUZCuXjVQnIJvvV/wuXB6E5F/iT/6dICDmY/tm
ZtsHIN8bF+FOMQI6FLD7cnT5ANz1/NbYhjA+7/o21P2MP185ErzvMD5f1VJY
YeAAjN+ds4ePF9/fvEnz6cUB+HzF0MeFDd+/tjJXAQxA16Y4WQlmfF6ZL4cX
ZAYgO6h/XctIQGt/U37p7x2AnpacElH/ZNHpiOdJQs39UNk7Jad9VBYZ7niy
v6u0H6oLJAYs98oiG6tHT56n98NrRQWMo62yKFjO4urSq36ooVp3URjKosT3
xpVxbv3QnDC2fr9AFpUwXJa9cq8fenyo6vDJkEW0djWmUu1+aEURPL8UKYvW
FRQf3Ffsh30041rlIFnEHEscFTneD5tXMvlPP5dFBDuhwhfM/VDyE8O+Ww6y
6AnLluXVuj5YGf/xx/nTssioiX+/UHEf/GIgFBqsIIso/ifgTEofPMZWfNdG
ShbN7XvI4/qqD3IWyQXkccqi6s63lWruffBA8FlbdkZZFPsu+z6rbR88o3pM
qGtdBhnwLtS+v9AHt8W5ysz6ZBBxkNnRAvTBWK7Mafo6GcQWLS4kQ+iD6dqt
pNoCGTRteqZpXagPejKapQQlyKByoVvOcF8fjAij9JwKkkHvaZ5ifvR98DWP
9vFsdxn0KCGmTXe1Fyr9vZaXZimD9CxL3Xkne+G4sEf/+gUZJHVs4Bitqxeu
Ej64qMnJIKa5X12p1b2wMa3I/SivDKKlcXs9KOiFN797LHD/kUaltmTpk0m9
UCeebkO7VxqFyer17wzvhYzOtxQ/Zkkjhx92T5v9euHKUUN/Iy9ppJP7mhjq
0gsvmzdtPDwrjcQfpg6bWvdCXanRl+fppRE9te6F+PVeGIZGWydjpNDwxpTc
8rleON+f3flsVRIVlTDQik72wqv7qjYYNiXQW3dhfy/pXjh89n6gDKcUslUB
itqCvXBWr69lMUoKae0wmeZk74UBu5IlN+elkEiF69vB7R7I2D0UrSoqjf75
hKskLPdAuXMkWX8dadR3pmDOZrwH0piPOzbZSKNcpq5QuY4eKPiaIzfmmTTy
r/+htlXRAz9KGSSGRUmjO6/Yv9fk9sDcfmJKUbo0Uj8vHRWQ0AOhevtGRok0
EmQ/p2n4rgd++DdBWKqWRhttd1aFnvVAHumUH40t0qjz7bMPs496oMrpTeDZ
LY0yLyecy7HqgbYeClWEAWn04kDFL1fDHrizc8BzdUga3e4b/ah+tgdGNV/q
bhuWRiqR/y6yKfbAEfFRuSr8Oa8x/9+u4z3wDTP88qVfGv0UOJEczd8DV8Mu
OId2SaOWUYPLlmw90FBnkSLcLI1S4hx3yP7rhvozZ+c4KqWR76236b8Wu6GY
CkfQ73xpZHYk2xCNdEPEZxun8kkaKX5r3vmitRvy1nrW/gqQRlwp89l6qBu6
/d788NVRGn23Zjbh+9wNT8T5XVLVk0YNUuLME3HdUPX7MT09YWmUsHQ6P+1t
N9SbvuIlMSSFnmTfvOHo0w2J3j3un+5KISMHzz3Kjt3w/ZoY/QEgieQoMcWM
Ft3QaISqyTkhiTjWv1i0XOmGlyn3m/mKpNB8Yf++MI1u2M3qWD8oIY1qXH59
NaN2w9Fcs54WF2kUp8RtfexYN2Rd6+R0KZJG7v9IB34c7IbGGp2kyAVpZAB1
K4qZ8XlpDuJxuL6JXnZ23n+64PiwaPyrUzKI4/Xol7D5LtjmMjGzdFsGLYXq
MmcMdUFZcaUntk9lUGo6KaG3rAv6v+cTmYQyyK/w44+FrC6Y/HLpS/SADLKq
4AL0cV3Q5ab6BvNPGSTWt94v5dMFNzwuF9WJyiL6CStxNccuqMi7yWunKIvG
F/scr1p0wb5LT/ba68qiGIYv7N6aXfDV9kbdP1dZdFD2yZle1i4ot12bx96M
59eJ5bcLfzuhXVFaiu+4LOo+fWOMbqkTDvtenZNYl0VvjdTdpNo64dkFZtpp
DqyHFnl1p8o74affwoza/AR00f7Igas5ndDvt6Ro8VECYnvG9NkrpBMOTI7e
MAMENBfovBX6tBPKaO+ZW8P6Uh81ey79USd8/8WBBrE+JScaRZRbdcJ6zpMN
R7D+PfvcON1j2AkTyvgOV2K9vF16krJwthO+GLl1yx/rsXpthhedUidMkTqA
iFkEJNIh2HpAqhOWb+f4rrQT0I7hgENSAp2Q0ztSuAb7v5FvO6xP7e2E9HVP
hj0siejryn+FBtsdsKvfQ3WtAvvvf7SdNssdkEpeSbLC/th192V9r/EOCGIH
X9cPYX3aX/0htKMDakqc+LX+mYCogvKLaZUdUP7qlufFIOy/JJIUy/M64EC4
fdvJR9hvkQ/69XzqgJXbgRa+pgTUofKiez60A24uGzUPYv38fPaPCJ1fB2z6
bl1rRSEgO7Ohr5LWHXAXVUsgDuudjvV51lPXO6CAssZdm2VZJPmwzNBApwPa
5w1x6VTLIhZP2cR7yh1Q/c7mqwuhsmjmZeyqp0wHVB6mvTl2QxbVvNt3KvRw
B+QoefmDWUQWfYr19k/j6IAnrpUf82qXQb5pq4OIrgMeS45nXTeWQTcLbkv0
rLTDIess02Tcf6rl3Y/mJ9ohz0zvtNNJaXS4SaNqR3c7DLMW4hhXkkFbPYX7
DtS0wy2op/86XQYNjR8zkyxsh+N3n5z7geuzZCEiXTW5HZ4kXJU8fFwWRfxi
+XMloh36Gz9T3n9ZFjnTu2vee9kOByNVXn1+JIsM9iyGeLq1QwGVVw4SIVj/
DprS3tm0QwbJ1wOdWG85RVtl00zaIZ8e486QKlm0LK3qgS60w9Uja+eY+mVR
q8Lnhm7QDjkldNZj5mXR8butbomy7TC1XvEF55YsehaxKOV0uB0KsY389GUi
oPF61hFN9nbYUs/18AY7AZ38IxFwcLsNcvXt6Ss4gP35cS3V2aU2GC3SSA4X
IKBVI8sfxSNtcNVdZJoL+5nUL/GXrpe1wVgBC00OAgHtWkA7pTLb4PxA+c84
OQK6cWg0/290Gxz5Z1C3pkhABz34D8Z4tMEIp0fFm6cJ6KlKyNDYyTZo1cI/
+c+AgMbsct58lmqDlT9t/I/gfjj5oU3F+1AbNFJJnZYxI6CpbV41zY1WWOB1
s3fJkoCQN2tj06NWOI2UFfQfEpDThKa0nUErvPjmfHYh9pMyp30D2OVb4ZpH
SheLOwFFMf67pL/WAreXZbs8vPF+4bc01PugBZazfQxK9ycg6dnjwOVSC7yZ
pfbzHa7nybNWcXzkFrgsHlbugPtNj3XMwmSlGf4kFwTtjiQgKf/2JZp9M3xW
VLiZnYD9YnDejiXbJjgaauKqiv19xM/lmwHnm+A9orzvG7wP6F6RriZIN0HS
279cnaXYLx9IfPFgoREGzx3w0yrH8Y4I4/xt3Qiz5sVMxuux///gKrbzTgN0
C7/bOdtPQG/zGZjazjZA4d08Xdl4n+lpfD0bJdkA9U6tiz8YxvvWRkwm+Xs9
bJy5wzGH9yNHvUqFW4/q4ePdnRnx3wjoPQPb+QrfOhiEThiew/vaOO87WX/L
OujgJeXXsob9PEGQ00irDgpe+T16/hcBZRsTen+w1kEjrufHT+H9rzL/8g3h
4FqYMprNtrmN55lV9EPPuBpY0MnTW473UdnHRw11fGrggKvhOAsbETmGZCke
tKiBvW7nHunuIaItVL6ddawGHuiyOt/OTkScfNMvRrOq4VrG080UvB+faJKJ
USmrgrH8sLAI7+OPaYWeLLFVcLX9wbVGPI8qNlRv9XhVQR7m32EDh4lI58il
Y3ZnqiD38KupJWEiMn/slBPdVAn5JlqeLx0hIj8Cqvk7UAHDujM3NKSJqDbo
oz0oqYCGs6WnKDJEtGv1GZ93RAWcp+w9IyBLRD755+2YDCvgI9R5mUbA71cc
5ObsLoeeqy9tqBQ8L6PK4OW8cqgWaGhGJ0dEf//G3Q0LLocnpo5l1WB2gXe+
HtIvh1LMjsfUqfj+p9dvi7ciqJLh9YFOkYhyP/Xvtc5EUDkgNzoB88qur0Xp
bxD8/evIbTUlIrpf78NG0kHw3nOzWduTRJR53KrAURLB1g5Lx03MC6+0zQtZ
EJwN3WHuo0xEne9F7ri8hZDxSNuolwoR6ZrNftnShZBFZoa0gblFOJvdlx3C
F57ct+8AIjo3+egWc0sZrGr4cL4Dc12icqH/6zL497ZTrZwqEWnc3cnKda4M
LowzJb3FXCnZaBrBXAatGHfBGcyqS0E5gnVfIccHhVHqKSIqyzbclfDsK3SK
VOp6gvnkg8NGEme+wo++J60Q5mK56YxMhq+woTnL5Ddm+Y10OkpFKayM+ed8
XI2I8koeXCn2LIXCukceXcJM9FBMUQGlsPmcwR5HzJmA7l/lvy+w09n9xyvM
UvR1umdLv0DX5bLWSMwpVf4JLa5fYEfy0oVYzEefX9m4dOILzCym7X2POeHs
IZ3+XyUwzQ8mvcEszDbxwbSgBLbdP5Ly/+fHtKSsTjiWwCsK6hG6mA8F2Wve
JZfABb3aVSHMEZeoUUs/iqHqq9RjU/j8Bw5sLT3ILobXO5oj32MO6atS+21X
DHudbsZoYOaMehX6WLoYGkfvd6LheAWY6M8xLBTB+GNTV+5jZhPiVXmRWgRn
XhQbLOD4v6SNBu29WwRFGW09/v//y92fEqeCxYtgtKZ9Tg7O31Mr2xO804Vw
fKq27DfON/1xypuYhELYsueCphRmz4U/Y6K3CvE+xlarhetjK7OckiJcCO8s
OPudx/Xk9p+fn8xYAeS/pxOtgOttg3xxKDemAPryxHUxnSCiR+vchBMmBXCl
djizCNfratGQTxl/AdRTH7igJU9E9m4fe9UH8uFrq/+scnH9LylbS9aH58NF
UwexdRIR3dtBfHLhaj7M3OW9h42Inz992nAXTz5M7C9U/oP7y7fZkFjWkwfN
VNU0c6SIiCPPhuVRaB58RNITlz6O/Uak54S0QR58LBV5/6Y4ER3zCimd4s6D
juQ/45piuD6skt9Fd+dCfX+6mTYhXH8XSu2uvMuFm9Wr3YuHiKiJ0qa550ou
VHS9OfryIBEZ8k8KVXPlwqli/2D//UQ0Sbfx270rBx45dzuqF88f+xnWTkpI
DgzruaNygomI/rUcTl+4lAMnn95qfojn2ct88tOE/TnwsdtPJbl17Gfea5oa
d36G3irWej/nCCje+zqVK/gzXLFWkJnEfkjm7n2OJv3P8INg7ueEBryfX/SZ
9eH8DGGTQ2kY9kca8mEVSh3ZsH876nnNK+x/DqVFrQZlQ+WLwWntZwjIjAE6
pullQz+5EHOmCGk0P9tx/ta+bLgrMMdC1oSAlmKbz8vHZ0ELs47967lYX+3W
tj8JZ0HvYJGxlgUCOqwkkMMdlwkn+tjNbvERkcLuM7efCmVCJps1ZgZ1PA+6
bQ6sfciAs80z3Xuscb3cL3XtikmHTvqHfoSXEVH4yUmp04LpcM8Jwse5n0T0
mZltNDc6DYoxv5x8epqEGnrIQaICafBjplH73mNkRPt4XT34fSpcLaHuPOlG
Qn/sfdboD6XChTqX6keSJLRfJS3JISoFXqlKqeSiJyEp1s5rNL4UGHLsXVPH
NBGd7vvDqh+ZDJWyYEZnBxEZfxIpK+dNhpQbrv0ylXheOmjbEyOSYKRPS8rt
AiJ6DRxE4g4mQUVi793QNCL6xBbZxRGeCLV8hgep8Xj+9Jc/8+RJhNHs+WA+
goh6EmcVlkM/wZL1+mW7t7heH+ybNzvwCSY2GFODX+F5f+pEdOu7BEi7w69J
eUpEgntvXATcCZC56eVT+SdERB30o8sK+Qi/Uk2EfV2I6M7DPgv/4Hg4Qzw1
99UOx09tx8EtzngYv5EtFXAXzwf2Yw22b+PglHVHmONtImpIcZI5HxQLZQOS
la8aERHt0YexUo5Y6LepK376ChGtPfc/ck3oA3wyscAnpktEBqXSSzyC0TBw
4ptX7Bkiembgof/r0Ht48RlHsgyeF4XLTQU9/FHwbrXc/FvcvweP2Dx5xxsB
HbuvJ3/F/XUWfplwPBgOWR+U6Tkcw379GqvWZZ4wWB09sNmH9XDwTSrHfu53
kJVsKfIK98PjLjMnjSMhMK3qz4o61mchfu4RF7lgKDBJuP4U7wcVNxpOZ5x5
C4ty3w6c/Iv3jeQnaWNXgqDJsbSZS6u4/r5TOLksA2HKhlFI5iz2M/e6fvgv
+MMjXpzeEqMEFLKhAtfY3sDyF7HToZ0E1Pc05bWx9CvoY3WnpbiGgA7t5zKq
PP8Cat6/dEsF+yPz2Mfix+2eQ2YTxzfpSQSUID37M9D/KfT7ZHjoIvZbsyWX
Kn5l+sCTg66SdB6437TKAkxbveBj5W9MxdgPTqbqlbwcfQLVfVK+qSoQkE31
0SuGQu7QR+TmixC8r62Nbn4/csMZPm7d2mrpl0GP/7S9XI1zhJciL/PcUpZF
u7gTj5TT7KHQryJfH2YCEjBb9xTQtIaPmR7wUlTw+0JiC4rqbsKrQ5ZsEjcI
6PHbd31JIQbQt/JNpZAbAfmuJLG7mKnAnPc+EZEBBLRye5d6RrAyEBDp0jKI
JSA+WdupvBsG4CTjN2P9TAJyv8mmDLJuAu/tp1WS2A9aS99kSpC2BlSRV1e0
qrCf/Dt4Z2ePPfjsy7gx34TjMb6rRf6dI/A9ocdwugvHr5ZIvnvZGSw6fQ+3
HSCg4HTj8Kj97uDTqfHjLjj+LG+f/2vueAJE5kopNhMEVK50jbij3gvE3eeK
PDWN35+5dCsi2QcE73oKZ7AfVBD2DSX5PQUxvtxC6jN4XwvmrW+0eg6YH4Zm
HcafZ+/K2ryt+QLsaTcMIE3i+Lqcltk6+goYHxSbZcTvE1/oNw/b9Qa46gpk
DPVg/2t6P5gw7Q8GxvYmOuJ52HqHfmLyZiAwHtY0tS/E9xM57/5ZPwh8Wwn2
eheO5+1gGPdjtbfg2va7QC68H86E0DK1ScGg1vbX0vqMDNK4IK3FIxICWIJE
nfyNcTyYnMcn9r0DAmWSjaiMgOjLK1yz6UJBxo7HbW9wvZq77uHy+IF5247n
G9abMrJhxtnxMCCVWBKbaYD1fTFe40B7ODh0N6hqvwful8TFURqKADsGKw7s
xvOkz0zBJSs7EpxsktLirsV+hdeH0z02Cji738zvWsR639GcphX4HtTl6jE7
HiShlVcHz3B7RoPdtnP3GrVJSPfMrZHx+zFgJkl5F50/CWVsZThlmn0A1443
9XPuJiNGY3e/r+KxwHy9041NmYzyioS7P36IBfv8hfV/fiWhW9y1wi954gDv
F77A269JiNPBxs4+IA6MS5oEXL9PQuUt+74YMMWD9nTZf4PXSchespBJ+Uk8
qPMwZWo5T0KH/Ywvi/6KBwFmXJYn1EmoZZIujvn+R7Cy+DaRUYmEQrlV2rh+
fATPj1T9YqGQkKmG6/bhBwmgkVe585kMCR11KpCRXEsA46N1HPzHSWgxacVE
3ukTUN6kbjw9SkJ5fTJvTv3+BBJ2z2yFiZKQO/O9Uh23RKB607REWpiETism
zV/9lwjeqF09LHWYhNjuTfDdepIE2EU6uB4LkFBX1GFtO7pkwH2noYvzEAm9
b7ru4uKTDC4UKrUM8ZHQ7X9hyb6MKaCYTWiwjZeEJGW6egOep4CxTZ/Mqf/H
25SDKYo5FZx7+efOfswlATryia9SQWjHqOYlHhLS/lEVUhqQBvx/soescOP4
idBV1e5LB058B0W0MA/oK692BKcDBffm9iguEor3cREZ4c4AMdK6+bP7Sehu
Xr7ebFgGKHHgOCSDmTD1w/MnbyYwtt7rZcFJQhvcMtnbUZlg5sc5t9f7SAhp
WI+yCGYBNt6arA8cJOTnlLj3QGwWGL99pyqKnYSOXf4Rw7EvG7QaPb7ksZeE
XtsEyB/QzwYvPxNHVfeQ0LKvdAt/cDZwGPpURWMlocvRjRbCXdlgRkxZxoyF
hIry7/47yv0Z9HI/35mzm4QOtTC9kzL4DOrOqg/37CIhz+lPUqSwz6C9svJb
3U4SmthSr6L2fQbEvMZub6y/Gjy068q8OaAhpRpubRNRqqznqppRDmDnbaGX
/0dEe7UEX2lF5YC9jn4HhP8QkYN5qciFoRyguWflauE61lNno5JLArmAS0mz
emmFiBSDNvSumeaCGydvfvqyhP1zSuis6Ydc4HTehpNjDvvTCorX7bFc8Fyk
+PrgJBFZDnQctBbOA0FfFKSYR7E+rthn37+ZB+gI2oaefUQkw8qu9fBjHohf
9xEVbieit6IZo66TeeBQ3uvMijoiWlc65+R5JB9sEh12yEIiMro8u/eZZT54
UcGfdCgP97fN88RXSfng5teQRdEk7O+fHlEJmskHSoZxt9LCsP+MruwOlSgA
jDumPpf7EtFM/g3b99YFIOVU2s96G7w/tmzvjE8rADdqEqoTdIgoezr6fdJC
AbBICeOexf6Sa1uJkiFdCEK/+nkPVBCQM89AY45dIWglPqn5pE9AQ7LOt4qy
CsHWuDBKwPNHVevA5tflQhC7+s2xDfv5BPO8t5XEIlDxeDQvFPuv3S76x+sd
isCyRMAh8JKIbIKWy1tyiwDPGZkpz49E1Jbif63rZxF492f7X0gREVEqpH70
yxWDXsYnW3kN2K8NNPiNPioGFqnOgrEDeP9cuSM0VVgMIvYUv+icISIzVqai
uQ38eci1D5/WiCixiPVilFwJEKQsqb7bQUJLFhzT5xxKwJ0KxJ6B60t+P7fH
38wSIOPFcYUF98NjxMuVMV8CbLbSFapwf9bYCqaZHPsCTn+3MFwUI6E9/KJq
ey2+gJTupIkQKdy/D6Xs7498Aelym9cCFEloUoTIJMRfCibpCOFrqrh/2+Ri
2q5iZihOptPE/XocNBHbS4Ea4cIpMX0Sou9Tv0Xb8xWcLtivfuYqCZ19qvXn
rfZX8NvSSlfYmIT6RvWO/az8CrSLfFV4LUhI6I0BTNhRBg5ZP3RRuktCVorX
Da4ol4Hr8xJvj9iS0HrIbd+CgjKgFWPYb+RIQipqd/mtVsuAs8we5VQnEnr6
3TaHhwBBlYTar3pXEuLSdhpzToHgbHYtm5cnCRn/cnOSmIYAPDtgxe9DQvr6
qky2+xD4pScu8Popfn5yhX61LAJGLPvtup6TUMT26RiBCwgsCG34rL0goZMG
tbMPbRDQD2N6tPyKhMbSz8q1vERgTlVdu+YNCfkyNHkeTUEgw2tj3SkAzwej
C02PaxGg30V3e1cQCTVlt/H0TiHg5d5+z+Etnu9Ml27J7iwH7/lMhkqD8XlN
uzOfi5QD5fhOp+kQEirMu/pnVLUc7BxQWfv+joSMWAfOKJiVA8YwBrqBUBLa
umEcFOhRDvKnzip/CsPzrmhkaCaqHJzXuaimH47nA/uNY6dKykFBxqeYccxz
FhMPIvrKgfeyee+lCBLyL7WAP9bLATgidycFM2n/DIs2dwXYHfGskoa5+661
QTy5AkQz2OrviCQhZ7QQ90evApz/kOpIj/kQz/1FffsKUNgd5jmLv49sfyik
+VcAjW8MlfmYb1c98GXIqAANmSxPrDDv5l9vvd5YAQTcRxe38HnS/3Pmz5ut
AFcrX6u4Y9at+2PJtrsSLAslvxvF91kV9Mi5fbQSJDP/YZPAHPpw+1/p6Upg
KnQw1xDfX7HJ6yz3rUowK/LjpR2Oz4jIzne2XpXgfZvWK2scP2+XZ2PVHyqB
rqhIjA6O79G23VKCZZXAPJk7lgvHv+HoK6dHQ5WA8UmQWUUgCdl57Kls+VMJ
gv5tR13B+ePsCtgrzlsFJtzbd7bg/BYc5zR6Qq0CeUctFCSxfht5hXzqvVIF
jtAaK2xeklCcTMRJv7dVoL5TPDnyGdYrxXJ0N7cKVH8Ta7zqS0I/z8yePtdV
BSLk4k798CIhLZMT5/ceqAYdGTfP5rlj/btzo/27fDUwNtu3OeCC+8/xxZX2
q9VgeuK0fN8jrCev+k1CIqqB68I9wQv2JBQZRkd7WFINPs2m76iwwfr8UcLy
6mA1qDLzKafH/RNe4mLHJ1ADPMJ5JIbNSUitJm5lU7kGrB17kmWH+2+hvf7R
sGkNuG+tmVCK+1N1lvdJbGwNuPaEteQh9htzP08xeJfXgKqd23IduL9Ddlg/
v0WrAc8sOU2aT+H+Y3vLeoahFgilV3EbY/8xw1MScFSsFnwwt2L+D/uPt6K0
/bvP1IIXQQwMf/E8OSnLEj5rUQtiJn9zzOJ5M61IOtT4rBbsDuQ/dxjPo0AN
o9j0pFrgLPaL9QnWY0V9bzH/ulpwjYFde5QJzx+T1OT7s7Wg+8qAB/NfIvK/
2yGlx1IHnk0h+lysVwoP/2STJOsAh5BM139Yj2ieInJcOnVAhteFL7kZ75uv
tYvXbOrA2+cP4XU8f+XDHZR739SBkMzIzqFoIhr7GFlelFkHON/MHBh0JaKX
WRVnIlvrwOPcMY3Tmnhef5mrd1uuA5qxgZ/Ssf8eqeG8YLKvHvSNv3z/4g0B
+XUodqiQ6sGPv3pyvZJERBq5aSB0qR5ckecbbcX6MDT7coDOsR7MBMYLt+D9
9dlajulESD3gXElKlswmIgLdIK0qvx5IVMjz3sD+dICNwSqxpx7Mae3nD8R6
4HtQcv75r3qQU3i49RvWYxmxS/fvHmwAQwN84iK/sb+VdVvVPtEAMn+3OBYz
4vpX+ugkZdQAGvbt9aDHfkZKs3Fzj1sDuDBZYa3IT0I9+qtPvkc1gGf34jv9
cT48Tfl3tpc2gGu13eEi0iR03FrdL2e4AYT4nKDfJ4f93cN7bCFbDUCo4WHT
/ZNYT7yCAx8ebgTHpq8F6mI/euzNF66rqo3ATk0Ylp8loY7wiXCFG43gfF3t
1daL2E8msArweTeCK/8dtPG5QkJtX64fGa5sBP+4g2e3zUjItdYnpWyyEeyj
J9K6b5OQWGeadCxjE+iU/zlki+vZeW5T7pZmE7h38AZ5/T8SElkXLTl9pwkc
fdl4fekhnq90OipHXzSBG+fSzhbh/jnM+15jtqEJPFToiGzC87/irYAfcb4J
pHEalLDhfrzN9qHehbUZkA+8/yiB533qdpwOi04zeOp5M3IH7ncdF1F/fZtm
kHd3Ne4rngffVxJaI183g4skT3sTPD8o00n6ks3NYC32IO0snk89ZhIhDxab
wd74Js9wPO9c+lO7v+xpARn72mjNUSRU1pRhqHOhBSQvTC59/0BC5hqykSF2
LeDFhaKZ4TgSYkDZg0P+LaDFQlEr/yOeD7m5pratLYCT/rGYSBLuRym52Pzv
LSBTfP5BUTIJvUksGP/H3grIrX9aT6RiPyukIKpBaAUslXTeiWk4/hHFt/11
W8FwX3jtVjoJPdyvlNhj3wrOCbN3qmWS0ME3pd8Eg1qB1LOaRocsEjLxhNZZ
7a1g/PrjxdDPJLTjj2r6rx+tQM++hfAqh4TaT4yvH2ZuA/+JkEPv5WK9WY/j
Oc3bBnRCqfsU8kjIMfemwh2JNnDwIe+rZcxn7EWvvT7RBqgcn2gh+SR0QHrS
JftsG1gW3Z4XK8DzYjYhsutaG7hld90+FnNxosWXjbttQI7tgzRTIQm9vHV0
6JBrGzhFXuw2xGws9O2v6ss2oPLmEPs7zNLDSQIWkW1gnn2/wxfMWxF3VF6k
tgHNQsaXjZjbDCTMMkrawG26iM4qzHH75560N2DnZjvyJRGzQ1tq7NpAG5jx
Ov7BHvPpN/fKeefbQA5DWa0wZm5tKZryZhsoXVWyKcbnm961SH+TtR1k50xm
yGMuqswQfcbfDnYffBMaju/3wtPudKpkOyh20Dgwgu9vpCxr0aLUDmJ4Unfs
wiz15/vTlXPt4NmFImZ2HL9/BdmJB4zbgeKofMUvHO+WB//VKtq0gy8cTsFl
2ST0gUCaMXVvB0cvWJTcwPmxX1zZ7fO6HZB9vp4azcDzPDVXIul9O/Dilt+k
4Pzut3LUbkxvB77BVk7muB4mReXufS9tB23F4n9Ncb0UjK292t/cDpwJf5yl
E0noeXRBOnW4HaybCLrU4XozNHJqvr7YDp67R3NK4XqU4FFYevKvHZyafNl+
KYaE/nRu7E3Y0wGiW2/HKOJ6bgoslq0T6ACVz4/EDOD6jz7vqrsg3QH6HNlZ
pLH+2rEo/ceh0gHONj/+K4H1VbV2M4hyoQMYSKzK1GH/tM+3NMfQtAMkSIx/
/Iv1kqbq0elu1wG0g8woJVgfF+J58l554Od3fv1uiPVxfWdOSOTrDvC6sDTF
AevhDiudhylRHYC2lCH2E+/PrPXTV4pSO8AVFyvn6ju43iS95GuLO0DTZx+7
OvP/+0t+np66DkBV5+XqwXp3/Hv+r8neDjC6srFVgvWOoqfbtzrdAVoW7K8S
1bC+5c4V0a93gOPjjzt7sJ5pcT+N2MfYCdi5PzXyHcH+0emwqxBXJ/DTaPfm
x3pl0l9sJCvaCUR32alfx/vWHaXLSiqkTnCwa0t55yDev6KX+M+f6gRDsUxn
AjOIyH3b7+913U6gO6pu+fM61oMbosPWZp2Al8PNRPIeAQVWfv3qYtcJKrUj
92Y+JKLII4Yxfh6dQEq4zehvGd4/nq88DnvdCSxaFy8XzRNR1uxrs8SoTqDx
sJeiwIb9+Dlx1fzUTqDHWiY8is9blVEuVFXcCebTJG8LY71uYTem66zrBANX
zynr4/v3/bc+Pt7bCQL93zspm+B8dAZWLE93ApWwB6WW93A+5CQ/bq91AsEA
ECvujPMRVu2zl7EL7CqfNYY+/58XZrcFuLrAkiRv0nV/EmIx/nNaSrQLdCHB
cQHs77jKQo4okbqAu3OfguD/68u7ftpQtwsMLI23ceP6p0zeqrUy6wJ7iyM2
+Ipw/DW2kh7ZdYH6O2tsLmU4/snhfk89usCzEVMRkSocfxby3ZDXXeDqZCTb
7zo8H2yaz36M6gKp/+kE1DSRkGWL1fGc1C4Qm1JqI9yK+4dAz1pe3AWGDXeu
kjC7vn0/31rXBaz/O9O3qxH795/yTSO9XaCz+J9Neyn2xwbt6YvTXSDOTjdq
FddneNG9N3/X8O/HpBLf4Hn4kW+XHStjN9h3sqem5TcZZbrHXuDj6gZXLPXG
im6QUdGIoqyEaDdYW1LWrdAiowrVbnYFUjf4Zmv8/qQqGTXF31/WONUNbjjk
mRkrk1HPTpb2K7rdgNLGVsyJecwy4fNts26gxOufLqFCRnN1Km8f2HWD3lVT
tAf/fu14v4O3RzdQ9rr4574aGe148+BS0OtusA0fWIqcISOW73sosVHdQMc2
K2w3fr9grtra1+Ju8KrOO1rqAhkd4x7ubqrrBlVfV12u6JERycmpYLC3GyTQ
ecX5XiYjTaV0p99r3YDB7de9KSMysq/k/kMh9QDtavL1+1Zk9G+b3slPrQd4
3+tdgdZk9PLk8uqgfg9gdcgMZrQjo0/5DYveD3pAxsrBVltHMhpIejLeloe/
zzLlm+JJRncmbUzFqnuA8vuHDuE++D5CRoNO3T1Akjf6luszMuKIpHQLrvcA
3vbd/DyvyejM69k6G2ovEHQOqckJJaOOup4zSLMXrBpyRCpEkJE5Y1XFfsNe
MEgYPvg5ioxcH8eUljj3gm5zn16XWDLKtr+UvbukFxwQYl+ySiEj5QxVaeOG
XjBd7Ag908ioYVY6NWugF8wRhSxeZZDR1M3dCQabvaDQfd7x4Wcy4rvyNSzh
ZB84+6PXMbSIjJKCUrk2dPrAxTbvLmoJGVFawoLOmfQBP8Sws/4LGV3UdHi1
4tEHGnsrLhaXkdGQj9luDf8+EDl79h0PIiNrpPM0IqYP0O+Y37xVTka+J8Sf
qMI+oNKjxVldSUacj7j+Brf2AZv832F9VWT0IYfO5dtoHwh5kDrTW01GUt+X
1hSX+8Agf+L5ihoyKpEccvDf0Q/sya47wmpx/u7Ufx/n6AdSXx9IXKkjo66E
Ahs54X5w+b/Z4U3MN8c/zvoR+8Ek0znBl/Vk9F0gyHLoVD/2h/OdW5jdjR5P
yOr3g2dPPVoMG3A9hd0z97nZD/irJctDMYd1Gg73OPSDa3/OgkLMYhwaRsd9
+sH8ffeiIsw5OuRej+B+QE9/xjECM3ghdLn9Yz9one58fRVzU/WedrG8fvCe
sj6zjN9nRL953rmqHyyfXKHcwvxNZaahsQufx5l7IA2f19GtW/PwVD9YTU/6
WYvvR19UUeWw1g8+VY9r5uH7B/zMOlXDOADk3lnL2uL4HCJGl/EewNyV/2YJ
xzPV9qWS7dEB0LFqW0CuICNqqlMRkh8ACpSGS1Scj6rp23JcmgOAf/vCmdWv
uJ7rJB30DQYAucmvwh/nUzd1JTPQYgC4+Z38PoLzf+B18XyL4wDQDrVlG8on
o2Fbz2N7fAeA0H/uLB45ZJRwUdPiXPAA0Nx5TaEwE+ebuDf+RfwAcIit7fNI
JSPC/u6R2s8D4APv7uDyT2S0/jOKf1f5AHjfkJR5H9drac9Nw9NtA4BT/QTd
f5Fk5F0k8c57dAAEFl+xSA4mI63I5Xa0NAA4JnScll+REbt74d7tfwMg4ZmC
yEHcTz0mj88p7xkE3F+bxIedyeg9OOPndmgQ6Gsp7ZqwwfkXZqsulhwE3ZqZ
E/GmeB4wdNJtKA4C/rLxSZ3zZLQ0GaEirz0Ivhh9dnlOJaO8GnM3x2uDYO8H
m9/tfLi/ksWLcu4MAkI7S0TyDxI69XLp57LTIMh6fXfkOPafu23yibLPB0HB
X4YDzQlE1HLe3c42dBB8PxWWEYf9b4iselrap0HA5jIlp7CK/dI+lpnZvEHA
0n/uK50YGQmttokdqxoEl5MW/q5qkNF0V9gNy85BsFuYx/fWTTJKLzCNSaAN
gk9b719wu5DRg/Ajg7Qfg+DhnPDWEzwvFF0XeITphgCvxp7fT6LxfDTOvWzG
MQRGw4Mr4tPJqEbZNSj68BD4EdLeqon79/XhUy2DMkMgSPSJQQ6uJ3263ax8
KkPgD2VUZH8HGR2caNE0PD8EbjLv/M9/iIxGqt75hhoPgVnD+rdgGs+7ROPy
rnv4+x2TOkrfycjGT3SL020I3Mt6bh30C89X6zlFvZdDwNPHqO38NhmVSTvn
NScPAWaxb6W8eyjIlx38YC0aAsf0Fg+T91OQ9g9GGe3aITDyuGF/7UEK4uhs
svbrGQKJc8O63QIU1JsXnFQzNQSGlYpjrotQUEyo0eTOtSEw+Uqy5spRCrrt
LCysvnMYZJb32HyVoKDjRjMmXvuHwdV/TL0vpChoWSkrEooMA7/GzBdZMhRU
IPCo9x9xGJx31qg4TKBgf3KS6+SpYeDx4EZeLWa1cQY9V91h4Lz1ySEAM3Nl
w5sis2HwZfyWoaEsBbUlBDWs2w2DS+tv0v7g54c+M2SSezwM0h8HbpzC7ze+
c/j0gzfDoIF8DXwTpSAR7WnPz++HQcpgiOTzQxQ0I5nx9XvaMKhWDIsJ5KSg
zD2Of6S/DANut2urIowU5PhdkWrTMAyOJgkGVK/g/LbTOab2D4NU+2fk3D6c
39y67JmZYXDi04742Gyc35CAxaMbw2DgUdvfbguc30cGxy2YRgDdy6T1ZQMS
umQoYPXxwAhQ0RYNj3mM+/lHIP27IyPAbvT3u8lGMup7sTPmGWUEjHmYbtVu
klGUiPMJZ/URgD7cNFkVpCDTL/Ndd/VHwFD8W/NBRQoSumxmf/3GCJ7/aQm/
9ShoYqGD9bz9CND4N/36owUFJT7VSFJ5MgKKDrtpJj6ioDuCJWoE/xFgcPIE
y/OnOD+F0iPC0SPApHz6ZdxbClq8GOeyP30EdAf3/6bGUFD2DBc345cRkLVq
yOyeTEEOXn7Z6/UjwPG58uWQzxRE4ft7bqZvBFxwOVX2oZiCfuXc/9b/bQTw
VnF8LEQU7AcnvBvXR8B/bIFnf9Tg/E4aCH5lHAVMDm6jpk0UpOLRUJzJNQry
1OKOcrRTEN0BlSuxoqPA+0LiImc3BVVlfl4OIo2CQLfDFg/6KOiZ5pHXPqdG
wXGfI8YnBylIayxc/KHuKNDimL3nNExBrC5slZZmo+Bdxl0e6VEKatnnaWpo
NwpeunbSbo9RUGDq6u+zHqMAMszePjJOQfrqVu+UXo8CSWXuy46YuYcGCNJR
o2DzPCnQAHOf44UmwdRRwFKSKtGGfx+5p8KKo3gU9DBftJzEzzdOlGOgrxsF
sZ50Ve9GKOgwSIlZ7RkFuzekfk8NURCt95Di1NQoSLnas9I9QEEJ9oHdPT9H
wd/sn60W+D65O70VJunGgPrH0P4QfF+udqVdJsxj4HSHrNONDgp6FL3W2c0x
BhJKiYL1Lbj/7mbFXTg4Bppv1yvVNVCQgvzd+7WHx4BaghyPEY5vJL2osqr4
GFDZEZXqXE5Bmy1DLMUyY8DV3ub+oVJ83qjQPqL8GBAVvcx3soCCvlrpJqYq
jwHL1RrVpiwKEqSwOIqeGQPpBeWjZTjfnjuqTr3XGQPZWQyF9HEUNN7kwc59
GZ/H3MrCOxz3ZwR1+M31MZBGnBIXDcD3s/iRuuvWGOAJqWOu9KUgRlKa8xPr
MbAel0qSd6Egy63bGhv/jQEXV3GoZkNBtQ2CXP+54OdVEvZHmlDQsbC+8VnP
MfDgluuLZh0K3sffZt30GwNrv4f+nDhBQfOyOh6DAWOguInv3qgwBen8ZTx3
OWwMgGTtBSbcr5l18GBzzBj4WphNMBvF+vTOZfpM4hh4d991aiAZ+8kb5Lyy
jDFQ+4ZBzAv71w7pRS9q/hiQX+a6m0QjIfKfxIvZpWNAZ+WO2/UnZBRSYy4g
UYXvf3TLg1yM9fIt33xc4xggMZjv/TFARlfNuor4OsfAp4NSaGoZ+29J/2fB
A2PAz4jT8iKet3wbmpfZaGPgnNTnmR9MFORWRSfydHYMFM4x3bJjxfHemlSO
/TEGxMwd5cnMFISodde+/B4DjZMTH03w72/9l/awh24cGIunperOkdGuNP+g
H8zjgO9fz9kSSEYpk/9lsHGOA2560n8q58hIR/BKvTjfOGg13q/T8gD7q6sK
U2oi46BPe7Y2ZpWM3gbx05keHwfalJ9fVqkUJNe4dciFNA7uOZ9bv3cX1/tO
mkKI4jjodZS+fCOIglxVqi9nqY0DcaL00KtcChJwTrZv0B4Hvq0LpEbcr+jz
q9dT+uOAY9byF2WRgm7O2yXvuD4Obu295uKySw4lm8qNyd8bB9umrs8uUuTQ
ufCDf/UejIMOh51Wj87KoaX2TR5bt3HguqFDKDCRQ+QzFRc/vhoHD9Yv/ODy
lUNlkhche/o4KLY+yyzeKIe6N+7EzCyMg4H456sBevLImaRTwrA2DrimtQbK
bsojPhvZHsF/4yDI/oKAkqM8Mh9d23NlDw2Uk3aqu4bLIwbefgl7bhr4ss5W
4JwmjxL1S8+8EqCBjGBaNoDyaKHa26Ncmga8JU032ebkUcC2RcSQHA3wNbho
lNJREenE2fxfyjTwYaJjVxw/FXU5SLVzatDAI7vDR8MVqMgpnX1R+gIN1Oz/
HLvfiIr4pld2nzWgASmWqEON3lRUerhH7LYpDTz4zZk1WURFZteKVZ9Y0sDP
ogsWlhwKiD74vXGkHQ1kmfBS4h1PoE9NT5zzH9HAUR199ykeBaS161ZI22Ma
MLC0sf3dRUVzQCN7/hkNpOnasARnU9EbF4mmXQE0EHBJ98ZwOBURctlmhMNo
wFP6/ISYHxV1LHxnUP5AA01NZocG3Kjo4dHOw4ZJNPBqaA9PjAMVHTQvUHqQ
RQM9d3M5P9yjoi8REVf9C2lAwGG0/4olFZl2uj9IgTSQNHhdz/ImFdHtMQ+o
qqUBQQkplgAzKkrQUE8bbaUBOd7ezQ8mVKTpebT2Ty8NWBW3rTka4/MWM09w
j9GAqnej0Mp1Knq9urBFmKGB/1TM8+nw57LSbXw6yzRQ91jf/i1muxOxoUO/
aGBn4JkqL/y8zDP2nLbbNBBmbX27yZSKFvVU/f/tmgBFb/50W5tTkZQpB4v/
3gnwr/fyTwN8PhvrsaeCByZAOKtF4avbVJT2KJsuS2ACcErGMDFa4fN4e3qA
IxOAcFHxPbxLRccDdH+3Sk0AJTHr8SIbKrobJfTQnDIBhK0aJpfuU1Fy0vLy
stIE+PZ4WcP8ARWJo8CZfecmgL2R9sUVVyqybDK/Ha8/AfxvzTVyPqGixD7C
GMloAtBJ79az86EisR9tvZfuToCH9BWZg6+p6Na/2EuT9hPgjmSD748gKopn
/q/V0XkCDEU0PdIOoyJhkX21755PgO7GsI2ueCoylxlXOxqA7/Py3SWOFCqK
VfxcVhA6AV7mETLjs6hI8JJeQe+nCRCtNndy8SsVmZgJk+5kTADfU976JdVU
9P7ej4yNvAlQXSLDzdxCRUNO5RIvSvF93t+qnuuhIn7foE+8Vfj9fk4zjmNU
ZBR4Qzi1cQIwNVKLK+aoKPI9MVqxcwIITRqd+bVGRf3JdLyNAxNAgLE6XpVe
AR3Mbw+5TpsAfhc6/w2xK6Cr5XEcC7MTIKqbd0XksAIKbf7vtfuPCTD7sEYk
kKCAevpP7d7zewL0G8hnT55WQNzT+3yjd0yC0k4kYGyigC6vjG9L754EdBV5
YhR3BRSy9dmtjH0S+P/H20hOVECdLN6/LvBMAl+W60//ziggTh79B6OCk+CA
z3jg27gTSE9U5Pv9o5MgX8roW4jQCRQou2K9Q2YS+JmEst2oUkBtShXTgXKT
QDZbduhqsAJi13p7U1h5Eix8aDs3958CunD55sjn05NgrpNTPdZQAfmbk4zU
dCbB6dKJf1fxeZtt6Hs6Lk2CpGElZUeyAmJz6dC7dX0S3KQFVjEcUUDnnsY3
r96cBIcIgWa2BxXQyyCHs77Wk+BEWsSHs3sUUEO0WjWXwyRwe+FlfJFBATGn
cp765DIJtHYVz2j9oSKtAlqpnNck6B08/nnPChX5VeQo1PhNApmVlxqPcT52
DeoTvoVNAn1fYcWdw1R05ptIutOHSTAmZ0Zew/n0XV0R3500CdSO5ItptlMR
A1vwYYmCSXA230WQVkNFagdvRRV/nQTbDkoneCuoyFuMzKNdPQk0SoK6X+P6
2aHcufde1yQQXba+ty+firwKmvqihyYBI1taRhWeN/SEmvi2yUlwp2RcJDEd
P1+0WF5+bRKctNsqG0vA52P+YEp3YAr8evS8pC6Uip57hx+jCE4B/x2FVI9g
Ktr9N2jF8ugUmC+Yj1UPpCKW777PmuSnwGCKR8zfF1S0p9s6M+zqFPBTNpaj
eeB5akt/oWpgCsRzvy87qk1FUdObPL9oU0BkctSUoEFFh8zXxiXmp4Dc5b0c
HGpUJHBp5mHA5hSw73m4dPIEFcU0jYMKhmkgmfp+24OC+0VjkHmNdRr8EpuL
cpelIqETLdFGh6aBRaholb8YFcXl1Fq9EZsG9z7xe7z+X8PlHk9l1sVxoZFG
KlIqyb1cKkbO4TlHCyddEFG5pdRIaSaU1CRJjOqVTkJSZKhGIqJ0cbeSW5Nr
uWRIqM5xKZ7naBA6591/fj+fvffa67d/a63nUWejltELEzQSQGuOr/VyVTbe
zSieFq0XgPrsOIn+QlLfK59U61oK4FiTXN1deTZm3MiNdbcVgOlsx8gAMj/0
lDI9YrYJQPO9ssLhSTJ/YtK1y3cJQPvh90N+IyxcNTv5K71HAFMrCnabfmTh
/bMJz7UPCuB9273toe0sXD15OcI1QAA/VJzUmmtZmHXsgn30SQF4LxiMj37G
QoPhcJXSswKIOr0iNvk2Cx8cCPkwckEAvFANyvAiC416grI0YwXQfTo89YIP
C3PdjhzfmSQAmXUD45w1LFzb4mt5MY3k8z4+K7LYDPPsvOWKMwWg2t2RmHTf
DI2r3Fu+5AngUNOV3iwDFuZbuqSsLBTAifViXHCQhSbP7X1dUAArPo5Ge/JZ
+NjYdt35OgEE+KEnk83CX7I3fH/eLICuy0Y/GipZWKBt/nLonQAeLUKzfpLf
+lQT/oo+AVyj21duHmChaVDETwaDAvI/sG7OoQmyf3NLOIsRAMvMPein2Ww0
UdP8bvNdAG3yu3cGEf2NmaNBTrOE8LP2+op+NTJPanB4t7wQ9mcsboxYxca1
KQt8/RYKYaTU+2ugCZkXtvluEZpCaB5ebZPMY6PhMqkWvr4Q5o+Fn5y2J/Ng
1Mku2UQIIp27/RM72Lj65ii3wFoIOrNVNUfIfNH5ulbr836y/3l5Qh7xp3bl
2RTmsBAikqjoTtLvtZIaF4mPCYH/t+XDduJnDesAuSWRQhAYpXm5JxK/JuZ+
2XJHCHHKfKzJZqOypdHznH4hFLvTt2aa2aikdMa4aEgIXZFK4/5tbFwgfJ1V
LRJCgJlJelMnGxXjfr/VIz0Aou2fxQf7Sf18zo5YoD0A4Z1qWZOkX0jz9R2C
fQZAoKg4Z4WSOYq69fo4nwYgZcAqvN6O9LMon+Ky4QF42ih3dmSbOeobpSfA
2ABcD1MIU3A2x32hSzfxpAdB7M4WcN3MsXGpwgM7jUFINLmxKMjHHLNcmWAP
r0FoLfc7axVK1jeXzPmjdRC+pL/I/nCfrH+53fhx1RAkHs+6/avYHOdNt8mX
NnyBmvcKiTP3LPBwZ2zPiicjMDTCxixTCvepWajElYzAtqis7FwzCt29++1l
X47AGtugXflsCrd8Xl801DICuRdiex9xKNRjOhOej47Ao8qWUxk8Cvvn6Gx1
NhwFi4cJb+x3UOhlXlgQdWcUlO82FYYco3Bn6P6hiaxRSNZuSHE8TqF9+VzN
3x+NQoWCbZHmCQqpjXuuOOMoPJ/rHFN5ikLV7dKH1XtG4ebqD+++hlM4ZKo3
v1uBhsv1NcwnPoWZ9kerTmyh4ZQwvUr1PoVVdzsvnHOgIZS+rVObRWHvtM3W
mO002LXyFYIeULgsR6Ux3Z2G5Heu+mUPKbysUNLx2o8GJQ+Br95TCu8f0Elu
P0JDi2Lwu2fPKKwu5Xv1HaXBVUnDkFdIofjIvr7xUzTkVX+c51RC4dGG2cOa
0TQI/Tt6jF+Q83QDc434NKT+eOGfWklhVti7QHYc4T9OzMhWEX3WPPjmcJOG
6Pje+KoaCndd2S7+I4uGY4mJ92bVUxgkKMLIXBrO1dIbbBoovLJB+0/+IxoU
5J3unGmksG7kP7m7RTRUD8TN62kmejmlLGx8RUPmUbWmbW0UumbKtr5roMFp
3EHXrZ3C4xL/6x9baNjjlst376AwJ89q+fdOGqjqXyJsOsl5ctnvZXpoqM10
CTH4l8LP3srpiv00jO9U2iPfRaH6AoGOzhANde1uCdndJJ6fk3DtCA0Vj4vW
HXlPoRsWZlmIaPhy8omddg+FwapaRzaO0/CpZF9oE+GrR2PWOk3RkCEJdzn6
gcLcum+0h5iGyIsTHrN7KfxHY2/BAWkG9JwtF10hLDhVeyLwJwborU+n5fso
lGkxNj89l4GokpmIU4Q19JOnohQZKIrRnN9JmBshUxarxIBiTKWUYT+FHp1H
wpMXM7AlWSXLn/BJk3brjGUMrPrYtC2dcHw0yOarM1BaNqxXSTiv735NsRYD
2cqb97whXG+hFF2tx4CX1iL5ZsIDcaH2zQYMVHupGBcTlh36NK9rLQM5r1Je
xhLWtHFs/vwLA49iLP9yIrwh+Xk8zWJAzcg8YpLcz1OksWuaYsA7N3BhNOGT
dpeW/AQMbDSffCsh+SbcGetcwGMg1HSRwW7C+VNet5ZvZiDkYozDTaJXvUvN
Xj17BmR+ozYVEj3Zi/Rahh0Z2HTOw6WO6H+n7TzvkQsDl+vk/YvI+ygkfX56
0pXoscsvKJq83x/utqu5ngxI1V6SYZH37V+akTxrLwMflj4JK31HoUOX7Lza
/Qxw6bbRpcQfz28dCL/sy8Dq9f/Nsyd+0tpbxTgfZiBxZlDT4S2F/JU6B5b4
M/ByrG5StYXCyd4/27uPMmB17uf6HOJPnzsft9wJJnouttSVJn5u9OGVHDrF
gP/v54uVXlFooXt3zZozDFy7+sq6o5rCvwXS6aJwBvyuWbA3k3pRvP+rUuGf
DNw0bop3L6cw5HBlVNhFBnqzNx2UFFH4yUBrwiaGgYWv5nmuIfXq+CXi8JxY
Bro3vp1qzqOwKLevqyGeAf3v/BetpP51Aq0dE64zMOdMweMVdymMNb6N7skM
GBaf84xOoXCKkTJV/4uBqRuVlUPxFPoW7Mv4eJv46+aRvNnRFDYH45KsDAZW
hksaL4RRyGFpXArIYmB+299rxwMpvDcRPmOay4CHVOesv7wpXFD0IeB7PgOZ
viXL3OwpDD0NfeVPGLjUz7NYaEL8zUnbEVXIQMHWFzciFSjc/kNcvbWUAevU
tsVz31hgSfle8/nIwGO/QBOBtQXqnSvPbn3JgHZgyObjkRYYZ62+IrmWgRNG
QRXrRixwRvpsrPdrBg7MvFD7qEvhwar3s3SbGPhZJTvf0YHClvOWwUNvGAhu
XGw8fZjUy+ZUQV47iV9x0Gd3JLn/nB/uJ/5lwCa4THpNEoUL//F6TfUwsHtn
4IujRL8zMaWWUv0MWNS/mV9H9Bc6qOVXf2bANQ9U0+oodFE8oxUzSM6f9Oiz
Jv1mdRxHbjHDwD9jd3uLR4i/XVJCur4R/6NY/O930j+Vp4fTJ4lf/5ZJ2i/L
wbfXi5sNpUTgEPkgY3QJBze4L+MxMiJ4L6zlqWhy8P7S00+fyYnA3jjJ+IM+
B8/eski2ni+CLVHFfVEUBw3uFPq4qYugsHP59Q53Dib6qLaraYnAMWNoZtib
g1K6p7b064rgc0qebNtBDrZlstf4rxFBwspwP5NgDp7LfTYeyRXB8VXnRzz4
HNK/Da/etBLB3iGd5u4EDialpunnbxTBxouqHJtkDj7k/8/rvYMIhtJ2lZXc
42C3v2cle48IzosMOuLLOWixVsz/EiaC1K17RDVDHBQ9tNV1rRCBYsV1h0EL
Lor1isuPvBTBJYozFbuBi/Jpa93/rBWBX6Nv2DoeFzVil8TkN4lg/q6CTx4O
XHQKHKTn9oog/KB1y/69XMxZxy+tkBqDZ9sqth6I4KJvfusOfZsxuDHg2L+k
iovlcZA6ZTsGvvVlbR9quah6PFvweusYqMcZzsl4zcV6s3MhAc5jMIe/e9+q
t1xcX2KYVrBvDEwfO9jO6+eidE3kkGX4GPjj5Vl+Ei6mdRlHuJSOwXXdQYVb
5pbY+RP/YSjrG9Q21GeG3LNEpYYF32T0/oNbhuyaf4I2YBinUtymPw6bOm3N
ujYBnvwxT26n2gRI+3h01MtY4e1DF1uXa0/Ct9p23ZDfrIif6y8v1f0OOuHf
ri1ptML5gQ9sXqpMgW22kpq9gTVWbCwse7ZsGnITTZSf8q1R7O/NclWcgdWm
iQ+1h6xRWu7NTcMfM5Bg9q/T2Y02yN4SVGknJYbrIqNIx3s2ON2dM6AiEsPM
kF6s/ywebjxSd3XbuBjesWcbyMrw8Mr0R/PzU2JYOFFemSzLQ61ly6O/SUsg
M6npa60cD7e4Reu/VZaAiUG+gZYiDxNbfH+7aiaBq5FF1u3LeOT7Vv3L3BAJ
NHRdG+eu5+GpXdQ1mzAJNKV1Ob8142Hlp13c0xES4NVve3CYzUNXGf7lwWgJ
RESXuV+neHjGatqoLlkCe9Xm/jVqxcNXxR3+50sl8KuzXevtbTxUshtTKUMJ
CG7uVDZ34qFXp2L5tyoJRN/L3d64nYf0hK3igQYJBJzbWTO1g4eLzZ48tOmR
gF9DXuoOTx7uq2pyPd0vgYu9vzUN7uZh1o5h8SOBBJw9z0vC9/CQG6TlpDkq
gZz0Xs+cfTy8MGvDhPuYBJRP6l6w+ZWHzVc90q5OkPgvW/Le+fBwmcaJzXXT
EljyP2FHgC8PffKujkokEvi53E8se4iH/wfNeqa4
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466900451111*^9, 3.4784396034966793`*^9, 
  3.4785278785183496`*^9, 3.4832952648119907`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to y", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportrollinput,opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774764889*^9, 3.478377747666337*^9}, {
   3.478377783866334*^9, 3.4783777839181623`*^9}, 3.4784393731743793`*^9, 
   3.478439452160078*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8lf8Xt/fehIxKsqNF+UQZ0ZBKvqXILEWKSEMKZcuIrCIzZO91HjNl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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924669043095417`*^9, 3.478439607469988*^9, 
  3.478527883070868*^9, 3.483295269820018*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to z", "Text"],

Cell[CellGroupData[{

Cell["plotTF[eom2,coupling2,supportrollinput,opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747682744*^9, 3.478377747698906*^9}, {
   3.478377783966734*^9, 3.478377784018618*^9}, 3.478439373759067*^9, 
   3.478439452210371*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fx1EJLYTsUBl3uZdSpE5DFIrI+CKSIjNFGSGElCjZISpUVvbm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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -25.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466908370902*^9, 3.478439611949328*^9, 
  3.478527888911063*^9, 3.4832952760017223`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to yaw", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportrollinput,opticyawoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747715989*^9, 3.4783777477322283`*^9}, {
   3.4783777840668993`*^9, 3.478377784119688*^9}, 3.478439374242858*^9, 
   3.478439452260655*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81f8Xx5FVZlZlZUu497pDIb1bklGioolIRVYoo6WkfFVkJTNkZO89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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246691264824*^9, 3.47843961629326*^9, 
  3.478527894924163*^9, 3.483295282493626*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportrollinput,opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774774975*^9, 3.4783777477661333`*^9}, {
   3.4783777841675253`*^9, 3.478377784222093*^9}, 3.478439374805045*^9, 
   3.478439452310508*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmXc81d8fx0kaRhpGkVkp3Gkl4RRCWqIhZCQpSb4oM0RDkV32XkXZZJ9j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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924669172847557`*^9, 3.478439620341316*^9, 
  3.478527901182166*^9, 3.483295289432289*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to roll", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTF[eom2,coupling2,supportrollinput,opticrolloutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777477831497`*^9, 3.478377747799203*^9}, {
   3.478377780642433*^9, 3.478377780697702*^9}, 3.478439376650053*^9, 
   3.4784394523613243`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81d8bt2VL9tYuUklL5SltbUkqodJCknyVUYSkMqLskiTKXgnRc41k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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466920695965*^9, 3.478439624093628*^9, 
  3.478527906731896*^9, 3.483295295560419*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Top mass force/torque to optic displacement transfer function plots\
\>", "Subsection",
 CellChangeTimes->{{3.4832946459177637`*^9, 3.483294660590148*^9}, {
  3.483294746950395*^9, 3.4832947871829967`*^9}, {3.4832998979812393`*^9, 
  3.483299900164207*^9}}],

Cell[CellGroupData[{

Cell["x", "Subsubsection"],

Cell[CellGroupData[{

Cell["x to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746633154*^9, 3.478377746644853*^9}, {
   3.478377780747471*^9, 3.4783777807927094`*^9}, 3.478439358850165*^9, 
   3.47843940462948*^9, 3.483294817239087*^9, 3.4832948492079678`*^9, 
   3.483294900010994*^9, 3.483294932330386*^9, {3.483294980642807*^9, 
   3.4832950028359632`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81f8Xx23uvcY1rk3SV8jIJsW7REoaRGnRQJJQRiiFFiVFykqphISE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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466778520212*^9, 3.478439485430641*^9, 
  3.478527704184457*^9, 3.483295298688979*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746662045*^9, 3.4783777466787443`*^9}, {
   3.478377780860149*^9, 3.478377780914689*^9}, 3.478439359606676*^9, 
   3.4784394055404*^9, 3.48329481725802*^9, 3.483294849226907*^9, 
   3.483294900029011*^9, 3.4832949323484592`*^9, {3.4832949806558647`*^9, 
   3.4832950028537693`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8198XNoqiQVkREVGZn/0xb5klSkK+RVRKhISsVGhQyshehZSMJHvf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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -45.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466783632835*^9, 3.478439490391252*^9, 
  3.4785277101240463`*^9, 3.4832953033420067`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746687168*^9, 3.478377746696575*^9}, {
   3.478377780965199*^9, 3.478377781010839*^9}, 3.478439360191482*^9, 
   3.478439406294216*^9, 3.483294817268324*^9, 3.483294849237339*^9, 
   3.4832949000393763`*^9, 3.483294932358733*^9, {3.483294980660974*^9, 
   3.483295002864334*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8198bJWVmz6ykUPZn2m7DKJskSSrSkKSQUSKiQZTISoSUVZKd3Gtk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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466788320264*^9, 3.478439493669572*^9, 
  3.4785277151841373`*^9, 3.483295307354862*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746713162*^9, 3.4783777467310867`*^9}, {
   3.478377781058949*^9, 3.478377781110216*^9}, 3.478439360686646*^9, 
   3.4784394068681717`*^9, 3.483294817273634*^9, 3.483294849244722*^9, 
   3.4832949000465384`*^9, 3.4832949323660793`*^9, {3.4832949806774693`*^9, 
   3.4832950028694897`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWHc81d8fJg2jkBUpoW+KCHHv5xo53ESJBpFEihSyChmRlVIZZVRGoUQU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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4784394972174683`*^9, 3.478527719623373*^9, 
  3.4832953107431803`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmnc41+/3x6WkhKRoyCj7PcyElEMos0GDRGiojJI0JDtUtopKslc+CNm8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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -22.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.478439407136755*^9, 3.478439418355668*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdmnc41+/3x6WkhKRoyCj7PcyElEMos0GDRGiojJI0JDtUtopKslc+CNm8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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -22.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.478439497336631*^9, 3.478527719737*^9, 
  3.483295310827765*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to pitch", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticpitchoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774674713*^9, 3.478377746763092*^9}, {
   3.478377781159789*^9, 3.478377781209103*^9}, 3.478439361147902*^9, 
   3.47843942300064*^9, 3.483294817290742*^9, 3.483294849259458*^9, 
   3.4832949000623198`*^9, 3.483294932381837*^9, {3.483294980694187*^9, 
   3.483295002887312*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVW3k4VV8XNl/uNVyuWcYIZShFUtmSKKmkyFBURIQkCSnSpAxJGow/IWNk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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466797325183*^9, 3.478439500542678*^9, 
  3.478527723713172*^9, 3.483295314006311*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["x to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[x0],opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746779937*^9, 3.478377746797263*^9}, {
   3.478377781260631*^9, 3.478377781310965*^9}, 3.478439361575379*^9, 
   3.478439438896866*^9, 3.4832948173073587`*^9, 3.483294849275738*^9, 
   3.483294900078886*^9, 3.48329493239847*^9, {3.483294980710619*^9, 
   3.4832950029039497`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUW3c41d8fp0QZSaWUiJKUeRfl4kRGoZJKkhGRjKSSFWVUX2VvkVD23ptz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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466802132057*^9, 3.47843950471726*^9, 
  3.478527728953517*^9, 3.4832953180756598`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y", "Subsection"],

Cell[CellGroupData[{

Cell["y to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746813946*^9, 3.478377746830666*^9}, {
   3.478377781359817*^9, 3.478377781410695*^9}, 3.478439362013962*^9, 
   3.478439439616886*^9, 3.483294817323955*^9, 3.483294849292759*^9, 
   3.483294900095468*^9, 3.483294932415173*^9, {3.483294980728099*^9, 
   3.4832950029212303`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc4ll8Yx9FQJCVkRKiUjPIuopySKKnsJIWyV6KsiEgp2ZIRWcneZJ9D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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246680707001*^9, 3.478439509128048*^9, 
  3.478527734701577*^9, 3.4832953233849*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746847114*^9, 3.478377746863484*^9}, {
   3.478377781461542*^9, 3.478377781510157*^9}, 3.4784393624750443`*^9, 
   3.478439440235651*^9, 3.483294817340763*^9, 3.483294849309409*^9, 
   3.4832949001120653`*^9, 3.483294932431685*^9, {3.483294980744669*^9, 
   3.483295002936982*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81d8bwG2ue3GvvYnsLQqVE2VEUlYyolTKSqgQGaX0LUJ2iJIksiKr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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -15.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466810917551*^9, 3.478439513159577*^9, 
  3.478527739226475*^9, 3.483295326794345*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746880033*^9, 3.478377746897133*^9}, {
   3.478377781560615*^9, 3.478377781610815*^9}, 3.4784393629588757`*^9, 
   3.4784394407419643`*^9, 3.4832948173573103`*^9, 3.483294849325707*^9, 
   3.4832949001286163`*^9, 3.483294932448131*^9, {3.483294980761075*^9, 
   3.483295002954112*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwc2nc41d8fAHAqZJRRRrIrQrj3YyVyiCgqq0SDBimVhAopIqtk7xVCZWZm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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466815232053*^9, 3.4784395179002867`*^9, 
  3.478527744580017*^9, 3.4832953320642347`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746913471*^9, 3.478377746930922*^9}, {
   3.4783777816603737`*^9, 3.478377781710813*^9}, 3.47843936340908*^9, 
   3.478439441259446*^9, 3.483294817373931*^9, 3.4832948493430758`*^9, 
   3.483294900145075*^9, 3.483294932465622*^9, {3.483294980777521*^9, 
   3.483295002971015*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc81d8fx1E0UAgZoZSRrHuve7nEoYSspJIQsioJGYUoqURD2dlE9l5Z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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466819426744*^9, 3.47843952258252*^9, 
  3.478527750541658*^9, 3.483295336533517*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to pitch", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticpitchoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777469474287`*^9, 3.478377746963317*^9}, {
   3.478377781760839*^9, 3.478377781813466*^9}, 3.478439363859208*^9, 
   3.478439441754499*^9, 3.4832948173907213`*^9, 3.4832948493595743`*^9, 
   3.483294900162621*^9, 3.483294932482086*^9, {3.483294980794867*^9, 
   3.48329500298766*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c41l8YxklGtpBNe9jvMFI5DaNkheQnUSgZSUhIIhSFsslIQnZWsnKO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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466823897972*^9, 3.478439526498692*^9, 
  3.478527756193668*^9, 3.483295341818818*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["y to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[y0],opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377746981037*^9, 3.4783777469976397`*^9}, {
   3.478377781861001*^9, 3.4783777819111643`*^9}, 3.478439364263809*^9, 
   3.478439442249517*^9, 3.483294817407241*^9, 3.4832948493761253`*^9, 
   3.483294900179291*^9, 3.483294932498661*^9, {3.483294980811363*^9, 
   3.483295003004386*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc81d8bwO17cbnDJrtBIUQZ5URCSiRJUkQ7SfFNJFSSZCSzjJDsJMmu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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668273345203`*^9, 3.47843953003332*^9, 
  3.478527761401968*^9, 3.483295346397046*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z", "Subsubsection"],

Cell[CellGroupData[{

Cell["z to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777470144176`*^9, 3.478377747030521*^9}, {
   3.478377781967656*^9, 3.47837778201213*^9}, 3.478439364702929*^9, 
   3.478439442722149*^9, 3.483294817424316*^9, 3.483294849393491*^9, 
   3.4832949001957817`*^9, 3.483294932515333*^9, {3.4832949808279867`*^9, 
   3.483295003021098*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fxystI4lkSwPZrnuva5+KkAZJSDJSSJIKRcouqWzZkURkr+xz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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668324134912`*^9, 3.478439534800036*^9, 
  3.478527767202735*^9, 3.483295350817444*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747047474*^9, 3.478377747064941*^9}, {
   3.4783777820621862`*^9, 3.478377782117507*^9}, 3.4784393651302958`*^9, 
   3.4784394432282543`*^9, 3.4832948174412394`*^9, 3.483294849409933*^9, 
   3.483294900212535*^9, 3.483294932531785*^9, {3.483294980844512*^9, 
   3.483295003037835*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc4l18bwKUimZmJhJCs7zAS8lRESSWEJKOIrPwiqSSKokJmZKRIZGTL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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466843582295*^9, 3.478439539122445*^9, 
  3.478527780168879*^9, 3.483295360593499*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747080618*^9, 3.478377747097636*^9}, {
   3.478377782166779*^9, 3.4783777822124434`*^9}, 3.47843936555762*^9, 
   3.4784394437569933`*^9, 3.483294817458259*^9, 3.483294849426454*^9, 
   3.483294900229032*^9, 3.483294932549625*^9, {3.483294980861271*^9, 
   3.483295003054566*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81d8fx+1xr+teK1y7JKvIqEhOiYyGUEiiIaWkQkmyMlKJjL5GKZUo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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -16.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668461984663`*^9, 3.478439542345305*^9, 
  3.478527784299974*^9, 3.483295363696432*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777471144238`*^9, 3.4783777471308613`*^9}, {
   3.478377782262466*^9, 3.478377782312475*^9}, 3.478439366097721*^9, 
   3.478439444274682*^9, 3.483294817474122*^9, 3.4832948494430103`*^9, 
   3.483294900245645*^9, 3.483294932566472*^9, {3.4832949808787518`*^9, 
   3.483295003071331*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c81e8XwI0KkZG94yujrMrK+tx7kRJCkiRSNCQUSVFJWZXITPZMVnbD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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -55.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466849640353*^9, 3.478439547508819*^9, 
  3.4785277968210917`*^9, 3.48329537310981*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to pitch", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticpitchoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747147533*^9, 3.478377747164796*^9}, {
   3.4783777823640633`*^9, 3.4783777824130087`*^9}, 3.478439366547752*^9, 
   3.4784394448259172`*^9, 3.483294817491292*^9, 3.483294849460388*^9, 
   3.483294900262499*^9, 3.48329493258202*^9, {3.4832949808945293`*^9, 
   3.483295003088112*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c8Fd4bx42MQiQrKxqSeacuyhGJpIWQRH2NhhmyIrKikKSQhlF2ZGbl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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466853766217*^9, 3.478439551611762*^9, 
  3.4785278017363234`*^9, 3.483295376827867*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["z to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[z0],opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777471815157`*^9, 3.478377747197897*^9}, {
   3.478377782462984*^9, 3.478377782514411*^9}, 3.478439366976221*^9, 
   3.478439445377042*^9, 3.483294817508235*^9, 3.483294849476776*^9, 
   3.4832949002791233`*^9, 3.4832949325988207`*^9, {3.483294980912408*^9, 
   3.483295003104607*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c4l28XwJOViDJDFAnFdxnlV/IUSokS2UKhIqGSrKIyU2SWGZKGEUJl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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -30.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466864957922*^9, 3.478439555279995*^9, 
  3.4785278142369967`*^9, 3.4832953861544847`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw", "Subsubsection"],

Cell[CellGroupData[{

Cell["yaw to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[yaw0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747213866*^9, 3.478377747231146*^9}, {
   3.478377782563344*^9, 3.478377782614772*^9}, 3.478439367391523*^9, 
   3.478439445916901*^9, 3.4832948175248947`*^9, 3.4832948494931993`*^9, 
   3.483294900295518*^9, 3.483294932615446*^9, {3.4832949809280567`*^9, 
   3.483295003121291*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWXc8198XJpSVVPYKlbKFz7JuVkoUknxRiowkScooGamksiMj2SR7hXCv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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668701597567`*^9, 3.4784395595523863`*^9, 
  3.4785278192057543`*^9, 3.4832953899161863`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[yaw0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777472482967`*^9, 3.478377747264744*^9}, {
   3.478377782663492*^9, 3.478377782715198*^9}, 3.478439367863937*^9, 
   3.478439446434376*^9, 3.4832948175412188`*^9, 3.483294849509849*^9, 
   3.483294900313102*^9, 3.4832949326320047`*^9, {3.483294980944706*^9, 
   3.483295003137917*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc81d8fx6NBKZFRSJFItnvda8VJ3ZsSFUXLaJCSFb4yS4SSVTZZkYQk
m3COUdn72nuTTUi4v/P7y+P58HHO+7zfr/cieM9Kx4Rx27ZtzDu2bfv/z3JD
wX46fQ7SVlmvmvYT0fEVkqb92hzsulnafhuzl59GwfT8HDzE7H35CmaNItug
zsE5uFeU7ZAi5kaen+pZ5XOQA1ix7MHc12qW8cB7Dp6Qb7T43EdE6xrZL+pY
56An5+uM3l4i0h+qnD3LhL/XYHBsxFzi2Hu7kD4LKwpeEsoxv0jeRf40Pwvt
fz1wSMbMvOvmlFvzLMwW+ahlg5m7dFNHLnQWCnpKsG7HTJBXPx7FPwsnDkXc
P9RDRDp3CWetuGahaM7cABNmmzf8987um4VUu5ELq91ElNW/FPt7YwaeG1ft
o2GWexXHd6pnBmro1e17h5nU+fdAb+QMvKj1wnoXZgXnNIajh2age1OOa18n
Ed34GCawtH8Gyr0ZUKjB7NDgDn4xzcCX4Qd68jAXCN10tVqdhmrlrF2BmJVq
d/6FbdPQkmM6Qw2zMr/R/J2QaXjW6teXmA4iUoXs/R8OTEM7WdsVSjsRlXGz
xTCwTMPjFePz0pjPWbIa3Nk+Dd1tC5p5MWvxs3TzL/+GEUp/L863YX8672gP
p/2GF0NeskdidpJfrfcP/w2TSXvrJmhElPu1p8TpyG9ofyn4iE0rtoep27WT
+zesk6D9uIm5xLDzlMJ+zCuUK2qYf+xrK/xDn4LRhUdY2TC3Pm7ItR6cglpv
v5xMayGixRNl6Q8Sp+DHt3ywr5mIJOM+xeiITUH+J2WXJJpwPN5fTm8/NgVL
zP7EsGFWCF8t1uebgomRyfXLjURECVTvfbB3Cp6bm6wpwnzLbZzPeXYS/rE/
q3gRs9edExEJmZMw9U9vwd0GIhoQ+BS0rDQJjdcKeOzqiGjs8OUER+IkHCYw
7LyG+feh1cwt8UnIY3q0moh5hU29mZl/EmbJ8wwu1hLRXoZxNn76BOQ45nrK
CrPioIg/tXwCer/scr5TQ0Tv4pNehV6cgN13Cj4IVRGRnoywhuPZCagb+0f+
XyUR8cIEFn3lCfjjOTm8GfOHnjh/QfEJ+PdFYL4b5syDUcFpeyagWTSbddcv
Imr2C4grqxqHRcebbD1+EhGHk0P+rPo4jGfOdvlcTkQdzKuOTWAclgj/bXLE
/D7sP+Vs+XHosvvZ+AXMx3NsShxPjEPbSxXak2VYn/PmFTuYxmFHuvchYczX
Htxt5P05Bn3Nv3EHIiIK1tGYOEcZgzJlfr9liomoiLXnQvapMajClkLdKCKi
4WqLVEHSGLzzzVH/F2bC2beWG8JjMGhHYok+5kZix/I3pjEoaMOj8fI7Ee3j
esDAXzMKk6fTj/0swPFof8G7pD0KB0fUu9hziSg9iMPljsYoPF+h868lh4ho
lz/21p0ZhV/eHK4JwXy8sjIumTgK7b2W7A5hLsvff8KQaxSuNSYN82QTET0i
mljVMQJ5nb0K9mbi/NEv0Iw1GoFDHJxP0r8QkWGq4B2z6yMwsrlN1QgzZf21
LenyCHz57Gj4fsxs4bcia1RHYOxHhinLNCJKbvk3vso/Aq+XtC2dSMX+1VD1
uNIzDOFSdL97MtafYnkBw81h2LQVn0j7QERHXonX1V4Zhow7RUXtMe9oDxoI
O4+5cjcPN+ZGO2MmKYVhyHzTTvVaPBE9zNipe+vgMExw0nKoiiWi8BPn5zNp
Q3BMTys+9D0R/eWqEzHWGYK6202GM0OI6M7ufh9djSFY0/Gp6TTmyo352XNn
hmDKosGe+mD898OceScJQ1Cz6ZTuWBC275u++hz7ELQKdhNhfUdE9prTpk5N
g/Bu0049RX8iWnZn+Rx4ZRCq0a+2L3jifLfn3+d+fhDWivzuMcFc8Uj6ie3p
Qeg5fGi54yXWw5Wrinoyg3B7vfelIg8iIh6JquJjG4Ru02f+e/oC18MCsamk
hgHIHTXtUuxCRPNzF8SLLw3A5P3zSvY2WD9sVtKK6gOQ2PfDpOUJEXnLBhNz
wABk3CdmL435iG2f8heZAVjY7HNqxIqILq7YaEYfGIDM5wf2n7bA9emvfPd6
Wj/M182VLDElohEl9+HF6H7oF2J+iRmzk0vt7yn/fhinf1pI+wGOH/3ORpd1
P/SQFe3uM8bx2OXD/12uH772YT8ydZeICg/0GDkX9UG16mt+RbeJSPuayEPb
L33wxNda0flbRDQRYm39OKYPCvrlKRzDzMWz88Vttz4YfON5wosbRGR9VOqD
MqUPZl43PCqpS0QiEm4j/2p6ob7TLwXCJSIKoh5/5NLdAzsPb0bXqBJRUhof
TbqmB4qdiwpIU8H3c3CoDRf2wJPl5hU+p4hoaJCBRyOyBzqL3KhRVSIimWf9
lQdv9sBwoevML0lEVJ8bKZrV1g3PlUTuchDH3/O/C37wsxtKBIzqnRDD9enl
6228ud2wu+4FR4soEfFfdehwC+mGlxlF/Y+KEJH5nO6rS9e6oRaZN9hHgIh2
i7JPTDZ1waDyE1fDOInocADztejSLmjLOXl1Bwe+f4UOr3zrgpIKRAtzdtyf
KmbD8gK7oO7uMUdJVvyeO7Xqnpe7IP816VwrJvyeX+VZCqALuvd8Uc7cie2V
+n50WqoLaji/65vdTkR/Nj6v6rB2QbaRh+O623D+RXh/EqjrhDsXH0e1rRHQ
jW3POVqLOqEK7Ujq6AoBmZvaP/dO64R2CTc9ZpYJKIhkcn32TSfM8igpGZsn
oKGmM0xFGp3Q3tqC6DhBQM/3bD24XtkBqyXR8BCNgG7V8nEIFHRAYaqU6ZsW
ApLzV4QTnzvgzlyB0JNNBDTF/t9BpzcdcOF9owe1loD0eKZ/vb/UAd3vE87P
lxKQbPduOxPQAVsEXWeVIAHtjT4hICXTAcmM8iVPiwioVOC+A2TvgHEJkz4/
cglIQrRLdKi1HZKW5oxjUwiIaWq1NeVHO6TZrHI9+oTtTeV6YZvbDktThASP
JhJQmLR2547wdtik5qSiGU1ANguWnnWv2mHHV1Wu0ggC0szylQ11bIfN3s8b
+EMJiFG+8vWJ2+2wrpdV77U/AfWujZLmL7bDErXoHSE+BJRfuH0o/1Q75DwX
pO3uRUAWqkBJ40g79Fvryv/rSkAd1Nwp88E2iK66kLgfE1AWU2soqbkNbhyY
PT5lQkD+VQtntsraIPONKMVXdwjorJZkVEBiG/zg6dDLqktAR/ZfVL8R0gar
z1cE/b5EQGuND5cEvNrg1FqQudN5Akq/lngx07QNJs1wp/koEdBr7rJVpxtt
0Enm1cIfAgEZd/QnnL3QBnffLZceEyMg1cjNy3uV2qBJx8vGC8cIiEefb6NV
rA0q/7USYOEhoGV+xeRovjboKk2cYt1PQPX9etce7G2DkU+MzAk7COhzvN02
6U0a1Lv0gXJ+TRa9vP8ubXWGBiN/kiI5fssiI+GMG6iPBq3XtCVP98gipfG6
Ha8baFBajvDmWo0s4vz8O0Mb0eDd9nqt8DxZNGe224D3Gw1mvK670h8ri6ol
TuwejqfBtmOmTqzusihxlpKT+o4GBSdOVJTclEXPM+7dtfOgwcMXKee7eWXR
LRu3fSp2NMijft16t5sMIsnFFOw0wfZ5buN8VyuD2Fa+m9Tr0uCBlNHOTFlZ
9Duvkz3sHA3aeWfdByay6KfjarGRPA1WHPUVWPSWRfHKXGaiojRo+4xRl+WD
LHLZJHAvHKLBfw190RO5skgPXikr2E2D6PF+VVApi2RfWFq6r7fC4+HPu1ja
ZRGbb//3sN+tsPF5VV3GsCyaDb2y+0tPKzx0b4U0PCuLauNL9crqWqH5w8OB
U9h/KWmExPaSVjjU2Kb7j4GAXuUlLEx/bYURVulSKnsIyLSMEzDGt0JvYa3a
enYCOt6x0inh0QoLjy68VjmK9TlseuKMXStUVhPapSpMQIMzHXbXTVrhO88Y
ehuON1q7UGau1wr3H+58zCFDQDHbv+93V2+F+7yGXm/IEZALq4RBmEIrXGTN
VIhUJKDbPNEpaSdbodtpGcUlFQI6JP2c2s7SCgnSkxUzVAJaUZx/N73RAs2T
HraGXyAgGuXuAMNsCzz7KPPpAS0CenfrrLNEYws85SI38uwqAVmbZFeqlbZA
i0xNh6d6BHTZWpj7emYLbE61vqxxE+e3F9O3F8EtcG4kVdvbENeHQIetUM8W
qCvSeOoPzoeqqMmLafYt0G++dJVyn4C8vtWMtd1ogVceTQQGmGJ9F52Sm77Q
Aq9KnVz1fYTz59eXFwzKLbCN8RjlCc63bb0BhyX4W6Dor5/PFi0JqG98m5ka
awssVReWfGtNQMWLT/L06M0wQNhHndeGgJyYr+m8GGyGeOJ2nbXD9ZHjR2xo
czOccBppVrInIPkj5JnU8ma4nPx8t91TnC/EQ6/aPjbDHVMKjF8dCahZ9TXt
d2gz/Kva9P6bEwF9u7B+jOFVMzzcLlrzwZmAAq89tuZ2bIbEEJ1BdxcCsjTq
KRY3a4bntvLEdHC90DTTYlG73QwVvvlNsT0jIPH/Sm7oaTZDxKKkDzHvcZNO
eqzSDKvY07IMnhPQhE/ckptUMwwS/8w/jflnCLta6NFmyK2wD5m5EdDHOHf/
VLZmyL+2rbAT88vUpW7E0Ay1rEWOK74goHu5xifbFptgUuN3tteYT5fS7H8P
N8FYo5w3VZiP1p6r2EZrgq9T6yPXMW+15bFz/2yCS8QglcPuBNQzKGokntcE
w2MNLaQwF05HpJ1OboJf/a7xy2KOWN2zrhvRBJvbLysdx+zA6KL+2KcJxolU
pTBh1ts3E+zm3ARPPcu+1I3PlztkOBRi3gTrHunSYzAfEGqQTjVogvnCuwN0
MM9LnnZFl5rgwgGmqj/4PQ0K36ppoAmuenM8eYVZ7FGDc5J0EyTpSqMt7A+v
iBmJp0ebIOtXt+47mAerWPrU9zdB5niibjr256n1kwGH6I3QqT0hcwz7P1zs
/OnJ2UZY4//f492Yl249WCjoa4R1Hb4TXDhel968/OBT3wiVh/rcWXA8U75/
uHq7pBFe+HHQfRLHf9c02iGR3gi1sln5vjoQ0N3D/Tkb0Y1QMnWb5W2slyLN
zQd1fo3wfMyrlzP/4fxy5TsU49oI37JdvGyM9Wb7RbHK0qIRZnZSEkqwHut7
rzsBg0bIfzmT/A/r1VM1uGfgVCMUmJmicFkQ0IBlpt83iUZYvsVgNWeG3xPb
qOp+uBE2eryW+PgQ97uG2TmdvY3wyTlLPbkHBDRK5zmjvtYAow5Bz0icT+/v
6CVOtDfAR2Un99BwvumUvtvlk9cACyJC+wYMcP1wZ6mptW+A1WL1JobXCejp
sLqkpV4DtCm50v0L57cU5WXAfnIDvMwVvbZwmYBGEtFCBlcDrBzlXm+7SEBR
Ozev6vyphzKml+Ss1fH5DxRzl1rrYdaxjMGcMwTE/Ou/QyHZ9XDfg9zBGFxv
7F/N9rTb1kNolOAoifuX5KQYcLxaD8uatjnniuPzL5jG8xLrIQPPb6Xk4wQU
mZKwvehAPXxCUx+cOkxA2iwDJgaLdTDZYuHcHU58vvnhyq2mOkhnPuM1iOtp
Se0NsbhvdZCxUU5VeRsB/ScZ4qv2tg5yJamFn1iWRRL+TbND1nVw/PE/ZcqY
LBqe3af98kod/MF2+tq2NlkUeVkjS1imDsYzlWQ5lsmiKxleXL/218FgJu0w
2RRZxMRe/vThXC00DX9rftlHFpU8oXfubqiFjv4xG2f1ZZFds/Kp1PRaKGr9
X2vTblkkTnSI0fSvhTeaBjZuHpVBQ0HZ22YtaqHAIPXBvJAsilievxegVYvn
kav5fub4Pl3JHzKStdCJo8SsOlwW7cp9dKJ5by0kMOnZ9eTLomLupNe20zVQ
+PaetwLN+L6nQ785a2vg+6fqD3aPyyKxjiOXclNr4AOXu3z/7z+DCrczrr+p
gQPXpnkDmLH+I8IO/DWrgf/d6hd35cZ6X2+xi9SogUuX7Wz2CxHQztts7cpi
NZBN/B7ZWwrr+bumYu/uGmj/honGifuHzeHXUc8mqyFPRoJQL47vSdcfm0er
qiHB9DFtA+thoJfhTmlyNXRZmM71uUZAWrFOx3c8rIaGpg/15Y1x/8jZztR4
oRrOx3bXrWE9t9X4TkaJV8NBJpPFx08I6M5aTDpxrgpSCVFpHjg/P7KKvqU3
VkFj/RhuOQ/cP45/s63JrIJqvVqS6a8IyE67XOG+fRWsyTOt3R9EQAWmmnzS
N6qgiWfM/a0wXM9caZvrilXwj5PIeMV73H9TxsvebVZCW0b6vpGPOD+279Uq
e1kJl/IM5JLwvDnIEyLt/6ASOrjSSt4WEpCIzJEDt85XQpKXfLhxCQFl6Mu0
L7BUQsU+Tt4fPwioPOfaXcGgX9DKRt3PH8/DU6bR/7nF/4QeOVs1f34TkPQz
kRuaHj9hrPavyLJZbG/wV6VDJj/h5UvyNe4L2D5USv8q+hNuI5yd68Pz+QHe
sdf9X3/ARWGPe2wMRKRYKxWjWlIBT1do6Ufi/eHZUJ7bnrgKmBzfv6uCC+/r
a6fvt72ogDr5DUGjB4lIU/iqqCUV/x6MMLMfxvvts6eZ0bXlMPhyfM++40T0
Sgb93Ogqg0oPlpyKCUT0622CNSgsg4KGwi5RckS0a8mL1z2iDIre771jQyYi
jxwtS6YbZbD4uoMaC96fnil1cx2glUKzD5V7p08TUXFUCbyWXQrj28YHg84Q
0cZG/KOwoFKoPmSoQ6IQkSN8WHxYpxR2BPdomKgTkR1lxfhEA4JUsxqqsxYR
ZX3sZDVLRzD5l9DnBbzfLe4qzk/zQ3Cyccehe1eIyKrKYy9BE8EENi8V2atE
1PL+2EPHdxBODlbavcb7YknGjV2JXsWQYFT6+fg9Ijple/TWSWoxDGxBTKr3
iaiANPYlfXsx/Lj7ja823lezC211C9yKYMP7nWMP8D77ucI/sd7pO9QWUnG4
YIb3TW/dtauK36HmFcscwmMiSrxwWLNztRDe4tqM4TInopj6z0vDdoWwzDl5
byXen4M7Ks78tSyA/RzfErutiehA1JvQZ5IFcHGlLMkf798BBjpT26fz4b8X
zw8q4X19rwCP6uuUfPi2DeX2YvYZ6n/L+igffq/QOeVoS0TMH5NGg07kQ63p
Yr29dkTkaWqhyDOWB8+Ytn0OxcwoJucXk5gHf0TQaw/+R0Ru0+sDQvfz4I3N
AxcCMG+ll8p9FsyDkSrNIRuYnZ+8eiU1kAu52X9yG9kT0Rrxck9WTC4sdbh7
MBez/QqXjKJBLtQ8Lvdz21MiWsrv8Sjhy4U77EekVDFbOye0n+3Kgf4GgQQL
zLMqZuJV4TlwXYftmS/mx9tkn1+6ngPfkYxdIzGvjVFu7DqYAwdoDEEhmF/W
3ZAtacuGLT/2bzljZss232Mfmg1LLdcOXcT8PtJtWFIvG9JtJePo2B7RF8FF
o1zZcLL/h1sI5mzT5JBoWhZ0tL0SxIT59KUiS92QLKhHrla4jN9XK9eovk83
C6qmBVbdx/65wTci8IMzCzJvnfyuiP05wrD216U1E+5IKdQqxfGwnmBpkQvO
hAUDYY////+QzfqjadNXM2EvJeagB46nTw7RM5EjE4LexSMWWA/c79UN9Vu+
weetLEp6WC8f3G/LcwZ9g7d12FqK7xCR1CMrtlqdb1AjaidTPtZj4WWPSY8D
3+DhVc08fU0iOkcOK1NuzoBfGVxlx3E+NR9OjVp6mwGHGCykCHi/N9oO7VK1
M/A8GDsylo73l8lmrfvsGfDOajVTpiP2d1ydFvnDV2ikbWkn9FYO7bL8Q/8o
+BXysdND5Pnl0FFl/kyu+HSYEZpZlzdMRArMVGNPgXRYUrim51dDRFdo5tx/
Yr9A2t8K/sliInr4IbjS+OgXaJdvIMieg/VjVeTUGpMGfR7X6LemE1H4qREJ
ypE0OJnP9k4shYi+7d7bnxWdCp2XPUW8koiouo34Vog/FaZz1BwOTiCioYTb
Z4Pep0AONqqzQDwRrVt7/GE8nALd9jluMMcSEYdq6iebqM+woX75ADmaiCRY
Wm4O8X6G/6q46aFRRETpWGfRiUyGJXyhz45GEpH+x2MlpTzJcDz2peHPcFwv
bDSsZSM+wa8y3wJfhhHRx72RrWzhSfBp1OyabAjO/85SL7eDSdD/XI8yTzAR
tSVNKsyHfoRBggPmTEG4nqkpRjeEJMJ0UYrCXCB+/38dJv5BHyD9pf337774
/We2Hdo68AF+MzG+n/SGiCL2i1ZbvIuHvjx7nr3xwe/9/FRK620c3K8oZqD2
Cr/XPnagiC0O/j0QbsbmTUR/vP2FbwrEQuOaC/ZtnkSkVyQ5e/BINLxTPmZK
8SAiLz1XndXD72GVmEH51AsiypuvzW3ji4Kvyg13eLoR0SFh8+chPBHwqDgP
5ztXIur2S2Hj4AqBL3bQlFex3p+1Gj09JxwMR4DROyrWuwAfV58jKQgqqjpc
9cD6Nk5+njqg+xaKWdh6VmE975qTO8D5IBCWc8nvacR6vvK4dcF/2h8GvHzP
X4brWYfnZ199yTfQtzXkkrEpER3m4LxVrvUahgrcHmQ3wf0i7tkJMUtvOOmk
MP4R19PJwqtlq+ke8Gj690UnA6z38yUBhg0voPYzA4v8Wzi/UrQLffqfw0cl
UUq069gf/f/mhO86QNeGqfcJ2tj+9UafpXg7uMZ54e9lXN93cSUJlw5Zw2uJ
H481aeDzguNy8yvvwez1rpyzZ/H370I6PgXrwQbR4lEJgOvH4qf9jkaqkCl7
/9ku3H94pS1Gs+/qgR2MQdOPZInI5d5eFfD1HlCvjuVQlSAiM8l7TImSZiCj
iudbgQjW20b3wx1t1iDjSsv5ZgFczwd31ZND7EAFlNN35sXv/yVLfHTNARQY
ner9iPtrUJp+eBSHC1DUjrEAe4lozzvvzbrm50Ap7JK27A4iKlW+Kbut6gVo
bC2dNvyH9+v02fsRyR6gbseybwLu5wqCL0MJrzyBvOB2poYxvD8G8VTVmHqD
gqddRnFdeH7Y9fWfsfpr4Eo7N11US0DmjhSpLZE3wKZgJD2uiIBOTHfeCdvl
B5bZez66fSagIUOrIJkxf/Akapft3nd4H3rIODxyLxCscTs1ttsSkMQxLZdv
Om+Ba9yR//6/r/t0h3E9O/MOBMU3ECy24/0xeChdgxAElPotmhr2yaJzlyTP
HzwWDGoTWrdZTMqiRCaHwWH2EHCfJTU1SpWAGEvLnDIYQoFNtoZSNt6n7zjt
43RdCAXGhjEdzoF4vibe+HJhMAwcqJS6F5lCQIdnPpzjbgoH91OWL89DvF8n
zfQPoQjAIiiXQ28ioA4jBcevGZGgJtbrbtogAZF5PA64xEWBO5ombK/mCCi4
uS71fOB7sFwBE/5gfy6+OUTlcosGr166XVDG9fEK9X7foFUMkCWwR/uyE9GX
rS9P041iwZuc+jQ2PiLaqe/yqvhEHED1OsWjQrhf5AvSEmLjgHB3SZEQ1sMB
G3NL64B4EOj2e1VIGcevnv27HtMHUC2bP8SI5xVr8TwmlecfgCEP1cPzPBHV
jzDE77ZKAFdlCsUjrhFRKJdqI+dCAmAM2u39Fevd8JwT/ahtInj4mMXBBdf/
mU+LBuSnH4Fr1WNvHZxf2R1Sfmp/PwJwLHbIBM8DLrsfF2k6JwHPrCB/Cs7f
vY+Hee8//wSO7RMVsHlGRK1RRzUsGZLBh49For/ccT+sve3o6JEMNk7eHVny
IiJxqdb2AO/PYG446FGvPxFpLFQEFwWkAvHd0v5CuJ4eOMZQ8Ys9DazldTE/
jiOiLh2VpeagNJATGqcVhuvzo+wc7cmwL6A7rfLEh89EJDO64LbMkw7Kds87
u6fhfs0llUGPSgd9H3v4Ln7F8+HTJFbuuK9A0Vh/NCwb9+NrCzFs7BnAwm9e
gT+PiHzNA8jcOhngM1u6lF8BEV2LrjERbM0AigOheVIlRDS8dbZCvuMbSF+J
iHjxE/e/g0O3VXgyweEdfwpMKokoRdpt6cytTPA5fhWSq4nI5k7RsUs9mYBi
yNodW4frt8Otwqv8WeBudTOTQgMRKb1d075pmAVumv64UNyI558yuRfGA1mg
1TCnzb+FiB50NR8yE8wGfTLrs12tuF4vWmdY3csGOd2JuRxtuL6w7D//X0I2
EP2z9U+hnYjeCX3pdxrJBq6iezw0OohoRfniUzfhHMB7n3vn+U4iunVtktXr
QQ4IVD0rI9uF+4u5d9KbTznAo3MqaWc3EQl6Cqu+ncgB1XBpqwLzy+hyWujJ
XHAbMJVa9hDRRM5di/dmueB8bbIpYy+ex+vpOz6k5oLmZDHD55gzxqLff5rO
BZeFnOkjmDnpynJfJPNA9HhFMKGPiBwOdtVkWuaB1I7uq6aYe6Qd7ud/zQP+
wZYG7phPn+f+VzyfBwZJS4X/58Q72e/KZfNB3upZ/f9/z+yoI1Zlkw/KePs4
pTGbv50vrc/KB9zHMsM78H2Nn/1vti7nA1Bs43APs1yZxEInqQCU9VD4a7D9
4V3Vr/rtC4D/3sJyNswbiw8FRvMKwPj18f9k8XuNWJjyp9YKgEWrxQ5x7J+k
fJbLUaRCwN0vFc6G/TdrwjZ20aYQuB9I+d6A/U3m4HLdSC8ESy6df0xwPJ4h
Hs4vvwuBT424eyOO10+LI6kGot+BLEs8ZS+O5z4+oTOsJt/Bh3Cr71xNWF+V
JzpL4r+D0Cd+MxP1OD/+k7C26vsOfnmf031Ri/vPMVkmAb4i8JBa+qOzCudL
Iymm8XoR+NA8e2Ea68/GVYmER0qgQG5f/1aO5zMxUCvbVAQGRk2qjyGsp46z
94f2FYO/hAxVUhERXfA8v/5Ooxh4XZk/2If1HkjQenvWuxioH6zo2J+F+2e/
tuhyeTFwM2c9XvgF92M/PZi4rQScYxLprfxERKZKt/V0VUoA//fS38fwPJQ+
bjSz06kE+MXOPEmOwHoLNn6Zm1sCTJp6jsq8JSLVM4/4TJdKANf2JjYPPE94
zllkHpSBwDyhn0/PBc+3720uVJpD4P5P0kYV93dOjacDDp8h4CoRnn5vhOel
VeenJ8cgOD5QyfIfnjd1dE4zWbAjMFqW2MuO97mV5DKdH9IIsNh3enHj/hZB
p8TwX0LguPhrVSqux6f0fk3+Z46AWEW9zBLetwfSLpDqfRDI83GcsSIQ0Mvt
tW4inxEwOBtJvdlAQKK3LtU++4XAHt/JTxv7sX0ZjQfbRxHwtVgu24H7szXT
1fvSO0qBphFj0Zub2F5DWrr3sVJwgWjc9xfvO3nZ19f7T5eCv5unCs3wPHWL
pYuqYFQKeuubPu/B8+DWXf23ga6lwNkgXvpdKp638/t6JqJKwdcZYoNTIa4n
+++KqhWWgpuVh1oO4XoyZTJsG9FRCjZ5/fg+Yz35F5nAhZVScKLiEdvNASKi
PTLT+0AsA7Mn3V5H/cH5habj17XLAJW0e9OQjvv/QasZHesyEMG45/EnZjlk
XGH7cvuXMiD44W78Fo8cYuZbabhdUwbed8cGCB2TQ2lPHPiyJ8sAk7tt6vpJ
ObR0xDXTWKQcsHjW0roV5JC7o9fAj9hyUFgucZPhmhwSaWSWOFJSDmx6aCXX
b8mhapE3T+17ysHcOaOvXnfk0IHWANYTPBXgj3ZqjIO5HIqXijj16l0FkPF2
D5twl0MaSqXoUVYF6GWVys98JYeWqZOUi60VgO7nPXLHXw6dN1DUYuX+AUpj
deKsIuTQ/JtOg+CIH6Cg5E2Bc7ocOj3J8zwu7ifImfpuIU2TQ1PLatvdS3+C
UhEDn/JOORS8zcz7/tBP0BZG+aPRJ4cmDhYGiBz/BcwsfH+QxuVQ4LlbcWmf
foE0EbLeqzU5NJAQWZqfXgluMpUddOQhIZ+vZdTIhkrgu7neasdPQnLfp6qc
5yvBPwHv6UeCJPSqWalZlVAFxK5mAbWTJCTD0D1UkVMFtO3MvqUqkJCbId+O
pqJq8PuJz/4kPRI6yvP+3GR1LRjlW9XuDCShsnf8r2R/1wKh/qvrj4JJyHhv
bJUjSx2wsmckb4SRUAo9XnOPZh1wU2GoEYnF94990hGvqwO71c4IxX4hofNZ
WYYWDfXAaIAc6lVDQgVJJt/XHjUCV2Xa233sZORzX6TnsFMjMLFiXFXjJiN9
gfGN0z6NYC6oWzeej4y2Ih7ifb0R6MxsS1gWIaNGvZNGXwobwaNf3heWJcgo
nmPqeVN1I+CTZU8nE8mI4ve4lOd3I1h7oBn66TQZcWlIDKn8awRp+8C9aXUy
Gts1w3iPpQkcIfyxjL9MRvnlX4S8+JrAjiM1iR3Xyei1myUlRbwJSK84yyff
IaNbKtIm9cpNYGB+UkDCjIwk1uc8Fy82gdn/RC+9siOjzdyMJG79JrDY1Dnz
+zkZ1ds++aVk3gTqeR59DvUlo1gZwoShSxPgMpu5OBhJRtYzi8wevk1A5l7/
kmYqGZ1JyTr56X0TWHaVaI4tISMOUzuNmrQm8CjPRlqwjYxGhEiP54qawCmv
aPmTy2SUO/DnDUddE1A4UvlfFb888o7OTZPvbQK1zNmDo3fl0Y1bT+tuzzQB
liw572J5BXTyoMLs880mMKzpxRLrJY/WW9ZYE/c1A02DhaBVSXlUG1ggXcnf
DFbkTW8nbZBRtJbTlWnJZuDN9gFxdpGR5R7lJ2yqzeD6Va4H5yEZnf71763c
pWYQ+uOO4LnPZMT+sijzhmEzWGyMVnELJaOh064tLpbNYGnbt/y9XmQ0/eFg
9hvXZuD/+f5OdQcyWtmRGRzp2wx2jfekZjwmI5aqMd38lGaQItlRI6VLRtzi
L8i/CprB5Se2rxc1yLi+8x1sq2wGzz4dtjmlRkZy2lc6lsbweR1h/+2VJiPV
rKl8xpVmcHCY8ZI11sd5Ls8I9p0twINfRoDzCBkZdBbckhZqAXVtNm9n95GR
112hXjOjFgA1N5pnZ0kosLy42NGyBbDFZFPPjZNQpPCNmFeuLeCJ+M3a8H4S
+jrpa5QU1QL2aQzt5mgkocKLJ07npLQAwUlmLYlKEqr4UipQUdACKG07/xNC
JNTxZGVwsL0FkDa8rF9/JaGhlsCy+bEWsLXnluBoEglNk8QT6H9aAIM0z9Rq
NAltWzcy5udsBdZrT/32viGhPfrrFAmhVrByqlZtxo2EOEuChZUJraBi2ltW
zZ6ETrpXjd240gr6HuvKNhnifBu5/8vUqBWI+wR8QtokpHpu65O9ZStwWVE9
7nEW519y+CtP11ZAqTnBWEMkIZ09xEfBvq2Aa+3TYbFjJKRvXnchIaoV0Ooc
r2zsI6EH9aZimSmtQMK2IeXUihyylmFkKS1oBbpK0/bCuF45vXv/u6GyFVTf
CGCUzZJDL5fJtX3traC5znN7mLMc8tdrSpsZawVvBAR1y/fJofD8x34bf1qB
fgRp0xrPKwm8uyxZdtIAMcg0vNREDqW7xF3i5aSBv2qvkoXi5FB+n5L0SSEa
CAncCDv2Qw6VnabtVyDQgIo280nGATlU+8Fq/pwaDVhZnctdWpZDbTv2NOle
oQHJocC1zZ0kNPAg8ZuxEQ1svxJ89ywnCU1Vqr6ztaSBUU2GOXsBEvoj1mnj
7koDjmX+n1nFsf/9bK++9aWBWahhoS+H/T+3Ty4uigbiq3lPR53C/tdO5vya
QgNRipY7V7E/j2Sd+VNcQAMVVd2ybzVISJSrl1ZbSQM517/XeFwhIcLTp7nd
7TTg5xD8cFiXhE51sodNjdHAr06X1+gWCakrpz39+4cGdGJyA0SNcDyiz91g
3tkGysrumYvcx/GgDygc5GwDBpknBMsf4HjcdeYREWoDLsPLR3eZkZB1Ode6
HKENGG9Rg/6Yk9AmnfHpqzNtoCj8fmONFe4Hp+aXunXagET+UeGLNiR0yLHX
Wvp+G6DzPKA9tSOhjznVM+62bWAz/uMpXawnwmKeWZtHG6ANvpgcfUpCSOrj
+MngNmAkqpIp7khCWo/fGbsmtoEfB0+Wn3Aioa5Pzwcbs9sARZEhuQvzwxFz
w+M/2sCMVdEVijP2r8Ct7qe0NtA1cuSAMWZ3A/UbNaNt4Mgvjg8KmNki5WhH
VtrAM++Y/Qj/fXSboI7Nrnag8HooZxXfJ8axv+EHdztILfY52eNAQvmXNy7y
nGgHvnO6Rx9h+6i+k5Xm8u2g/YywRsR/JNRc2UZF6u3g0tpBqQe2JHRnZ0UZ
x412IFWkPfrLmoRm1L4B04eYC0ybsi1IyOlZTFGhQzug9qsQBLE/mb+/UWR9
3Q7UT3uGbZmQUMiqQ+7dCHy+3pPDyndJ6JjcA2LO53Zw7Pn6VXSbhDKsr2Yw
F7aD0DtGRU9wfFW+nJbUr24HtWubdmKXSKh6UjLla1c7iDApLSmgktANEb4T
23/j85uczXuVSWj0HnOi3r92QCd2RCnIkJBN7B+BFJYOQGa4ST2L83Fbz1D0
Jl8HKBTv+yXGTkJ+hxp5tSU6ALuWhnzAPznEq1sclniqA1w9krDRj+eFT29T
ONc0O8B0SUKfaY4ckqsPe3vRoAO8dDyxoGmB82ePJ2usRQeYZQ8TrmIkosvq
Nm8WXTtAFkX+PNVMDvV4GDGf8+8AleviD7WK5JAZ0vSMiOkABVnV15un5dDq
hiLjTHoHEA7hzWzfT0IvFU88Pw07wBhPddELnD8H7Dk3gho6gIfJ0cdeZ0go
NpPBcby/A0i5r/3TxfOExNzsH6X5DmD4rsm9xhTXT/EeG/9tnaB38+2GLY6n
+sOquUG2TlCq8tvzqycJtSbmmpMEO4Gy9r3wsnckNMf/9kGPWicg9Z5TkUwh
IZdbz4aldTpBbvDv+cpsnK9hj+943OsExdeyLKtLSOg427lbYh6dgG30gZl6
EwllahLbXYM6QVTG2I3+ThICrwWuNSV0gk//ZHUODpHQLcZ/Wg4VnaBZo+aN
zwIJjatOVNe0doK538+prWskZOdMUz862glCjJUsu+kkFLD8Ve3nzi4g6xQW
R8L9pGLMmMSp3gWeXl/PeSmM55lKcRsdvS4wZmifVyNGRldSFtMDTbrAy2ua
T+Zxv+q1cBPd97ILZDzeEdmpiPvhchTfrtIuUBvx/YqOJhkVtd27QWnsAkt1
plNfr5CRe/7JEPf+LrAy2y26co2M9rvksdI38fd10rJnDMiozeDZRZV93SB0
u5Tjxbtk9B5QXzkf7gZ6To0DFBMyEt3ewrCm1A1Wx+/G8VqQ0exIhCpZoxt8
HzCy2vOEjLJ/3nG2u9kNbk+FtB35j4yckk/kZz7sBsasxPE0RzJS85ldnn/a
DcKH7a9oupERs3mOrLR3Nwh5srPRGPf/ei0XS4vQbiCgVl6JcH8Plj6bmvqx
G3Q/DPn+Ds9Dt9j3TExmd4NrpmNlDR64ny81Hhet6Aa7ZPf46nvjeaw17O6D
lm7wN2D8WZgPGdmGC3cPLXSDrCve8u6BZKTkNH1QkKEHpOo9j6MGkdE2/axr
Rmw9AMiMGs+EkJHvUbX6bqkeMCxNFFrA85UOAzMLr2oP+KmTOnUpmowODder
39DqAYve78RCYsnoY5J+aevjHqCdaKbSnUBG5q+Etg4494DgJVTS9ZGMCGZT
Sto+PUDrmZ1Q2ScyKpF0yK5L7gG3wlxSz+F57eV+sMCS3wO8XIfDh9LISGNh
p5TGrx7grDW2eT+djNhaas1etfUAOHNlq+orGbVnB336OYrttwqI5/hGRjGh
t0Z2/OkBAm3ujSCTjIwdBAXP7ugF/CG/dLSyyEjs1oTBC45ekNVwq0Ypm4zm
lb9GwmO9wOB0ePauHDz/8du3b8r2Aq5n925/xexCP8V5Sq0XlPObdhJy8Tw5
uF3b6UovuOuoxRqAeXd5tV++US8YzHodVoq5MfFt9YplL3AxDf35C3Oo1w0m
0rNecPGMeEgMZv2HRym2fr1gRosx7AzmYxpjbt/e94KcMouJ/983If6leC61
F/ApbOcZwval77Nbl/zeCyZ0ieyt2H67OSV58+pe4LlHceE5fp9SE4NdSmcv
SKQ8He/LwPHLqsyYmOgFpEHSvwnsr5/BATMia71gWb3nVzD2p6+9npgJUx84
0V93rB3r6+oNftME7j4QaWmZ8CEJz4cLgYwhwn3A5MV7mX8fyKjj9Y4YL7k+
cOhJMjOMIaOoYw6KDmf7AMPFBNQWQUaG33+3PtLpA5PrP4uPB2P9XTOyvn23
D5CP7Ka5+5HR8HQzi5Z1H9AzPPupxJOMkjzPfVJ9js/vHG4OciGjh0cKz8j4
94FZa1XFDzhfxPIk+wSj+8CHXfWf9I3JaOZyvCNHWh/wrct6OH6VjDImOLl2
fu8DbuOS0Y2qZGTz4lXGSlUfEHnMsWlwDM+vvBsXJzr6AOO8s7IBri+rmVbj
neN9IOch20m3tP/Pl8PuNSt9IKDlfs4rPB+5jOgdKd7ZD6RL7VXUIZ7vXKsL
0jn7QZyTqQTC9YeBW1U3TqgfMF+s/reigutR+rf5t4R+MJtMzvfG9cBLXdjX
Q60f7BI/8R/fMzwfD4Sf+O9KP3h+wUkD4HmdxXFv+QOjfjCpeV5BB+u7nt3N
8IZlP3id/WdTBO8jgSlLfy+49oOvYksXzjXg/DprGqLs2w8UFyc29vXj/aqn
S0Yyqh+IhOp5lc6QUeS+MlO2gn4gdcjV6TOzPNJPIm1nrOwH23h59whxyaOj
4HPMUls/uKQj/+6QoDwaaj+sNDraD+irjz/ESMijROtAWttyP7jNWIR+yssj
5wqGY56TA2Dc8W/HSpM8OrI1ohK3MAD+kyPZWfTKIyRfefP73wGQkb7k+nNc
Hu1K9X+7sHsQKN07JCuxLo8+jzz5svfAIOgRvafiy6iANI/oVp3gHQSp6Y5z
HnsU0Lu3fAyGYoPgwvl/4DmPAiLVbB12JAyC0iaXoCgBBdSxY0ghWGkQcNPM
eD1OKCB+h2Trao1B8LnnT0qdnAJKNiQNkB8PAs/XZYx1WgroYvihDW3bQUDQ
rrKpvqqAZpv+HbRwHgTFFtFV324qICK17HLCm0Gga7SrmmKigErEL8P9aYPg
zz06b5yzAqKtPYyZmB4EHzU8Cqc/KiAHgmbh9j+DQPk40wRTqgLiNZduO7I5
CPaXVsvxZiigO/1/9unuGwLMeV88hQsV0PQPd9dSySGg+3HqTH+dAmIMeq8f
aTkEeBjmQzmWFZC0ZCOv5vwQMA8Rvx59ShFZKsaF9qwOgXuvV/jyTiuidKr1
AQv6EFBT+fOpjqKIJAzZ9vizDgO/UQvtBU1FJBZw5W+DxDComtyw4zRQRMcX
GtuvPhoGSZRkNpqLIjqU0xR8e2gYyAf42L0qVETbVFpYH7eOgNnhJF0DGSUk
Fy3rxz84Bt5tN45q4FFGiz0ig8ojE8A7/wLt3F9lVF9+RSazYgrknt57jxOe
Qvv+0XYX1U2DQYvtKgcDVdCjzoA+/uxZQEupksi4rIo+XbSu+O/8PIhWEzeQ
2Q1Qrc5PQ5GLCyDVOWourBEgty+5K+6nFsHPcPJCOuU0MslovXryzBIIic7+
eTn5NOrc5ZfuTF4GgoOCezd2qKEDdWzL20X+gJjGJxxhRmrIVblsi3ZyBTg4
Tr9PLlVD9pv7mK4dXgXozN6FPfxnULypdyuf0BpwMPI4N/38DHqrVuvLI/wX
ZDQN+vUPnEH7rVLP4JEd2Co9KjZRPosgJb84l/cfSFuAB968P4u2LIzIeqwb
4B61qFxv5SxiZGqOEN/cAKIfjWs9dCiI6ZUdtwLDJhj+OP6L+RoF7d19MIiy
cxMkQNZyP10KYvMp2K+9exPEGvw+QrtMQVws+r4G+zbBypRGftgNCuL13WI2
Y98E+0Vvmn3A5x3ZF+9pz7UJKhZnzP5/npD/WUYPnk1wSyN1UcSAgkT3jz0L
4N8EHOKjh1v0KEgy8NW/KMFN8Mj2cK08Po/ALu6QLLwJmCR8AnLuUpD8u7rl
7JObIJW3qYl+i4JOcVg/KZXcBEW8ZJH7+hR0+eD6/SWVTRDOPdL6G39/Lfz9
AF0Nc11Js+Z9CrrBAwz2ntsEEqlT1F4LCjKIHOw8pLEJ/mkQlO9ZUdA9vpd6
wpcwSyUOOZhSkP1R1gvXDTeBz/HMok5zCnp/4pjU92ebIO+qBS96SkHxyRUp
v9w3AdtMl/unlxSUdNL0RKvXJlh4f9FWwouCUlN2Jw74bIILFjtTPzhTUIZ4
msCM/yZwoiWaCbhSULk0meNo7CbQqK3Z4eBOQZUZHQHiCZuA4Ov3utaDgmpl
nfcqfNoEO94w6xzwpKCmTP7XlNRN0ONi2NkRREFtRLRT++smsCLBnwYhFNSd
fc/dIAvbe1megec1BQ2QdtIf5W2CsFNRcabhFDSa+8nZ/vsmWL/7pv37Gwqa
ktdYc4eb4LexnulePwqay5+2CyjfBJ8TxY31/SloWTFgIerXJihUia9LDaCg
tUJZy+SaTWCidThhPZCCNpVbp7IbNsGR4zwnPOMpiLHY3rS0ZRPM/s0JDMX2
7VLlGalr3wSm9l6c+cEUxAK/3+nq3gSe2x6PcSRhPZ027B3rx+97b8vlEob1
VLrt1tIw9q/AtNkvbC/vmYQ2+vgmQIOLJw9EUtDRcurVvdP4vZBLRz+Kgo5T
JhoOzW+CvRSfb2lfKOjkDx9N4eVNEHDDwED2KwVJnZOskl3bBOrLr6m5GVhP
vxqoqhubQFzfSlI5E+vpvE2ZxrYtMFOwjwtlUZAPgWWOfccW2BPHsGP1AwX1
HU7k62TaArUfk8ImEihIlknlfBzLFqCsfdh1/SMFvVyg2Znu3wKfYrbLmBdQ
UHu3ZbwUxxaIzbLwbyukILGfTPV/uLfAF3q1jVoRBblmxK0X8W6BcspvvbRi
CmqMVDzx8sgWkPreqHQQ4vzwbL568dgW0A2UjDNLw/qzeux2QASfxy4NQ/H7
qm7u+NJ5cgsoXSq/WZZOQYcp0Z1xkltgVehAZVkFBVlJkXc9lN0CB3gaUiR/
UlDZoQaCNGkL3DW6tyqD38u1/aHRisIWaAW2kY/xex/ObPMtPrUFfi5OxwVn
U9D39oj8l6e3QEiOI7GzhoJYywijFylbIDHji9BoLgVlhxqrdl3cAo/1lSOJ
+L3bTlfOr9zaAhbPHB5X4/dcFbvLX2K4BYJEdinJtON84Fy/4HlvCzgrqNQc
QBSkOSmewGG2Bep2D4neLKOgiHcBujKOWyCN7crvfmzvtIuo+6rLFmD08iZ4
D1HQadPS9BK3LbCLL45tcZiCgrRvdXu+xPE66j6rP0pBY8pLTFqvtoB8mWaD
IbZXUcRXjtN3CxxPTPhMmKAgXzbhu90BW+Bi/P2nDXUU1L9e7PchaAs4XRce
ya/HehjVK3wUtgU2VcpO205TkGfD3JhM1BYYklf3X2ykoI6CVxxrMVvgnVDt
3/NzFCSeKHgafsD3hYRfE2uhoGf+heZeSVtgzKfVg9qK89PhaoRWyhb4mlLn
93oJ6/P+9A/OdOz/pg5XpzYKeqrludj9bQtcd6ukGK1QULX8kaMJOVvgJsvq
0epVCuI/lnfRrGALEPoX1+X+UpD13isOssVbQMWwkBa7juvFykTiGtoCYbXE
2ZVuCuIefNEEK7bA8/uHhAR7KehRDe+WV+UW2L7RbTywRUFFOVlil2qxPs9Z
yZ/qp6D9cZrXuRrx9yyDljoDuN75jHr0tGA97yIsCmynohy7ZxkJ7VtAptAt
0BX7n9noYK9Z9xY47Wfi8g77//aFjN2E/i0QGKvs1TNCQenEC+S/Q1ug5quv
Xi0zFTEcGbqHxrbAi1Fhafk9VHSN2TnAe2oLHNu8vTg4TkHJixxFl2bx/eOW
P5ZxfP71pE1wLW6BSeUIaaYpCqKYVwZqrWyB81J/mRV/U5D/v2EFz/Ut8NDY
l+yK43OMl+/1MiMdSMswh9bMUpD5Z7KsBBMdMNzesv2H45OjoNN5n4UObAVY
2sQWKOj89dcnWzjowGdOVvwVjse7scSmPYfo4OGvq/tzDlNR93/I8cxhOlDK
bY0Z/oPjtbNH0EmADvwvq35iw/GwDF6t+nacDnjMm5VU1igoX4jDZlKUDuqO
iMjsFqIixiwpXkFJOhAHScwhOD6aZzTKbsjSAfsooKJ/FBTSZGIWSKKDhqKb
5ypPUFHfnRcHKhXpYLx0uzUXjo/o/PtCugodkNi2X1sUoyKb5/n35M/QgdW7
7pGH26ioiLV1j9U5OojMcLj0nIGKdsXMZSZp0MGywEvGZEYquizJcrvvEh14
Mt7q/YLjF14ksp37Kn7/RUWbbgIVDV08k6p1nQ4C/MKfWstRkUS3wVXP23TQ
whl65yYTFf1n5vivyIgOPrnPcoTLU1HJ3+CE5ft0cCjL3jBpNxUxv864KPGQ
Du79idKoxfHUOVS7dN+cDh7QvNoWWKjo/afxqChrOnAsfbhvWoWKxsjbKS12
dECI1mpWZqUi6Z9Hpvc40sGpxHDKnf1U5KCrFHzGlQ6SU87ffslGRWUjuqec
XtDBzj1hB5PZqUhvu5/v5GvsL/Eyz1kOKnI5/U+iMpIOvj0YuP70EBX9bOCm
0WPo4OMOh2+6l6lovxHBVT6BDkId/9QV8FLRjVktYatPdJCXScx+rkNFH1wf
1SWl0sH2hNM5nNeoaHqv5399X+ngu7u4KN8RKiK/j+PnzqaDnHWwTfkoFbmJ
F/3QyqeDEpcnvrcEqKiqsN3Cs4gOnpk01DkKUtEBjSWuYkQHGz4GeZu3qUi/
k7VkuYIO0ubl7PKwHuZXqazGdXSQz1j5b0mYipS87+ZGNdHB0e1hbew4/h7c
roYtNDqoVCg3lxalotqP4btYuujgpazQRcOTVMRNyk4/00cHXsvcDY+wHu5U
NOg5DdHBrd+K0V7iVPT56u+tb2M43o3H05XMqGhxaNenySk6cDr7obVRkopO
2Ry7LDhHBxK7Oj8bW1CRF4Pq6o0lOogn772xKk1FjYE3YwNX6UC2oTjR35qK
eAX+U6/8RwcOX5kpUlgv978GztHpdHCWmxaTb0tF/wMVly41
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466875049713*^9, 3.478439562502277*^9, 
  3.478527824159316*^9, 3.483295393640958*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[yaw0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747282455*^9, 3.478377747298711*^9}, {
   3.478377782763011*^9, 3.478377782815172*^9}, 3.478439368268825*^9, 
   3.4784394469742117`*^9, 3.48329481755833*^9, 3.483294849527335*^9, 
   3.483294900329596*^9, 3.483294932649572*^9, {3.4832949809615383`*^9, 
   3.4832950031548357`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmXc81V8Yx1GhVCRCRjSokJ3Mc+/FVSiSXUZZTSQRCSkisoVCVmRmZXOO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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -55.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466880963873*^9, 3.47843956630342*^9, 
  3.4785278300668793`*^9, 3.483295398092401*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[yaw0],opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747315681*^9, 3.4783777473321447`*^9}, {
   3.4783777828634043`*^9, 3.478377782913505*^9}, 3.47843936869659*^9, 
   3.478439447525621*^9, 3.483294817575159*^9, 3.48329484954414*^9, 
   3.483294900346196*^9, 3.483294932666051*^9, {3.48329498097815*^9, 
   3.483295003170762*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c81d8fx++1R4SsiJLsHRr0dUpCooySpKhECRnJKEVUGrZkp5JC9sjK
+2PvvffM3vNeLvd3f//c+3g+zufzOe91zvv1Frr72PA+FQ6H26b8/P+//LbQ
MJm8BD1i36WCB0hwbFNZ9ylhCXT1Cq0uUviNv07B/PISmM9uG+AprFPsHNo7
ugTyiR9POvSToOVglVZ2+RLEsE8p6fSRYKjDJsPq7RLYceQmLnaTYFsnx7uR
dQmk8i+UbraRwGysZvE8/RJ8lsBdTKBwifvgzULyIhjNpzwxoLD3L7oTP5cX
YWFRPi+5lQQMdDdmvdoWIbxMq8ukhQTcpbuGSuGLcM0qV+p7IwmOn9Q6Fi2w
CGwRrrwL1SQwvHP8/GOuRZgX9rj4hsJOHwTunmdZhG7lgF1BCmcPr32ZIy3A
go7b/OUqEij5xfOfGViAspM0Hb8qSKDcS+QYjFqAEdqyMxqlJDj17Df+MO8C
0BpPDnIWksDkx+cja/sXgKMqUiG2gARuza9QNf0CkA1E145RuED4hufjrXnI
dJwsPp5PApUGWiJ0zUNdq7+xVh4JVAXMly0+zQPz6rsdoywSqAH78DeOeeCm
M4zbSCJBGTdbHJ55HnJyGlycKaxpz3rLgnoe7thT5y//IoGeAHO/wPocNAv1
u8/8pMTzGU13ROccKI48G27/QQKPk1tNARFzwBVTFvzhKwny0gdKPATnYJL6
qal3BMUe+n7PXu45AOpdgbnPlPjf7j1zav8caEsJKV2lcCVLV+EGeRbczYhX
j4WToONRc57D6CxsOP8xKA4lwapYWZpVwixYL6t61AWQQCb+Z5yh5CzI+5Xe
ueFLyUfMlbTuo7OQlxB6It2HEr+Irb9m/LNQ/MfpIg2FNYK0Bq32zcLH5kyR
394kMPWa4n+2OANZ56ziVl9Q6s1CLPJ71gwwGsqU3HAnwciRn6HrKjPA07E8
/M6OBJOHrnx3V5yB3q+SUZW2JJjj3crak5qBrg/NTjgKb7JptTEIzED5b6Zn
zjYk2IefYhMgT0PEhfKay9YkOD0qGnChfBoauU9Y9FqQIORrol/4pWmgJv2w
PGFEAmN5ER3389OQX8389KwhCfjgO7OZ6jQ401cYXDQgwbeB+AAhqWmgpYu/
c/0KCbJ4osN+M02D4dXEHMtLJGjzD4wvq50CnaYXv9XPk+CAh1v+otYUnBMt
8CArkKCHYcu9FU2Bz705t2F5EsR8dlHNOTkFl1RW6EvkKOcv16nEXWwKGNlf
tzyVodTnsm0FDf0UVG66tXeJk+Cq1Z0WvqpJGPqK2i8fJkGYoc60psYkzD96
FLOfmQTFrAMXc85MwlT4s1MdjCQYr7NLEVKeBIZ3Xdc/M1Dycz7YniQyCV5S
r3kP0lHOr2LPeib9JNyzLn/IhCcBC5cVXqD+H/w+auT9bXMH3nR7860Z/INy
GX6fyJEdSAs98NxC5x/cObTPVXJ4Bzqv/BhsVP8HeIuCXwWDO3Cspib+l+I/
KB7/UdTWtwNl+fvFbnP9gwzDJzeXOnaAHBmrWNszARlKVEYtNTvgZlag+8V8
Aip8I8sE03fgdoqQhc31CfCI0/C6nLoDGtvvnJWvTEBvWVHNs5Qdyjk3japX
m4CA4IXZpp878Kt9Z2pLYAIOiMwzXI/fgR4dNR/9gXG49+THybmgHTh1urwA
f2Mckph8JegcdkDQT6qxQX8cTman3Bq22wGa7tCRz9rjwHa9NCz30Q60PLGk
lz01Dh1cbgQT6x14kEF7zZRnHN7SqrE8u70DEWLay1mdY8AiGEQjrrsDRK5G
UUvDMdhXwFdEPrYDFozD76/pjEGAZcPJZ0d3oIa0vKipPgYOfAJSa4cp749z
/pE4PgY3Fmhu9/BR7Ms001piH4OiS0x6rmw78FR33tqjdRQeHqn6h9/ZhvVX
zElB+qNg4u7axN+4DWZPBVheaVO4OznjYN02VDyUc3Q+OwouDZsKB6q3IUzf
6LSx/ChoT5esErBtUBSMruVno3zvye3AgJxtcCqQnE1sHoGgAhrG/qhtWF66
KPX38ghcHaOyKbq3DcVsj+VOa42AQMK0wE2LbXirEKaYi0YA7MIZNs22QdB5
SDVVfgQGUg9bCBhvw6VNJ91YjhEQ1j91TEF7G/SIJ/u3fw/D+u7JQ/eltqGQ
Y8D8WfEQ4HyODRYuEMHgqugD59QhCC91U0yfIcL0JweHR3FDEBfw7VXsPyJw
HaT1vuk1BANDSQPWg0RwOCz7TVVjCLrNyPJZDUQQlfaa2KkfhLQDpe4cyUQI
vXDs4fP+AXBYCWf7bk6ExN/8nXL1A8C9j/GYkSkRCg8cODdeOACcPUFc21eJ
MDaKP6gTNQAGmpX/SesQQf7FcA3PjQF4M+qEDisRoSkvSjy7qx/4pFo2pego
zwuEhFlV9YO/RJoJwhFh0/cdji+vH8JqsoS0twkgYOTW4/WpH7qG916eXiSA
7dI1v8tX+6HFKcgtopMAjOLs0zOtfSCf5GAl+40AhwIZrsaW9oHyFdWDH6IJ
IL9JBv3MPrA5L2DRH0YAk4rFz3+C+mCWa1zE+C0BEi0atF5f6YM+G83ujEcE
0Ih8+/NIYy84Kv053a9AgJdMe1bXa3oAu/KxdDJrC0wb+A8cKegBwgB90U7y
FigFnIbppB4oxnucw3/fgll2Fx6PDz2gsHH47GDIFhgfnK+OudwDyVOtE+2O
WyAt3ic+1tEN9TT6+4Kkt4B+dqsjubIbxlOrJ8KFt2AshcvbOa8bph3vcXzg
24LPcga9NBHdwKFJ76nCsAVUJ2veid3sBtzhYUgb24SeC3mztqNdYJcXcj8r
dBOy6TvCldu6IFMpc/rxu00IqF1R3yvrAnXhIjvul5twXk8mOjChC160hygL
2GxC2tWES1nWXWAQpXyXAW2C772Q31sLnXAD2lhpJjZAwdve/tV2B1zqb7rn
z7MBbB+Hiz7PdQDt8Z8Ms4wbsBiuz5g60AFOYusPj5LWIfn38YTukg4wdNTq
EB5Zh2M9m73SPh1QMXbKzjhxHXjlXl7oZqasF9Vpt0uuw+bp5ZB5UjuUfCuZ
DuNbh06NOyP4xXZISHyVJcK0DiGm559Jt7SDJv0+yJheg31v6DO9w9qB6LRd
f/n7GuAGAw9JC7QDmSjQF82yBkNTOJtzrO3wHeO6UUFchb+rjn+MyW1A3m/n
+PPfKngwXDX0Hm2DrFTvwPDiVVhX5PXr+tEG6wd3EyasVqFN7V3nXHgbRJWQ
XdP0VyHz4vZRvF8bxKg76QirrIK9+cBfKZs2MPr4I5Bm3ypMv49f85JtgxO2
bdq3U1ag6hP7ufDDbaDcN3vzdMgK/Ih/FZDC1gZnkk91JbmtwN08S4mu1VYo
epBf+p/GCgyMiptL/WkFhQ+BPvWdy9B8KrOuE7WC/PGJUs2/SyD5sPlZolwr
RIgU3l12XoI3kQvSrodboVIu6cA/8SU4sy0RyEtugX+7dxUt/Bchueib0c2S
FrD5LKAqqLYAdPMYjXRaC/wpjDL9NUHROYeGc0mxLbD1bV09228eeD35eeM8
W0Alia6luGYOXquFDYycaQHHxyZCe8KzMGKf5Z8p3QIW1ZWMpMwZOPOlRe3V
Icr36ZWFiKoz8I98UF2L0Ax+KkH3a9WnIcbCOGG6uxkEP3FsrpVMgWFpCN37
P83gG31+sFZ5CrBXzPUNT5vh5KFf4insk+A6riVjb9wMK5Zm60ku/0BWwzdw
/4lmsDPpkVVum4Bo2l0jw40m6KOyUJhxHAdDq9N5ax1NkC17OwBljwFDtQvv
p5wm8GuNEXw8MwpP/RYHup2bQJ79JV2i7AjIzEgid6MmmJp5HC3zZAgmLlp/
5VNsgve1w+9ZrAYgKvk7dTFHE6iu0dxdle4DA+aR+7dWG+G0oiH+Smk3MNge
qtlrbYQ48cQKq4OdUNJgIhmf2Qhd4nE6t8XbwEXm08dzwY0Q7l7c4V7QCNIB
rYtjDo2wtSqv3K5aBeOLLAa++o3Qv/LfSoZgEURd0ckWkW+EBw7d+Y94okA/
4w1X9f5GiJ9Zf5DUmoXo2ctdHyw1gLXPKaszI7WoxJHcy9jcAN6eC3QuuT3o
SZvqmZS0BtCbJeGmaieRlKJbnG5AA2S+9DYsPLSNxkJzcIt2DTAsUf16smoc
Ra4v3w3Ua4BZvogAg8ROpH9NplJepgHuv89iy/tdiejyHoq17WuAmZWXGfY+
v9Bf7sR3zvP18MjegJeX6xc8cR2b42yoh5rBreydXQDJHsHLeSn1cOuwRV6/
Sw2MnrqZcf1DPcgMjCL2lmaIiPzMQbSpB5H9RCWyWDtc3m5/EqVTD3eqC1cj
2LuA9iZbt6pkPXzbyxQUzaXcm0W6pwcZ6+Ejc7xLsWA/OB16F/1ipg4KrrkW
BF4fBAnPyt3DtXXAGsx0ot5qGEYG8Ralv+pg4j6LHlvSCOh98ThG86AO7l1O
kLhqPQYhudT0LRfr4FVfqQWH6Dh01X+ciZaqA9nyu8/U+8fBghCXprhUC+th
L028pf/BD1bxYHJLLXyef5DBWPcPZo9lOtdn1cLKSIYi/s4kPDEoP3XvaS1s
3Ulxuug5BQXWuvxyJrVwcXtV/hn1NOx5du5un66FvcZDd8Z8p8EveaosZLcG
XhpvzkZ5zEAM9T69Mt8aeIAk/nGdnoPRg5/kAqxq4M6LDyg6fg5E5QU5TLVr
wPz6yV+Idh4yzOS7V5hrYOqHRqtX1TyU5169IxRaDU5+k/k+0ovA0DB4fuFJ
NVAXqZ4t9FoE3TEr0QLjatDsoGKmaV+ELlb3OX2+amA3ULoh6rQEs9axLl5f
q2DTvC/3+uVlkHshaqLrUwXHmx49rXNchidh6Sq896tge8/e+GPYMuxhpeR0
8SpI5XY5xtOzDBx8k++G0yvhG/dO2cz1Fbgu/9g2JbgSnDa5xNyfrkCMJuGy
q3Ml7ArOjL0KWwFRZybO/ScroYm7kJW7eQVON8jGqZVUAJubLucPtVV4MfbH
iym+AoLXCKlON1ahjHD2Xpd3BfxRm9Xodl4FXREjcfsLFSAeJNLu8HMVLF64
ZsU2lIMCyStBlmkN/OSxKlJfGVjHvSqtgzWoDv7ugArL4MdEWPZi1xrQrb3h
exVZBo7Cnb9hYQ18cvXs6U3KQFOl7bwDpb+8UOnn4ugsBfPwwNUzDuvwRGPT
UqwZA1/aoeAe1g3I/tHLapOGwRGG99QBQhuwSvc3/7c/Bg8DpavplTbgca3P
vuO6GByVzXfSNdmA9pijD9xDAMr29LKV4zagJMOELuHNX/Cv+CVx8cgmnHE+
bCpx4S9cYy/3z5DbhALlydQ06r+gbvfSb0ZtE3IKna8VeBUDTssnv81sE5Iq
AhKaPIqgXG9HISR8E8J6KtSJ9gWQaCmUdopqCziiP4S/kCkAtRFbnm3WLQi8
ZThLPZ8Plb+098L4t+D92HAw68N88Ai1KjFR2gKv+e0R4Xt/gAbt5QhZbsEj
nMLLy9dzoTh4r3e3eAsIkxomdDy5cL0iPVe3egt8G00USrpyQOm2xJpH6xbE
RHmNyxjngNw/RvOn/7agQalFi+VaNnzVkDqyyEwA2YeP2RoMMyEtwNKHxogA
hVd8Znw4MuF1hpnfrZsE0DzxuUy1LQNuJvTpRtwjgDk1PEkxyAC7pDnHbGcC
HFYVyOL6mgbCXfpWr0IIMPb95vnQmGQ45Pp5M7COANsOPhtUh5LBNEKsd18r
AQ6opfx0ik6CV/IeWrbdFL3Ws81sGPULZoXJNW3jBPixL6qDLSIR7CcCBdR2
CFDSW/rGiycRrnWNiTRT9GVX4syp5fAf4OhmGqlO0Z90507HNn9KgJvaxz+3
sBHhgUvP/YDQb3CiqPvp22NE8FLH8e5xfINI6vM2khJEiNwvXmcX8hWu9d68
ki5DhLokV1m94Hgwlu0Ov32ComeffhkpZouH5x25tX4qRNh4GyBy48gXqJxU
DAxTI4Jxscwij2As6NPn39XXJMIbY0/DrUMxELGio4yj6OU/yw15XfzR8P19
gHCwHhF4RWxffjoYCWgT1V+j6Ot+/2S2A1yf4Jq0zwkrCyK86DB31RQJgztB
jkoLd4lwhJ9ryF05FJgCEy6Y3CeC5a+XKSPXgqH0jBhj30OKv0tKHJxWQYAj
YI+WHxFB/1HHSsB8AKzri6vP2hGh53XSRzOZD/DXOiX6rSMRDh3gNC3Xewc8
PzvKJZ2JYBH/QkzS/i2MPexNynhChASZmfWggNegJvf+0MGnRJgpNCrbSvOB
/WGyM/dciSCrXRJ4u9kbWCo8+4PciDCRbFD4fvglBEWH//3iTgTbStFrJkee
w7zr1vUgD0q8hneWRO64wbcsF8e7zyj+bbe8X/v6BMoqlJq5nlPs50oUKR1z
gKf7Y5WSKSxgvukloGUDGhcM7x32pOwXFp+XX3MX5Jwk+F0o/CLkU8/PMGMY
ihHkS6Gw7+rP/e7mavBm7+KhUgqvWtKdTw39D3k2dPTnUZhPzu5fzh1jZBC4
wPaRws/v7vsPpd9FX6iKHc9S2EbmLn2CjA2Sdr+a1U7ZX5rU/4CmywHFQLLv
BQonjNI1nfj0BLm5+UZ8oth/qFpB8eFVN+Q0bxNdTvEv9LdZRPSB56hVK+ZU
M8V/ppC3u41tL1EJIvHmU+JTqnpDAVfrjWh4acY9KfF7nrZ4L/KXDwqlylI5
QonvKSHf8ON+r9HrVtfSOEr810MP1tZbv0WGa+LcRCciZNCl71hqvUOPM6c6
ZCn5s3XXkN0T/YA0f7F/Ro+JIDbfa/GZzh/5P5Zak6Tku/kB1fjE3SCUnuJT
EfiA4s9RveeZhsFol1x3ncGKCO/7P3O9UA9B58cmsBv3iKB5WUab52gY2oug
k3l9i+IvvdvoOPsnxG2cpnibMg9SlZZ5ZODD0YM2eR7W60QoUTRJvTj6GTkL
lhotX6HEY+GbJndrBEp+9y5ESJcIHokLw2NYJHrdYO4upk2EEwd9OJ7HRyOz
9oGBNESEsLbGFO2gGKREpyQgp0rJ1wfeC1xesejpcvJHb8p5S91LdU0z/4IY
NBcvRUkTgdbsud9fsXikfsnulLkYEXLyhTq/f4lHU0Yc/mtCROBwsrV3CPyK
3N70PnrLTZlHJ/BfGR9/R0d+q0Vc2CVAOJdaC+fKd8Qr2LvQs0GA25oe5MPO
CSg684qkFGX+XPi5euuE6w90/LuhNf0QAXJ6ZP3PEX+gwtiQ9gDKPPqc8VGx
7rNEFKLJvtvcQIB9j8b57r38iXw27HvcCwnQEX1Yxx7/CxFqmIOHMwgQ03DT
3Z2iu96f5TtATCSAlGxHd+DbJBQRujV0lnIf6qxUhBUHpqDkuC8DK5YE4DiK
r6hm/43WXb3eV5gQoM/wv7W20N8o4XEB0xldAjzMyTWY+ZyKTmlT+bAdJ4Cf
ayIrd3w6Sgq41MxE3ALxqytxbOwZKPCItiA2swUfbQNPcBtmoHIzY2/avi24
Glt/X6gjA2Xf7KtXLNiC8b3zFSd7MtGeo09sMWV+1eQZu/nfwSy09edJZPDt
LUiW81pTN81Cp2v6m3t0tsDJovjo5YEstPExRDRFaAu63EwLjQSykdJJrnPS
+7ZAJZhgcON2NkpOHvRi3twEqjIlb8uRbKR20UeysXoTrPraeG2EctCIYh3P
9/RNqFt1yHh8NwfVphgLl1D6YYhw6rDHRA6SRDVnE+9ugtBrEbXg6VxEYyXS
d215A3xjyzvDJfLQN4vLz+xbN2A6945djE0eijB1tvfJ3ICMydiYn/N5qOqE
W7mD/QZwklWVUmX+IO+837SylzbAjaevPsv+D8K694tnim7AWW3unb/LfxBj
6Y1jVb3rkGCRE1KukI8+DGnvHs9cBwZ3Q8lap3zk1Zthzv92HVqSAm50rOej
T5fnNfCy62DOTJ8/SyhA4ncMHjLfX4PEfOYr0cqF6N2n7AoOhTVYvM82ecmp
EG06/hyc3KboI+wgZ+pcIbJVFJPXe7sKVXaCKbfEi5C/X/LMi4urwMIvrM56
vwh9yVgsKmRYhRgXaYfHQ0WoQE2f7YLnCkwcVaA/wl+MemQ3TmwqrIBUi3Jc
y/VitKdIQ+c8tgxOnirK3mHFiG1Vkl43YBkKJVGDQmsxGv165AZZaRmoes7f
G2P5i3p5XldPpyzBxdfa2yE6f9FDwpb9/Mgi9AwbiK+X/0Wl5wPtBAUW4Ii/
MSTgStAcdx+h4PA8WKvcNL72XwkyecSKp9s3B2lT5gu0HiXI+q0iL+3QDGyG
Wfrm5ZUgRfe2uA9B06Cm/pDfeq0EvZjztCg6NAWvl+yyeOQBPVjj/y3j/g8a
Ypwu1tgCctIb5HsbMQ6cOq4jbkmAsOGaE6NWo2C29cxVYhLQNwWWd9feDYKh
4Vl6O3YM1Ukqlb/d7ILNX2WGlXIYckz4ewA9b4BIskacwGUMmUzyBnoyfYIz
xtUzLrYYsjEJZ/hM6kYjvy8qN73HEDeL2MJg8j/kS93gJZqEoWK3z3tGellI
3PRyw4tqDOFdNY8vUOa7howWnu5/GBI/Ho1vEe8EB3qje3I0pciZzEdTEjoA
nLc7094eLUW4f97PHpwZhT8517eHz5YirX61ky7p42DK3HfhlHkp+u/5hlZg
zT/Yu2MWHORZijZeZNRXxk3Bt/yhgenoUvTm+2da7XMzoLn/jvi5Qsq6rZVA
XOEszN4fd47sKUUs6fzrdznmIaD4PqxslqJaF9076pcX4PiBaSYdrjKkld9J
CnVahM6HNsbfFMvQDqN35d9XS+CGzX/dNihDlYucfwrPLsMhnscLhg5l6NPD
cy+f5i+DZYWzL3VqGUrdoHr8f33PwL/ZfLO+DO09lhtT3F6B345u/DkzZYjp
D+4a981VWBP0zLIULUffr8oWH2dbg3AX8m6xRjkyq/3PTYJS/yoN3he57pUj
ubWwtua8NXjl/mak8ks5ur58QVzBYB1EWxikBUvKUcjN/RFmUetQJ/rB9elA
ORLhW0znG10Hjo5AVrGDFeg7tUr8mvUGfJWNPOMXUoGmCMMHa25vgo5KKfYw
uwK5iPJc4ovdhPULMxqXOirQv55r5OzeTdC+dVqPlbsSETgWzh6+vAXLH3pv
hUVWonhP2jsHRAkQ9Rk/5lJYiSpypfVWKPerxncJq+v9lcgJW5NPfU+AiEJ3
ez6BKsRELv6zMkuAszMHX8bHVyHjIlmR8S9EmF0/R/2qtAq9eq7itlBH6V84
m7f3xqrQ+t34XrENIkzzFAaKHqtGTWDjoqO1DUGapvG/f1YjH1UDK/LYNox8
jyrNT6tBVfw7pztIO/A+vexCVHMNOj6Y8yVWgARKRbO1z5ZrkDqH8MHp/0jg
16bSpna8FmlWm8bv8ySBPL5/rCK3FrUaJb0e2yCB121+mtbiOsQ7/EC4rX0X
JG3O+2UN1qEtBXR0cGEXOlwe7Qvbq0PHsq7z+tPvgbh/Eef1s/Vo30Gh+tHT
e9BSdFNksLweVVktLPtE7cHhgzGaM3UNyKe86VGyLhnKQgT8FOYa0Bqn79kT
d8hgue9LrTtzI5q9f3fDw4UMyeSvuky6jaghiPmrQiwZlCZ/Gko1NiIOQkCs
5QwZuswlwpwXGhGj4/0rNTtkcO9N7ixiaUJ3oz4kr9PhsJKGVBPdy03ou4e7
bxYvDtPOzr5t19yE3C1zkxNVcNistHJ87lIT8gw2Z2lXx2H+iXmju/ubUYBl
uuOwDg5riyywDNBvRkoG0+kRpjjslhfYpLc2o4/EXedANxxWkHi/iPCwBRkn
/HcvIg2Hvb8nOnDIowVd7Hwq25CDw8yOTJHOvm9B3smbT0cKcdhe5AO1d8kt
6MxsuVpyFQ7T8H9UenCuBcnRBWhjAziMS0d67L+dFhT1qiF9YxSHTdItUN1l
bkX2RWfqmKZw2Dsve41kqVbET1/u2b6Mw5qcHatVbFtRYCg1qZcKj32RPz59
+3krIlhelGGgx2MOC6sMPh9b0blT6x85mfHYAesnOvW/W9FN5pieKg48NiGs
/GipuBUpTHw7Y8uNx/JGNj4caGxFque2SxYP4jETU9fGmwutCJ9lOfXuCB6T
4Dm1+HK3FWksuE1/FcZj2+0E1gSWNvTK+PffT6J4LFbPQ39epg1VFI3a75fG
Y/ZMqo5sam2otSHudZgsHjtbvROsdLkNVf9M/7cmj8fGznq2P7dvQ49Cz1Yh
ZTw2/40n54NnG5qnio9hPonHNmmywqI+tqHfxlNsuafwGM5a1yUpug3dOGVT
qKqCx5hrJ6/lJ7ehyVp76S+qeIxbyvtEdUEbUpdi2hw6g8eO+PPzdNW0oQDq
na/b/+ExyaXcrYnuNvRxyTtvRQ2PKRno96xNtqHknJO55QiPqWXP5lNttqFY
rlE+h7N4TJvrdSQ7bTvqPXrWfJPChq6HPY5wtqOlwbH1a+fw2K3eAlM54XZ0
gWZJO4DCD1Svqqodb0ePW2fL4ijsFLvIr3euHZ1886riDYWfk/1IN/Xb0cZz
naQLFH5zR3jQxrwd3Qr0rOqjfD+o/O9fd/t2xOX/x+YChaNETOL8PNvR7POU
QV+KfQlvV198/tiOfM06zSMo9qfPfDRPjG5HyvvEJF9S/Cu8JHY2N7kdnWHJ
sDtF8b8itfRIRUE7Ss9ARuWUeDXtN8O317QjLz38juBpPNbjuDk62t2OvjJy
PNehxHusPahsebIdPc3fP6Hx/3woS30nb7Qjokb8CRZFSj4+V/qw0nYgfvYV
22+U/OG2zS0FODuQRKKMCzUlv0xm2xrSwh0oF7+gICeFxzhLwkRUj3egPwVh
7sfEKfXzqnbSRL8DLdmdK7MSosR/4l61tXkH2mLeks4UoMRfc+/nU/sOxPHL
ah0o9WfIpPgw7GMHGuVeKTvGjsfMbBsvfo/uQE8wr2zXfXjMqslaMiu5A51q
iG31o9S7R0jMXHNNB4qgdw8dIuEw3/UTDUPdHahlovzF4S0cFmDc+nthsgOl
vRkS5lnBYd/56OyZaTtR8dwg79EJHJb2PP4yH2cn6ud6NyI/iMPyh1TkJIQ7
EcP3L3oLnTis4dvjZc1znSj10L7vlpTz20XD1HpNvxNpTH1ZO1iCw0asEjIt
zTuRpJp3jmMuDtuQ7HV65dmJmlarPHe+4TCcv7NR8MdOJHRL3Fc0EocxLbEo
xUd3IrNDiYv/AnCYYLb6xt+CTjRt6WjN7o7DxLkGOxtqOhGhd9D3iR0OO+7q
mtff3YmM3tzgNb2Dw7RUf7sSNzrRoNF91c9aOMyhnGtb6XgXQtPkOWkWHLZL
pnL1U+9Cip9i/cW2yPD+zPJav2EXov+yL/NSGxl+5NYtvHLuQuq3/hNX9CHD
8dU/Nl0+lPVvQmYlJmTAZH9MSYR1ocDSKG45aTL0/Xw52pLThbyOHLSRbdiD
BxO2t49VdqGJwQ3rhxF7sHHEtN+1swth6pP2o3f2gC1KqVNwswsN+E5tJMzt
QmyXkKETXTdaLGeaepRC6ScH9jdXcnejd7ITu/esd+HCx5ka25PdKPYYtaRN
GwnaarouYFrdaLD5tVGoFwksaCvKDph0ozeZ0v2HJEiwcC4TWT/oRp3iJT/N
6nfA40VccaFbN1J/IN761moHGIo+nGZ9140K6uLDk4jb8GnLLe9OZDd6UXCB
FO6zDUeVrBRzk7qRpq60yyDVNmQ4GGUwFHYjj4+WNMkuRPgv9ayMWV03eskt
8CahlwB1MzLJ6X3dSHJePeGPFAFMRPnFqOe6UdmMSMMf6y34d5chwXinG521
X09rersJTl82jiQz9yDtjjalJz4bgBsYi93l70HdrdESrnrr4M/bwmcg3YM6
C2oOtTWvAt+1v58TzvSgCpf9pi6jy/AzOJmToNuDVJ+xd7Bengelps/Bl271
oGAvI6oa2nEoY3rN+sWuBwW4FuDyAmbRFS2nD6uePWiksOdlgsAYDPiYM2gG
9KBehltH9Q/Ngw2m+zoyrgeZxYqeTN9Yhi3SaaqFtB6En9b7L5Z2DXxPi708
Cz3oa2Z18PF4il56ykkKbe5Bl4evZNRR5qMvWXj3qeEe9IzKe+8+6xZILy1u
qCz3IFJuvkkWHQEKpQacAnC9SNA14+bzMQJoPahdGmXrRS+S7KrLfhKhIyHP
VlmoF10yptKrM92Gu6PfZ/wUelGlmqh9/t42LAkEWw2c60XXEM/m0qcdeG76
YlzOsBfdS8nb1jlKAqbPjyx87vYil5uy2NkfJDjGpmkq6dOLrlJ7m3qG7kKW
rmK3Z2gvai2WrXyD2wP07sjV1u+9aObSfrYq6z0wpdrRc6voRa9H8S/ZxMgw
pTZdV9/Ri87qC6uRX5LhybNOrcP/epGul5DIagcZAtfTz1XR9qEWNpYdJope
qJi0VObU6kOfLmkOT1PO//saKSdD4z70/HCHdAXl/tBPXk0Lut+HVMYNmiPx
eGzQzkucxbcPzSr101tS+lfCFa37l0L70KmK9L92hnjMRoH127tvfSi3sUsj
5hHlfl2P5qcr7UOP34n0v43GY8Vdd000WvpQPY8up1EWHnuVL/Hp1XAfEr4L
YeY1eGz/8z+s5N0+VGZ1r8tgFY+JU7fjCSr9iHSlYJxTjQpbnIhUO6HTjwbl
owQfXKHCcqosnj250Y8yYpAqvwUVdu794vqyaz9yqnvQ8uslFcZgm6sg97Yf
Zb8tu/wmgApr0ntubxfej4zuN0NtDBVmys40PZPTj5RY2va9/kOFHVlrOSZe
0Y++9rA93i2nwiY7Pt+xau9HH6TsWweaqbDfebfjEsb6kZbwSs7RfirMOUKk
f2ylH/WULF5q+keFqXjM8wjhB9Aq8avb0BIVhjPLvmrONoAilE/UGxCpsI+H
zzX1yw6g53M+bqZM1JghnoGZT20A/dyngebYqTHe8SYtE70BFM4VutPJS40N
VXzyDTcbQFrXWRx4DlNjPxLNSjseDaBPj2PXUo5RY7Z+wnsczwbQ6JuLNoES
1Nhxm1kVg/cDyLtr8sxfGWqMcCnTNTByAEW6B1yRV6DGSmTcchp/DSBG65+b
Y4rUmO9+tMKcT7FvRH+2SZka01mhldWppvCFxZMLJ6gxtvYGG7+uAeQa5adw
4iQ11p0T+rPq3wDiTUw2/UpZjws3naDZGEDTXhcNRSjvW7oJCZ2nGURzQ4oF
f45TY5Km07e8DwyisXVLTj05amxZNT0Kjg4i8xmn5B5JaixP4Gn3rsIgOrbv
6E1dEWqKnjjDeebcIFJ8P/s4QpAaUx+lNvDQH0Rmcyv3UripMcbyOv9880G0
XBD+1ZGFGmtJCK7btB9EAm+kFDupqLHwNyb0yi8GUat0x72/m1SY2YPDGs7+
g8gz6JMu6wwVdlRn0iszZhCJtD3V/tVLhU1Lpf5dShlEdGlr2tY1VFgay5Nt
maJBNDNXhj+aS4U9WVI5aVs3iKpetg//+kLJbyv+SXLvIDIcXSuseEvJb3ZN
xvQ0xR5qRSllOyqsKixwQZQwiCbqk+6kUerz41Njyfv0Q6gbd9W4S5YKMzIR
sP7OPYTklKTozzFRYdwrQVSfRIZQUwKLgMYYRb+8o4l7ozSEzv0ubI7MxWPR
R91Ou50fQh60TquvffDY7aK5joeGQ4j/gGs93yWKHrxq7nDzzhDS5+TYL0rR
w+Pzbcx6DkPonjMrHCjDYYmvNX+qvRxCHQMGeUDptw8EC9XlA4aQbOR4ixgz
DpP8IzMkFDuEYv4yPyiTIsPCla/uB34PoZehH2MPsu5BxjQnF23RELrz4tU1
pUQSOHn7ZWzWDiGRCZ8am5ptUOIjXZruGUL1kv3hYewE2Mp6PNU7NYQG6ifH
6s6sQeGl8Vf1m0Oo8aujpEdsDno+YSz4l3YYOat2C6aprIOaZ11BGucwcniy
nBDLRAQ8t9q1eOFhdN39cJX45g5UpGUuBx8fRt5TwpOMPHvwRkvko8+5YdQm
4nGovpoM2iMRYi76w0j2+sZWVAQOY3bfV25lPozeXjcpiFCi6EN2r9sm9sPo
YN9k5eMSih5NXiNe9BxGdUE5o+YqVJjheetPqh+HEQvjZKxBChXGNdAnLxM9
jG41i/DfOECNRbGUWbMVDCPx64K6jk3UmFmiMjVVzTBKS5E8HS5Mgx1GSXFr
XcPoi4/ue7EnNFiCQ1Bn1/owKlr6TV3LSItl07w6NYEfQavrncH5V2gxzlZV
uluMI2gt7NfuYAgt1v0w/etl3hEUJPbi5TA7HWYWHd6jcGIEvRdUi7cm0GF/
rfUTk/8bQR91mFmYZekxQSWmJ8IXRlDCooak4V16bLTBcz/X1RF06Ng3Calq
esxqz1KT4Eh5/o+trrgvA1ZdJ8jp6D6CxD8cAMFMBkz8c8/ojNcIGvyy/v7C
IAM2J6fr2R84go7XdPPpKzJiDncUc0pSR5BxakDi7W5G7FkF/ujrmRH0lPfc
dgQtMya4N/Ff/MoISk6OarsjzYxhJ2tuFBFHELN7mUWuITNGlxIQvMI4iviz
n9WzxjFjIcH8+NuSo0gC0WbtyO3Dft1WHjnxaBRZDV1Sij7PgnUSHsRNz48i
Y60X/wZP78fcjusWUm+Mol8JzMrvr+/H+GzlugR3R5F0pa8wk8t+zGJ4g+Ua
yxj6dalu3C99PzZf+cqzVGYMVTNXHrzMzoZRhcaYRdmPoT2i5LcZLzZMTqaF
T3d5DBlTf8jxv8qO2Z+ODx/YGkNFXbUKnhbsWNoFBw478hg6Iqmgd9eWHZO+
zcYUwDqOvNha91h82THJQH1is/Q44ugYer6UxY4dW2npNno4jjJ+f00lsnJg
vLmtYTfHxlF+Z6TYLsaB4f5rZ33UMYFsB/tx2eycmFKsgr/A6CQKsF6TlM3g
xlYHREdVJ6ZR6h9xpXL2g1hTub58VsUsenxUlbFdjh9j2elkLG6cRzsy7F6p
DwSwh72BQwI5iyhr6yG71ePD2M9LDhUu2sso4vMtm+HMI1iDYdVt0Usr6OGB
ZxhDiRDmlZq3+erMKnrRVNC1mXsUu5/RYSShvob2N3i9nseEsV46/7RnJ9ZR
k7O720r+MYyjkW2dWnQD2cjiH59KEcE8Vcv2OiU20Y1x3jKtTFHs6S4L/dVD
W+hrqn7E9R9i2Ffrtx38wgT0vuHgU6tUcSz4XMPHgyJElMRZcd4oQwLb/zhF
nSLZkUWxpdiPr5IYaOT/zePbQZtxkXxHf0phe3bmJ4xZSWghe5DnaLQ0RkXf
Fim1S0JK7G9D0HsZ7KS2U5kObg91HGbvi/SXxXYGfk9zre6hIgHjiICXcpiG
bU2Q3uYesur4NVrlI4cF7Iyfer29h0YOn5Ikv5XDjvLxv1unIiN/cbaCx0Fy
mPb1dxLtB8iIIwka9b/KYZ9a79sEKZPReabJdo5yOUyuSnCeyZ2MPEKzpC9R
y2Nu11TC1D3J6MU9nKY1rTxWNnHtjIc3Galc2L7tQy+PGVP7f5x5R0ZRHWuB
Rczy2POzO9I1UWT0nxjjohSnPFZb2G33upiMIuUPRO8Tkcc4dNa4/mJk9KFO
P11cTB4z62UtWa8gowdRZ8s1JOSx5a0LrJaNZNR99dTscxl5jFs5J019iIyE
bUKUFpTlMYuKZmOPMTJSnX+kyXhKHksymtvLnKTs/377uoiKPHbG6egVoSUy
2vf2lMctNXnsDV5ty2SN4k/k9Hv3s/JYS9CNL0FbZDQlfyX6k7o8xnfERatm
h4wcEm1TMjXksXvpQUtkMhlVGZ4ratSUx/4HBMWbRA==
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466883980711*^9, 3.4784395692051477`*^9, 
  3.478527833722913*^9, 3.483295400861356*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[yaw0],opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747348585*^9, 3.478377747364773*^9}, {
   3.4783777829637327`*^9, 3.4783777830139933`*^9}, 3.478439369123975*^9, 
   3.478439448088316*^9, 3.4832948175916023`*^9, 3.4832948495604963`*^9, 
   3.4832949003627234`*^9, 3.483294932682908*^9, {3.48329498099467*^9, 
   3.483295003187654*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVWXc8lu8bRaWyZ1YKhTLL+z6vEW4Ushr2V0XLrCSbMhKihLIqDUVESDIy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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246688807664*^9, 3.478439572601288*^9, 
  3.478527837537532*^9, 3.483295403729788*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["yaw to roll", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[yaw0],opticrolloutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747382025*^9, 3.478377747398735*^9}, {
   3.478377783064495*^9, 3.4783777831158953`*^9}, 3.478439369551487*^9, 
   3.4784394486619596`*^9, 3.483294817608303*^9, 3.483294849576889*^9, 
   3.483294900379326*^9, 3.483294932699382*^9, {3.4832949810120373`*^9, 
   3.483295003204591*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHc8lt8bxyOriAolWyqSjGfYnpOIsqkQIaOUJKFQQoqUIjtJmQ17ZWSc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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246689209197*^9, 3.478439576602054*^9, 
  3.478527843415103*^9, 3.483295408104735*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch", "Subsubsection"],

Cell[CellGroupData[{

Cell["pitch to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[pitch0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747415605*^9, 3.478377747431857*^9}, {
   3.478377783164138*^9, 3.478377783214637*^9}, 3.478439369978833*^9, 
   3.478439449303227*^9, 3.483294817624578*^9, 3.483294849593453*^9, 
   3.4832949003959427`*^9, 3.483294932716072*^9, {3.483294981028678*^9, 
   3.4832950032209682`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8198XNj/29rGVlFWkhJS4hSiphCQpKkmyvmkgCi0KFQrJzN47hHvs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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924668926913147`*^9, 3.478439579969301*^9, 
  3.478527847624425*^9, 3.483295411526949*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[pitch0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747448872*^9, 3.478377747464966*^9}, {
   3.478377783265456*^9, 3.478377783314869*^9}, 3.478439370385262*^9, 
   3.478439449899227*^9, 3.4832948176419992`*^9, 3.483294849609953*^9, 
   3.48329490041329*^9, 3.483294932732622*^9, {3.483294981045347*^9, 
   3.483295003238707*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHc8lt8bx5MiO7IjpCjzGZ6HrFNkJJUoSVZFIlHyzayIrIyyJUKiJCFb
Ocfee++9ZVRGSn7n95fX+3Xfz32uc53P9bmuQ+SGg77V7l27dq3v2bXr/38r
zERGdnaWodRewa83o0joyDpF9+HmMmy7+sH5MmbfYJ2ixZVlSJcnJKqFWefr
g/C+sWXYQn5yRgJzK1+11peKZfhIfK1tOZKEhjtts275LUPtZ43IGfOWTq5X
E+syFNl+HuAWQUIm47VL6vTLMKCbQ8AWc6nr0LXinSWIaLfirmL2ek9HTVtZ
gudPvLypgHkf3dV5z3bM/E5sa+EkxF22rS8XtQSfJFGqbTGT5LWOxAkuwVt7
hhi1wkhI/zpJ3YFrCbIOrHuTMDs+F7yhzrIEV4M+Tghi/jLy883C3++QJfS6
4a+XJCTnn3hQefA7ZFAw3puImdL3m2Po1Xc4o5xz58cLElJwz6AR4v0Oh2Rv
X38aSkJG76KFf7J9h2YHr9raYnZpeQpq6L/D/e63LutjLhK9+shhYxGOtyq0
iWBWbNz7G3YvwpZ1s2swhISUBM1XLCIXIXP6vqhfwSSkCtlHkjkWIWn5l5tm
EAmVc+9PoGFahN1n/upLYda0ZzW1oF2Ee3ZOM3NgPifINCD4awEySO46PPQc
59N9T09M1wLsTuvruo/ZTX6jOSRmAVbUqCtHBpJQ/ufBUrdDC5BsYDdW7o/j
oR941Me9AHX5v4SlYC4161NWYFuACyVbQr6Yq1i6i9d25uGKcmeTNubOOy35
98bm4VWL6PuNfiT0Q7w881bKPPQsy/vc6EtC0olpCfoS85CTwTD9sw8+j9cX
MnsOz8Nfz87JBGNWiNn4ZnJwHl4BiQG2mE+/0Bq6xTwP78f4Vh3BbOw5c9B9
aQ6Oyr3QjfbGerMQj32bMwfzX5rcdnpKQqPCaeG/FOfggPb6WRZPEpoWuPDW
lTwHxZyl9aaekNAC70bOP8k5aDP96sg3zOv7tdr3Cc7BQ6YCKnaYmWlm9gvu
zMJxJXi09jEJnRgTC9GomIWWY7deP3xEQmFJqf5RZ2fhpdCMkxluJGRIOKrj
qj4LI+gkelwx88O3TCZKs/CWPklSC3PyYGKIiOQsLB4wZhxzJaEcnriIDMZZ
mPj2+Ct2zO3BoYnldTNwjtsi1cqZhA64uRQuac1A5QMXnnQ/IKHefRuubWAG
Hki/+ucV5tfR/ynlys/A3dUnxc0xH8lzLHUVn4ELNIVB045Ynyt2lXvoZ2D2
yBvP1fskdOnW9Vb+6mk4/XoubsOBhCL0dWY1T09Dwdcxs+gOCX1lHTyTqzwN
Jc6Y8TzBPFF/96MIZRqq8uqtKmMmqb+0/3t0GnqdKU4psMX1S+79lU0/DZ8d
8f7z3oaEWLhu0Qg2TEG2Ke9fbtb4PHq8+H9enIL/YhIUe2+QUGb4AQ8LnSno
pzRWGYi568K7oSa1Kdhz59asMuYjtbWJ78lT0K7s0+ab61jPhWziZlxT8Ieg
gNR1CxLaiY0n1/VOQlGZW2daTHH9mBTpvjGfhML/BG0uG5GQ2UcRC9srk9Dq
P1XOH1ewXrYCHlAuTEJxb0/JEMz7Y4xfNahOQhkDwqtKQxJ63/FnZkNwEjJ+
OmQscRnnV0fVW29wAhqnX7ftvYj1d6KiiObqBPz02tkyX4eEDvlLNjXqTcAn
lHV9Vcx7esJHo7UnYHmBom/VGZwPJ0t6GYUJWJ+rldemTUK3s/ZeNuaZgHxS
P5jGNEkoRlx7JadrHJ72GzrVr0ZCv7maxCz1x+HfYFoOSUUSsmAYCbysMw6f
JBw/GneChGr/rixpqo3DQx455xkxx0xwFhwnjUPqDOvQlDyOL9tEa5l9HM74
hmS+pJDQQ91Fa7e2MXjHxle3mEBCv54yfXihNwaPn6lTBmK43h8KsjzVHoPB
Azcbg4+SUKWN7P0HJ8egwe3WowNHsB70DE4YEsZg38AZCUdREiIfiqs7uH8M
ioUFH3kpjP2wSGI+tWUUuv88zfaCn4RWls9Ifjs/Cs2JgzEuLFg/+x1kT2iN
Qhdm5er3zCTkR4wg54FRmB01/aiHCefvwbDSJ8IolB/19CAwktDZdUfdeI5R
OCiyT7OVDvvTb/mBrYwRuLn7ztmKHSKaVHw68SN+BG67/Dva/4+I3DwaF+ZD
RuDWmOPp5W0ier9j8bf/3gis3/1egfMvEe2hCxQskRuBfEfLbLU3iaiYY9Dc
/eswdAjo3nt5hYguXhK7/eDTMFyHtv7nloloNvLevTsJw1AtsXBVfYmIuPj2
el3zHIYX2wRMJRaJ6J6QTLLS6WH4NdyqZXCGiMSkPCf/NAxBB6GfN9qGiShc
44iNx8AgvMzrYl1UT0SpGQe7ZBsGYZObXfnJOrz+gQOnJooHYfMjH7nKGiIa
H6Ph03k1CI2uRHPCSiIiPB6p5bk6CAnHDZOelhJRc/6rY1+6B+BJZvhOOhu/
LxgWcat6AMbe3f3Y7jMRrfsE7OLPH4BbOWj93SciEjRw6fWMHICnFAJ096UT
kd3yZf/zlwagpe50t28yETEcY5+da+uHpR4V3dphRCQQuu9SfFk/JOw9Syv8
Aq+/vgP1svuhJ9um8HIwERlVLkUXvOiHJ5Mq5JwC8H4sGrWeXeiHsf9uC3B4
4v3UVHxRAP3wy/CAWtIjHK9MidCiTD8sqPi9c9SdiNb+ftjQZ+2Hy4KBeawP
ieh0rF+acFMftFX169S7g7+/68mBzq99UMW5O9rzNo7X+uETv4w+KHHhM1+y
Fc4nxerK0vM+KGw2m1lgjvffpkb/VacP+hXRi/AY4P0rKD5wUOyDi250B+EF
vL9E4shhiT7I9T0t+6Iu3o+9cEEAQx8806x0hqhBRE8Y/926UtsLZ+5GtaRT
iMi48eAB4aJemPgJWJYRiUgu5ASc/dAL38vV3SmQJqJ59v943J73wofmJfbU
o0RU1RFWoebRC2lfFLwrFCaixMgsB6a7vdDe4X4MswARGfIt1rw+3wsjBuXl
uDiIiDjA4GQFeuFV8UOK35iJiDleXFiG0AuFdx+kCNIT0bSZRuO6cC/cG5Av
LklDRGXCN10gey8MfMrU1L9FQK/HPY/47+6FbHF6wwK/COhhSkKr3s8eaNmQ
zjC8SEAXb3314JvsgZ3s0Q57pwhI6lj/sfHOHlj7acbMcZCA6Oc3OtOreuAG
S3rrZjsBjX/k8nqQ3wMDHLuLrtUS0Ne7ZGnlNPzcWd9a/SsBRcte7NsT0wOz
RnT4pDIJyHHV/lmTfw+kC/6P7XQ8Ael+CSJGueLnJ+uGRfwJSPy/9CEz2x6o
nGf/htGOgHbL1waIX+uB6SS55TdqBDS0OUVZOdsD/7Ny07y+KIsKi2nHC5V7
oPsPntyCfTIozEMkxEu6B7b92t7uOkhAd1WBos6hHtj7NyTzkT0Bae8yneZg
64F+X+6AllQCOlzuFjaw0w0boncOqHQT0LZ3jGrKSje8krlOmKYlol6N/Hm7
sW541aefNQmf7xf6zihKezfst44OZfuPiELqVtX+lXdDi1d7tsUniej2c7bl
6i/d0Kuh65CnHAmpn5OOC03phrsaSmvok4joENtZLaPIbug32u33/hYRbbbe
/ins2w1TW+4/cj9FRB1hvm/mHnZDx7N5V5OxPjIvpZzNse6Gc/SSZ1pYiSiA
u3zDzagb+rz6Y/ELn6dl78hb9TP4ezDYc36WgPhMDv7tlOiGbRUDajE1BPRL
8MT7+IPdMDpYPvV2AQE1jxheusXcDae3zn9lTyMgn5thGRvfu+C6Dq1WnA8B
mR/NMkLDXXCwW+Fr4X0CUpxp2hPQ0gVP1YjcZDUlIM4PC1kXURfUFzJw6dYg
oGVbBlP+7C74clSNu1+CgOqlxBkmkrrgleku0zUGAkpZOp33MawLSgnTczt9
k0VPsm5cd/LugmzLfFf5FWWRsaMni4pTF+z67+jRQzvSiCKXULTXqgsane1w
2Rcug/avl1g1X+6CEV50x84ZyaKFgj72aM0ueL5a7ndQsSyqdt34Zi7fBYUb
Ng7K/5FFSUpctseOdcG5GabAm1wE5LFN4l7l7YKVDu9bf4sTkCHUKy9i6IJ7
GB8lscsTENHL3v7pVif8fGOi6Z06Ae0PGimJXuiES176HIfPE9BSlB7Dp8FO
qAFb+2WuEFBjUplheVMnlBk4oM1hTkDpGaSUntJOWKll+XzHioD8C96uLn7u
hF959nAKYv1al3OC3UmdcDJgwNof51Oz6VkQT1gnDMp8kGz0kICO9K73SXl3
QhGzQ4cT3bDeJ6zF1Zw6odbjT1l3HxPQ2PdepytWnXC6rehykxcBoc0z5XaG
nTCypHupFp9XAm0J21OtTujUC9/c9sP7ZZUyjVbohCXwvNiXAAK6xhefnnG8
E1pFi/BnPsfneYR1s4wfv+96TdAsmIB4ZZ9o9DB1QjYZ9d01IQS0fmIlbPFv
B4y5bzu7EEpAXaevj9IsdcDb3zUMWl4QUO6FdmmekQ5IMYlSevCSgMKM1d2l
Wjvgo/kkgT7M96xya0+VdcDWlLVtmjACunDvKPeVnA74YpvgtoSfy7hH3bR7
2wFF1ckVCZiZfemzvSI64NaH0bccmOdfuPyLetYBb+pGPTmD16uLmzub8bAD
juZqX1DD8bxPNY4ts+6A+mJSr//g+H2zG6a7jTrgu+lU5wdBuB6+KsstnumA
O37H76UFEpB6zScvGqUOmO5i8jQC+8vh9kMt3FIdkETfu1fel4B2DYUKSAl2
wPyK8xGB3gQ0PLPL9hRrB+StTZsL8CSgbz/uFxjutENRhdVimUfYP7fH99it
tENDVxWv+64E5Lbvkr7XWDt07FeXO/MfARkdqHoT1d4OfZdql9LvEZD8Ier3
jxXt8OHYHqeAOwTEfTxNsSy3HVZ/6PHvxHr5Reb1737XDglvPZldsJ7aVQO6
FqLaYenX4ixjIwLKPrN1mMa/HZow5giY6BHQi0t37nG7tkN1Pn8RfS0Csjcf
/CZp2w7jm/Ou71HBfmp7junUtXZI11d76iiRgCT/KzUy1G2Hh1kMWzRECYjR
Uzb1jko7fLHxMBxyENBsYOJPT5l2qHonymL/Nq6nSPZTUULt8LdsZuCrOln0
LvFpyMf97dA/8aRci7cs8vn4cwDRtEPOtIDdZD5ZdCPf8nj3jzZoPnTkraCi
DDpZ1vVwYaINOgxLLTxllEFCjZqVu7raYFuEpcYKuyz6113Azl3dBv3XrmcK
BMqiwbFj5pIFbfD1bJl6UJ8sKl6MzTj5vg3SXFJ7lsFIQLEbjFuXY9ughNfH
0crDBOSy20PrTmAb7LpQYroX168hy/cIT/c2yJAlYhCgTUByvGbjkXZtcIo7
4P4unD8O0RbZj6ZtcBe7ltIIzveK9MlH6HwbDDp448dDRwJqUciu7wJt0J3F
x383rjcJmxb3VNk2OH035HAwrh/f2O9SzkJt0OXMrxrFCAJS3joeyrvTCpOj
wC0P7J8xEton55Za4d0PhBMgi4B+Gt9aLRpuhXbH5NefFWJ/KEk2uFbaCkfi
fNs6sR/TLaI9Upmt8NVY1n8/mgnousBI3t/4VljSJjEHu3A9PjrIm/CoFUqf
vczhO05Az1QjBkeVW+GQg4/5pd8ENGqfE5wt1QqtSJfKg//heN60qj4VaIUH
3TzQa9yvpnb41LQ2W+DsD/YVDRYiQk+ZGhoftsAkqYzBXUJE5DyhJW1v2AI5
+PjojooSkcxpn1A2agv8y3/pgow4EcXt3TbQX2uG0U8OK6/JENFD/6XBngfN
MDnZ3cJRhYik5ySAq0EzvPTIijJ8Es/PZ6yT+MnNkOOoIbP8aTz/Mo1amf5o
gmGnq31ydIhIKqRtafxeEzS7+yx9zJCIJpZYLvroNcGf0aLr1VeJ6NUFnS9H
CU3wxVOblngTIqJnr3C+vdwI+T7s9IvcwPNZeO6upbuNcDpYbTbYjohif63c
CD3XCMt3cm8wOhCR3mXpKoJ0I3wvO3jK/T4RfeNODXiw2AA1Elg1lfB8GBMb
zfHbtgF+SyvRU3pCROfeuB3Zc7seyin4RNuEElFYHi1965l62Jm5aCb+koi6
G4Lm4iTr4fPY2PIhPM9abCZkkpfr4K4TNDVyUUTkdLFC4ebDOpj8bq95yGsi
KrLWPShrVAc5Ys9mHEggon+Pura3TtTBelYHnbA3ROSfPlMetl0Ld2uJl7nj
efk1LfO5cp9a6JtmaEHznojG+CJlQ27VwrOf53YbfMDzP+EQh7F2LWQY3b6X
gOftLBNCzypTLdTkrhg+jOfxirxL10XCa6DE8bUjE3h+39c4pP7dqQY+FKjS
3fOFiHTHb4kVGdbA/d8uBAvl4v2wui7o8dfAgGanB6fz8fxpHf+fZ1I1nK9Z
dtAuJiLZx2JGut7V0L7ty7ZiCd5fxGdFXqtqGNYs3yD+Fe8Hle18PlYNNeyD
ZVa+EZF6j864O2M11LsSWtOA7xP+3zsqtRarIGrPSU2CRMTBPx0w8rkKenFP
ySuXEdEVgoPdx5dVsFxzYnZXOd6/5uZ55wdV8PijsSGIWewBIyebfBU8+3v4
uRS+r5xolElQLa2ED54nJqFqIno8XuDJmFgJ25vYha/g+0355smb3V6V8OOo
fuUMZt2jBsfsNSrhfK6n5UYtEb1UGmRUFK+Ehu859B/i+1H3Ravvexkq4ZX4
Iu1lzBaPnXPiGytghuuAdAu+T72L2BVpk1kBp6wZGagNOD/pAc6UFxXQ+/Dn
6ijMsmUcxjSOFTDhrse1VcxOPXHKTQYVsEnaqUSjEZ//9yNCsZQKeLJ9vC8c
8z/aTBorngoYoWT8YQCzOr/8JOF3OfztmHFQsAnni4Cq//aXw/XBKREjzDUv
394DxeXQPie87gVmup++/E9jy+ElydZvZZhPX7KtrHQph8eQ9uw8Zu+8c/b0
RuWQ9MORyNyM88FN5NWRL4cesp6eRzHvcuEsD+IuhwZsF0uomEHfxp2WtTIY
cNm6GmB+rDjAxdFVBlvle3xOYv4WVwov5ZZBMUv5XgXMf/8m2USHl0HrmdDE
Y5gVzZ4d6Hcsg7VLWl/ZMLvC298E9MsgDRPHviUcT6GwrrU5sQw28PaYVWBe
95JlT95fBsfd38SGYqZMcJRMLiNI1+kWqo/Z6fS6pXgLgkpvrbiYMX9518dq
m4lg5o7UvxKcrx903wozghEsl9Djv4GZcDvxxrIdgvNpI/L/cP4d6ryZSboI
Pqq4evgF5kwJ63wnSQSnFHySeTAvPtexKGBEsDFb7XEEPt+O14dvu4ZByHg8
VO8uPn8987mSf3oQMv9uL6/FemkWyWLzYYPQWOu9Hy/ms5MPbzI0l0K9lEgD
E6yv2lSVgpCgUrhjsNodjvWoabOHifNsKbTijP5WWoXrUbLBLJahFDbuRGUO
Yv2WZhnRpfh+g1dLmokrWN/KD4SMj2t8g9wPxtcncT0UUaY/ZdJ+g+k74pIN
iIhyix9cLvL8CpcPPPxng+uJ+Ejxgyr4CityWmNEcL1lAprtiu0SCG7mRtfi
+vxQGZLS7FYC6Re4DMcLcf34Xd40OFECVXYpVBoUEFHKGQHdvo1i6EmR+pGd
R0QJzR9+TjgVQ+G4HFNiDr6fv7ynZUMuhtqm7wf1srCfGsjHLa0WwY/ie+Ou
ZhJRRG+l2m/7Ikgk+wUcxv7DEfc86rF0ERxgfnJ1NI2IQk3152kXC+G+7CNv
n74josDxkZesNoXw1OH77+wTsR+9S50KFy+ELrZ/aPPiieiZ9d0TfNMFMDPZ
8lDfKyLyXNwaFb1ZAPeH1rdmR+B6ySyT+yBSAC9x1v53Hfuv+31/f5nRfGj+
n+TwZDDuP+tchBOm+bBSISr2qi8R/Swc9C49mA/rZhYl1J8S0T33tz3q/Xmw
NXWqc+UREd3ZRXxy/koedG96aPzUCd+vpk8b0fHkwSamrOX7uF/4NBkRS7tz
IcXKUYLVloj259oxPozKhTsdYOmcJfanV54T0oa5cI+LpbOYGREd84r4OsWV
C19efv498Ao+L+v3kfFdX2CbmnPrHT0iOnn+q/3lyC/w8p8/0vnaRNQo16rF
cvkL5A5p9tXH/dHo4KRwFecXOCwWLy8qj/slzeZvj84caChxRmi3NI5/lqlD
LiIHHhjWo/smQkTbzUIZiwY5sKLKZpKNC+c3j/ws5UAOFOXnPhtHR0Tcr7XM
TDqyIWu/kHHHGgElP70mzxmeDeuWn68Pj+H52sZhf6N+Nhyt/1x7sY6Aii94
z3lzZEOzuEc/H3/A9w9qdLlSexZc2E79ZOqB502Bj3E/X2bB6Kf9qi4y+P5H
C50+XsyCJhcbj20ZSaOFufZzN9mzYFOc5sIrMr4PJTadoyZ/hv/0Ij9XPMHz
jP3azjuRz/DReENKZgYBCSkJ5nAlZULzmJNnMhoJSGGfhuUz4UwoSO8RFDhF
QHpddtxrbz5BFpTtP47nmdvJEbWWQp+gm+nvbR4mrA+Hr26dCRkw3DPuzQ4f
7t/Kk1KnD2XA1maG8sN4PslmYB75Ev8RrgInygiJiOq7yS9FBT/C70Zdk854
Phl/e009/HU6tNlgoRzSIqKte95ruwXSoZ3eVtLGBSI6oPoxzTHuA+xvpWqK
GOH5hKnj6jj/B3jhXYlEjjn2294tJv1X7+FYrFHPV3w/N3l3uLSM7z2sOvnB
Ru8u9i9HnXvE2DRIoaWauD7A/YP5Vef+mFR4m77Y7MtjXP99Zb6ePKlw7+NX
bzq9cf9JnVNYiXoHLQddSBn+2N9PnYhviUyBcnsOXw3Hej/Eev0C4EqBJ2zb
sj9GEpH8gD/N54i3UPhljEBQLBHd/q/XKiQ8GdKUtrFk4/ryVNvF+48jGfZ8
KI/Yeovrl+1Y/d2wJNivQqvJjeszZ/CCxxB7EixkEBvdi+u3/oOzzLmXiZDv
kdZ4fQbOz8M3o1/3J8JCCa+Xtz4T0ZpfyNGrwm8gZ9mR7T48Txh+lV7iORQP
1yJKz57F84Kv4SP9DYHXUD7o2hUd7DcFK4353Qfj4JWT2fdF8fwwGyhwMJ//
FZS98z2/G/sT71G7J5F8sfCOfCWbJfavM7Bkwok3BhYfo5f+/7zgdpVJ+xJP
NKR33/Bkwv6X/tM4g8wdBZ3vBFKOYH8cCE7ff4ArEtKvWh/ixP75uNPcWfNo
BPzFJ5TbhFn4INewKyUcJnBeK7aowP3vev3pTxphsEyY/nc9Zsv3Tz6OXn4J
NWZ3fBmwH9Mty3Fw3noBiSF7/Hgx693pXA1ZDIHe1crwB34/YlMVrjEHQ4PT
N1deYO599iHIRPo5NN+sLJzF6wkc4DSuOBcAryvJxM7j+CwSH4tL2PtBhbx4
0mMcf4r03K8XIc+gRXV6gBve31yxQflGpjekHUg2iMD5kNEuDTVr8YKvE12k
ZbE/T6ZfLA4ceQI1Wp8GV+L821WJXTYS9oCNcfpW3Ph810b+LB+97gL/ng4K
7MZ6fLzVGvgzyQlS8uPEfh0hIzqu1KNl4/eg0Fsa1sQ1IhI0X/cU1LKFzNc+
Vi4P4fUiEvMLa29As3Pv2h904N+HRfamRRjCm4YuzwpxP/X5kcbmaq4K1Wyi
Vpxwf/thSaf+KVwF7I4IH2rF++WXvTuVe90QCCuwdt3C+/G4wawCPt8AYTUP
Jf8VEZGt9A36FGlbMMNuwuOI+4vU34Hbe7rvgbKEJt403E9SxuiaqZFOYP6W
Uumzjzh/NUSyzSUX8PlL+JsN3C/CM0xi4g54gKyUJLUpPB8zhvltN7U/AYER
hqflsN7LlK4Sd9V5gYjIYpMqXB8emUs3Y997A/KF9L77AUSkIOITRfJ/BmL8
Npn2eRLRr3C+ugZrP7DiK9Ok8R+el+k+/7HUCgD5Ymr+Lf///6/raZl/Ys+B
jwqbn7AxEYkv9llE0wUDF301ubvYr8fNHMIJ0yHgvPtgsSX2k5bbuycmb7wA
HbWXnF5h/5U6fM4jW/8lSNh3rbZikYACB6K5HquFAWUuHa0dfP+bjRjP1CGF
A6GvFXuCrWWR5nlpbZ7DEWCLz+dP1QsCSqF3GZtgjwSCPeoPL80Q0O6ycrcs
miig+5/1iXperCc3Fs5Hq1Hgofw7g0Ul7B9ko09nxqLBpdEq3xu43wh8T9bk
bosB3Wp5ciz2uH5Sv4+Mo1iQNPvtmr0X1qu5guvnrFfgGWIstMH3FSqfN4dH
YhyQu49+vEjC+m5v+qj94jUwXScMamK9/XjOq8HlGQ/o/BhetmF9fvr3yTnT
/A2wYIWbYu1EtNfEw/+beCIQcXg4QB3E/a5QpOvtm0SwbGotlDGF5wFHO/t7
oUlgstBgkW0Dn1cze4khfTLQTTba4t/B/UyygF7lSTIQjNw9WEVHQs2TNEkM
Dm+B1szZP4JcJBTFpdrKufoWhM0EHL8tQEJmmm47Qg9SwLPwkq6boiT0Pe2H
KdX5Hcg2jrnhRyCh3F6Z4FO/34Gkw4sCRVQS8mC481XXPRWEtTOcyVImIeY7
E/w3n6QBK0/qyb9aJNQZJ6RjT/MeaNYsvjE8R0KvG6+5unq/B6PM7Xle+iQk
KdPZE+r3AVxUCgu4aEJCOquVEV9DP4L3PByP/90lIY7DNJU17BkghVJoTu9I
Qv36Kj/bwzMAfdvovvn/SMgmN+/iXPQnsNFZ6q7yiIQIU6uev/gyQUTjCDXT
k4Q2uWSyduIyAd/I6Veb3iTk75zKyp34GdALfRLmDSShY5dWE/azZwFKkkv8
QhAJBdmFUrn1s8Anmmy7yFASWvGRbj4YngVmxOT4OcNI6FJ8g5VIZxbonxKd
tIogocI8m20xrmyQZJic5R9FQgLN9JFShtngbKAAjVsMCXlOv5MiRWcDYov/
OPUVCU38U6+U780GrRca+kriSEiTZ/yaCl8OaOmRadgTT0Lpsp4/1YxzAJHl
yQBzAgmxah96rh2XA2hp67SbMTtafD18fjAH6E3uVlB7Q0LdLsbFBoJfwIWp
kgcWmBVfbl68avYF6HtocwthTvgQNWf25gsgTl3gccS/310u52U5+gX0Xk7M
0sHr3epv57UVyQXzNJV+UTie+h/3shxu5IK2c8QnqrEkJMPEpv3f21xAdP66
cwTvL0z004jbZC5QDXOzFcX5WFc66+x5NA/caYwTowsmIeNLc6y+t/LA/lcb
mr6+JFRq55f6PC0PyNJJVqs+JiGRZ0dVX87mAcvDM5yxD0jIJ76iK+p4PtDg
+r6WakVCs3nX7762zQdP/zGPN2N96Dbv7En+mA/MI1oE1uRJKGs6/nXaYj5Q
cVSIy2UhIc4dJblP0gXA53mezWXshy48/Q059gWgSJVXhgHPF4OyLjcLPxcA
iwvNWrK4Hk5qc//5tlIAegbMlqu1SSjFIjesglgIgqa//zvtRkL7XPUl6hwL
Qcx6zuHfiSRk93KlrPlLIRj0/j35toyEWj+EXO38VQhms5S4AoZJSK5carWP
UgSs3swJL2+SUEx/vf/IwyLA6ioZmcJORuZM9IXzm0XA9Zu2EP9JMkotZLoQ
RykGBTE5PYcvk9GS1f7ps47FgP1qmoSILRk9RnycnxaKQf8ZrmC2SDKqvnvo
o+mxEiB/5CdL/EcyYjkoqsZqVQI+7+K6YVdBRpdqxftKk0pA9/I/A/YhMnr9
n9Q9h+ES4N6WtnnrNxlNHibSCx/8ClRG3+q18ckhyVZKQuuVr8DMZ/rx4Ek5
5PhIkYJHatDlsEIv5CSHiiVAI7HtK7hUdVj7a6Uc2t2rfnOc5Ru4u/K9c2OM
gs48094K0/kGuPM92b+MyqEXpHMv1f2+gaSC59IPouRQ78jFY78qvoHq9Uvh
tvZySDjYEKbsKgWOPr/Lpw3kkLXiNcPLKqXAj+XDQhJeP3PG/Ptet1LAljPr
PEiUQ+sRlj75+aXAe2RWWVRMDqmq2Ry0/lkKxsRiEl8JyKFny3dzeAgQUMpX
ufM55VDja8cztXYQvNw/f42bVQ5x6jiPunyAwBppbDjvk0MmG+7Ox6ch8ON4
e+8DrRzS1z9Jf5cdAUl5DtdnO2S0/r5cv0oWgRexz9WX/5BR7M7pBMHzCGxd
pRdt3SQjZcOauf/sEFDjFF/mWiej0YwzlOZABO6+/jyd/ZOMfGgbPcU+IDB0
0GwyepWMjhmfb3xcgwCfBaHh2zIZNWa18vRMIaDEucJ7cImM7tEb3JTdUwZU
SYXh7xfJiNOsK9PvcBk4vjrEaLFARgW5V7ZGTpYBvgt0YsrzZGTM1K+hYF4G
eM3LVBXmyOjfdZOXLx6VgYzt/Wp6s2SUXDg8OBtXBj5GbkZ7zpCRJtv1Y6eK
ywB77xe26mkymreaeBDbWwYKKoJaBDGHfLWCq+tloPhFoNazKTIiHZhl1OEq
B7/0bohtTZJRl42tYTK5HDT/ltNzw+yCFpO2LpaDflvUTYtZgMfhu/69ctBl
9/VHxAQZWVY+8KH9VA5WYh841IyT0b6D6y3XGsrBmiZPlxXmjPsuB3PnygFL
5EbbXsw/Dz3KsRSrAL/aiQ4aY2QU9d/O9tfTFeDI9HzC+CgZKTZ6neG6WQGW
t52feGB+6uo7WvWmAjT3azUkjZCRWOs+qUOlFSBSs/uPBOZ6sefODwcrwG1S
3c2MYTKyf8RS0bxVAQQbtqaOYOboDGUV56sE80d7rofj+siX4DB+Il8JsjVu
ZK8P4vx6RbzruVwJAm7JpJ3DnCQTq+wfVgmCT2XEt/WTkY5iGbL5Uglqpsdt
5/rI6JfG3OmznZWg1X7tyWIvGSVcZK+TWqsEJvYft3t7yEjb9MQ5Vu4q4Kx2
bDKjm4x+3L7etkytAktrl1hudeH6dAq43HalCmy5OIvt7iSjled9phGxVeB4
aVFrbysZvYqmGf+vuAr04S7H0kJGp98ev3VloAos0tlH8DVhv8i8OK/wtwr0
M0sc+F1PRjHFrvb8gtUgn1t1KK2WjNSqk378UakGRctTVJFqMlpsq3s4ZFYN
cr1rkTn2i6ih1a3SJ9XAlrfH0BSR0ck5vieJidVgQTZmmuMb1suvU7RPy6rB
9Xg6RZciMorYZet3c7waeNTs+eKdR0aqzGFMGrQ1wNv2/erxbDKa5SkOFTtS
Ayjm2yamGWTcH8YP7NOoAcrhhV4sabh+ZBlj5qxqwD/xD2SxJDKaViQJNPjW
gFj9dwYhr8johaZxYkZaDWgu+LRPLByfv/7TIyG1NUDr71/eykDsX6bp7x3m
asAz6ckWohfWr0271EXGWkB/JsXsyEMyUvhvK4skWQvaaK/HEm3IaNzzMIVT
txbcDZ73LrlKRkFBOkVrdrWgX4I0XaNJRtQYR5We4FrQ4meYnSqD6/ntq7LC
zFqsdwd/elYyCvxcrvGqpRbcp3Vk7R3E/l4yX+e+Ugu65oXuZriT0HA1x3lT
9jpg7LW68VsczxPtiu2qpDqQKnAn5WstCZGGbxgKG9SBB+VNLTKMZDQ4F9hP
41QHPNpHVtPlyMh3LcdsIqIOiHJcfB94iYwINAPjlXl1wM3i33NNezLqZ6a1
Tu2uA+7nzynu8sH+wiu54LdRB54/8W2YjiIjmSMGDja89YChIkAiF+e3V9b9
p86JemB/++fb8XxcL0pvnaWM68H4Gtvv6koyktJq+MPiXg/0Mqf0E9rIyNPs
4J62r/XAD9wvaMP+IWGr7p8zVA/uBugv38F+1vnfHeaIf/Vgkz78s9s29rPg
Es4rJxvAFvHYoRP75VB7zESMwvUGULAsfY4W9xOPFCZB/qcNQJtw5aSLiBxq
Lbl2dKiiAZhwFfl6Yz93q/H+UDrZAPSuivuKn5BDRzo+SifubQRPM0sZwrD/
u8z/odzUagTOjoVqTeflkBDfa825+kZweKiYX91GDpWHCfoTFxrBCXWPQRsH
OWTJ/KbOlakJSEoauTn+J4fSd5J0GXWbQDQDVzDBSw7JTafpSzY1gSNWRSmB
0XJI+8sXs7stzcAooO5OLpJD81KUxLzlZiCetGwZWSWHglPzx7bZWsCGSIGj
TT3eX2yRZYheC3j0npnxe4ccMvWEtp/b8PM41rP3puVQUapVyaZNKxh5I1Nf
zUBBgTfFBgXcWoHYMJvhflYKMhGe+XsysBUE+bTHGXBQ0L/Y26oB6a0g1ejN
q1p+CjodfKeMb6EVaKQlyv0nSUHND+7XKNq1gZ1DJksiuhT0hkCaNfNoAwmC
whYyehR07/uPfd5BbeCbWJ2s4iUKOmDtpNOQ0Qb2nO9bumhCQUbGzk3XvrcB
ur929WF2FDR+8lGHh307+KnPny8bQkGLyTy5zx+1gygir8/FMApa35MT8Sqo
Heg/WL/mF0VBTHXTlwvT28GHLq72U28oiFvSi1pT1A6q0geTO95ScP8+yNNd
2w7Oi9fej3xPQXIX9Xp/TreDF7WtxMUcClL9Ml+4e70dmGRX/C0upCBtrmex
7Hs7wE8l1l+qkIL0nYXchDk7wKOHakJz1RRk2ldkLCvaATycZ36kt1LQbaVL
SqqkDuAkzPv57zAFOcYvHTx3qgNM2W/JnvxDQR47/n+v6XWARAkfgaC3VOR7
XXTI1rwDZG+Q5Cn9eP6o+PbN1b4DxF2V4AgNp6BXR40S/B91gPXE4B+/sygo
xe/H4+igDnAF6k+ZIwr6PBdknhrXAa7LUzfcGiio+Kz4ybz0DtDYs5Uy0ElB
lZ/KhCuLOkBhy7lrz4YoqPf++thYTweQvFHLELeE89vxonxlugOIPb2+kbKB
80uRfLuz1gEiMyvMb9JQ0Xp0lTfr3k5weyL6hhQzFe3aMrcU5OwEJiU115x4
qYjRZOu0lGgn0HkraTwrRkWcpRFHlUidIELYQTdZgYoOCcvS6ZzqBM4K1iFJ
F6jo+NO6aSO9TuDzcHvq0D0qkpu8WWNt3gl0jd0Olb6jIlXNf2kP7TuByGm5
UguCPNJ+H+P/7FEnuL9wicZ4jIr0Gck2EUGdAPiv1pDsqcjErunM27hOwDm0
O/mqBBXdaraWyEnvBA9unY3u+4n1RtjNVFbUCWZtVz3jcL7cwl4vtNR2guXk
/J78AAry+UVtHO7pBFYRB29nnKagEMO2jO/TnSDPkXxgoUEOxRTeCf671gnO
BfIOhITKobf8dPZMe7vAsx+Lf84foKBMj8Tz/JxdgPZX8vULWhRUOKwoe1y0
C5y88Fl+6hYFlZ/sYlMgdYH70+KJko8oqDHZYUXzVBcw1U9olMN67t7D2HZZ
rwu8bk/kWo6joNFbKdmW5l2A5o9OoE0aBc3XqoY9sO8CVd4iflrZFLQm0ef4
9FEX4M97ePlHEQXtCn5g8DKoC1hp0ulnl1EQ4zKLXGJcFxA8eKUxv5aCDn1R
W/tW1AXETh2xPdRFQce4hroaa7vAy0yd+qx+CiI5O+cP9ODf70koXxqhIC2l
DOffa11gTiDQPGEO6z1e02jf3m7w8qpU4WGsF5OdUQUezm7wmGwg6PoD57eC
a0uO1A0EteX35WxR0PbObmd/tW5Aqv8cvfIP+4nyys8B/W4Q9lY7nZWWit7l
1X9/+qAbfFqrz9tgpKL+tCdjrbndYMSeYa6Wj4o0guZq7eR7QES3o8miHBW1
13ZrIK0e0MHMTiuF9WSxt7L8gFEPeMKu63VLiYrcHid8LXbpARuMtyRbTlFR
1j2DrH3FPSB+vvyTz3kq4r/8LTpFuRd4d86kyd+morSX6Zybur0gcD9tpt8d
rL/m6JdnTXuBTQ18PIb1dEHL8fmPR70gUXRff+F/VDTobb5PM6QXOFAQjaIr
Fdki3WexCb3gmMeiSqMHFfmcEH9yEvaCKBbjTmkfKuJ4yPk3vKUXGFIHfu32
p6I3OTSuMyO9II59p/vXcyoqlhx0DNnVB/66W6WBCCrSul23PLa/D7im5WYn
x1BRZ0q+HUWkD4TfHdsjH09Fy4Ivbw2e6gOdC98lD6RRkYfx4wlZ/T4gxcze
Z5+B6y/6joX3jT6wyCF0+0gOFUV3GA11O/aB1TPFAqcLqejIfk1jCe8+EGF4
T2u8lIpydMk9j8L7gNca5TNvNRWBAOFLbW/7gE9tfsq+ZipqrGJpO5LbB9Re
Jx0b7qYi491/zrlU9oFK7rzxzlEqmlGdrW/o7AN3ZUcNTi5SkZN7l5bQVB9I
Gc059uo3Fe0uLK90XOsDkTalIvEM8ij01+dT1Xv7wdnTZjkegvJIgBhfysfd
D5T09LRuy8uj9LuBSnfF+kGmqvfTvSbySD7duRBR+4HkWAqPc4w8qpy2pHBq
9QNZgZo3r04poMBaSUd9w36QMd1+cVe3PNJL/5H5wqofXLv7u2rFQR5xBxUt
NDv1A2p42K14/P2hu57HWHz6wefj5Sy8bPIo5YKW1dnwfnC/xPul5xI+TyJr
ckByPyhlUpcPaqciwoGu4ZrsfhCGbtJ4F2H/+xV3kK6sHyyTGwKuJVPR1+4b
Rqdb+8Hmu46gG0FU9LTweOTTkX7wizTYzO5MRWweBaw72/2gXij4wBddKuo2
fXxWhWUAxBtIPGunUtFroOHvLjAABjxNlgeEqOiGCHNVkeQAuBxl4CZLT0XH
aDtoNhUHwLUAQfm5BQpamoxVpeoMANhYRHnTSEG51RbuTlcHwDu5mxoVqdjP
3osX5tweAMIz+mernSjoVODSrxXnAUD2opwsPUpB++zyiLJ+A0B/6vo5Hh45
1HzOw/5u1ADoTv43MYj7fYSs+seP7wZAuGJ8YMxlCjJmZ5ydyx0Ao7+Y2PIf
4375s/XIsUrMsXrhYq8oaLoz+vqtDhzvtsMbxUwKysg3S0gZHwBWK9ThL98o
6EHM0YHx1QHQyr55aG89BSm6LfKI0AyC9+aceftwP9pl8uWS+f5BkBh0xPnM
IAVVq7i9jBcaBBb66jlHJigoSOhU84DMIJB2ScofmMX+Q7OPiV91EKSkw7T4
7xTEO9GsZXRuELRISl8MXqWg4cpInyiTQdB3eVdd5S8KepdqUtZ5ZxDYmGnW
X8H9zM5f9B+H+yAwUa/TvPwb+53tvOLFwEFwo3HYpRb71ebZbOfQ2EHw+qp1
YhHuz6XSLrlN7wcBV7fFM5m/uD+wgVWmwkFwvtqzVQKzzupeGZ2aQbB9hP90
Fn5/f0ejrX/3IFhc9h4oxd/ryQ1Pq54aBGziBp2X8HoJUcaTe9YGgcv6/WR7
HI+li4iI+p4h8OIGbTPdGgVJGM+aeh0YAsOWxQVc2E9XlD6/goeHwHa0rcpL
7Lf5gg97tolDoNr3uZzd/P/nB2VO5VNDYOmbanrkFAWpjdFedNMbApL5Xs0b
2L8ZKuqDC82HQKqWr/nDPgpqTXlZv24/BJSUa3UX2ygoyteInvJ4CBh+FTxw
rA77+W2h0w+Ch0ABU/fsVCkFHdaZ9sx+PQSeOqT8rMLz0Kzkp2/LH4fAUSmf
ZsUU3O9YnLakS4bAWF1JjTWev5yWFeXt6ofA1+t6Nr3u+LzbaJzS+4YA4/sn
qMEUn/eX2qzZ2SHwXIn71xYRn3dE6HexzSFgOtsamTMhh4IeGkpY0Q+DJrVf
MALP8wZGgtZvuYdBc0lOtf66HOJefbE78ugwoDdPWt19Cs8vAXsSfOWGgX5c
uH2CPQXFHXY54aI+DNKd1Jk7QinIrGSh00Z/GFg7Zl3gTcf6vWR+79r1YWAS
Fy87j+e3icV2pnP3hkFB1LHBN+0UlPpMM031yTAYM/2eT4/1d/tQsRohZBhc
uKrll4b1JVEgPSwSPwyKNRqX+nE/+34hyfVAxjC45AUtJ3D/yprl5NpbMgws
fdbUVrmoyNHLP2u9bhjY0RtQjwvj/sL/9+xs7zAQS27KSDtORRs5DjN9M8Ng
rUydy5uE/XzS8NC3vSNgZiJNMlINzz+P6osyOUfAW0OHc9NnqIiGW/VyougI
iDY4HVOvh+dFraNB3qdGwN4voPCOKRVpj8aI/6c3AnLteAfkblIRkytzxS3z
EfDG55tkOu53L9J//j7zaARwHnL+nOaI5yd160iloBGwmFmgR8F+xTXYT5CO
GwHKWdzCbu5U1Ot0vvFQ+gjgyuMyd35CRa9Yyq33F40ABevv9dLeeN5KpdDu
rh0BdnXvEuN9qUgIfEj42T0CsjU5E6oDqGi8R0BxamoE7Glt2EnD/phy70VX
968RYKs34X4ylIq+7HmqMEkzCgIv6p4IeYnnxTYlOlOGUWAyp1YREk5FD+PX
Orr2j4JxoSObqpFU1GPzOek87yj4HJf+41UUFSlQbRxqhEbB2KXji/HROL7d
oionxUeB72oDlxrun3+aBxmLZEaBqiPPLU/MJnFRvUTqKLj8qsRQD/M3a73U
dJVRoGTJEJyGf39IjtFJVGMU3P7xzdIVf99zV+Wp17qjYPfFz3r5uD+PNT5i
47o0Cu72qf/TCaMitVj5oeBro4ChP1ZQCO8nxWo1ne7mKFiJvxZ/APf3vaSP
Lk9sR8HjlNv0u3B+bv2z1Ny8PwqE+FntMnE+a+oPcd53HQV3YvIbOnH+j0X3
js15joJ0zaUJBjx/BN4M+3zDfxT8+fhwMOs6FS3I6j4aCB0FD2ntj7RdpCLd
v3vPXooeBa/O3ov4pkxFmbWQtylhFORXputL4X7CFuk6rZE6CmLB5CshrN97
18m5pZ9GgWfc1YoMfJ9ol/7uJZ+H8/Vi7Z+SCgWRt1IvZH0dBXKp8xY/sP4j
qi0Ej1eOglOaJgHex3D/C+NfSGrA39O8I9pzmYqumHcW8neMgnjlAdr7LlRU
KBniG94/CphCn4IOnC/+Ta1LzOOjgF0trUTkExW5V9IcfjY3Co7v4X0TWI7z
/W9SJXF1FKSJzD690ENFSL72asnvUVD2o82FZZ6Kbt7/+F83zRjoOk9dp/9D
RXQfQ16uMoyBWsksmX94nvgwef8TM8cY2Cd7VX6JXR7pHrpcJ84/BgKsF0zy
5OTR8hWFKbXDY+A+DdnFUlkehb08SGMmMQb8+rj5z2jLI0rDPwFX0hhwfvi9
weySPOrdM64QoTgGZIoUJBQt5JGgy/t79TpjQOeMxgcaZ3n03owySr0zBs7b
NwCeJHl0Nob378UHY0Cp4LvpTro8Wmr7w3PXfQx8vT3vkp0rj8ga5RfePh8D
F5OvWT2tkUelkhcgW8YYQF8Bq9SCPOravJ0wuzgGrFS5krylFJALSbeYdm0M
3EXx1ipyCojfTrb70PYYkPzVszimpIAsRtZYLrOMA4v26MUlHQW0WPX0UZn0
OFD/7Rcte1sB7Q5/bfLKfhzILCroDr1RQLLSrfy6K+Mgd88nxh26E8j+RGLU
4MY46F9kCEbMJ1Cmxj2OuzvjIC9Cd8Wd4wSSMtvPGMI6AU5L+K6NCp5AEqF6
v1ukJoDDaaN1a7kT6Mhqa4+BzQToUwrYemZxAvHmtUVcG58ArhfVXHLzTqBd
Kh2sdzonQUJGzrzaFUXkld/YGz84CVw9jB6EmCii3YTq5NbJSWCVm9DQfV0R
0YoWUalrk6A2VD7C1E4R0TG8MaPhngJh8o33TnopIpYu28zoK1NAUlJYRy5d
EYWct3SpN58CGpwvtk58VkSstaZq29ZTgH8P+6xCriLaX6LXfcNlClh159kL
lyoiziTqP+nYKbC3N1fOp00RRfITai2SpsAde42Dat2KiDvieFj4hykQ9TtU
8me/IuLxExD7XTQF2v2dMo5PKiL+u7vPV/ZPAdITurKiNUUUN/2HZ2N8Chya
KRSd+K2IBCzWxo4vTIHLaXetl7cVkaDB7H+hf6ZAzsUX/yXtVUIJjWOgnHYa
DLY071dlUEKHNAcY1pimgRVX8WQ6sxJ6Azs7xDmnQTbNys4omxISPtEcbyww
DdKB6IFeDiWUlFNjHXxkGpBdD3L7cimhw1JlRCQ1Db6dXmoa5lFCb98V//kh
Nw3ON8iId/ApoSNCuVVHVabBvisfL+gdVELvYj6FGmlMAy6Tmw6qAkpIjCPt
6vNz08BAvarhMebU54mipZenAcu9o39m8fvie199XzGdBhrHyf6a/Ero/ePw
AtFb0+Bh/dves3i9Y5tBXob200Bpx+Xvcxzfh/u+ZwMeToOhpijtG0xKSGLh
CdfXx9Ngf8JT66pdSuijpevIku80yB2myRhbUURSw44fREKngfP5A5/pehXR
pyt2Dy5FTwORhLHs2gxFJNNmpeL3ZhqUq8A3lhqK6LOOOX1x2jSA+wiugkAR
ESqN2hY/T4MaawXS8SZFlKWiHydUiN//4BQ3zamEiAVnrfTRNLh62+n5orYS
yiFoyD6rnQYnjM/mZz5QQqR01d8FrdPgupRTESFWCX0RVaiY750Gdaz+b++V
KCG5eGKw4Ng0eHf8XVjkgBIiO3rRScxNg1vEs9daf+Pfa7U9oa5Og2dKhY8V
eZQRYfWe4wWaGfCi/KUo20VlJKWRdcVLZAb8d+pKrUGtMpLk39UWfHwG8LTd
3n9+VhlJLF/QeUWcAbteP0OvGVTQsdhl5S+nZkBT7GHvCT0VJG4P8uGZGXB2
3lqx9qEKElMPlW28OAN+h9XJXY9XQUd5R973Xp0BxUzPo2vLVdCR7zKHp67j
9xn2tKpMqCDR8sdxqzYz4H3mNKvebxV0OLqZ89/9GQDNfzJG7FJFInaHQhjd
ZoC24O6nDvi58Cl7ep6nM6CTsX+lcFYFCXGXeooGzgA6J7XNyg4VdGiBZUs2
DMe3WOHAWaqCBJHpA+VXM6C0nfPDjQ8qSCDy06J28gzQNZcxNolSQQdtt60u
p88AB4PQjePPVBA/ODdyPQfHcycup/g/FcTHGW9kXzwD8o7PX561VkG8c4tt
buUzgGxxxNDvmgriKVU+61c/A06WHQy/i/PBHR5UGd4+AzJvsA06aaogztuD
Kon9M4BPhS3CXUUFHVCRKsgYnwFBydeCLCkqiIPDg1A0PwNsx3nDuWVU0P6Z
hg9VP2bARkfSkru4CmL7elC0fWsGsPWaDnmJqCDWl3deD++eBVKJvKK8AiqI
5VYJ1wLjLKg1EU0l8KggZiWm0A2OWaDvn3YQcqggpv3X9u05OAtaVh6VFbKq
IMapdK/9orPAsz1alJNJBTEUb20JSM6CnU6BhVp6FbQvVMfpOHkWXHwfndey
RwXRW776TlGaBeMM9T9EdqsguhPzt9TUZ0Ed03ZN0Y4y2suqOHr+7Cx4b9yz
8XJbGe2ZCLh6zWAW/NhYbnr3RxnRFva1W1+bBZkLLiyrv5XR7uDjuk43Z8HQ
R/dxh01lRHPDtcrzzix4FHWi69CGMtolX6ca/GAWqBQawq01ZbTDxFcY6z4L
7sg/K9+F+d/obWKqN44fOp2U+aWMtvMK03Oez4KI7o4Oz5/K6G/gviMwHD9/
fUJn/Ycy+mNuFN8QNwt07bsSgjBvyb3n7n07Cy68qVk7hfk3w2bo5MdZYCrG
FMOJeXNYi2H1yyww2BxY3o1540v00+2SWVC25v+MCfO6/8wfhspZUPoj+a8U
5jVT+f+4G2eBxwsP9luYf5H8lg53zoLdjitReZh/0vdYyw7OgrYBSyd+HN+P
QbExpclZkMe1NyUcc4jPzeJvC7MAhIQd5cb7OS6VGA5+zoK+4eKq95grOwbt
yrZmQaWlSZcO3r+FO5+m+u45kHfS+/MfzH8PGwpVMcyBsbL3hcXryii6PmxT
k30OvNmkNfPD+WzmY/6oIzwH9rMqGmvh/NuWafs0is+BadqB7BNb+Pxsnpme
l50D921UUuXxeSkX/mPTV50DzFtiny7h8/xguOp01WQO6K/2Xd6Hz//0P+nz
AzfnALvZ4wBdWhU0+s5W3PTOHOD4+d02FuuFe22iz8JtDvwTtWbTxXryCe9W
vR0zB5ws8z1YWFSQRWvJPudOHL/P84xmPhX013lzbHNgDniKly17HlRB0UKU
EreJObCgfu+BgqAKarbPvPv4xxxo+7Y3NV9YBSmzJLU/2z8P4hNfzC7g+uDR
8X0doTsP+G7YKAvJ4/cr9Ag5lfMghLOgabeRCvrYm3+lu3EebIN1b0NjFeT/
XeDJVuc8qPPW/ZNhooLUeOaa1KbmQXX+sfnr11VQvq3XnY69C8C+jJt13lYF
JbDnpP7SXACnRdpprB+rIHvzA4LydQvgfw2UeTyVWxfHTUVuJDeUJFxcDYZu
maKznoOnFKFJKsKNopuoaCQqDcgQl16SmagUKcm4QkrdpERJURKKOPs5SiHn
3X9+P2vtvdfvt9ZeQ/obF9fm0f833jqt8ukgaNhcYP8aX4G+7bGd824PgbzB
Xq26NB56qJkrXagYgoHwAmXbTB66uHfbSdUNQZPPH8P/ZfPQ9tOye1+eD4Hz
sJ5VWz4PdUl7wt3hITiUvUa77xYPu2W0V69bNAzLIwJcRQ08dDUrKwnPGoaM
fONQ4RAPNx7z/DJaMAz6Uqaq/oSHdtWymv8UD8OflcaGX4Q8XG7jFrMOh6Hi
6/E7nT94ONtJwle9cxiuuAwVowTgl6W6M95OF4BbToCYlzLgFbuA+iBbAcTV
TUxMWALWZ7efCbMXAKeTdSAOAN+PW62OchLAlmk8Ry0rQNXrSk0ZLgI4VWEu
YlYBnp9e8eqJD2WjuKs+6wADnk4Z0IwQgIuVx4H13jSu41+4OFoAr/4NvFq/
C7Ag5LW/6QUBlF/fpL1sN2C3/rUR+2QBeHTvOyrrD7gpxmnyUIEA9p9isy4c
BlzueGlmU6MA5lUWZAxGAjpfkXr5+qkAjC42ampHAx4Q+SV9fC6AD12Syc6x
gNdvMnN/tgugChojriUAqiv0amt/EUCR68sk+VR6n49jn8GQAAa2zf6lnAa4
GcsKzDkBJH/9bjY7AzAuIMrAcUwAhvMOPZbMAZR8bmR2VJaAafcsrcBrgBoL
UsbC5Qm8qszWMisEtDwhWRWrSKCi+HAguQF4cEkbP1eVAEnfmMG/BRgfAVJF
6gRqNJV0X5UA3vyQ31CuRSB5YOp69zuA/ReO2TUvJGDRW+hkUwYo9aVHrsOA
gM/mFsf0e4CaVg7Nn/4iYHTr9erP5YC8lLvxAhMC4Xmb5mlWAm7lNDaNL6fx
8JJotoq+vyZSZSoQ6EhrgE3VgAlZwnYFawLDC97dcagBLBpzTZ27igDrpWdn
hID/rW/YrmtH809vN/hB2XSW7vMBBwLWaR0VyfcBs1pPWxevJyBjkL1FsxZw
+sVPdw46E3DvLZWKpnzIhdWz3Erg0P3dYW8od8/JTRHfTiCo5Ppa6TpA+w4p
uYeelPVTMhQo3031Cj3vTUDVc2yDkOZrba8n63wJXNyo9OYa5ej52l4qfgR8
dU0WmlD+8f5U29sAArr9XwuiaT07sj7aZgVSPenvFAppvU07rCt2HSawY7M7
G0P1metk6+sHE3gW9MhwIdWf0yuRwYUSOGY898Rh6pd8/t+KZacITBW/7uNP
/TziWxsecpaAnZbNX5LU/56FWqNWUQRiyYo6Hdofh8ETvjKxBLLXsP0PigHv
FX7oeBpPQPFjglsT7b+2P98hIYnA/SzPvdoFgLFGmeiSQiBjxh6Smw04RsSW
qqfRuKsk6F4G9C7xyP2YSeB4yYCfbyJgcyCqFOQSmLJbKVztPKCFiUbk3gIC
K5tmDjwMA8wbDZ1YWkggXWG+Wel+QIV7XXt/FtH3Oz/moAfgsaPwofo2nQe5
ue6vbAF7LdI3hJcRKPL8V7lYF9Dp1+SD1ZUEtl9G7UK6Pyqqt5vNQAKCqWui
ZD3p/gmrvvqyjkBOXKCxbg4PL/DV56U8JPB+35H5oYqAExLHY92fECgtubvn
nT3gzvp34jrPCLT9TJojeRDw+ekVgV9eEJDP2R1/JIn+h1WXe2+2EWie+Y/X
bepXnswvl6A3BJY99pi7vxFw5mPXJ8s7CYBMosPtTsDgqMoVYt0E6ku2es3j
APvs1YoefCLQeS7MVk6CwfXywVpRnwnUpl4LCZZlUO+ChbQyIZDoemeLiiqD
LUnlzYvEOOCvWGwnb8Igz0XVmkhyAI6/NaZZMpg/5+idUmkO5kxTkP7dmsHj
qeYp/BkcJLcKEqodGVyYVbZjszoHVi6G64p9GEzcMbtNTYuDtmcuL0f2Miim
c9i2W4cDNcvV+TZBDLZeMdX30+dAZCqzU/0kg2GFpd9PWnKgOGswLeAyQ/fd
orhkhgP1fuaxfy6DFy+nLyiy4aDBofDI00IGs5Rm1TXYcqDnk3Mpo5TBG9Hn
XN/Zc/D5SHWQNDJYPuXXN6ETB3Hnrvgueszgg5B9sbKbOLg3Ighc1cpg87dP
eppbOFDtyjS5/YHBt35ba03dOPCQ2GcvJmCw/1PTNgdPDvJiHtvqifNR6Gb9
zcub5k9f4LREhY+TrXdjjvlyUBXVJxdgykdZh8V68X4cnOm49NvuYD4qN2Tc
z9/HwaLIHcq2+/ioxVPaVhPEgZv0xourLfhoUBox0nqEg2/Nhs4xWnw0N5iM
HgzhwFrN0GFckY82efv/lDzJQd8Rl1gizUcn9T6cc4aDipzSaWkiBl2Ttm01
iuRArGzJoMpPBn3km4UrYzhY0uvCvhEyGHjGJtotngP/D1/F44cZDJ0s0w1M
4qBnw+5a6UEGIw/qY2QKByqpLQ9nfWYwaShzS2YaB+ujtD+n9lJ/dyoL72Zx
8PfWqulRPQwWdkaeb8rjwGjsykRTN4NlziKdT1c5aDbXFHel/tU3HagZv8FB
jZEe9+d76u/KfhfFEg4ungtOWNjFYEe1K6d3lwO/sKcabp0M9po8j4IKDoaI
3Ni9dwxyN1gd5xoOnBIbvS0pT+qWV++po+e3ffz7/VsGp6UbuJx6yIFzu/Pp
LMqzVLJJ8hMOHLIn3oRS1ohViSp6RvsxxaItiPJi6fPaD1s4mGatt+IkZbNQ
sep3rzgwDpFTy6ZsMxq4eaSDA6+Wk+VtlB39Pwtk33Mg1xcXP5e+v7XPLVKz
h4OSfp/VAZR3ur/4w6yfA0bWvaCF8v5XK6scBjnobOlNtaF6jjtWOHsLOKjd
5b6wlnLkQ0PBsRGqt/BcgB3Vnwg5EfE/OJiSczK7i/J1w+jKGjEheKWundCh
/pVdEXdukxKCT5Ooq41y3fyDw4MyQvBfUqsXR/1+M8NdS3Um5baDgjm0HzIC
o3OBmkKo/HH10vE+6odPrmaUjhDs0/sSd/YzOP/9nIrMBULosyjv2kD7a9Is
MdS0RAiuG5w2rBhg0Mr20NlPxkLoPiUvbk7nwQEHNCbMhdCaED/F/CvVb+ZR
rsgTwpO18YtXDDHoXfRywwIrIbT7KrMsnaf2qdE3jpmMwGTNy5c6dJ4VnyqM
SOp+AxwdDGVj+RhiUTvZuuA7DAdGX4n5yseDv+SkN6qNQvWyQrf6lVaYuevs
y7l//IBb+r+vmZdvRfflf+fn6PyErXvrfs2SscYZ/tes6pTGQM7iW/MLT2us
sSmrKlUdh6GzKXWr66xx0s/dxFl+AjRD7nz3VLdBCekXyYt+TYAsniJ4yAZN
bffXrhGbhPUDm+0fvLbB8bfX+5W4SZB8orrSeSmLNnsexa39PgkkL6DyyzIW
Y8Y/mp0em4QZEnZLQ01Y1FKdGzEiIQLhsUitfHMWbTdHLGj5XQSNaZrSY8Bi
4nPv3XHGInhSqdZ/2Z5Fwwb1QdkjIvjxuU2q15vFw5uW/2sVIoLe2cGRR3ex
WNuzyfLoCRF0lFxQmOHLorNk9PnPESK42PObutkeFoOZ8cWPUkSQ67qYF7mf
xcbyV36nK0VwMzoz3iCURcU1QqUqFEHPKdn5dWEsurbLV4/Ui6BItePa5pMs
CkZZea+nIvCaWdwQdppFZePbN6w6aX1pmuItUSx61D9zPtotAiOFe3G7olks
2DAwWdwrgp2StzUmYli03K/lqDksAjO/F3ydeBbPiPNGXYQiONsz8uJeAovN
cVvS40ZFMK3rsJdDIouqGkGrHo3T+zvdvncnsbjjZtywSCSCMzuzzx36H4v/
B64duhI=
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466893169702*^9, 3.478439584040698*^9, 
  3.478527853531859*^9, 3.483295416095357*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[pitch0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747481554*^9, 3.4783777474986877`*^9}, {
   3.478377783365024*^9, 3.478377783415765*^9}, 3.478439370800365*^9, 
   3.478439451912611*^9, 3.483294817657813*^9, 3.4832948496273527`*^9, 
   3.483294900429641*^9, 3.4832949327494783`*^9, {3.483294981061754*^9, 
   3.483295003254786*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmXc8lt8bx0kZoWRHhEplPo/nseMYhewVkkKlYaX42kQiGpSRKCIiMzur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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466893726523*^9, 3.4784395873797083`*^9, 
  3.478527858601152*^9, 3.483295419824141*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to yaw", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[pitch0],opticyawoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747515319*^9, 3.4783777475324507`*^9}, {
   3.478377783465704*^9, 3.478377783515093*^9}, 3.478439371272708*^9, 
   3.478439451959631*^9, 3.483294817674592*^9, 3.4832948496436872`*^9, 
   3.4832949004447327`*^9, 3.483294932765964*^9, {3.483294981078209*^9, 
   3.483295003271185*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c81d8bN9KiYSYiFJXNvZ9rlROREoWQijRQJCE7MyXKzgglfYkyys4+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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466894206287*^9, 3.478439590876416*^9, 
  3.478527863097582*^9, 3.483295422773348*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[pitch0],opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747549424*^9, 3.4783777475657187`*^9}, {
   3.478377783565462*^9, 3.4783777836155653`*^9}, 3.478439371700444*^9, 
   3.478439452010869*^9, 3.4832948176922693`*^9, 3.483294849660122*^9, 
   3.483294900463628*^9, 3.4832949327824993`*^9, {3.483294981095915*^9, 
   3.483295003287939*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c8le8bNg8lI3tmlFGRlZLiSYkoKUX2KFTK+KqEKFTSki0hlMge2eF+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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466894766156*^9, 3.478439594166936*^9, 
  3.478527867103322*^9, 3.483295425793601*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["pitch to roll", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[pitch0],opticrolloutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747582581*^9, 3.478377747599025*^9}, {
   3.4783777836658583`*^9, 3.478377783717371*^9}, 3.47843937221796*^9, 
   3.478439452059874*^9, 3.4832948177084503`*^9, 3.483294849677918*^9, 
   3.483294900480381*^9, 3.483294932799868*^9, {3.483294981112485*^9, 
   3.48329500330494*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHc4ll8cxq1IMjLKiCgt653IyEFDaaGSJGRFQyohFGWUhERkZkUR2dnn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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466895240679*^9, 3.478439598855193*^9, 
  3.478527872246492*^9, 3.4832954297579947`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll", "Subsubsection"],

Cell[CellGroupData[{

Cell["roll to x", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[roll0],opticxoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747615584*^9, 3.478377747632732*^9}, {
   3.478377783765902*^9, 3.478377783817721*^9}, 3.4784393726902533`*^9, 
   3.478439452110503*^9, 3.483294817725257*^9, 3.483294849694532*^9, 
   3.483294900496212*^9, 3.4832949328164787`*^9, {3.4832949811291027`*^9, 
   3.4832950033266068`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnc4l98bx42GSkZWyKyIiM8y40RGiZIkIUTDCl8kCtlJki2kyCp7ZYVz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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466900451111*^9, 3.4784396034966793`*^9, 
  3.4785278785183496`*^9, 3.4832954343198423`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to y", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[roll0],opticyoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774764889*^9, 3.478377747666337*^9}, {
   3.478377783866334*^9, 3.4783777839181623`*^9}, 3.4784393731743793`*^9, 
   3.478439452160078*^9, 3.483294817742272*^9, 3.48329484971093*^9, 
   3.483294900513628*^9, 3.483294932833027*^9, {3.483294981145576*^9, 
   3.4832950033382597`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVV3c81d8bt6897sW1RUlFohAVJySFImmhNIhU8pUyE5VQ9swoo5IdklF0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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924669043095417`*^9, 3.478439607469988*^9, 
  3.478527883070868*^9, 3.4832954377135887`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to z", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[roll0],opticzoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747682744*^9, 3.478377747698906*^9}, {
   3.478377783966734*^9, 3.478377784018618*^9}, 3.478439373759067*^9, 
   3.478439452210371*^9, 3.483294817758349*^9, 3.483294849727586*^9, 
   3.4832949005301228`*^9, 3.483294932849366*^9, {3.483294981162251*^9, 
   3.483295003354651*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fx1EpIyQrIoQId7i4fJUTKYUiSSpFRamQUDIqq5KMyMgMkey9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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466908370902*^9, 3.478439611949328*^9, 
  3.478527888911063*^9, 3.483295441770447*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to yaw", "Text"],

Cell[CellGroupData[{

Cell["plotTFf[eom2,makefinputvector[roll0],opticyawoutput,0.1,100]", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.478377747715989*^9, 3.4783777477322283`*^9}, {
   3.4783777840668993`*^9, 3.478377784119688*^9}, 3.478439374242858*^9, 
   3.478439452260655*^9, 3.483294817775258*^9, 3.483294849744019*^9, 
   3.483294900546557*^9, 3.483294932866798*^9, {3.4832949811796494`*^9, 
   3.4832950033721323`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c4lm8bx43SQEZIQkmREp79GLmSjIySJEWohKyEjMpIiF8oO1tSISEr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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -40.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.39246691264824*^9, 3.47843961629326*^9, 
  3.478527894924163*^9, 3.4832954463801403`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to pitch", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[roll0],opticpitchoutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.47837774774975*^9, 3.4783777477661333`*^9}, {
   3.4783777841675253`*^9, 3.478377784222093*^9}, 3.478439374805045*^9, 
   3.478439452310508*^9, 3.483294817791958*^9, 3.4832948497609167`*^9, 
   3.483294900562929*^9, 3.483294932883348*^9, {3.483294981195281*^9, 
   3.4832950033883*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHdcjl0YxysUQnsvUZJUz6inYRxU0kAqSVsopSU0aaOMtGiTRNp7j3Pa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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, -35.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3924669172847557`*^9, 3.478439620341316*^9, 
  3.478527901182166*^9, 3.483295450826886*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["roll to roll", "Text"],

Cell[CellGroupData[{

Cell["\<\
plotTFf[eom2,makefinputvector[roll0],opticrolloutput,0.1,100]\
\>", "Input",
 CellChangeTimes->{
  3.391280825699009*^9, 3.391319737111731*^9, {3.391321492791369*^9, 
   3.391321502283556*^9}, {3.4783777477831497`*^9, 3.478377747799203*^9}, {
   3.478377780642433*^9, 3.478377780697702*^9}, 3.478439376650053*^9, 
   3.4784394523613243`*^9, 3.483294817808503*^9, 3.483294849777356*^9, 
   3.483294900580535*^9, 3.4832949328997087`*^9, {3.483294981212908*^9, 
   3.483295003405196*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmnVUlU8Tx29Ih/SlS0rSwCBkRcBAFEQFRAUkVJASMECQMlDp8ieK0iIh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     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.392466920695965*^9, 3.478439624093628*^9, 
  3.478527906731896*^9, 3.483295454624709*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1097, 1012},
WindowMargins->{{Automatic, 551}, {Automatic, 28}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{36, 36}, {72, 72}}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 362, 4, 67, "Section"],
Cell[910, 26, 385, 7, 38, "Text"],
Cell[CellGroupData[{
Cell[1320, 37, 101, 1, 27, "Input"],
Cell[1424, 40, 202, 3, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1663, 48, 110, 1, 27, "Input"],
Cell[1776, 51, 397, 5, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2210, 61, 95, 1, 26, "Text"],
Cell[2308, 64, 135, 2, 27, "Input"],
Cell[2446, 68, 336, 8, 27, "Input"],
Cell[2785, 78, 660, 14, 43, "Input"],
Cell[3448, 94, 382, 9, 27, "Input"],
Cell[3833, 105, 579, 12, 27, "Input"],
Cell[4415, 119, 726, 14, 27, "Input"],
Cell[5144, 135, 532, 11, 27, "Input"],
Cell[5679, 148, 892, 22, 27, "Input"],
Cell[6574, 172, 735, 19, 27, "Input"],
Cell[7312, 193, 796, 20, 27, "Input"],
Cell[8111, 215, 789, 21, 43, "Input"],
Cell[8903, 238, 842, 21, 43, "Input"],
Cell[9748, 261, 784, 20, 27, "Input"],
Cell[10535, 283, 816, 20, 27, "Input"],
Cell[11354, 305, 608, 16, 27, "Input"],
Cell[11965, 323, 214, 4, 27, "Input"],
Cell[12182, 329, 264, 5, 27, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12483, 339, 208, 4, 26, "Subsection"],
Cell[CellGroupData[{
Cell[12716, 347, 304, 5, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[13045, 356, 475, 7, 27, "Input"],
Cell[13523, 365, 1834, 36, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15394, 406, 473, 7, 27, "Input"],
Cell[15870, 415, 1809, 37, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17716, 457, 452, 7, 27, "Input"],
Cell[18171, 466, 2028, 42, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20236, 513, 452, 7, 27, "Input"],
Cell[20691, 522, 1833, 39, 133, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22561, 566, 423, 6, 27, "Input"],
Cell[22987, 574, 1691, 33, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24715, 612, 474, 7, 27, "Input"],
Cell[25192, 621, 1663, 33, 143, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26892, 659, 453, 7, 27, "Input"],
Cell[27348, 668, 1563, 30, 141, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28960, 704, 109, 1, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[29094, 709, 627, 9, 27, "Input"],
Cell[29724, 720, 1827, 36, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31588, 761, 653, 9, 27, "Input"],
Cell[32244, 772, 1825, 36, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34106, 813, 502, 7, 27, "Input"],
Cell[34611, 822, 1770, 35, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36418, 862, 501, 7, 27, "Input"],
Cell[36922, 871, 1720, 34, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38679, 910, 475, 7, 27, "Input"],
Cell[39157, 919, 1832, 38, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41026, 962, 475, 7, 27, "Input"],
Cell[41504, 971, 1788, 37, 139, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43329, 1013, 454, 7, 27, "Input"],
Cell[43786, 1022, 1718, 34, 143, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45541, 1061, 500, 7, 27, "Input"],
Cell[46044, 1070, 1725, 34, 143, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47806, 1109, 478, 7, 27, "Input"],
Cell[48287, 1118, 1465, 29, 133, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49813, 1154, 47, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[49885, 1158, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[49928, 1162, 26, 0, 27, "Input"],
Cell[49957, 1164, 351, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50345, 1174, 282, 9, 27, "Input"],
Cell[50630, 1185, 1337, 29, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52004, 1219, 568, 14, 27, "Input"],
Cell[52575, 1235, 19718, 326, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72342, 1567, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[72385, 1571, 26, 0, 27, "Input"],
Cell[72414, 1573, 345, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72796, 1583, 282, 9, 27, "Input"],
Cell[73081, 1594, 1427, 33, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74545, 1632, 547, 14, 27, "Input"],
Cell[75095, 1648, 20632, 358, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[95776, 2012, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[95819, 2016, 26, 0, 27, "Input"],
Cell[95848, 2018, 350, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96235, 2028, 282, 9, 27, "Input"],
Cell[96520, 2039, 1430, 33, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97987, 2077, 534, 15, 27, "Input"],
Cell[98524, 2094, 19870, 336, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118443, 2436, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[118486, 2440, 26, 0, 27, "Input"],
Cell[118515, 2442, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118899, 2452, 282, 9, 27, "Input"],
Cell[119184, 2463, 1267, 29, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120488, 2497, 541, 15, 27, "Input"],
Cell[121032, 2514, 20415, 347, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[141496, 2867, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[141539, 2871, 26, 0, 27, "Input"],
Cell[141568, 2873, 343, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141948, 2883, 282, 9, 27, "Input"],
Cell[142233, 2894, 1266, 29, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143536, 2928, 591, 16, 27, "Input"],
Cell[144130, 2946, 20634, 350, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[164813, 3302, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[164856, 3306, 26, 0, 27, "Input"],
Cell[164885, 3308, 345, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165267, 3318, 282, 9, 27, "Input"],
Cell[165552, 3329, 1369, 30, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[166958, 3364, 564, 16, 27, "Input"],
Cell[167525, 3382, 20557, 350, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[188131, 3738, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[188174, 3742, 26, 0, 27, "Input"],
Cell[188203, 3744, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188587, 3754, 282, 9, 27, "Input"],
Cell[188872, 3765, 1351, 32, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190260, 3802, 637, 16, 27, "Input"],
Cell[190900, 3820, 19778, 332, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[210727, 4158, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[210770, 4162, 26, 0, 27, "Input"],
Cell[210799, 4164, 349, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211185, 4174, 282, 9, 27, "Input"],
Cell[211470, 4185, 1347, 30, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212854, 4220, 563, 16, 27, "Input"],
Cell[213420, 4238, 20618, 354, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[234087, 4598, 18, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[234130, 4602, 26, 0, 27, "Input"],
Cell[234159, 4604, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234543, 4614, 282, 9, 27, "Input"],
Cell[234828, 4625, 1327, 30, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[236192, 4660, 641, 16, 27, "Input"],
Cell[236836, 4678, 19892, 335, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[256777, 5019, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[256821, 5023, 27, 0, 27, "Input"],
Cell[256851, 5025, 352, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257240, 5035, 283, 9, 27, "Input"],
Cell[257526, 5046, 1212, 26, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258775, 5077, 579, 16, 27, "Input"],
Cell[259357, 5095, 20587, 351, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279993, 5452, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[280037, 5456, 27, 0, 27, "Input"],
Cell[280067, 5458, 349, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[280453, 5468, 283, 9, 27, "Input"],
Cell[280739, 5479, 1363, 32, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282139, 5516, 592, 16, 27, "Input"],
Cell[282734, 5534, 19891, 334, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[302674, 5874, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[302718, 5878, 27, 0, 27, "Input"],
Cell[302748, 5880, 353, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303138, 5890, 283, 9, 27, "Input"],
Cell[303424, 5901, 1314, 30, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304775, 5936, 609, 16, 27, "Input"],
Cell[305387, 5954, 19851, 334, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[325287, 6294, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[325331, 6298, 27, 0, 27, "Input"],
Cell[325361, 6300, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325745, 6310, 283, 9, 27, "Input"],
Cell[326031, 6321, 1367, 32, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327435, 6358, 561, 16, 27, "Input"],
Cell[327999, 6376, 20614, 351, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[348662, 6733, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[348706, 6737, 27, 0, 27, "Input"],
Cell[348736, 6739, 342, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349115, 6749, 283, 9, 27, "Input"],
Cell[349401, 6760, 1230, 27, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350668, 6792, 599, 15, 27, "Input"],
Cell[351270, 6809, 20276, 346, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[371595, 7161, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[371639, 7165, 27, 0, 27, "Input"],
Cell[371669, 7167, 341, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372047, 7177, 283, 9, 27, "Input"],
Cell[372333, 7188, 1250, 28, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373620, 7221, 566, 16, 27, "Input"],
Cell[374189, 7239, 20524, 349, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[394762, 7594, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[394806, 7598, 27, 0, 27, "Input"],
Cell[394836, 7600, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395220, 7610, 283, 9, 27, "Input"],
Cell[395506, 7621, 1359, 31, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[396902, 7657, 597, 16, 27, "Input"],
Cell[397502, 7675, 20598, 352, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[418149, 8033, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[418193, 8037, 27, 0, 27, "Input"],
Cell[418223, 8039, 349, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418609, 8049, 283, 9, 27, "Input"],
Cell[418895, 8060, 1343, 31, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[420275, 8096, 566, 16, 27, "Input"],
Cell[420844, 8114, 19910, 332, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[440803, 8452, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[440847, 8456, 27, 0, 27, "Input"],
Cell[440877, 8458, 348, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[441262, 8468, 283, 9, 27, "Input"],
Cell[441548, 8479, 1227, 27, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[442812, 8511, 540, 15, 27, "Input"],
Cell[443355, 8528, 20595, 351, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[463999, 8885, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[464043, 8889, 27, 0, 27, "Input"],
Cell[464073, 8891, 344, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464454, 8901, 283, 9, 27, "Input"],
Cell[464740, 8912, 1370, 31, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466147, 8948, 634, 16, 27, "Input"],
Cell[466784, 8966, 20651, 351, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[487484, 9323, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[487528, 9327, 27, 0, 27, "Input"],
Cell[487558, 9329, 344, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[487939, 9339, 283, 9, 27, "Input"],
Cell[488225, 9350, 1367, 31, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489629, 9386, 611, 16, 27, "Input"],
Cell[490243, 9404, 19851, 336, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[510143, 9746, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[510187, 9750, 27, 0, 27, "Input"],
Cell[510217, 9752, 346, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510600, 9762, 283, 9, 27, "Input"],
Cell[510886, 9773, 1239, 28, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512162, 9806, 568, 16, 27, "Input"],
Cell[512733, 9824, 20320, 343, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[533102, 10173, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[533146, 10177, 27, 0, 27, "Input"],
Cell[533176, 10179, 343, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533556, 10189, 283, 9, 27, "Input"],
Cell[533842, 10200, 1351, 31, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535230, 10236, 564, 16, 27, "Input"],
Cell[535797, 10254, 20550, 348, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[556396, 10608, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[556440, 10612, 27, 0, 27, "Input"],
Cell[556470, 10614, 343, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[556850, 10624, 283, 9, 27, "Input"],
Cell[557136, 10635, 1224, 27, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558397, 10667, 565, 16, 27, "Input"],
Cell[558965, 10685, 20321, 346, 447, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[579335, 11037, 19, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[579379, 11041, 27, 0, 27, "Input"],
Cell[579409, 11043, 347, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579793, 11053, 283, 9, 27, "Input"],
Cell[580079, 11064, 1303, 29, 95, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581419, 11098, 566, 16, 27, "Input"],
Cell[581988, 11116, 20674, 352, 447, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[602723, 11475, 268, 5, 34, "Subsection"],
Cell[CellGroupData[{
Cell[603016, 11484, 26, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[603067, 11488, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[603114, 11492, 336, 5, 27, "Input"],
Cell[603453, 11499, 18571, 310, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[622073, 11815, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[622120, 11819, 335, 5, 27, "Input"],
Cell[622458, 11826, 26042, 433, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[648549, 12265, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[648596, 12269, 335, 5, 27, "Input"],
Cell[648934, 12276, 22318, 372, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[671301, 12654, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[671350, 12658, 341, 5, 27, "Input"],
Cell[671694, 12665, 19631, 328, 373, "Output"],
Cell[CellGroupData[{
Cell[691350, 12997, 22127, 368, 375, "Input"],
Cell[713480, 13367, 22150, 369, 375, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[735691, 13743, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[735742, 13747, 345, 7, 27, "Input"],
Cell[736090, 13756, 17829, 298, 377, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[753968, 14060, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[754018, 14064, 338, 5, 27, "Input"],
Cell[754359, 14071, 22709, 378, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[777129, 14456, 23, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[777177, 14460, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[777224, 14464, 335, 5, 27, "Input"],
Cell[777562, 14471, 25349, 422, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[802960, 14899, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[803007, 14903, 337, 5, 27, "Input"],
Cell[803347, 14910, 20241, 338, 378, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[823637, 15254, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[823684, 15258, 339, 5, 27, "Input"],
Cell[824026, 15265, 23711, 395, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[847786, 15666, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[847835, 15670, 338, 5, 27, "Input"],
Cell[848176, 15677, 26173, 435, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[874398, 16118, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[874449, 16122, 349, 7, 27, "Input"],
Cell[874801, 16131, 24984, 416, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[899834, 16553, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[899884, 16557, 342, 5, 27, "Input"],
Cell[900229, 16564, 23221, 387, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[923511, 16958, 26, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[923562, 16962, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[923609, 16966, 336, 5, 27, "Input"],
Cell[923948, 16973, 25636, 426, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[949633, 17405, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[949680, 17409, 341, 5, 27, "Input"],
Cell[950024, 17416, 56567, 933, 385, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1006640, 18355, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1006687, 18359, 338, 5, 27, "Input"],
Cell[1007028, 18366, 18338, 307, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1025415, 18679, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1025464, 18683, 341, 5, 27, "Input"],
Cell[1025808, 18690, 54449, 899, 380, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1080306, 19595, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1080357, 19599, 353, 7, 27, "Input"],
Cell[1080713, 19608, 21740, 362, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1102502, 19976, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1102552, 19980, 340, 5, 27, "Input"],
Cell[1102895, 19987, 53961, 891, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1156917, 20885, 28, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1156970, 20889, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1157019, 20893, 337, 5, 27, "Input"],
Cell[1157359, 20900, 21899, 365, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1179307, 21271, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1179356, 21275, 339, 5, 27, "Input"],
Cell[1179698, 21282, 21687, 361, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1201434, 21649, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1201483, 21653, 339, 5, 27, "Input"],
Cell[1201825, 21660, 25773, 428, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227647, 22094, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1227698, 22098, 350, 7, 27, "Input"],
Cell[1228051, 22107, 16327, 274, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1244427, 22387, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1244480, 22391, 353, 7, 27, "Input"],
Cell[1244836, 22400, 16764, 281, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1261649, 22687, 27, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1261701, 22691, 352, 7, 27, "Input"],
Cell[1262056, 22700, 25527, 424, 380, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1287644, 23131, 30, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1287699, 23135, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1287750, 23139, 347, 7, 27, "Input"],
Cell[1288100, 23148, 18561, 310, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1306710, 23464, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1306761, 23468, 347, 7, 27, "Input"],
Cell[1307111, 23477, 26000, 432, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333160, 23915, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1333211, 23919, 349, 7, 27, "Input"],
Cell[1333563, 23928, 22252, 371, 377, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1355864, 24305, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1355917, 24309, 351, 7, 27, "Input"],
Cell[1356271, 24318, 19620, 328, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1375940, 24652, 30, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1375995, 24656, 355, 7, 27, "Input"],
Cell[1376353, 24665, 17900, 299, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1394302, 24970, 29, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1394356, 24974, 351, 7, 27, "Input"],
Cell[1394710, 24983, 22653, 377, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1417424, 25367, 29, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1417478, 25371, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1417528, 25375, 340, 5, 27, "Input"],
Cell[1417871, 25382, 27287, 453, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1445207, 25841, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1445257, 25845, 341, 5, 27, "Input"],
Cell[1445601, 25852, 20090, 335, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1465740, 26193, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1465790, 26197, 338, 5, 27, "Input"],
Cell[1466131, 26204, 24506, 408, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1490686, 26618, 27, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1490738, 26622, 352, 7, 27, "Input"],
Cell[1491093, 26631, 25648, 426, 380, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1516790, 27063, 29, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1516844, 27067, 353, 7, 27, "Input"],
Cell[1517200, 27076, 27226, 452, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1544475, 27534, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1544528, 27538, 353, 7, 27, "Input"],
Cell[1544884, 27547, 24411, 406, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1569368, 27961, 267, 5, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1569660, 27970, 26, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1569711, 27974, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1569758, 27978, 480, 7, 27, "Input"],
Cell[1570241, 27987, 18360, 307, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1588650, 28300, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1588697, 28304, 480, 7, 27, "Input"],
Cell[1589180, 28313, 27005, 449, 380, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1616234, 28768, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1616281, 28772, 477, 7, 27, "Input"],
Cell[1616761, 28781, 23481, 391, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1640291, 29178, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1640340, 29182, 489, 7, 27, "Input"],
Cell[1640832, 29191, 19789, 331, 373, "Output"],
Cell[CellGroupData[{
Cell[1660646, 29526, 22127, 368, 375, "Input"],
Cell[1682776, 29896, 22148, 369, 375, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1704985, 30272, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1705036, 30276, 479, 7, 27, "Input"],
Cell[1705518, 30285, 19157, 320, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1724724, 30611, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1724774, 30615, 481, 7, 27, "Input"],
Cell[1725258, 30624, 23769, 396, 382, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1749088, 31027, 23, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[1749136, 31031, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1749183, 31035, 477, 7, 27, "Input"],
Cell[1749663, 31044, 30621, 508, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1780333, 31558, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1780380, 31562, 479, 7, 27, "Input"],
Cell[1780862, 31571, 19986, 334, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1800897, 31911, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1800944, 31915, 483, 7, 27, "Input"],
Cell[1801430, 31924, 30152, 500, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1831631, 32430, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1831680, 32434, 480, 7, 27, "Input"],
Cell[1832163, 32443, 26003, 432, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1858215, 32881, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1858266, 32885, 484, 7, 27, "Input"],
Cell[1858753, 32894, 30465, 505, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1889267, 33405, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1889317, 33409, 484, 7, 27, "Input"],
Cell[1889804, 33418, 26799, 445, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1916664, 33870, 26, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[1916715, 33874, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1916762, 33878, 480, 7, 27, "Input"],
Cell[1917245, 33887, 25616, 426, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1942910, 34319, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1942957, 34323, 483, 7, 27, "Input"],
Cell[1943443, 34332, 56333, 929, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1999825, 35267, 22, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[1999872, 35271, 478, 7, 27, "Input"],
Cell[2000353, 35280, 18259, 305, 376, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2018661, 35591, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2018710, 35595, 485, 7, 27, "Input"],
Cell[2019198, 35604, 54285, 896, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2073532, 36506, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2073583, 36510, 486, 7, 27, "Input"],
Cell[2074072, 36519, 21614, 360, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2095735, 36885, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2095785, 36889, 484, 7, 27, "Input"],
Cell[2096272, 36898, 53832, 888, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2150165, 37793, 28, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2150218, 37797, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2150267, 37801, 483, 7, 27, "Input"],
Cell[2150753, 37810, 21897, 365, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2172699, 38181, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2172748, 38185, 483, 7, 27, "Input"],
Cell[2173234, 38194, 21677, 361, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2194960, 38561, 24, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2195009, 38565, 482, 7, 27, "Input"],
Cell[2195494, 38574, 25725, 428, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2221268, 39008, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2221319, 39012, 480, 7, 27, "Input"],
Cell[2221802, 39021, 16304, 273, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2238155, 39300, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2238208, 39304, 498, 9, 27, "Input"],
Cell[2238709, 39315, 16768, 281, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2255526, 39602, 27, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2255578, 39606, 486, 7, 27, "Input"],
Cell[2256067, 39615, 25532, 425, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2281660, 40047, 30, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2281715, 40051, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2281766, 40055, 483, 7, 27, "Input"],
Cell[2282252, 40064, 20204, 337, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2302505, 40407, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2302556, 40411, 480, 7, 27, "Input"],
Cell[2303039, 40420, 26578, 442, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2329666, 40868, 26, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2329717, 40872, 485, 7, 27, "Input"],
Cell[2330205, 40881, 21736, 362, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2351990, 41249, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2352043, 41253, 495, 9, 27, "Input"],
Cell[2352541, 41264, 17302, 290, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2369892, 41560, 30, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2369947, 41564, 499, 9, 27, "Input"],
Cell[2370449, 41575, 17787, 298, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2388285, 41879, 29, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2388339, 41883, 492, 9, 27, "Input"],
Cell[2388834, 41894, 23034, 384, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2411929, 42285, 29, 0, 24, "Subsubsection"],
Cell[CellGroupData[{
Cell[2411983, 42289, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2412033, 42293, 486, 7, 27, "Input"],
Cell[2412522, 42302, 26559, 441, 374, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2439130, 42749, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2439180, 42753, 482, 7, 27, "Input"],
Cell[2439665, 42762, 19942, 333, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2459656, 43101, 25, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2459706, 43105, 480, 7, 27, "Input"],
Cell[2460189, 43114, 23572, 392, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2483810, 43512, 27, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2483862, 43516, 488, 7, 27, "Input"],
Cell[2484353, 43525, 26773, 445, 378, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2511175, 43976, 29, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2511229, 43980, 493, 9, 27, "Input"],
Cell[2511725, 43991, 25726, 428, 373, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2537500, 44425, 28, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[2537553, 44429, 495, 9, 27, "Input"],
Cell[2538051, 44440, 22268, 371, 373, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
