(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    164314,       5579]
NotebookOptionsPosition[    142899,       4840]
NotebookOutlinePosition[    143566,       4865]
CellTagsIndexPosition[    143523,       4862]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Xtra-Lite (Lateral) Model of Quad Pendulum - V5.1
CUSTOMIZED TO EXAMINE DUMBBELL FIBRES/RIBBONS\
\>", "Section",
 InitializationCell->True,
 CellChangeTimes->{
  3.388837309994549*^9, {3.394008419088697*^9, 3.3940084193655033`*^9}, {
   3.4115060991688957`*^9, 3.411506155550926*^9}, {3.4154626792084837`*^9, 
   3.415462692748197*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Version history", "Subsection",
 InitializationCell->True],

Cell["\<\
modelversion = 5.1; modelcomment = \"GEO-style quad pendulum with massless \
blades with z and x DOFs\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.3888409990879173`*^9, 3.394007306071328*^9}],

Cell["\<\
modelversion::usage = \"modelversion is a number specifying the version of \
the default model.\"; 
modelcomment::usage = \"modelcomment is a string describing the default \
model.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
03/15/06 - v4.0: First release, based on v4.0 of the plain xtra-lite model.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
06/15/07 - v5.0: Updates for Mathematica v6. Made loading of several packages \
conditional on $VersionNumber. Major rewrite of eigenplot[] to use either old \
v5 code or new v6 code depending on $VersionNumber. Cleanup of instructions \
and ::usage tags. Removed obsolete mentions of mbei and mbel.\
\>", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.388837320058503*^9, 3.3888373553337727`*^9}, {
  3.3908947759700613`*^9, 3.390894782548765*^9}, {3.390902605716703*^9, 
  3.390902635919635*^9}, {3.390902977500495*^9, 3.390903001634634*^9}, {
  3.390903090593232*^9, 3.3909032159985027`*^9}, {3.3909106283063383`*^9, 
  3.390910632380883*^9}, {3.390983126497892*^9, 3.390983182496921*^9}, {
  3.390983240784521*^9, 3.39098326429506*^9}}],

Cell[TextData[{
 "07/21/07 - v5.1: revised naming of attachment points (+y=left, -y=right) to \
restore right-handedness of coordinate system. Corrected yaw/roll swap error \
in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v6 sections of eigenplot[]. Changed default values of upper two mass \
display sizes (nx, ny, nz, ux,uy,uz) to match controls prototype."
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.388837320058503*^9, 3.3888373553337727`*^9}, {
  3.3908947759700613`*^9, 3.390894782548765*^9}, {3.390902605716703*^9, 
  3.390902635919635*^9}, {3.390902977500495*^9, 3.390903001634634*^9}, {
  3.390903090593232*^9, 3.3909032159985027`*^9}, {3.3909106283063383`*^9, 
  3.390910632380883*^9}, {3.390983126497892*^9, 3.390983182496921*^9}, {
  3.390983240784521*^9, 3.39098326429506*^9}, {3.3940072960526667`*^9, 
  3.394007370896594*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Instructions", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Basic info", "Subsubsection",
 InitializationCell->True,
 CellChangeTimes->{{3.390900153524959*^9, 3.390900162573744*^9}, {
  3.39090026831347*^9, 3.390900270941489*^9}}],

Cell[TextData[{
 "1. This notebook,  ",
 StyleBox["ASUS4L2LateralModelDefn.nb", "Program"],
 ", defines the structure of the \"Quad Xtra-Lite Lateral\" model plus a \
default set of numerical parameters. It contains only definitions and setup \
and does no non-trivial calculations. It is set up as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " autosave package, so that whenever it is saved, a matching .m file, ",
 StyleBox["ASUS4L2LateralModelDefn", "Program"],
 ".m, is automatically created to match.\n2. The directory in which this file \
lives is called the \"model\" directory. Also in the model directory should \
be a number of \"case\" subdirectories, each one relating to a different set \
of numerical parameters. Typically at a minimum there will be one called ",
 StyleBox["default", "Program"],
 ". Each case subdirectory has a \"case calculation notebook\" with a name \
like ",
 StyleBox["ASUS4L2Lateral", "Program"],
 StyleBox["ModelCalc",
  FontFamily->"Courier"],
 StyleBox["XXX",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 StyleBox[".nb",
  FontFamily->"Courier"],
 "., where ",
 StyleBox["XXX", "Program",
  FontSlant->"Italic"],
 " reflects the name of the case, e.g., ",
 StyleBox["Default", "Program"],
 ". \n3. Actual calculations are done by evaluating the calculation notebook. \
However certain initial setup is absolutely required. See the Installation \
section below.\n4. All interesting symbols have ::usage tags defined for \
them, so once the definitions have been loaded you can get help on them with \
the ? operator. For example to get information on wirelist, type ",
 StyleBox["?wirelist", "Program"],
 " into an empty cell and evaluate it. You can also use ",
 StyleBox["??", "Program"],
 " to get the full definition of a symbol."
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.390898912297555*^9, 3.390898971191886*^9}, {
   3.390899033418228*^9, 3.390899050459704*^9}, {3.3908991639856243`*^9, 
   3.3908992377735157`*^9}, {3.390899278445751*^9, 3.390899407202043*^9}, {
   3.3908994581244717`*^9, 3.390899490138706*^9}, {3.390899526055862*^9, 
   3.390899564834382*^9}, {3.390899607979657*^9, 3.390899611723463*^9}, {
   3.3908996585998993`*^9, 3.390899730063924*^9}, {3.390899831208743*^9, 
   3.390899936294351*^9}, 3.390899997981559*^9, 3.390900029881538*^9, 
   3.390900115134425*^9, {3.3909001705581417`*^9, 3.390900229779457*^9}, {
   3.390900304744508*^9, 3.3909003659168663`*^9}, 3.3909006509937057`*^9, 
   3.390900740724802*^9, {3.390900787039826*^9, 3.390900794331431*^9}, {
   3.390900828305066*^9, 3.390900848369504*^9}, {3.39090087864429*^9, 
   3.390900880346094*^9}, {3.390900974088498*^9, 3.390900991909726*^9}, {
   3.390901117877975*^9, 3.3909012239143343`*^9}, {3.390902053181583*^9, 
   3.3909020535007877`*^9}, {3.390902378419729*^9, 3.390902383533333*^9}, {
   3.390902460343025*^9, 3.390902491362994*^9}, 3.390902521740151*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation", "Subsubsection",
 InitializationCell->True],

Cell[TextData[{
 "1. Each case calculation notebook has two hard-coded paths which need to be \
set before ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can find either this file or the modelling toolkit files.\n2. For each \
case that you want to work with, open the calculation notebook, e.g., ",
 StyleBox["./default/ASUS4L2LateralModelCalcDefault.nb",
  FontFamily->"Courier"],
 " and follow the instructions there.\n3. If the calculation notebook has not \
been updated for v6, you will also need to change any cells that draw \
graphics to ensure that the call that does the plotting (e.g.,  ",
 StyleBox["eigenplot[]", "Program"],
 ", ",
 StyleBox["plotTF", "Program"],
 StyleBox["[]", "Program"],
 ") is the last item in the cell, with no other statements or semicolons \
after it. So a line like\n",
 StyleBox["\tStatus[\"Plotting mode\"]; eigenplot[...]; Done[]\n", 
  "Program"],
 "needs to be changed to one of the following:\n",
 StyleBox["\teigenplot[...]\n\tStatus[\"Plotting mode\"]; tmp = \
eigenplot[...]; Done[]; tmp\n\tDoWithStatus[\"Plotting mode\", \
eigenplot[...]]", "Program"]
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.390895989331669*^9, 3.390896005055393*^9}, {
   3.390896138352129*^9, 3.390896155815584*^9}, {3.3908962510552607`*^9, 
   3.390896264673067*^9}, {3.390896310654554*^9, 3.390896357459404*^9}, {
   3.390896393513556*^9, 3.390896507380135*^9}, {3.390900004623743*^9, 
   3.390900008778612*^9}, {3.3909000513207283`*^9, 3.390900060298376*^9}, 
   3.3909001126449623`*^9, 3.390900205051589*^9, 3.390900322806341*^9, 
   3.3909003796061163`*^9, {3.3909004293819027`*^9, 3.390900512880816*^9}, {
   3.3909006957064047`*^9, 3.390900697337941*^9}, {3.390900888098996*^9, 
   3.390900916324728*^9}, {3.390909977462151*^9, 3.390910057980851*^9}, {
   3.390910142943276*^9, 3.390910374034505*^9}, {3.390910408645831*^9, 
   3.390910471263891*^9}, {3.390910510368824*^9, 3.390910520508794*^9}, {
   3.390910555871768*^9, 3.3909105901986847`*^9}, {3.3909150822858667`*^9, 
   3.390915170619685*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Customization", "Subsubsection",
 InitializationCell->True,
 CellChangeTimes->{{3.390900255420475*^9, 3.390900258248887*^9}}],

Cell[TextData[{
 "1. You should rarely if ever need to change this file. Certainly you should \
never need to just to change numerical parameters - that is designed to be \
done in the case calculation notebooks.\n2. If you want to make major changes \
(e.g., adding a new mass) that will render existing cases irrelevant, copy \
this file and a seed case to a new model directory.\n3. If you want to make \
minor changes (e.g., adding an asymmetry in the wires) that will apply to \
just one case, copy this file into a case directory and change the copy. A \
definition file in a case subdirectory will be used in preference to the \
master copy in the model directory.\n4. Make any changes to the ",
 StyleBox[".nb", "Program"],
 " version (i.e. this file), not the ",
 StyleBox[".m", "Program"],
 ".\n5. All cells need to be initialization cells to take effect in the ",
 StyleBox[".m", "Program"],
 " version. If you add any new cells, be sure to set the initialization cell \
attribute. \n6. Document what you do! Add/revise comments throughout the \
code, add/revise ::usage tags, add new entries to the version history, and \
update these instructions as necessary."
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.390895989331669*^9, 3.390896005055393*^9}, {
   3.390896138352129*^9, 3.390896155815584*^9}, {3.3908962510552607`*^9, 
   3.390896264673067*^9}, {3.390896310654554*^9, 3.390896357459404*^9}, {
   3.390896393513556*^9, 3.390896507380135*^9}, {3.390900004623743*^9, 
   3.390900008778612*^9}, {3.3909000513207283`*^9, 3.390900060298376*^9}, 
   3.3909001126449623`*^9, 3.390900205051589*^9, {3.3909003018210087`*^9, 
   3.390900332352118*^9}, 3.390900970966445*^9, {3.390901003868222*^9, 
   3.3909010604618263`*^9}, {3.390901308965708*^9, 3.3909014504262877`*^9}, {
   3.3909015457877827`*^9, 3.39090155519311*^9}, {3.390901625700287*^9, 
   3.390901724824378*^9}, {3.390901769659301*^9, 3.390901783339962*^9}, {
   3.3909018173997498`*^9, 3.3909018337654057`*^9}, {3.390901899302813*^9, 
   3.390901970830018*^9}, {3.390902082997788*^9, 3.390902200897435*^9}, {
   3.390902238931303*^9, 3.390902265569161*^9}, {3.390902303874765*^9, 
   3.390902422038218*^9}, {3.390910756407991*^9, 3.3909107594990788`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Disable spell-checking. There are so many variables with similar names that \
it's useless.\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dependencies", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Standard packages", "Text"],

Cell[CellGroupData[{

Cell["Standard packages for use in plotting eigenmodes", "Text",
 InitializationCell->True],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Graphics`\"]]", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837375508451*^9, 3.388837394354858*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Shapes`\"]];", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837375508451*^9, 3.388837394354858*^9}, {
  3.388856501574243*^9, 3.3888566481548977`*^9}, {3.388861247010874*^9, 
  3.38886127843696*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["If[$VersionNumber<6., Needs[\"Graphics`Polyhedra`\"]]", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837400609071*^9, 3.388837404849434*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Standard package useful for pasting together state-space matrices\
\>", "Text",
 InitializationCell->True],

Cell["\<\
Needs::ignorethestupidwarning = \"The following warning message about an \
obsolete package is harmless.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837423685124*^9, 3.388837426298386*^9}, 
   3.388838090102798*^9, 3.3888414561152163`*^9, {3.388842144917989*^9, 
   3.388842179404908*^9}, {3.38884222785511*^9, 3.38884225832124*^9}, {
   3.3888422978116283`*^9, 3.388842312596134*^9}, {3.390811830092298*^9, 
   3.390811841589985*^9}}],

Cell[TextData[{
 "If[$VersionNumber>=6.&&(!MemberQ[$Packages,\"LinearAlgebra`\
MatrixManipulation`\"]), \n\tMessage[Needs::ignorethestupidwarning",
 StyleBox["]\n];", "MB"]
}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837423685124*^9, 3.388837426298386*^9}, 
   3.388838090102798*^9, {3.388841450184997*^9, 3.3888414865122633`*^9}, {
   3.388841516718423*^9, 3.388841588668529*^9}, {3.388841827527543*^9, 
   3.388841830700273*^9}, {3.388842102929759*^9, 3.3888421411862497`*^9}, {
   3.3888421853223963`*^9, 3.388842217967772*^9}, 3.388842319506626*^9, 
   3.390811778530374*^9}],

Cell[TextData[{
 "Needs[\"LinearAlgebra",
 StyleBox["`", "MB"],
 "MatrixManipulation",
 StyleBox["`\"]", "MB"]
}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.388837423685124*^9, 3.388837426298386*^9}, 
   3.388838090102798*^9, 3.3888414561152163`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Custom Packages", "Text"],

Cell[CellGroupData[{

Cell["\<\
Custom rotation matrices in terms of yaw, pitch and roll angles\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<RotationsXYZ`\>\"", "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions to display status in window", "Text",
 InitializationCell->True],

Cell["Needs[\"StatusWindow`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions to export in Matlab .m format", "Text",
 InitializationCell->True],

Cell["Needs[\"MatlabExport`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters from Bench", "Text",
 InitializationCell->True],

Cell["Needs[\"IFOModel`\"];", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The toolkit", "Text",
 InitializationCell->True],

Cell["Needs[\"PendUtil`\"];", "Input",
 InitializationCell->True],

Cell["\<\
If[utilitiesversion>=3.0,Null, Print[\"Incorrect utilities \
version\"];Abort[],Print[\"Utilities failed to load\"];Abort[]];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3909032575389347`*^9, 3.39090325851551*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The model proper", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Variables and parameters", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
The \"variables\" that specify the state of the system for the purposes of \
the normal mode calculation. This list should not include \"parameters\" such \
as displacement variables for the support structure which only vary for the \
purposes of perturbation and transfer function calculations.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
allvars::usage = \"allvars is part of the specification of the model. It \
should be a list of the position and angle variables for the system. It \
shouldn't include velocities, or the coordinates of the support structure.\";\
\
\>", "Input",
 InitializationCell->True],

Cell["\<\
allvars = {
\tx0,y0,z0,yaw0,pitch0,roll0,
\tx1,y1,z1,yaw1,pitch1,roll1,
\tx2,y2,z2,yaw2,pitch2,roll2,
\tx3,y3,z3,yaw3,pitch3,roll3
};\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
longpitchvars = {
\tx0,pitch0,
\tx1,pitch1,
\tx2,pitch2,
\tx3,pitch3
};
longpitchvarsM = {
\tpitch0,x0,
\tpitch1,x1,
\tpitch2,x2,
\tpitch3,x3
};
transrollvars = {
\ty0,roll0,
\ty1,roll1,
\ty2,roll2,
\ty3,roll3
};
transrollvarsM = {
\troll0,y0,
\troll1,y1,
\troll2,y2,
\troll3,y3
};
yawvars = {
\tyaw0,
\tyaw1,
\tyaw2,
\tyaw3
};
vertvars = {
\tz0,
\tz1,
\tz2,
\tz3
};\
\>", "Input",
 InitializationCell->True],

Cell["\<\
longpitchvels = {vx0,vpitch0,vx1,vpitch1,vx2,vpitch2,vx3,vpitch3};
longpitchvelsM = {vpitch0,vx0,vpitch1,vx1,vpitch2,vx2,vpitch3,vx3};
transrollvels = {vy0,vroll0,vy1,vroll1,vy2,vroll2,vy3,vroll3};
transrollvelsM = {vroll0,vy0,vroll1,vy1,vroll2,vy2,vroll3,vy3};
yawvels = {vyaw0,vyaw1,vyaw2,vyaw3};
vertvels = {vz0,vz1,vz2,vz3};\
\>", "Input",
 InitializationCell->True],

Cell["\<\
allfloats::usage = \"allfloats is part of the specification of the model. It \
should be a list of the positions and angles of connections where one elastic \
element is connected directly to another with no mass element between.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390903359850348*^9, 3.390903361363131*^9}, {
   3.390903392303484*^9, 3.3909034268703537`*^9}, 3.39090954336796*^9}],

Cell["\<\
allfloats = {
\tqzul,
\tqxul,
\tqzur,
\tqxur,
\tqzil,
\tqxil,
\tqzir,
\tqxir,
\tqzll,
\tqxll,
\tqzlr,
\tqxlr,
\tqqxulf, (* extra floats to represent upper neck ends *)
\tqqyulf,
\tqqzulf,
\tqqxurf,
\tqqyurf,
\tqqzurf,
\tqqxulb,
\tqqyulb,
\tqqzulb,
\tqqxurb,
\tqqyurb,
\tqqzurb,
\tqqxllf, (* extra floats to represent lower neck ends *)
\tqqyllf,
\tqqzllf,
\tqqxlrf,
\tqqylrf,
\tqqzlrf,
\tqqxllb,
\tqqyllb,
\tqqzllb,
\tqqxlrb,
\tqqylrb,
\tqqzlrb
};\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4115061799461823`*^9, 3.4115063890684*^9}, {
  3.4115064732671022`*^9, 3.411506482890458*^9}, {3.4115065147236633`*^9, 
  3.411506544677074*^9}, {3.411507495376813*^9, 3.411507506589574*^9}, {
  3.411507793494739*^9, 3.4115078067191257`*^9}, {3.415462938091638*^9, 
  3.415463013230749*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The state of the support is defined in terms of \"parameters\" rather than \
\"variables\". These are fixed for the purposes of the normal mode \
calculation, but can have displacement inputs applied.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
allparams::usage = \"allparams is part of the specification of the model. It \
should be a list of the positions and angles describing the state of the \
support structure, plus any other coordinates that are constant for the \
purposes of the normal mode calculation but through which one might want to \
inject a displacement input.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"allparams", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "x00", ",", "y00", ",", "z00", " ", ",", "yaw00", ",", "pitch00", ",", 
     "roll00"}], " ", "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Geometry", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note:  the z direction is up. The x direction is along the axis of the optic \
and the y direction is transverse.The global origin is midway between the \
points where the wires attach to the suspension structure. \
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["The local coordinate origin", "Text",
 InitializationCell->True],

Cell["\<\
LCO = {0,0,0}; NOM::usage = \"LCO is the local coordinate origin for any \
mass, {0,0,0}.\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The centre of mass is at the centre of local coordinates unless otherwise \
specified for a particular mass\
\>", "Text",
 InitializationCell->True],

Cell["\<\
COM = LCO; COM::usage = \"COM (=LCO) is the centre of mass in local \
coordinates for blade tips and other objjects not having a custom definition.\
\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Fixtures such as wire attacments points are applied relative to the fixture \
reference point unless otherwise specified for a particular mass\
\>", "Text",
 InitializationCell->True],

Cell["\<\
FRP = LCO; FRP::usage = \"FRP (=LCO) is the default fixture reference point \
in local coordinates relative to which offsets to wire and spring attachment \
points are calculated. The pendulum masses have custom definitions, FRP1, \
FRP2 and FRP3.\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of parameters specifying the position and orientation of the support \
structure\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"support", "=", 
   RowBox[{"{", 
    RowBox[{
    "x00", ",", "y00", ",", "z00", ",", "yaw00", ",", "pitch00", ",", 
     "roll00"}], "}"}]}], ";", " ", 
  RowBox[{
   RowBox[{"support", "::", "usage"}], "=", 
   "\"\<support is a list of the parameters specifying the support structure.\
\>\""}], ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The lists of variables specifying the top blade springs", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"bladeUL", " ", "=", " ", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"b2s", "[", 
        RowBox[{"support", ",", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", "nn0", ",", " ", "0"}], "}"}], " ", "+", 
          " ", 
          RowBox[{
           RowBox[{"RotationMatrixXYZBS", "[", 
            RowBox[{"0", ",", " ", "pitchbul", ",", " ", "rollbul"}], "]"}], 
           " ", ".", " ", 
           RowBox[{"{", 
            RowBox[{"qxul", ",", " ", "0", ",", " ", "qzul"}], "}"}]}]}]}], 
        "]"}], ",", " ", "\n", "    ", 
       RowBox[{"support", "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", "5", ",", " ", "6"}], "}"}], "]"}], "]"}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"bladeUL", "::", "usage"}], " ", "=", " ", 
     "\"\<bladeUL is a list of the variables specifying the upper left blade \
tip.\>\""}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"bladeUR", " ", "=", " ", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"b2s", "[", 
        RowBox[{"support", ",", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", " ", 
            RowBox[{"-", "nn0"}], ",", " ", "0"}], "}"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"RotationMatrixXYZBS", "[", 
            RowBox[{"0", ",", " ", "pitchbur", ",", " ", "rollbur"}], "]"}], 
           " ", ".", " ", 
           RowBox[{"{", 
            RowBox[{"qxur", ",", " ", "0", ",", " ", "qzur"}], "}"}]}]}]}], 
        "]"}], ",", " ", "\n", "    ", 
       RowBox[{"support", "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"4", ",", " ", "5", ",", " ", "6"}], "}"}], "]"}], "]"}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"bladeUR", "::", "usage"}], " ", "=", " ", 
     "\"\<bladeUR is a list of the variables specifying the upper right blade \
tip.\>\""}], ";"}]}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940073971723223`*^9, 3.394007399603619*^9}, {
  3.394007739895566*^9, 3.394007740194845*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The nominal working position of the tips of the blades relative to the \
structure\
\>", "Text",
 InitializationCell->True],

Cell["\<\
bladeULnom={0,-nn0,0};
bladeULnom::usage = \"bladeULnom is the nominal position of the upper left \
blade tip relative to the structure.\";
bladeURnom={0,nn0,0};
bladeURnom::usage = \"bladeURnom is the nominal position of the upper right \
blade tip relative to the structure.\";\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Wires from the blade tips lead down to the first mass. ", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bladeULa", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeULa", "::", "usage"}], "=", 
   "\"\<bladeULa is the attachment point of the wire on the upper left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeURa", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeURa", "::", "usage"}], "=", 
   "\"\<bladeURa is the attachment point of the wire on the upper right blade \
tip.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The top mass is attached by wires to the tips of the blades. Also known as \
mass N for historical reasons (N=new?)\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"massN", "=", 
   RowBox[{"{", 
    RowBox[{
    "x0", ",", "y0", ",", "z0", ",", "yaw0", ",", "pitch0", ",", "roll0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"massN", "::", "usage"}], "=", 
   "\"\<massN is a list of the variables specifying the top mass (a.k.a., \
mass N).\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The top mass COM.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"COM0", "=", 
   RowBox[{"{", 
    RowBox[{"COM0x", ",", "COM0y", ",", "COM0z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"COM0", "::", "usage"}], "=", 
   "\"\<COM0 is the COM of the top mass (a.k.a., mass N) in local \
coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The top mass FRP.", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FRP0", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"FRP0x", ",", " ", "FRP0y", ",", " ", "FRP0z"}], "}"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"FRP0", "::", "usage"}], " ", "=", " ", 
     "\"\<FRP0 is the fixture reference point of the top mass (a.k.a., mass \
N) in local coordinates.\>\""}], ";"}]}], " "}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The attachment points on the top mass for the wires from the top blade \
springs above in local coordinates\
\>", "Text",
 InitializationCell->True],

Cell["\<\
massNl=FRP0+{0,nn1,dm};
massNl::usage=\"massNl is the attachment point of the wire from the upper \\
left blade spring at the top mass.\";
massNr=FRP0+{0,-nn1,dm};
massNr::usage=\"massNr is the attachment point of the wire from the upper \\
right blade spring at the top mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940074089468822`*^9, 3.3940074115063677`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intermediate blade tips and attachment points thereon", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bladeIL", " ", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"massN", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "n0", ",", 
          RowBox[{"-", "dn"}]}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchbil", ",", "rollbil"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"qxil", ",", "0", ",", "qzil"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"massN", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeIL", "::", "usage"}], "=", 
   "\"\<bladeIL is a list of the variables specifying the intermediate left \
blade tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeIR", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"massN", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "n0"}], ",", 
          RowBox[{"-", "dn"}]}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchbir", ",", "rollbir"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"qxir", ",", "0", ",", "qzir"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"massN", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeIR", "::", "usage"}], "=", 
   "\"\<bladeIR is a list of the variables specifying the intermediate right \
blade tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeILf", " ", "=", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "su"}], ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeILf", "::", "usage"}], "=", 
   "\"\<bladeILf is the front wire attachment point on the intermediate left \
blade tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeILb", " ", "=", " ", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{"su", ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeILb", "::", "usage"}], "=", 
   "\"\<bladeILb is the back wire attachment point on the intermediate left \
blade tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeIRf", " ", "=", " ", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "su"}], ",", "0", ",", "0"}], "}"}]}]}], ";", 
  RowBox[{
   RowBox[{"bladeIRf", "::", "usage"}], "=", 
   "\"\<bladeIRf is the front wire attachment point on the intermediate right \
blade tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeIRb", " ", "=", 
   RowBox[{"FRP", "+", " ", 
    RowBox[{"{", 
     RowBox[{"su", ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeIRb", "::", "usage"}], "=", 
   "\"\<bladeIRb is the back wire attachment point on the intermediate right \
blade tip.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940074157635517`*^9, 3.3940074190147963`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The blade tips will be attached by ideal zero-length springs to their nominal \
working positions on the top mass. \
\>", "Text",
 InitializationCell->True],

Cell["\<\
bladeILnom=FRP0+{0,n0,-dn};
bladeILnom::usage = \"bladeILnom is the nominal position of the intermediate \
left blade tip relative to the top mass.\";
bladeIRnom=FRP0+{0,-n0,-dn};
bladeIRnom::usage = \"bladeIRnom is the nominal position of the intermediate \
right blade tip relative to the top mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.394007429091775*^9, 3.3940074319867697`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of variables defining the second mass (also known as mass U for \
historical reasons (U=upper in triple pendulum?))\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"massU", "=", 
   RowBox[{"{", 
    RowBox[{
    "x1", ",", "y1", ",", "z1", ",", "yaw1", ",", "pitch1", ",", "roll1"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"massU", "::", "usage"}], "=", 
   "\"\<massU is a list of the variables specifying the second top mass \
(a.k.a., mass U).\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The second mass COM.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"COM1", "=", 
   RowBox[{"{", 
    RowBox[{"COM1x", ",", "COM1y", ",", "COM1z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"COM1", "::", "usage"}], "=", 
   "\"\<COM1 is the COM of the second mass (a.k.a., mass U) in local \
coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The second mass FRP.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FRP1", "=", 
   RowBox[{"{", 
    RowBox[{"FRP1x", ",", "FRP1y", ",", "FRP1z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FRP1", "::", "usage"}], "=", 
   "\"\<FRP1 is the fixture reference point of the second mass (a.k.a., mass \
U) in local coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The attachment points on the second mass for the wires from the intermediate \
blade springs\
\>", "Text",
 InitializationCell->True],

Cell["\<\
massUlf=FRP1+{-su,n1,d0};
massUlf::usage=\"massUlf is the attachment point of the front wire from the \
intermediate \\
left blade spring at the second top mass.\";
massUlb=FRP1+{su,n1,d0};
massUlb::usage=\"massUlb is the attachment point of the back wire from the \
intermediate \\
left blade spring at the second top mass.\";
massUrf=FRP1+{-su,-n1,d0};
massUrf::usage=\"massUrf is the attachment point of the front wire from the \
intermediate \\
right blade spring at the second top mass.\";
massUrb=FRP1+{su,-n1,d0};
massUrb::usage=\"massUrb is the attachment point of the back wire from the \
intermediate \\
right blade spring at the second top mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940074386923237`*^9, 3.394007447467231*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The second mass holds the lower blade springs.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bladeLL", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"massU", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "n2", ",", 
          RowBox[{"-", "d1"}]}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchbll", ",", "rollbll"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"qxll", ",", "0", ",", "qzll"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"massU", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLL", "::", "usage"}], "=", 
   "\"\<bladeLL is a list of the variables specifying the lower left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeLR", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"b2s", "[", 
      RowBox[{"massU", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "n2"}], ",", 
          RowBox[{"-", "d1"}]}], "}"}], "+", 
        RowBox[{
         RowBox[{"RotationMatrixXYZBS", "[", 
          RowBox[{"0", ",", "pitchblr", ",", "rollblr"}], "]"}], ".", 
         RowBox[{"{", 
          RowBox[{"qxlr", ",", "0", ",", "qzlr"}], "}"}]}]}]}], "]"}], ",", 
     RowBox[{"massU", "[", 
      RowBox[{"[", 
       RowBox[{"{", 
        RowBox[{"4", ",", "5", ",", "6"}], "}"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLR", "::", "usage"}], "=", 
   "\"\<bladeLR is a list of the variables specifying the lower right blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeLLf", " ", "=", " ", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "si"}], ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLLf", "::", "usage"}], "=", 
   "\"\<bladeLLf is the front wire attachment point on the lower left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeLLb", " ", "=", " ", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{"si", ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLLb", "::", "usage"}], "=", 
   "\"\<bladeLLb is the back wire attachment point on the lower left blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeLRf", " ", "=", " ", 
   RowBox[{"FRP", "+", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "si"}], ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLRf", "::", "usage"}], "=", 
   "\"\<bladeLRf is the front wire attachment point on the lower right blade \
tip.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bladeLRb", " ", "=", 
   RowBox[{"FRP", "+", " ", 
    RowBox[{"{", 
     RowBox[{"si", ",", "0", ",", "0"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"bladeLRb", "::", "usage"}], "=", 
   "\"\<bladeLRb is the back wire attachment point on the lower right blade \
tip.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940074532768106`*^9, 3.394007458443059*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The lower blade spring working positions", "Text",
 InitializationCell->True],

Cell["\<\
bladeLLnom=FRP1+{0,n2,-d1};
bladeLLnom::usage = \"bladeLLnom is the nominal position of the lower left \
blade tip relative to the second top mass.\";
bladeLRnom=FRP1+{0,-n2,-d1};
bladeLRnom::usage = \"bladeLRnom is the nominal position of the lower right \
blade tip relative to the second top mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.394007467829069*^9, 3.394007470948122*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The list of variables defining the third mass (all known as the intermediate \
mass or mass I)\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"massI", "=", 
   RowBox[{"{", 
    RowBox[{
    "x2", ",", "y2", ",", "z2", ",", "yaw2", ",", "pitch2", ",", "roll2"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"massI", "::", "usage"}], "=", 
   "\"\<massI is a list of the variables specifying the intermediate mass \
(a.k.a., mass I).\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The intermediate mass COM.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"COM2", "=", 
   RowBox[{"{", 
    RowBox[{"COM2x", ",", "COM2y", ",", "COM2z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"COM2", "::", "usage"}], "=", 
   "\"\<COM2 is the COM of the intermediate mass (a.k.a., mass I) in local \
coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The intermediate mass FRP.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FRP2", "=", 
   RowBox[{"{", 
    RowBox[{"FRP2x", ",", "FRP2y", ",", "FRP2z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FRP2", "::", "usage"}], "=", 
   "\"\<FRP2 is the fixture reference point of the intermediate mass (a.k.a., \
mass I) in local coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The attachment points on the intermediate mass for the wires from the lower \
blade springs on the second mass\
\>", "Text",
 InitializationCell->True],

Cell["\<\
massIulf=FRP2+{-si,n3,d2};
massIulf::usage=\"massIulf is the attachment point of the front wire from the \
lower \\
left blade spring at the intermediate mass.\";
massIulb=FRP2+{si,n3,d2};
massIulb::usage=\"massIulb is the attachment point of the back wire from the \
lower \\
left blade spring at the intermediate mass.\";
massIurf=FRP2+{-si,-n3,d2};
massIurf::usage=\"massIurf is the attachment point of the front wire from the \
lower \\
right blade spring at the intermediate mass.\";
massIurb=FRP2+{si,-n3,d2};
massIurb::usage=\"massIurb is the attachment point of the back wire from the \
lower \\
right blade spring at the intermediate mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940074784924107`*^9, 3.394007485861738*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The attachment points on the intermediate mass for the wires to the optic \
below\
\>", "Text",
 InitializationCell->True],

Cell["\<\
massIllf=FRP2+{-sl,n4,-d3};
massIllf::usage=\"massIllf is the attachment point of the front left fibre at \
the intermediate mass.\";
massIllb=FRP2+{sl,n4,-d3};
massIllb::usage=\"massIllb is the attachment point of the back left fibre at \
the intermediate mass.\";
massIlrf=FRP2+{-sl,-n4,-d3};
massIlrf::usage=\"massIlrf is the attachment point of the front right fibre \
at the intermediate mass.\";
massIlrb=FRP2+{sl,-n4,-d3};
massIlrb::usage=\"massIlrb is the attachment point of the back right fibre at \
the intermediate mass.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.394007488772787*^9, 3.394007496364861*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The lists of coordinates defining the upper neck ends.", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.411506430521994*^9, 3.411506436159186*^9}, {
  3.415463049929572*^9, 3.4154630627348967`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nulf", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxulf", ",", "qqyulf", ",", "qqzulf", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nulb", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxulb", ",", "qqyulb", ",", "qqzulb", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nurf", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxurf", ",", "qqyurf", ",", "qqzurf", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nurb", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxurb", ",", "qqyurb", ",", "qqzurb", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nulf", "::", "usage"}], "=", 
   "\"\<nulf is a list of the coordinates specifying the left front upper \
neck end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nulb", "::", "usage"}], "=", 
   "\"\<nulb is a list of the coordinates specifying the left back upper neck \
end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nurf", "::", "usage"}], "=", 
   "\"\<nurf is a list of the coordinates specifying the right front upper \
neck end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nurb", "::", "usage"}], "=", 
   "\"\<nurb is a list of the coordinates specifying the right back upper \
neck end.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506445025433*^9, 3.411506445489744*^9}, {
  3.41150656008786*^9, 3.411506711116489*^9}, {3.415463090461507*^9, 
  3.415463105645054*^9}, {3.4154631413507433`*^9, 3.415463153435749*^9}, {
  3.415463195685586*^9, 3.415463236886869*^9}, {3.415463280367918*^9, 
  3.4154633063125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The lists of coordinates defining the lower neck ends.", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.411506430521994*^9, 3.411506436159186*^9}, {
  3.415463049929572*^9, 3.4154630627348967`*^9}, {3.415463124612927*^9, 
  3.4154631252975397`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nllf", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxllf", ",", "qqyllf", ",", "qqzllf", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nllb", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxllb", ",", "qqyllb", ",", "qqzllb", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nlrf", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxlrf", ",", "qqylrf", ",", "qqzlrf", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nlrb", "=", 
   RowBox[{"{", 
    RowBox[{
    "qqxlrb", ",", "qqylrb", ",", "qqzlrb", ",", "0", ",", "0", ",", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nllf", "::", "usage"}], "=", 
   "\"\<nllf is a list of the coordinates specifying the left front fibre \
lower neck end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nllb", "::", "usage"}], "=", 
   "\"\<nllb is a list of the coordinates specifying the left back fibre \
lower neck end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nlrf", "::", "usage"}], "=", 
   "\"\<nlrf is a list of the coordinates specifying the right front fibre \
lower neck end.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nlrb", "::", "usage"}], "=", 
   "\"\<nlrb is a list of the coordinates specifying the right back fibre \
lower neck end.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506445025433*^9, 3.411506445489744*^9}, {
  3.41150656008786*^9, 3.411506711116489*^9}, {3.415463090461507*^9, 
  3.415463105645054*^9}, {3.415463180334035*^9, 3.415463187013547*^9}, {
  3.415463248944501*^9, 3.415463259427451*^9}, {3.415463312487953*^9, 
  3.415463327121243*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The list of variables defining the optic.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"optic", "=", 
   RowBox[{"{", 
    RowBox[{
    "x3", ",", "y3", ",", "z3", ",", "yaw3", ",", "pitch3", ",", "roll3"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"optic", "::", "usage"}], "=", 
   "\"\<optic is a list of the variables specifying the optic.\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The optic COM.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"COM3", "=", 
   RowBox[{"{", 
    RowBox[{"COM3x", ",", "COM3y", ",", "COM3z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"COM3", "::", "usage"}], "=", 
   "\"\<COM3 is the COM of the optic in local coordinates.\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["The optic FRP.", "Text",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"FRP3", "=", 
   RowBox[{"{", 
    RowBox[{"FRP3x", ",", "FRP3y", ",", "FRP3z"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FRP3", "::", "usage"}], "=", 
   "\"\<FRP3 is the fixture reference point of the optic in local \
coordinates.\>\""}], ";"}]}], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The attachment points for the wires from the second mass above\
\>", "Text",
 InitializationCell->True],

Cell["\<\
opticlf=FRP3+{-sl,n5,d4};
opticlf::usage=\"opticlf is the attachment point of the front left fibre at \
the optic.\";
opticlb=FRP3+{sl,n5,d4};
opticlb::usage=\"opticlb is the attachment point of the back left fibre at \
the optic.\";
opticrf=FRP3+{-sl,-n5,d4};
opticrf::usage=\"opticrf is the attachment point of the front right fibre at \
the optic.\";
opticrb=FRP3+{sl,-n5,d4};
opticrb::usage=\"opticrb is the attachment point of the back right fibre at \
the optic.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3940075023897467`*^9, 3.3940075096932487`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Items that contribute to the potential energy", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Gravity", "Text",
 InitializationCell->True],

Cell["\<\
gravlist::usage = \"gravlist is part of the specification of the model. It is \
a list of expressions for the gravitational potential energy of various \
objects. All the terms are taken implicitly to have damping of type gravtype.\
\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
gravlist = {};
AppendTo[gravlist, mn g b2s[massN,COM0][[3]]];
AppendTo[gravlist, m1 g b2s[massU,COM1][[3]]];
AppendTo[gravlist, m2 g b2s[massI,COM2][[3]]];
AppendTo[gravlist, m3 g b2s[optic,COM3][[3]]];\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wires. ", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Usage note for wirelist", "Text",
 InitializationCell->True],

Cell["\<\
wirelist::usage = \"wirelist is part of the specification of the model. It is \
a list of structures defining wires. Each structure containing the following \
items:\\n
{\\n
\tcoordinate list defining first mass,\\n
\tattachment point for first mass (local coordinates),\\n
\tattachment vector for first mass,\\n
\tcoordinate list defining second mass,\\n
\tattachment point for second mass (local coordinates),\\n
\tattachment vector for second mass,\\n
\tYoung's modulus,\\n
\tunstretched length,\\n
\tlongitudinal elasticity,\\n
\tvector defining principal axis 1,\\n
\tmoment of area along principal axis 1,\\n
\tmoment of area along principal axis 2,\\n
\tlinear elasticity type,\\n
\tangular elasticity type\\n
}\";

\t\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialize list of wires to zero", "Text",
 InitializationCell->True],

Cell["wirelist={};", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Upper wires", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeUL,
\tbladeULa, 
\tbladeULavec,
\tmassN,
\tmassNl,
\tmassNlvec,
\tYn,
\tuln,
\tkwn,
\t{1,0,0},
\tMn1,
\tMn2,
\twireUtype,
\twireUatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeUR,
\tbladeURa, 
\tbladeURavec,
\tmassN,
\tmassNr,
\tmassNrvec,
\tYn,
\tuln,
\tkwn,
\t{1,0,0},
\tMn1,
\tMn2,
\twireUtype,
\twireUatype
}];\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Intermediate wires", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeIL,
\tbladeILf, 
\tbladeILfvec,
\tmassU,
\tmassUlf,
\tmassUlfvec,
\tY1,
\tul1,
\tkw1,
\t{1,0,0},
\tM11,
\tM12,
\twireItype,
\twireIatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeIR,
\tbladeIRf, 
\tbladeIRfvec,
\tmassU,
\tmassUrf,
\tmassUrfvec,
\tY1,
\tul1,
\tkw1,
\t{1,0,0},
\tM11,
\tM12,
\twireItype,
\twireIatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeIL,
\tbladeILb, 
\tbladeILbvec,
\tmassU,
\tmassUlb,
\tmassUlbvec,
\tY1,
\tul1,
\tkw1,
\t{1,0,0},
\tM11,
\tM12,
\twireItype,
\twireIatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeIR,
\tbladeIRb, 
\tbladeIRbvec,
\tmassU,
\tmassUrb,
\tmassUrbvec,
\tY1,
\tul1,
\tkw1,
\t{1,0,0},
\tM11,
\tM12,
\twireItype,
\twireIatype
}];\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Lower wires", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeLL,
\tbladeLLf, 
\tbladeLLfvec,
\tmassI,
\tmassIulf,
\tmassIulfvec,
\tY2,
\tul2,
\tkw2,
\t{1,0,0},
\tM21,
\tM22,
\twireLtype,
\twireLatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeLR,
\tbladeLRf, 
\tbladeLRfvec,
\tmassI,
\tmassIurf,
\tmassIurfvec,
\tY2,
\tul2,
\tkw2,
\t{1,0,0},
\tM21,
\tM22,
\twireLtype,
\twireLatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeLL,
\tbladeLLb, 
\tbladeLLbvec,
\tmassI,
\tmassIulb,
\tmassIulbvec,
\tY2,
\tul2,
\tkw2,
\t{1,0,0},
\tM21,
\tM22,
\twireLtype,
\twireLatype
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[wirelist,{
\tbladeLR,
\tbladeLRb, 
\tbladeLRbvec,
\tmassI,
\tmassIurb,
\tmassIurbvec,
\tY2,
\tul2,
\tkw2,
\t{1,0,0},
\tM21,
\tM22,
\twireLtype,
\twireLatype
}];\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Fibres", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Upper necks", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.4154634651814413`*^9, 3.415463467626718*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tmassI,
\tmassIllf, 
\tmassIllfvec,
\tnulf,
\tCOM,
\t0,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506758189762*^9, 3.4115067978834333`*^9}, 
   3.4154634299018593`*^9, {3.415463557798984*^9, 3.41546356275115*^9}, {
   3.415463660684115*^9, 3.4154636676607428`*^9}, {3.415464971737947*^9, 
   3.4154649772457657`*^9}, 3.415466467465485*^9}],

Cell["\<\
AppendTo[wirelist,{
\tmassI,
\tmassIlrf,
\tmassIlrfvec,
\tnurf,
\tCOM,
\t0,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506811397604*^9, 3.4115068268640842`*^9}, 
   3.415463430580315*^9, {3.415463566415409*^9, 3.415463569919765*^9}, {
   3.415463629307098*^9, 3.415463630898829*^9}, {3.41546498917811*^9, 
   3.415464991638406*^9}, 3.4154664675095377`*^9}],

Cell["\<\
AppendTo[wirelist,{
\tmassI,
\tmassIllb, 
\tmassIllbvec,
\tnulb,
\tCOM,
\t0,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506831926078*^9, 3.411506847047192*^9}, {
   3.4115069116101627`*^9, 3.411506915529984*^9}, 3.415463431516317*^9, {
   3.41546357357578*^9, 3.415463576648291*^9}, {3.415463624802312*^9, 
   3.415463626506423*^9}, {3.4154649971934137`*^9, 3.415465000462788*^9}, 
   3.415466467548791*^9}],

Cell["\<\
AppendTo[wirelist,{
\tmassI,
\tmassIlrb,
\tmassIlrbvec,
\tnurb,
\tCOM,
\t0,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506853575745*^9, 3.411506860503745*^9}, {
   3.411506919426365*^9, 3.411506923474594*^9}, 3.415463432332026*^9, {
   3.415463589080764*^9, 3.4154636220905743`*^9}, {3.4154650122794523`*^9, 
   3.415465017055566*^9}, 3.415466467594523*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Midsections", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.4154634651814413`*^9, 3.415463467626718*^9}, {
  3.415463522872572*^9, 3.4154635322936373`*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tnulf,
\tCOM, 
\t0,
\tnllf,
\tCOM,
\t0,
\tY3,
\tul3*(1-2*nf),
\tkw3m,
\t{1,0,0},
\t10^-20, (* needs to be non-zero *)
\t10^-20, (* needs to be non-zero *)
\tfibretype,
\tgravtype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506758189762*^9, 3.4115067978834333`*^9}, 
   3.4154634299018593`*^9, {3.415463772932979*^9, 3.415463789034766*^9}, {
   3.415463862158531*^9, 3.4154639120328283`*^9}, {3.415464056791456*^9, 
   3.415464077641748*^9}, {3.415464163901843*^9, 3.415464165414123*^9}, 
   3.415466452202723*^9, {3.415466486156383*^9, 3.415466491297843*^9}, {
   3.415469608850444*^9, 3.415469609861953*^9}, 3.4154696401736917`*^9, {
   3.415480983661825*^9, 3.415480985132386*^9}, {3.415481043399778*^9, 
   3.415481044479739*^9}, {3.415481486340433*^9, 3.4154814880351133`*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tnurf,
\tCOM,
\t0,
\tnlrf,
\tCOM,
\t0,
\tY3,
\tul3*(1-2*nf),
\tkw3m,
\t{1,0,0},
\t10^-20, (* needs to be non-zero *)
\t10^-20, (* needs to be non-zero *)
\tfibretype,
\tgravtype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506811397604*^9, 3.4115068268640842`*^9}, 
   3.415463430580315*^9, {3.41546380004099*^9, 3.415463811723632*^9}, {
   3.415463882862269*^9, 3.4154638930555677`*^9}, {3.415464065464612*^9, 
   3.415464080281118*^9}, {3.415464158269841*^9, 3.415464160989799*^9}, {
   3.415464212287694*^9, 3.4154642171524878`*^9}, 3.415466452247748*^9, {
   3.4154664973198853`*^9, 3.415466498468245*^9}, {3.415469616150032*^9, 
   3.4154696362061243`*^9}, 3.4154809905934753`*^9, {3.415481036303154*^9, 
   3.415481038239312*^9}, {3.41548144755237*^9, 3.415481482589913*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tnulb,
\tCOM, 
\t0,
\tnllb,
\tCOM,
\t0,
\tY3,
\tul3*(1-2*nf),
\tkw3m,
\t{1,0,0},
\t10^-20, (* needs to be non-zero *)
\t10^-20, (* needs to be non-zero *)
\tfibretype,
\tgravtype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506831926078*^9, 3.411506847047192*^9}, {
   3.4115069116101627`*^9, 3.411506915529984*^9}, 3.415463431516317*^9, {
   3.4154638206766453`*^9, 3.415463829973764*^9}, {3.41546388572254*^9, 
   3.4154638981201963`*^9}, {3.415464084034031*^9, 3.4154640886012897`*^9}, {
   3.4154641707422543`*^9, 3.415464171838525*^9}, 3.415466452285425*^9, 
   3.415466505181869*^9, {3.415469618558515*^9, 3.415469633366067*^9}, 
   3.415480993304635*^9, {3.41548103293519*^9, 3.415481034023095*^9}, {
   3.415481493268909*^9, 3.415481495278143*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tnurb,
\tCOM,
\t0,
\tnlrb,
\tCOM,
\t0,
\tY3,
\tul3*(1-2*nf),
\tkw3m,
\t{1,0,0},
\t10^-20, (* needs to be non-zero *)
\t10^-20, (* needs to be non-zero *)
\tfibretype,
\tgravtype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506853575745*^9, 3.411506860503745*^9}, {
   3.411506919426365*^9, 3.411506923474594*^9}, 3.415463432332026*^9, {
   3.415463836678232*^9, 3.415463848077462*^9}, {3.415463889092416*^9, 
   3.415463901511983*^9}, {3.4154640977706833`*^9, 3.415464101361792*^9}, {
   3.415464175078382*^9, 3.415464176318749*^9}, 3.4154664521535597`*^9, 
   3.415466508761923*^9, {3.415469624157325*^9, 3.415469627942156*^9}, 
   3.415480998233547*^9, {3.415481029473661*^9, 3.415481030766101*^9}, {
   3.41548150017234*^9, 3.415481501621173*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lower necks", "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.41546349227883*^9, 3.4154634980832777`*^9}}],

Cell["\<\
AppendTo[wirelist,{
\tnllf,
\tCOM, 
\t0,
\toptic,
\topticlf,
\topticlfvec,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506882194569*^9, 3.411506889081924*^9}, {
   3.411506931362896*^9, 3.411506935331526*^9}, 3.415463439395172*^9, {
   3.4154636867977448`*^9, 3.415463693326149*^9}, {3.4154641097633753`*^9, 
   3.4154641140917377`*^9}, 3.4154664672958517`*^9}],

Cell["\<\
AppendTo[wirelist,{
\tnlrf,
\tCOM,
\t0,
\toptic,
\topticrf,
\topticrfvec,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.41150694487689*^9, 3.411506965132845*^9}, 
   3.41546344006866*^9, {3.41546369769337*^9, 3.41546370330173*^9}, {
   3.415464118699979*^9, 3.415464121219965*^9}, 3.4154664673429947`*^9}],

Cell["\<\
AppendTo[wirelist,{
\tnllb,
\tCOM, 
\t0,
\toptic,
\topticlb,
\topticlbvec,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506972694572*^9, 3.411506984214487*^9}, 
   3.4154634408366613`*^9, {3.4154637081904583`*^9, 3.415463716951282*^9}, {
   3.4154641272523737`*^9, 3.415464129764874*^9}, 3.4154664673801737`*^9}],

Cell["\<\
AppendTo[wirelist,{
\tnlrb,
\tCOM,
\t0,
\toptic,
\topticrb,
\topticrbvec,
\tY3,
\tul3*nf,
\tkw3n,
\t{1,0,0},
\tM31,
\tM32,
\tfibretype,
\tfibreatype
}];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411506989327443*^9, 3.4115070014951763`*^9}, 
   3.415463441748226*^9, {3.4154637212233562`*^9, 3.415463728127386*^9}, {
   3.415464144349042*^9, 3.4154641468772383`*^9}, 3.4154664674252033`*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blades", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Usage note for springlist", "Text",
 InitializationCell->True],

Cell["\<\
springlist::usage = \"springlist is part of the specification of the model. \
It is a list of structures defining springs. Each structure containing the \
following items:\\n
{\\n
\tcoordinate list defining first mass,\\n
\tattachment point for first mass (local coordinates),\\n
\tattachment angles for first mass (yaw, pitch, roll),\\n
\tcoordinate list defining second mass,\\n
\tattachment point for second mass (local coordinates),\\n
\tattachment angles for second mass (yaw, pitch, roll),\\n
\tdamping type,\\n
\t6x6 elasticity matrix,\\n
\t1*6 force vector\\n
}\";\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialize list to empty", "Text",
 InitializationCell->True],

Cell["springlist = {};", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Upper blades", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tsupport,
\tbladeULnom,
\t{0,pitchbul,rollbul},
\tbladeUL,
\tCOM,
\t{0,pitchbul,rollbul},
\tbladeUtype,
\t{
\t\t{kbux,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbuz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdu*kbuz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tsupport,
\tbladeURnom,
\t{0,pitchbur,rollbur},
\tbladeUR,
\tCOM,
\t{0,pitchbur,rollbur},
\tbladeUtype,
\t{
\t\t{kbux,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbuz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdu*kbuz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intermediate blades", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tmassN,
\tbladeILnom,
\t{0,pitchbil,rollbil},
\tbladeIL,
\tCOM,
\t{0,pitchbil,rollbil},
\tbladeItype,
\t{
\t\t{kbix,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbiz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdi*kbiz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tmassN,
\tbladeIRnom,
\t{0,pitchbir,rollbir},
\tbladeIR,
\tCOM,
\t{0,pitchbir,rollbir},
\tbladeItype,
\t{
\t\t{kbix,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kbiz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdi*kbiz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lower blades", "Text",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tmassU,
\tbladeLLnom,
\t{0,pitchbll,rollbll},
\tbladeLL,
\tCOM,
\t{0,pitchbll,rollbll},
\tbladeLtype,
\t{
\t\t{kblx,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kblz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdl*kblz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
AppendTo[springlist, {
\tmassU,
\tbladeLRnom,
\t{0,pitchblr,rollblr},
\tbladeLR,
\tCOM,
\t{0,pitchblr,rollblr},
\tbladeLtype,
\t{
\t\t{kblx,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,kblz,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0},
\t\t{0,0,0,0,0,0}
\t},
\t{0,0,bdl*kblz,0,0,0}
}];\
\>", "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell["The kinetic energy", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["The moment of inertia tensors in body coordinates", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IBU = {
\t{Ibtxu, Ibtxyu, Ibtzxu}, 
\t{Ibtxyu, Ibtyu, Ibtyzu}, 
\t{Ibtzxu, Ibtyzu, Ibtzu}
};\t(* upper blade tip *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IMN = {
\t{Inx, Inxy, Inzx}, 
\t{Inxy, Iny, Inyz}, 
\t{Inzx, Inyz, Inz}
};\t(* top mass *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IBI = {
\t{Ibtxi, Ibtxyi, Ibtzxi}, 
\t{Ibtxyi, Ibtyi, Ibtyzi}, 
\t{Ibtzxi, Ibtyzi, Ibtzi}
};\t(* lower blade tip *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IM1 = {
\t{I1x, I1xy, I1zx}, 
\t{I1xy, I1y, I1yz}, 
\t{I1zx, I1yz, I1z}
};\t(* second mass *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IBL = {
\t{Ibtxl, Ibtxyl, Ibtzxl}, 
\t{Ibtxyl, Ibtyl, Ibtyzl}, 
\t{Ibtzxl, Ibtyzl, Ibtzl}
};\t(* lower blade tip *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IM2 = {
\t{I2x, I2xy, I2zx}, 
\t{I2xy, I2y, I2yz}, 
\t{I2zx, I2yz, I2z}
};\t(* intermediate mass *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IM3 = {
\t{I3x, I3xy, I3zx}, 
\t{I3xy, I3y, I3yz}, 
\t{I3zx, I3yz, I3z}
};\t(* optic *)\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IBU::usage = \"IBU is the MOI tensor for either of the upper blade tips.\";
IMN::usage = \"IMN is the MOI tensor for mass N.\";
IBI::usage = \"IBI is the MOI tensor for either of the intermediate blade \
tips.\";
IM1::usage = \"IM1 is the MOI tensor for mass U tips.\";
IBL::usage = \"IBL is the MOI tensor for either of the lower blade tips.\";
IM2::usage = \"IM2 is the MOI tensor for mass I.\";
IM3::usage = \"IM3 is the MOI tensor for the optic.\";
\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["The expression for kinetic energy", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
kinetic::usage = \"kinetic is part of the specification of the model. It \
should be an expression for the kinetic energy in terms of derivatives of the \
variables (e.g., Dt[x1,t]).\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
kinetic = (
\t+(1/2) mn Plus@@(Dt[b2s[massN,COM0],t]^2)
\t+(1/2) omegaB[yaw0, pitch0, roll0].IMN.omegaB[yaw0, pitch0, roll0]

\t+(1/2) m1 Plus@@(Dt[b2s[massU,COM1],t]^2) 
\t+(1/2) omegaB[yaw1, pitch1, roll1].IM1.omegaB[yaw1, pitch1, roll1]

\t+(1/2) m2 Plus@@(Dt[b2s[massI,COM2],t]^2)
\t+(1/2) omegaB[yaw2, pitch2, roll2].IM2.omegaB[yaw2, pitch2, roll2]
\t
\t+(1/2) m3 Plus@@(Dt[b2s[optic,COM3],t]^2) 
\t+(1/2) omegaB[yaw3, pitch3, roll3].IM3.omegaB[yaw3, pitch3, roll3]
);\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Values of constants", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Default values (converted as closely as from Matlab code by Ken Strain et al, \
plus a bit from Bench) as a huge list of substitutions. Don't hack this list \
unless the new values are pretty definitive. Rather, add overriding \
substitutions to the empty list in the line that looks like \"overrides = {};\
\". at the beginning of the calculation proper. Some of the values in this \
list can be symbolic, but there should be enough numerical ones such that \
when all the dependencies are sorted out (by Recurse[]), everything ends up \
numerical.\
\>", "Text",
 InitializationCell->True],

Cell["\<\
The substitutions below are for the quad pendulum protoype at MIT, with CAD \
data for masses and moments of inertia
\
\>", "Text",
 InitializationCell->True],

Cell["\<\
defaultvalues::usage = \"defaultvalues is part of the specification of the \
model. It should be a list of substitutions for all constants. Some of the \
values can be given symbolically in terms of other constants in the list, but \
there should be enough given numerically that the whole collection becomes \
numeric when Recurse[] is applied.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
defaultvalues = {

 g\t\t-> 9.81,

(* MASS (N) is REPRESENTED by a rectangular BLOCK *)

(* in reality it will be larger and less dense. *)

 nx\t-> 0.130,\t\t\t(* dimensions of MASS (N) (square) *)

 ny\t-> 0.500,

 nz\t-> 0.084,

 denn\t-> 4000.,\t\t\t(* density (steel with holes) *)

 mn\t-> 17.6246 (*denn* ny* nz* nx*),\t\t(* MASS (N)  *)

 Inx\t->  0.1640 (* mn*( ny^2+ nz^2)/12 *),\t(* moment of inertia (transverse \
roll) *)

 Iny\t->  0.0483 (* mn*( nz^2+ nx^2)/12 *),\t(* moment of inertia \
(longitudinal pitch) *)

 Inz\t->  0.1594 (* mn*( ny^2+ nx^2)/12 *),\t(* moment of inertia (yaw) *)



(* ******************************************************************** *)

(* MASS (1) is REPRESENTED by a rectangular BLOCK *)

(* in reality it will be larger and less dense. *)



 ux\t-> 0.130,\t\t\t(* dimensions MASS (1) (square) *)

 uy \t-> 0.500,

 uz\t-> 0.084,

 den1\t-> 4000,\t\t\t(* density (steel with holes) *)



 m1\t-> 16.3747 (* den1* uy* uz* ux *),\t(* MASS (1)  *)

\t

 I1x\t->  0.1302 (* m1*( uy^2+ uz^2)/12 *),\t(* moment of inertia (transverse \
roll) *)

 I1y\t->  0.0460 (* m1*( uz^2+ ux^2)/12 *),\t(* moment of inertia \
(longitudinal pitch) *)

 I1z\t->  0.1255 (* m1*( uy^2+ ux^2)/12 *),\t(* moment of inertia (yaw) *)



(* ******************************************************************** *)

 ix\t-> 0.12,\t\t\t(* dimension of MASS (2) (cylinder) *)

 ir\t-> 0.14,

 den2 -> 2200., (* fused silica *)

 m2\t-> 16.24 (* den2*N[Pi]* ir^2* ix *),\t\t(* MASS (2) *)



 I2x\t-> 0.1880 (* m2*(ir^2/2) *),\t\t\t\t(* moment of inertia (transverse \
roll) *)

 I2y\t-> 0.11393 (* m2*(ir^2/4+ix^2/12) *),\t(* moment of inertia \
(longitudinal pitch) *)

 I2z\t-> 0.1130 (* m2*(ir^2/4+ix^2/12) *),\t(* moment of inertia (yaw) *)



(* ********************************************************************* *)

 tx\t\t-> 0.12,\t\t\t(* dimensions of MASS (3) (cylinder) *)

 tr\t\t-> 0.14,

 den3\t-> 4000.,\t\t\t(* density (sapphire) *)



 m3\t\t-> 28.41 (* den3*N[Pi]*tr^2*tx *),\t(* MASS (3) *)



 I3x\t-> 0.2818 (* m3*(tr^2/2) *),\t\t\t\t(* moment of inertia (transverse \
roll) *)

 I3y\t-> 0.1664 (* m3*(tr^2/4+tx^2/12) *),\t(* moment of inertia \
(longitudinal pitch) *)

 I3z\t-> 0.1664 (* m3*(tr^2/4+tx^2/12) *),\t(* moment of inertia (yaw) *)



(* ******************************************************************** *)

(* NOTE: These lengths were interpreted as stretched lengths in the Matlab. \
They are
  now consistently interpreted as either stretched or unstretched lengths \
depending 
  on the value of the switch constant unstretched. 
*)

ln -> 0.54,    \t(* wire length 1: short version *)

l1\t-> 0.304,\t\t(* wire length 2: short version *)

l2\t-> 0.302,\t\t(* wire length 3: short version *)

l3\t-> 0.6,\t    \t(* wire length 4 *)



 

(* ***************************************************************************\
*************** *)

 nwn\t-> 2, (* number of wires (-> number of cantilevers if fitted) per stage \
(2 or 4) *)

 nw1\t-> 4,\t\t\t

 nw2\t-> 4,

 nw3\t-> 4,



(* ***************************************************************************\
******** *)

 rn\t-> 400.*10^-6,\t(* radius of wire (N) *)

 r1\t-> 280.*10^-6,\t(* radius of wire (1) *)

 r2\t-> 280.*10^-6,\t(* radius of wire (2)  *)

 r3n\t-> 180.*10^-6,\t(* radius of wire (3) *)
 r3m\t-> 180.*10^-6,\t(* radius of wire (3) *)



(* ***************************************************************************\
********* *)

 Yn -> 1.65*10^11,\t(* Youngs Modulus of wire\t(N)\t(s/steel 302) *) 

 Y1\t-> 1.65*10^11,\t(* Youngs Modulus of wire\t(1)\t(s/steel 302) *)

 Y2\t-> 1.65*10^11,\t(* Youngs Modulus of wire (2)\t(s/steel 302) *) 

 Y3\t-> 1.65*10^11,\t\t(* Youngs Modulus of wire\t(3)\t(s/steel 302) *)

 

 (* blade design *)
 
 bladealpha -> 1.58,
 bladeY -> 186*10^9,
 hmin -> 0.001,
 hinc-> 0.0005,
 hsteps -> 12,
 wmin -> 0.03,
 wsteps ->18,

 mntb -> (mn+m1+m2+m3)/2,(* total per blade *)

 mnb  -> mn/2,(* uncoupled mass *)
 
smaxn -> 9*10^8,
lmaxn -> 0.55,
wmaxn -> 0.1,

ufcn -> opt[mnb,mntb,smaxn,lmaxn,wmaxn,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,1],
lnb -> opt[mnb,mntb,smaxn,lmaxn,wmaxn,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,2],
anb -> opt[mnb,mntb,smaxn,lmaxn,wmaxn,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,3],
hnb -> opt[mnb,mntb,smaxn,lmaxn,wmaxn,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,4],
stn -> opt[mnb,mntb,smaxn,lmaxn,wmaxn,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,5],

 intmoden -> 55*hnb*0.37^2/(0.002*lnb^2), (* scaled from GEO blade *)


 (* blade design *)

 m1tb -> (m1+m2+m3)/2,(* total per blade *)

 m1b  -> m1/2,(* uncoupled mass *)

smax1 -> 8.5*10^8,
lmax1 -> 0.42,
wmax1 -> 0.055,

ufc1  -> opt[m1b,m1tb,smax1,lmax1,wmax1,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,1],
l1b -> opt[m1b,m1tb,smax1,lmax1,wmax1,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,2],
a1b -> opt[m1b,m1tb,smax1,lmax1,wmax1,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,3],
h1b -> opt[m1b,m1tb,smax1,lmax1,wmax1,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,4],
st1 -> opt[m1b,m1tb,smax1,lmax1,wmax1,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,5],

 intmode1 -> 55*h1b*0.37^2/(0.002*l1b^2), (* scaled from GEO blade *)

(* blade design *)

 m2tb -> (m2+m3)/2, (* total per blade *)

 m2b  -> m2/2, (* uncoupled mass *)

smax2 -> 8.*10^8,
lmax2 -> 0.34,
wmax2 -> 0.044,

ufc2  -> opt[m2b,m2tb,smax2,lmax2,wmax2,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,1],
l2b -> opt[m2b,m2tb,smax2,lmax2,wmax2,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,2],
a2b -> opt[m2b,m2tb,smax2,lmax2,wmax2,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,3],
h2b -> opt[m2b,m2tb,smax2,lmax2,wmax2,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,4],
st2 -> opt[m2b,m2tb,smax2,lmax2,wmax2,g,bladealpha,bladeY,hmin,hinc,hsteps,\
wmin,wsteps,5],

 intmode2 -> 55*h2b*0.37^2/(0.002*l2b^2), (* scaled from GEO blade *)



(* ***************************************************************************\
************** *)

dees -> 0.001,

dm\t\t-> 0.001,\t(* height of wire break-off above c.of m. mass (N) *)

dn\t\t-> 0.001,\t(* height of wire break-off below c.of m. mass (N) *)

d0\t\t-> 0.001,\t(* height of wire break-off above c.of m. mass (1) *)

d1\t\t-> 0.001,\t(* height of wire break-off below c.of m. mass (1) *)

d2\t\t-> -0.001,\t(* height of wire break-off above c.of m. mass (2) *)

d3\t\t-> 0.008,\t(* height of wire break-off below c.of m. mass (2) *)

d4\t\t-> 0.001,\t(* height of wire break-off above c.of m. mass (3) *)

(* additional information for ribbon breakoffs *)

(* these are needed in translation/roll mode calculations *)

twistlength -> 0., (* length of twist section in ribbon *)

d3tr -> d3 - twistlength,

d4tr -> d4 - twistlength,

(* ***************************************************************************\
*************** *)

(* X direction separation  *)

sn\t-> 0.00,\t\t(* 1/2 separation of wires (N)   *)

su\t-> 0.0025,\t\t(* 1/2 separation of wires (1)   *)

si\t-> 0.0025,\t\t(* 1/2 separation of wires (2)   *)

sl\t-> 0.007,\t\t(* 1/2 separation of wires (3)    *)



(* ***************************************************************************\
*************** *)

(* Y direction separation *)

nn0 -> 0.25,   \t(* 1/2 separation of wires (N) at suspension point *)

nn1 -> 0.05,   \t(* 1/2 separation of wires (N) at mass (N)   *)

n0\t-> 0.2,\t\t(* 1/2 separation of wires (1) at mass (N)   *)

n1 -> 0.07,

n2 -> 0.12,

n3\t->ir+0.0065,\t(* 1/2 separation of wires (2) at mass (2)   *)

n4\t->tr+0.0015,\t(* 1/2 separation of wires (3) at mass (2)   *)

n5\t->tr+0.0015,\t(* 1/2 separation of wires (3) at mass (3)   *)



(* true lengths vertically from attachment point to attactment point etc. *)
(* NOTE this section has been adjusted to remove ambiguity - stretched \
lengths have been used throughout *)

tln -> Sqrt[sln^2 - (nn0-nn1)^2]+dm,

tl1 -> Sqrt[sl1^2 - (n0-n1)^2]+dn+d0,

tl2 -> Sqrt[sl2^2 - (n2-n3)^2]+d1+d2,

tl3 -> Sqrt[sl3^2 - (n4-n5)^2]+d3+d4,

ltotal  ->  tln +tl1+tl2+tl3,

(* ***************************************************************************\
******** *)

(*  represents small loss *)

bd -> 0.00, (*  makes phases of open loop plots look nicer *)

leverpitch -> 0.06,

leverroll -> 0.09,

leveryaw -> 0.09,

gainf->1,
gain->6/gainf,
gainvpr->gain,
gainlty->gain,
gainpitch->gainvpr,
gainroll->1.4*gainvpr/3.,
gainyaw->1.*gainlty,
gainvertical->2.*gainvpr/3.,
gainlongitudinal->gainlty,
gaintransverse->2.*gainlty,


(* *********** END OF STUFF COPIED FROM QUADOPT.M \
**************************************** *)

unstretched -> False, (* switch specifying whether ln...l3 are interpreted as \
unstretched lengths or stretched lengths *)

vertblades->True, (* switch specifiying whether the blades act vertically or \
at right angles to wires *)

matlabcompat->False, (* switch for certain fudges to simulate GEO Matlab \
model *) 

uln->If[unstretched,ln,ln-(mn+m1+m2+m3)*g/(nwn*kwn*Cos[ArcSin[(nn0-nn1)/ln]])]\
,
ul1->If[unstretched,l1,l1-(m1+m2+m3)*g/(nw1*kw1*Cos[ArcSin[(n0-n1)/l1]])],
ul2->If[unstretched,l2,l2-(m2+m3)*g/(nw2*kw2*Cos[ArcSin[(n2-n3)/l2]])],
ul3->If[unstretched,l3,l3-m3*g/(nw3*kw3*Cos[ArcSin[(n4-n5)/l3]])],

sln->If[unstretched,ln+(mn+m1+m2+m3)*g/(nwn*kwn*Cos[ArcTan[(nn0-nn1)/ln]]),ln]\
,
sl1->If[unstretched,l1+(m1+m2+m3)*g/(nw1*kw1*Cos[ArcTan[(n0-n1)/l1]]),l1],
sl2->If[unstretched,l2+(m2+m3)*g/(nw2*kw2*Cos[ArcTan[(n2-n3)/l2]]),l2],
sl3->If[unstretched,l3+m3*g/(nw3*kw3*Cos[ArcTan[(n4-n5)/l3]]),l3],

sin->(nn1-nn0)/sln,
si1->(n1-n0)/sl1,
si2->(n3-n2)/sl2,
si3->(n5-n4)/sl3,
cn->Sqrt[sln^2-(nn1-nn0)^2]/sln,
c1->Sqrt[sl1^2-(n1-n0)^2]/sl1,
c2->Sqrt[sl2^2-(n3-n2)^2]/sl2,
c3->Sqrt[sl3^2-(n5-n4)^2]/sl3,

pitchbul->0,  (* pitch mounting angle of upper left blade spring *)
pitchbur->0,  (* pitch mounting angle of upper right blade spring *)
pitchbil->0,  (* pitch mounting angle of intermediate left blade spring *)
pitchbir->0,  (* pitch mounting angle of intermediate right blade spring *)
pitchbll->0,  (* pitch mounting angle of lower left blade spring *)
pitchblr->0,  (* pitch mounting angle of lower right blade spring *)
rollbul->If[vertblades,0,-ArcSin[sin]],  (* roll mounting angle of upper left \
blade spring *)
rollbur->If[vertblades,0,ArcSin[sin]],  (* roll mounting angle of upper right \
blade spring *)
rollbil->If[vertblades,0,-ArcSin[si1]],  (* roll mounting angle of \
intermediate left blade spring *)
rollbir->If[vertblades,0,ArcSin[si1]],  (* roll mounting angle of \
intermediate right blade spring *)
rollbll->If[vertblades,0,-ArcSin[si2]],  (* roll mounting angle of lower left \
blade spring *)
rollblr->If[vertblades,0,ArcSin[si2]],  (* roll mounting angle of lower right \
blade spring *)

An->N[Pi]*rn^2, (* effective average cross-sectional area of top wires *)
A1->N[Pi]*r1^2, (* effective average cross-sectional area of second wires *)
A2->N[Pi]*r2^2, (* effective average cross-sectional area of third wires *)
A3n->N[Pi]*r3n^2, (* effective average cross-sectional area of fibre necks *)
A3m->N[Pi]*r3m^2, (* effective average cross-sectional area of fibre \
midsections *)

nf -> 0.1,
kwn->Yn*An/ln, (* net longitudinal elasticity of top wires *) 
kw1->Y1*A1/l1, (* net longitudinal elasticity of second wires *) 
kw2->Y2*A2/l2, (* net longitudinal elasticity of third wires *) 
kw3->1/(1/kw3m+2/kw3n), (* net longitudinal elasticity of fibres *)
kw3n->Y3*A3n/(nf*l3), (* net longitudinal elasticity of one fibre neck *)
kw3m->Y3*A3m/((1-2*nf)*l3), (* net longitudinal elasticity of fibre \
midsection *)

kbuz->mnb*(2*N[Pi]*ufcn)^2, (* net elasticity of upper blade *) 
kbiz->m1b*(2*N[Pi]*ufc1)^2, (* net elasticity of middle blade *) 
kblz->m2b*(2*N[Pi]*ufc2)^2, (* net elasticity of lower blade *)

kbux->10000*kbuz,
kbix->10000*kbiz,
kblx->10000*kblz,

bdu->If[vertblades,1,1/cn]*(mn/2+m1/2+m2/2+m3/2)*g/kbuz, (* effective initial \
upper blade deformation *)
bdi->If[vertblades,1,1/c1]*(m1/2+m2/2+m3/2)*g/kbiz, (* effective initial \
middle blade deformation *)
bdl->If[vertblades,1,1/c2]*(m2/2+m3/2)*g/kblz,  (* effective initial lower \
blade deformation *)

Inxy -> 0,
Inyz -> 0,
Inzx -> 0,
COM0x -> 0,
COM0y -> 0,
COM0z -> 0,
FRP0x -> 0,
FRP0y -> 0,
FRP0z -> 0,
I1xy -> 0,
I1yz -> 0,
I1zx -> 0,
COM1x -> 0,
COM1y -> 0,
COM1z -> 0,
FRP1x -> 0,
FRP1y -> 0,
FRP1z -> 0,
I2xy -> 0,
I2yz -> 0,
I2zx -> 0,
COM2x -> 0,
COM2y -> 0,
COM2z -> 0,
FRP2x -> 0,
FRP2y -> 0,
FRP2z -> 0,
I3xy -> 0,
I3yz -> 0,
I3zx -> 0,
COM3x -> 0,
COM3y -> 0,
COM3z -> 0,
FRP3x -> 0,
FRP3y -> 0,
FRP3z -> 0,

btx->0.03,\t\t(* display size of blade tip *)
bty->0.03,\t\t(* display size of blade tip *)
btz->0.03,\t\t(* display size of blade tip *)

Mn1-> (1/4) N[Pi] rn^4, (* moment of area of wire n in direction \"1\" *)
Mn2-> (1/4) N[Pi] rn^4, (* moment of area of wire n in direction \"2\" *)
M11-> (1/4) N[Pi] r1^4, (* moment of area of wire 1 in direction \"1\" *)
M12-> (1/4) N[Pi] r1^4, (* moment of area of wire 1 in direction \"2\" *)
M21-> (1/4) N[Pi] r2^4, (* moment of area of wire 2 in direction \"1\" *)
M22-> (1/4) N[Pi] r2^4, (* moment of area of wire 2 in direction \"2\" *)
M31-> (1/4) N[Pi] r3n^4, (* moment of area of wire 3 in direction \"1\" *)
M32-> (1/4) N[Pi] r3n^4, (* moment of area of wire 3 in direction \"2\" *)

(* damping stuff *)
temperature      -> ifo[Suspension,Temp],
boltzmann      -> ifo[Constants,kB],

alphasilica-> ifo[Suspension,Silica,Alpha],(* coeff. thermal expansion *)
betasilica-> 0.00015 (* ifo[Suspension,Silica,dlnEdT]*), (* temp. dependence \
Youngs modulus *)
rhosilica-> ifo[Suspension,Silica,Rho], (* mass density *)
Csilica-> ifo[Suspension,Silica,C], 
Ksilica-> ifo[Suspension,Silica,K],   (* W/(m kg)       *)
Ysilica    -> ifo[Suspension,Silica,Ey], 
phisilica->2. 10^-8,\t\t\t\t\t\t(* intrinsic/bulk damping *)
phissilica->ifo[Suspension,Silica,Phi], (* surface damping, units of m *)

rhosteel  -> ifo[Suspension,C70Steel,Rho],
Csteel    -> ifo[Suspension,C70Steel,C],
Ksteel    -> ifo[Suspension,C70Steel,K],
Ysteel    -> ifo[Suspension,C70Steel,Ey], 
alphasteel  -> ifo[Suspension,C70Steel,Alpha], 
betasteel   -> ifo[Suspension,C70Steel,dlnEdT], 
phisteel -> ifo[Suspension,C70Steel,Phi], 

rhomarag   -> ifo[Suspension,MaragingSteel,Rho], 
Cmarag     -> ifo[Suspension,MaragingSteel,C], 
Kmarag     -> ifo[Suspension,MaragingSteel,K], 
Ymarag     -> ifo[Suspension,MaragingSteel,Ey],
alphamarag   -> ifo[Suspension,MaragingSteel,Alpha], 
betamarag    -> ifo[Suspension,MaragingSteel,dlnEdT], 
phimarag -> ifo[Suspension,MaragingSteel,Phi],
tmU    -> ifo[Suspension,Stage,4,Blade], (* ?????? *)
tmI    -> ifo[Suspension,Stage,3,Blade],  (* ?????? *)
tmL    -> ifo[Suspension,Stage,2,Blade],  (* ?????? *)

magicnumber->7.32 10^-2,
deltabladeU->Ymarag*alphamarag^2*temperature/(rhomarag*Cmarag), (* cf Bench \
delta_v1 *)
deltabladeI->Ymarag*alphamarag^2*temperature/(rhomarag*Cmarag), (* cf Bench \
delta_v2 *)
deltabladeL->Ymarag*alphamarag^2*temperature/(rhomarag*Cmarag), (* cf Bench \
delta_v3 *)
deltawireU->Ysteel*temperature*(alphasteel-betasteel*g*(mn+m1+m2+m3)/(nwn*N[\
Pi]*rn^2*Ysteel))^2/(rhosteel*Csteel), (* cf Bench delta_h1 *)
deltawireI->Ysteel*temperature*(alphasteel-betasteel*g*(m1+m2+m3)/(nw1*N[Pi]*\
r1^2*Ysteel))^2/(rhosteel*Csteel), (* cf Bench delta_h2 *)
deltawireL->Ysteel*temperature*(alphasteel-betasteel*g*(m2+m3)/(nw2*N[Pi]*r2^\
2*Ysteel))^2/(rhosteel*Csteel), (* cf Bench delta_h3 *)
deltafibre->Ysteel*temperature*(alphasteel-betasteel*g*(m3)/(nw3*N[Pi]*r3n^2*\
Ysteel))^2/(rhosteel*Csteel), 
(* deltafibre->Ysilica*temperature*(alphasilica-betasilica*g*(m3)/(nw3*N[Pi]*\
r3n^2*Ysilica))^2/(rhosilica*Csilica), *)
taubladeU->rhomarag*Cmarag*tmU^2/(Kmarag*N[Pi]^2),
taubladeI->rhomarag*Cmarag*tmI^2/(Kmarag*N[Pi]^2),
taubladeL->rhomarag*Cmarag*tmL^2/(Kmarag*N[Pi]^2),
tauwireU->magicnumber*rhosteel*Csteel*(2*rn)^2/Ksteel, (* cf Bench tau_steel1 \
*)
tauwireI->magicnumber*rhosteel*Csteel*(2*r1)^2/Ksteel, (* cf Bench tau_steel2 \
*)
tauwireL->magicnumber*rhosteel*Csteel*(2*r2)^2/Ksteel, (* cf Bench tau_steel3 \
*)
taufibre->magicnumber*rhosteel*Csteel*(2*r3n)^2/Ksteel, 
(*taufibre->magicnumber*rhosilica*Csilica*4*(N[Pi]*r3n^2)/N[Pi],*) (* cf \
Bench tau_si *)
damping[imag,bladeUtype] -> ((phimarag + \
deltabladeU*(2*N[Pi]*#1*taubladeU)/(1+(2*N[Pi]*#1*taubladeU)^2))&),
damping[imag,bladeItype] -> ((phimarag + \
deltabladeI*(2*N[Pi]*#1*taubladeI)/(1+(2*N[Pi]*#1*taubladeI)^2))&),
damping[imag,bladeLtype] -> ((phimarag + \
deltabladeL*(2*N[Pi]*#1*taubladeL)/(1+(2*N[Pi]*#1*taubladeL)^2))&),
damping[imag,wireUtype] -> (phisteel&),
damping[imag,wireItype] -> (phisteel&),
damping[imag,wireLtype] -> (phisteel&),
damping[imag,wireUatype] -> ((phisteel + \
deltawireU*(2*N[Pi]*#1*tauwireU)/(1+(2*N[Pi]*#1*tauwireU)^2))&),
damping[imag,wireIatype] -> ((phisteel + \
deltawireI*(2*N[Pi]*#1*tauwireI)/(1+(2*N[Pi]*#1*tauwireI)^2))&),
damping[imag,wireLatype] -> ((phisteel + \
deltawireL*(2*N[Pi]*#1*tauwireL)/(1+(2*N[Pi]*#1*tauwireL)^2))&),
damping[imag,fibretype] -> (phisteel&), (* ((phisilica + phissilica/r3n/2)&) \
*)
damping[imag,fibreatype] -> ((phisteel + \
deltafibre*(2*N[Pi]*#1*taufibre)/(1+(2*N[Pi]*#1*taufibre)^2))&), 
(* ((phisilica + phissilica/r3n + \
deltafibre*(2*N[Pi]*#1*taufibre)/(1+(2*N[Pi]*#1*taufibre)^2))&) *)
x00->0,
y00->0,
z00->0,
yaw00->0,
pitch00->0,
roll00->0,
constraintsubstitutions[] (* generates and splices in substitutions of form \
kconx1->0 *)
};\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3909830676385803`*^9, 3.390983080642127*^9}, {
  3.394008200434445*^9, 3.3940082413765583`*^9}, {3.394008325506398*^9, 
  3.394008330767562*^9}, {3.4154643568527403`*^9, 3.4154643637274437`*^9}, {
  3.415464405390304*^9, 3.415464432932406*^9}, {3.415464467188801*^9, 
  3.4154646878480177`*^9}, {3.415464724701033*^9, 3.415464761289872*^9}, {
  3.415465381539312*^9, 3.415465545370368*^9}, {3.4154669356045027`*^9, 
  3.4154669363837767`*^9}, {3.415466976860549*^9, 3.415466982505513*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usage tags for all the constants", "Text",
 InitializationCell->True],

Cell["\<\
g::usage = \"g is local gravity.\";

nx::usage = \"nx is x size of top mass (mass N).\";\t
ny::usage = \"ny is y size of top mass (mass N).\";\t
nz::usage = \"nz is z size of top mass (mass N).\";\t
denn::usage = \"denn is density of top mass (mass N).\";
mn::usage = \"mn is mass of top mass (mass N).\";
Inx::usage = \"Inx is x-axis MOI of top mass (mass N).\";
Iny::usage = \"Iny is y-axis MOI of top mass (mass N).\";
Inz::usage = \"Inz is z-axis MOI of top mass (mass N).\";

ux::usage = \"ux is x size of second top mass (mass U).\";\t
uy::usage = \"uy is y size of second top mass (mass U).\";\t
uz::usage = \"uz is z size of second top mass (mass U).\";\t
den1::usage = \"den1 is density of second top mass (mass U).\";
m1::usage = \"m1 is mass of second top mass (mass U).\";
I1x::usage = \"I1x is x-axis MOI of second top mass (mass U).\";
I1y::usage = \"I1y is y-axis MOI of second top mass (mass U).\";
I1z::usage = \"I1z is z-axis MOI of second top mass (mass U).\";

ix::usage = \"ix is thickness of intermediate mass (mass I).\";\t
ir::usage = \"iy is radius of intermediate mass (mass I).\";\t
den2::usage = \"den2 is density of intermediate mass (mass I).\";
m2::usage = \"m2 is mass of intermediate mass (mass I).\";
I2x::usage = \"I2x is x-axis MOI of intermediate mass (mass I).\";
I2y::usage = \"I2y is y-axis MOI of intermediate mass (mass I).\";
I2z::usage = \"I2z is z-axis MOI of intermediate mass (mass I).\";

tx::usage = \"ux is thickness of optic.\";\t
tr::usage = \"uy is radius of optic.\";\t
den3::usage = \"den3 is density of optic.\";
m3::usage = \"m3 is mass of optic.\";
I3x::usage = \"I3x is x-axis MOI of optic.\";
I3y::usage = \"I3y is y-axis MOI of optic.\";
I3z::usage = \"I3z is z-axis MOI of optic.\";

unstretched::usage = \"unstretched is a switch that specifies whether ln, l1, \
l2 and l3 are to be interpreted as unstretched lengths or (approximate) \
stretched lengths.\";
kwfromunstretched::usage = \"kwfromunstretched is a switch that specifies \
whether the net elasticities of the wires are to be computed using \
unstretched lengths or (approximate) stretched lengths.\";

ln::usage = \"ln is part of the specification of the model and represents the \
wire length from structure to top mass. It is interpreted as either a \
stretched length or an unstretched length depending on the value of the \
switch constant unstretched.\";
l1::usage = \"l1 is part of the specification of the model and represents the \
wire length from top mass to second top mass. It is interpreted as either a \
stretched length or an unstretched length depending on the value of the \
switch constant unstretched.\";
l2::usage = \"l2 is part of the specification of the model and represents the \
wire length from second top mass to intermediate mass. It is interpreted as \
either a stretched length or an unstretched length depending on the value of \
the switch constant unstretched.\";
l3::usage = \"l3 is part of the specification of the model and represents the \
wire (fibre) length from intermediate mass to optic. It is interpreted as \
either a stretched length or an unstretched length depending on the value of \
the switch constant unstretched.\";

uln::usage = \"uln is unstretched wire length from structure to top mass.\";
ul1::usage = \"ul1 is unstretched wire length from top mass to second top \
mass.\";
ul2::usage = \"ul2 is unstretched wire length from second top mass to \
intermediate mass.\";
ul3::usage = \"ul3 is unstretched wire (fibre) length from intermediate mass \
to optic.\";

sln::usage = \"sln is stretched wire length from structure to top mass.\";
sl1::usage = \"sl1 is stretched wire length from top mass to second top mass.\
\";
sl2::usage = \"sl2 is stretched wire length from second top mass to \
intermediate mass.\";
sl3::usage = \"sl3 is stretched wire (fibre) length from intermediate mass to \
optic.\";

sin::usage = \"sin is sine of angle of top wires.\";
si1::usage = \"si1 is sine of angle of second top wires.\";
si2::usage = \"si2 is sine of angle of bottom wires.\";
si3::usage = \"is sine of angle of fibres.\";

cn::usage = \"cn is cosine of angle of top wires.\";
c1::usage = \"c1 is cosine of angle of second top wires.\";
c2::usage = \"c2 is cosine of angle of bottom wires.\";
c3::usage = \"c3 is cosine of angle of fibres.\";

nwn::usage = \"nwn is number of wires from structure to top mass.\";
nw1::usage = \"nw1 is number of wires from top mass to second top mass.\";
nw2::usage = \"nw2 is number of wires from second top mass to intermediate \
mass.\";
nw3::usage = \"nw3 is number of wires (fibres) from intermediate mass to \
optic.\";

rn::usage = \"rn is radius of wires from structure to top mass.\";
r1::usage = \"r1 is radius of wires from top mass to second top mass.\";
r2::usage = \"r2 is radius of wires from second top mass to intermediate \
mass.\";
r3n::usage = \"r3n is radius of wires (fibres) necks from intermediate mass \
to optic.\";
r3m::usage = \"r3n is radius of wires (fibres) midsections from intermediate \
mass to optic.\";

Yn::usage = \"Yn is Young's modulus of wires from structure to top mass.\";
Y1::usage = \"Y1 is Young's modulus of wires from top mass to second top \
mass.\";
Y2::usage = \"Y2 is Young's modulus of wires from second top mass to \
intermediate mass.\";
Y3::usage = \"Y3 is Young's modulus of wires (fibres) from intermediate mass \
to optic.\";

mntb::usage = \"mntb is design load on upper blades (on structure).\";
m1tb::usage = \"m1tb is design load on intermediate blades (on top mass).\";
m2tb::usage = \"m2tb is design load on lower blades (on second top mass).\";

mnb::usage = \"mntb is the \\\"uncoupled mass\\\" (its share of the mass only \
one stage below) for the upper blades (on structure).\";
m1b::usage = \"m1tb is the \\\"uncoupled mass\\\" (its share of the mass only \
one stage below) for the intermediate blades (on top mass).\";
m2b::usage = \"m2tb is the \\\"uncoupled mass\\\" (its share of the mass only \
one stage below) for the lower blades (on second top mass).\";

ufcn::usage = \"ufcn is the \\\"uncoupled frequency\\\" (what they would \
vibrate at with only their \\\"uncoupled mass\\\", mnb) for the upper blades \
(on structure).\";
ufc1::usage = \"ufc1 is the \\\"uncoupled frequency\\\" (what they would \
vibrate at with only their \\\"uncoupled mass\\\", mn1) for the intermediate \
blades (on top mass).\";
ufc2::usage = \"ufc2 is the \\\"uncoupled frequency\\\" (what they would \
vibrate at with only their \\\"uncoupled mass\\\", mn2) for the lower blades \
(on second top mass).\";

lnb::usage = \"lnb is the length of the upper blades (on structure).\";
l1b::usage = \"l1b is the length of the the intermediate blades (on top \
mass).\";
l2b::usage = \"l2b is the length of the lower blades (on second top mass).\";

anb::usage = \"anb is the width (at the base) of the upper blades (on \
structure).\";
a1b::usage = \"a1b is the width (at the base) of the the intermediate blades \
(on top mass).\";
a2b::usage = \"a2b is the width (at the base) of the lower blades (on second \
top mass).\";

hnb::usage = \"hnb is the thickness of the upper blades (on structure).\";
h1b::usage = \"h1b is the thickness of the the intermediate blades (on top \
mass).\";
h2b::usage = \"h2b is the thickness of the lower blades (on second top mass).\
\";

snb::usage = \"snb is the (maximum?) strain in the upper blades (on \
structure).\";
s1b::usage = \"s1b is the (maximum?) strain in the intermediate blades (on \
top mass).\";
s2b::usage = \"s2b is the (maximum?) strain in the lower blades (on second \
top mass).\";

intmoden::usage = \"intmoden is the frequency of the internal mode of the \
upper blades (on structure).\";
intmode1::usage = \"intmode1 is the frequency of the internal mode of the \
intermediate blades (on top mass).\";
intmode2::usage = \"intmode2 is the frequency of the internal mode of the \
lower blades (on second top mass).\";



(* ***************************************************************************\
************** *)

dees::usage = \"dees is the default vertical distance from a wire attachment \
point to the COM.\";
dm::usage = \"dm is the height of the wire attachment points above the COM of \
mass N for the wires leading down from the upper blade springs.\";
dn::usage = \"dn is the height of the wire attachment points below the COM of \
mass N for the wires leading down to mass U.\";
d0::usage = \"d0 is the the height of the wire attachment points above the \
COM of mass U for the wires leading down from mass N.\";
d1::usage = \"d1 is the the height of the wire attachment points below the \
COM of mass U for the wires leading down to mass I.\";
d2::usage = \"d2 is the height of the wire attachment points above the COM of \
mass I for the wires leading down from the mass U.\";
d3::usage = \"d3 is the height of the wire attachment points below the COM of \
mass I for the wires leading down to the optic.\";
d4::usage = \"d4 is the the height of the wire attachment points above the \
COM of the optic for the wires leading down from mass I.\";

twistlength::usage = \"twistlength was left over from Ken Strain's model. \
It's not used and it's anybody's guess what it is.\";
d3tr::usage = \"d3tr was left over from Ken Strain's model. It's not used and \
it's anybody's guess what it is.\";
d4tr::usage = \"d4tr was left over from Ken Strain's model. It's not used and \
it's anybody's guess what it is.\";

sn::usage = \"sn is x-direction separation of wires from structure to top \
mass.\";
su::usage = \"su is x-direction separation of wires from top mass to second \
top mass.\";
si::usage = \"si is x-direction separation of wires from second top mass to \
intermediate mass.\";
sl::usage = \"sl is x-direction separation of wires (fibres) from \
intermediate mass to optic.\";

nn0::usage = \"nn0 is the y-direction separation of the wire attachment \
points on the structure for the wires leading down to mass N.\";
nn1::usage = \"nn1 is the y-direction separation of the wire attachment \
points on mass N for the wires leading from the structure.\";
n0::usage = \"n0 is the y-direction separation of the wire attachment points \
on the upper blade springs (mass N) for the wires leading down to mass U.\";
n1::usage = \"n1 is the y-direction separation of the wire attachment points \
on mass U for the wires leading down from the upper blade springs (mass \
N).\";
n2::usage = \"n2 is the y-direction separation of the wire attachment points \
on the intermediate blade springs (mass U) for the wires leading down to mass \
I.\";
n3::usage = \"n3 is the y-direction separation of the wire attachment points \
on mass I for the wires leading down from the intermediate blade springs \
(mass U).\";
n4::usage = \"n4 is the y-direction separation of the wire attachment points \
on mass I for the wires leading down to the optic.\";
n5::usage = \"n5 is the y-direction separation of the wire attachment points \
on the optic for the wires leading down from mass I.\";

tln::usage = \"tln is the vertical distance from structure attachment point \
to the COM of mass N.\";
tl1::usage = \"tl1 is the vertical distance from the COM of mass N to the COM \
of mass U.\";
tl2::usage = \"tl2 is the vertical distance from the COM of mass U to the COM \
of mass I.\";
tl3::usage = \"tl3 is the vertical distance from the COM of mass I to the COM \
of the optic.\";

ltotal::usage = \"ltotal is the vertical distance from the structure \
attachement point to the COM of the optic.\";

bd::usage = \"bd is a control system parameter which is currently not used in \
the Mathematica.\";
leverroll::usage = \"leverroll is a control system parameter which is \
currently not used in the Mathematica.\";
leverpitch::usage = \"leverpitch is a control system parameter which is \
currently not used in the Mathematica.\";
leveryaw::usage = \"leveryaw is a control system parameter which is currently \
not used in the Mathematica.\";
gainf::usage = \"gainf is a control system parameter which is currently not \
used in the Mathematica.\";
gain::usage = \"gain is a control system parameter which is currently not \
used in the Mathematica.\";
gainvpr::usage = \"gainvpr is a control system parameter which is currently \
not used in the Mathematica.\";
gainlty::usage = \"gainlty is a control system parameter which is currently \
not used in the Mathematica.\";
gainpitch::usage = \"gainpitch is a control system parameter which is \
currently not used in the Mathematica.\";
gainroll::usage = \"gainroll is a control system parameter which is currently \
not used in the Mathematica.\";
gainyaw::usage = \"gainyaw is a control system parameter which is currently \
not used in the Mathematica.\";
gainvertical::usage = \"gainvertical is a control system parameter which is \
currently not used in the Mathematica.\";
gainlongitudinal::usage = \"gainlongitudinal is a control system parameter \
which is currently not used in the Mathematica.\";
gaintransverse::usage = \"gaintransverse is a control system parameter which \
is currently not used in the Mathematica.\";

An::usage = \"An is effective average cross-sectional area of wires from \
structure to top mass for the purposes of calculating the longitudinal \
elasticity.\";
A1::usage = \"A1 is effective average cross-sectional area of wires from top \
mass to second top mass for the purposes of calculating the longitudinal \
elasticity.\";
A2::usage = \"A2 is effective average cross-sectional area of wires from \
second top mass to intermediate mass for the purposes of calculating the \
longitudinal elasticity.\";
A3n::usage = \"A3n is effective average cross-sectional area of wire (fibre) \
necks from intermediate mass to optic for the purposes of calculating the \
longitudinal elasticity.\";
A3m::usage = \"A3m is effective average cross-sectional area of wire (fibre) \
midsections from intermediate mass to optic for the purposes of calculating \
the longitudinal elasticity.\";

kwn::usage = \"kwn is net longitudinal elasticity of wires from structure to \
top mass.\";
kw1::usage = \"kw1 is net longitudinal elasticity of wires from top mass to \
second top mass.\";
kw2::usage = \"kw2 is net longitudinal elasticity of wires from second top \
mass to intermediate mass.\";
kw3::usage = \"kw3 is net longitudinal elasticity of wires (fibres) from \
intermediate mass to optic.\";
kw3n::usage = \"kw3n is net longitudinal elasticity of wire (fibre) neck.\";
kw3m::usage = \"kw3m is net longitudinal elasticity of wire (fibre) \
midsection.\";

kbux::usage = \"kbux is the net transverse elasticity of the upper blades (on \
structure).\";
kbix::usage = \"kbix is the net transverse elasticity of the the intermediate \
blades (on top mass).\";
kblx::usage = \"kblx is the net transverse elasticity of the lower blades (on \
second top mass).\";

kbuy::usage = \"kbuy is the net longitudinal elasticity of the upper blades \
(on structure).\";
kbiy::usage = \"kbiy is the net longitudinal elasticity of the the \
intermediate blades (on top mass).\";
kbly::usage = \"kbly is the net longitudinal elasticity of the lower blades \
(on second top mass).\";

kbuz::usage = \"kbuz is the net vertical elasticity of the upper blades (on \
structure).\";
kbiz::usage = \"kbiz is the net vertical elasticity of the the intermediate \
blades (on top mass).\";
kblz::usage = \"kblz is the net vertical elasticity of the lower blades (on \
second top mass).\";

bdu::usage = \"bdu is the effective pre-stretch distance of the upper blades \
(on structure).\";
bdi::usage = \"bdi is the effective pre-stretch distance of the intermediate \
blades (on top mass).\";
bdl::usage = \"bdl is the effective pre-stretch distance of the lower blades \
(on second top mass).\";

kbyawu::usage = \"kbyawu is the upper blade yaw stiffness\";
kbpitchu::usage = \"kbpitchu is the upper blade pitch stiffness\";
kbrollu::usage = \"kbrollu is the upper blade roll stiffness\";  

kbyawi::usage = \"kbyawi is the intermediate blade yaw stiffness\";
kbpitchi::usage = \"kbpitchi is the intermediate blade pitch stiffness\";
kbrolli::usage = \"kbrolli is the intermediate blade roll stiffness\";

kbyawl::usage = \" is the lower blade yaw stiffness\";
kbpitchl::usage = \" is the lower blade pitch stiffness\";
kbrolll::usage = \" is the lower blade roll stiffness\";

Ibtxu::usage = \"Ibtxu is the upper blade tip x MOI\";
Ibtyu::usage = \"Ibtyu is the upper blade tip y MOI\";
Ibtzu::usage = \"Ibtzu is the upper blade tip z MOI\";
Ibtxi::usage = \"Ibtxi is the intermediate blade tip x MOI\";
Ibtyi::usage = \"Ibtyi is the intermediate blade tip y MOI\";
Ibtzi::usage = \"Ibtzi is the intermediate blade tip z MOI\";
Ibtxl::usage = \"Ibtxl is the lower blade tip x MOI\";
Ibtyl::usage = \"Ibtyl is the lower blade tip y MOI\";
Ibtzl::usage = \"Ibtzl is the lower blade tip z MOI\";

Ibtu::usage = \"Ibtu is the MOI tensor of the objects representing the tips \
of the upper blades (on structure).\";
Ibti::usage = \"Ibti is the MOI tensor of the objects representing the tips \
of the intermediate blades (on top mass).\";
Ibtl::usage = \"Ibtl is the MOI tensor of the objects representing the tips \
of the lower blades (on second top mass).\";

btx::usage = \"btx is x-direction size of the box drawn to represent the \
blade tips.\";
bty::usage = \"bty is x-direction size of the box drawn to represent the \
blade tips.\";
btz::usage = \"btz is x-direction size of the box drawn to represent the \
blade tips.\";

Mn1::usage = \"Mn1 is the moment of area of wires from structure to top mass \
in direction \\\"1\\\".\";
Mn2::usage = \"Mn2 is the moment of area of wires from structure to top mass \
in direction \\\"2\\\".\";
M11::usage = \"M11 is the moment of area of wires from top mass to second top \
mass in direction \\\"1\\\".\";
M12::usage = \"M12 is the moment of area of wires from top mass to second top \
mass in direction \\\"2\\\"\";
M21::usage = \"M21 is the moment of area of wires from second top mass to \
intermediate mass in direction \\\"1\\\"\";
M22::usage = \"M22 is the moment of area of wires from second top mass to \
intermediate mass in direction \\\"2\\\"\";
M31::usage = \"M31 is the moment of area of wire (fibre) necks from \
intermediate mass to optic in direction \\\"1\\\"\";
M32::usage = \"M32 is the moment of area of wire (fibre) necks from \
intermediate mass to optic in direction \\\"2\\\"\";

(* damping stuff *)

damping::usage = \"damping[imag,dampingtype] is a multiplier giving the \
frequency dependence of the imaginary (i.e., lossy) part of any potential \
terms tagged with symbol dampingtype. It should be a Mathematica pure \
function which accepts a value of f in Hz. It defaults to 0& but can be given \
a value via a substitution in defaultvalues. damping[real,dampingtype] is the \
corresponding real (i.e., elastic) multiplier. It defaults to 1&.\";

temperature::usage = \"temperature is, well, guess.\";

alphasilica::usage = \"alphasilica is the coefficient of thermal expansion \
for silica.\";
betasilica::usage = \"betasilica is the temperature dependence of Young's \
modulus for silica.\";
rhosilica::usage = \"rhosilica is the density for silica.\";
Csilica::usage = \"Csilica is the heat capacity for silica.\";
Ksilica::usage = \"Ksilica is the bulk modulus for silica.\";
Ysilica::usage = \"Ysilica is the Young's modulus for silica.\";
phisilica::usage = \"phisilica is the bulk loss angle for silica.\";
phissilica::usage = \"phissilica is the surface loss angle (units of m) for \
silica.\";

alphasteel::usage = \"alphasteel is the coefficient of thermal expansion for \
C70 steel.\";
betasteel::usage = \"betasteel is the temperature dependence of Young's \
modulus for C70 steel.\";
rhosteel::usage = \"rhosteel is the density for C70 steel.\";
Csteel::usage = \"Csteel is the heat capacity for C70 steel.\";
Ksteel::usage = \"Ksteel is the bulk modulus for C70 steel.\";
Ysteel::usage = \"Ysteel is the Young's modulus for C70 steel.\";
phisteel::usage = \"phisteel is the bulk loss angle for C70 steel.\";

alphamarag::usage = \"alphamarag is the coefficient of thermal expansion for \
maraging steel.\";
betamarag::usage = \"betamarag is the temperature dependence of Young's \
modulus for maraging steel.\";
rhomarag::usage = \"rhomarag is the density for maraging steel.\";
Cmarag::usage = \"Cmarag is the heat capacity for maraging steel.\";
Kmarag::usage = \"Kmarag is the bulk modulus for maraging steel.\";
Ymarag::usage = \"Ymarag is the Young's modulus for maraging steel.\";
phimarag::usage = \"phimarag is the bulk loss angle for maraging steel.\";

magicnumber::usage = \"magicnumber is a geometrical factor for thermoelastic \
damping.\";
deltabladeU::usage = \"deltabladeU is the thermoelastic damping parameter \
delta for the upper blades.\";
deltabladeI::usage = \"deltabladeI is the thermoelastic damping parameter \
delta for the intermediate blades.\";
deltabladeL::usage = \"deltabladeL is the thermoelastic damping parameter \
delta for the lower blades.\";
deltawireU::usage = \"deltawireU is the thermoelastic damping parameter delta \
for the wires from the structure to mass N.\";
deltawireI::usage = \"deltawireI is the thermoelastic damping parameter delta \
for the wires from from mass N to mass U.\";
deltawireL::usage = \"deltawireL is the thermoelastic damping parameter delta \
for the wires from mass U to mass I.\";
deltafibre::usage = \"deltafibre is the thermoelastic damping parameter delta \
for the wires from mass I to the optic.\";
taubladeU::usage = \"taubladeU is the thermoelastic damping parameter tau for \
the upper blades.\";
taubladeI::usage = \"taubladeI is the thermoelastic damping parameter tau for \
the intermediate blades.\";
taubladeL::usage = \"taubladeL is the thermoelastic damping parameter tau for \
the lower blades.\";
tauwireU::usage = \"tauwireU is the thermoelastic damping parameter tau for \
the wires from the structure to mass N.\";
tauwireI::usage = \"tauwireI is the thermoelastic damping parameter tau for \
the wires from mass N to mass U.\";
tauwireL::usage = \"tauwireL is the thermoelastic damping parameter tau for \
the wires from mass U to mass I.\";
taufibre::usage = \"taufibre is the thermoelastic damping parameter tau for \
the wires from mass I to the optic.\";\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.415464769090788*^9, 3.415464796693597*^9}, {
  3.415465572725556*^9, 3.415465724947836*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initial position (nominal)", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Approximate starting values for finding the minimum of the potential. The \
stretch of the wires has been anticipated in these values and a vertical \
pre-stress has been applied to the blades in the model itself, so the only \
sag that should show up relative to them is due to longitudinal stretching of \
the blades (which cross-couples to vertical via the diagonal wires).\
\>", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
startpos::usage = \"startpos is part of the specification of the model. It \
should be a list of approximate values of all variables to be used as a \
starting point for minimizing the potential. The values can be given \
symbolically in terms of constants defined in the list defaultvalues.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
startpos = {
\tqzul->0,
\tqxul->0,
\tqzur->0,
\tqxur->0,
\tx0->-COM0x,
\ty0->0,
\tz0->z00-tln,
\tyaw0->0,
\tpitch0->0,
\troll0->0,
\tqzil->0,
\tqxil->0,
\tqzir->0,
\tqxir->0,
\tyawir->0,
\tpitchir->0,
\trollir->0,
\tx1->-COM1x,
\ty1->0,
\tz1->z00-tln-tl1,
\tyaw1->0,
\tpitch1->0,
\troll1->0,
\tqzll->0,
\tqxll->0,
\tqzlr->0,
\tqxlr->0,
\tx2->-COM2x,
\ty2->0,
\tz2->z00-tln-tl1-tl2,
\tyaw2->0,
\tpitch2->0,
\troll2->0,
\tqqxulf->-sl, (* extra floats to represent upper neck ends *)
\tqqyulf->n5,
\tqqzulf->z00-tln-tl1-tl2-d3-nf*sl3,
\tqqxurf->-sl,
\tqqyurf->-n5,
\tqqzurf->z00-tln-tl1-tl2-d3-nf*sl3,
\tqqxulb->sl,
\tqqyulb->n5,
\tqqzulb->z00-tln-tl1-tl2-d3-nf*sl3,
\tqqxurb->sl,
\tqqyurb->-n5,
\tqqzurb->z00-tln-tl1-tl2-d3-nf*sl3,
\t
\tqqxllf->-sl, (* extra floats to represent lower neck ends *)
\tqqyllf->n5,
\tqqzllf->z00-tln-tl1-tl2-d3-(1-nf)*sl3,
\tqqxlrf->-sl,
\tqqylrf->-n5,
\tqqzlrf->z00-tln-tl1-tl2-d3-(1-nf)*sl3,
\tqqxllb->sl,
\tqqyllb->n5,
\tqqzllb->z00-tln-tl1-tl2-d3-(1-nf)*sl3,
\tqqxlrb->sl,
\tqqylrb->-n5,
\tqqzlrb->z00-tln-tl1-tl2-d3-(1-nf)*sl3,
\t
\tx3->-COM3x,
\ty3->0,
\tz3->z00-tln-tl1-tl2-tl3,
\tyaw3->0,
\tpitch3->0,
\troll3->0
};\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.411507183134612*^9, 3.411507199134735*^9}, {
  3.411507288631873*^9, 3.4115075540795393`*^9}, {3.411507763379282*^9, 
  3.411507777006044*^9}, {3.415465750674877*^9, 3.415465817063723*^9}, {
  3.4154663278221817`*^9, 3.415466393958716*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Model-specific utilities", "Subsection",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Some useful sets of overrides", "Text",
 InitializationCell->True],

Cell["\<\
NOTE: The lists of overrides defined below are wrapped in the Sequence[] \
function so they will splice themselves into any list. This makes it easy to \
combine them with additional substitutions, e.g., overrides = {lockedblades, \
m3->30};\
\>", "Text",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Overrides to immobilize the blade springs and transfer their compliance into \
the associated wires (for comparability with the Matlab in transverse/roll, \
yaw and vertical)\
\>", "Text",
 InitializationCell->True],

Cell["\<\
lockedblades = Sequence@@{\t\t
\tkwnusual -> (Yn*An)/ln, 
\tkw1usual -> (Y1*A1)/l1, 
\tkw2usual -> (Y2*A2)/l2, 
\tkw3usual -> (Y3*A3)/l3, 
\tkbuzusual -> mnb*(2*N[Pi]*ufcn)^2, 
\tkbizusual -> m1b*(2*N[Pi]*ufc1)^2, 
\tkblzusual -> m2b*(2*N[Pi]*ufc2)^2, 
\tkwn -> recipadd[kwnusual, kbuzusual], 
\tkw1 -> recipadd[kw1usual, kbizusual/2], 
\tkw2 -> recipadd[kw2usual, kblzusual/2], 
\tkw3 -> kw3usual, 
\tkbuz -> 10^5*kbuzusual, 
\tkbiz -> 10^5*kbizusual, 
\tkblz -> 10^5*kblzusual, 
\tkbuy -> 10^5*kbuzusual, 
\tkbiy -> 10^5*kbizusual, 
\tkbly -> 10^5*kblzusual, 
\tkbux -> 10^5*kbuzusual, 
\tkbix -> 10^5*kbizusual, 
\tkblx -> 10^5*kblzusual
};
\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.390983219481341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Overrides to immobilize the blade springs but not transfer their compliance \
into the associated wires (for comparability with the Matlab in \
longitudinal/pitch)\
\>", "Text",
 InitializationCell->True],

Cell["\<\
lockedbladesLP = Sequence@@{\t\t
\tkbuzusual -> mnb*(2*N[Pi]*ufcn)^2, 
\tkbizusual -> m1b*(2*N[Pi]*ufc1)^2, 
\tkblzusual -> m2b*(2*N[Pi]*ufc2)^2, 
\tkbuz -> 10^5*kbuzusual, 
\tkbiz -> 10^5*kbizusual, 
\tkblz -> 10^5*kblzusual, 
\tkbuy -> 10^5*kbuzusual, 
\tkbiy -> 10^5*kbizusual, 
\tkbly -> 10^5*kblzusual, 
\tkbux -> 10^5*kbuzusual, 
\tkbix -> 10^5*kbizusual, 
\tkblx -> 10^5*kblzusual
};
\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{3.3909832287303553`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Some matrices to postprocess the angular displacement elements in a \
eigenvector into a more convenient basis\
\>", "Text",
 InitializationCell->True],

Cell["\<\
e2b::usage = \"e2b is a matrix that applies omegaIB[] to all the the angular \
displacement elements of an eigenvector, converting them to body coordinates.\
\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2b := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaIB[yaw0,pitch0,roll0],
\tIdentityMatrix[3],
\tomegaIB[yaw1,pitch1,roll1],
\tIdentityMatrix[3],
\tomegaIB[yaw2,pitch2,roll2],
\tIdentityMatrix[3],
\tomegaIB[yaw3,pitch3,roll3]
}]/.optval; \
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2s::usage = \"e2s is a matrix that applies omegaIS[] to all the the angular \
displacement elements of an eigenvector, converting them to space \
coordinates.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2s := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaIS[yaw0,pitch0,roll0],
\tIdentityMatrix[3],
\tomegaIS[yaw1,pitch1,roll1],
\tIdentityMatrix[3],
\tomegaIS[yaw2,pitch2,roll2],
\tIdentityMatrix[3],
\tomegaIS[yaw3,pitch3,roll3]
}]/.optval; \
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2ni::usage = \"e2ni is a matrix that applies omegaSNI[] to all the the \
angular displacement elements of an eigenvector, converting them to \
non-incremental yaw/pitch/roll format.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
e2ni := DiagonalBlockMatrix[{
\tIdentityMatrix[3],
\tomegaSNI.omegaIS[yaw0,pitch0,roll0],
\tIdentityMatrix[3],
\tomegaSNI.omegaIS[yaw1,pitch1,roll1],
\tIdentityMatrix[3],
\tomegaSNI.omegaIS[yaw2,pitch2,roll2],
\tIdentityMatrix[3],
\tomegaSNI.omegaIS[yaw3,pitch3,roll3]
}]/.optval; \
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Some vectors representing various interesting excitation inputs\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportxinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "x00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportxinput::usage = \"supportxinput is a vector representing excitation of \
the support in x.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportyinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "y00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportyinput::usage = \"supportyinput is a vector representing excitation of \
the support in y.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportzinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "z00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportzinput::usage = \"supportzinput is a vector representing excitation of \
the support in z.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportyawinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "yaw00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportyawinput::usage = \"supportyawinput is a vector representing \
excitation of the support in yaw.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportpitchinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "pitch00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportpitchinput::usage = \"supportpitchinput is a vector representing \
excitation of the support in pitch.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"supportrollinput", " ", "=", " ", 
   RowBox[{"makeinputvector", "[", "roll00", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
supportrollinput::usage = \"supportrollinput is a vector representing \
excitation of the support in roll.\";\
\>", "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Some vectors for selecting various interesting excitation outputs\
\>", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticxoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "x3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticyoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "y3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticzoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "z3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticyawoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "yaw3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticpitchoutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "pitch3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticrolloutput", " ", "=", " ", 
   RowBox[{"makeoutputvector", "[", "roll3", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticniyawoutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "yaw3", "]"}], ".", "e2ni"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticnipitchoutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "pitch3", "]"}], ".", "e2ni"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"opticnirolloutput", " ", ":=", " ", 
   RowBox[{
    RowBox[{"makeoutputvector", "[", "roll3", "]"}], ".", "e2ni"}]}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["A switch variable to turn graphics on and off", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["doplots = True;", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
doplots::usage = \"doplots is a switch that enables plotting when set to True\
\";\
\>", "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utilities to do plots of the mode shapes", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Various utilities that were formerly in MyShapes`", "Text",
 CellChangeTimes->{{3.390909710957782*^9, 3.390909723227395*^9}, {
  3.39090978021671*^9, 3.390909786501658*^9}}],

Cell["\<\
MyOpenCylinder5::usage = \"MyOpenCylinder5[(r:1, {h1:1,h2:1}, (n:20r))] is a \
list of n polygons approximating an open cylinder \\
centered around the z-axis with radius r from z=h1 to h2.\"; 
MyCuboid::usage = \"MyCuboid is like Cuboid[] but works with RotateShape, etc\
\"; 
MyOpenCuboid::usage = \"MyOpenCuboid is like MyCuboid[] except that the faces \
on the +x side and -x sides are missing\"; \
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390741560268106*^9, 3.390741566680647*^9}, {
  3.390741659535034*^9, 3.390741659538233*^9}}],

Cell["\<\
MyCuboid[{x1_, y1_, z1_}, {x2_, y2_, z2_}] := {Polygon[{{x2, y1, z1}, {x2, \
y2, z1}, {x2, y2, z2}, {x2, y1, z2}}], 
\tPolygon[{{x1, y1, z1}, {x1, y1, z2}, {x1, y2, z2}, {x1, y2, z1}}], 
\tPolygon[{{x1, y2, z1}, {x1, y2, z2}, {x2, y2, z2}, {x2, y2, z1}}], 
\tPolygon[{{x1, y1, z1}, {x2, y1, z1}, {x2, y1, z2}, {x1, y1, z2}}], 
\tPolygon[{{x1, y1, z2}, {x2, y1, z2}, {x2, y2, z2}, {x1, y2, z2}}], 
\tPolygon[{{x1, y1, z1}, {x1, y2, z1}, {x2, y2, z1}, {x2, y1, z1}}]};
\t
MyOpenCuboid[{x1_, y1_, z1_}, {x2_, y2_, z2_}] := {
\tPolygon[{{x1, y2, z1}, {x1, y2, z2}, {x2, y2, z2}, {x2, y2, z1}}], 
\tPolygon[{{x1, y1, z1}, {x2, y1, z1}, {x2, y1, z2}, {x1, y1, z2}}], 
\tPolygon[{{x1, y1, z2}, {x2, y1, z2}, {x2, y2, z2}, {x1, y2, z2}}], 
\tPolygon[{{x1, y1, z1}, {x1, y2, z1}, {x2, y2, z1}, {x2, y1, z1}}]}
\t
If[$VersionNumber < 6., 
\tRotateShapeXYZ[shape_, yaw_, pitch_, roll_] := Block[
\t\t{rotmat = RotationMatrixXYZBS[N[yaw], N[pitch], N[roll]]}, 
\t\tshape/. {
\t\t\tpoly:Polygon[_] :> Map[rotmat . #1 & , poly, {2}], 
\t\t\tline:Line[_] :> Map[rotmat . #1 & , line, {2}], 
\t\t\tpoint:Point[_] :> Map[rotmat . #1 & , point, {1}]
\t\t}
\t]; 
       
    MyOpenCylinder5[r_, {h1_, h2_}, n_Integer] := 
    Graphics`Shapes`Private`MakeShape[
    \tBlock[
    \t\t{rcphi, rsphi}, 
    \t\tTable[
    \t\t\trcphi = N[r*Cos[2*Pi*(i/n)]]; 
    \t\t\trsphi = N[r*Sin[2*Pi*(i/n)]]; 
\t\t\t\t{{rcphi, rsphi, h2}, {rcphi, rsphi, h1}}, 
\t\t\t\t{i, n}
\t\t\t]
\t\t], 
\t\t0, 1
\t] /; n > 2; 
         
    MyOpenCylinder5[r_:1, {h1_:1, h2_:1}] := 
    MyOpenCylinder5[r, {h1, h2}, Round[20*r]]
];
    
MyOpenCylinder[r_, {h1_, h2_}, n_Integer] := Table[
\tPolygon[{
\t\t{r*Cos[2*Pi*(i/n)], r*Sin[2*Pi*(i/n)], h1}, 
\t\t{r*Cos[2*Pi*(i/n)], r*Sin[2*Pi*(i/n)], h2}, 
\t\t{r*Cos[2*Pi*((i + 1)/n)], r*Sin[2*Pi*((i + 1)/n)], h2}, 
\t\t{r*Cos[2*Pi*((i + 1)/n)], r*Sin[2*Pi*((i + 1)/n)], h1}
\t}], 
\t{i, n}
] /; n > 2; 
\t
MyOpenCylinder[r_:1, {h1_:1, h2_:1}] := MyOpenCylinder[r, {h1, h2}, \
Round[20*r]]\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.390734449808799*^9, {3.390735448048636*^9, 3.390735453032578*^9}, 
   3.3907355872156267`*^9, {3.3907358309621277`*^9, 3.390735883724985*^9}, {
   3.390739837348567*^9, 3.390739980000832*^9}, {3.3907400190235*^9, 
   3.390740045499159*^9}, {3.390740097325039*^9, 3.390740211073441*^9}, {
   3.3907403197890053`*^9, 3.3907403770944853`*^9}, 3.390740425953703*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Various interesting groups of points, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
maxx:=Max[nx,ux,ix,tx];
maxy:=Max[ny,uy,ir,tr,nn0,nn1,n0,n1,n2,n3,n4,n5];\
\>", "Input",
 InitializationCell->True],

Cell["\<\
ztop:=z00/.constval;
zbottom:=z00-tln-dm-dn-tl1-d0-d1-tl2-d2-d3-tl3-d4-tr/.constval;\
\>", "Input",
 InitializationCell->True],

Cell["\<\
If[True,
\tsupportpoints[sub_] := {
\t\tGraphics3D[Point[support/.constval/.sub]]
\t};
\treferencemarkers := {
\t\tGraphics3D[Point[{+maxx,+maxy, ztop}/.constval]],
\t\tGraphics3D[Point[{+maxx,-maxy, ztop}/.constval]],
\t\tGraphics3D[Point[{-maxx,+maxy, ztop}/.constval]],
\t\tGraphics3D[Point[{-maxx,-maxy, ztop}/.constval]],
\t\tGraphics3D[Point[{+maxx,+maxy, zbottom}/.constval]],
\t\tGraphics3D[Point[{+maxx,-maxy, zbottom}/.constval]],
\t\tGraphics3D[Point[{-maxx,+maxy, zbottom}/.constval]],
\t\tGraphics3D[Point[{-maxx,-maxy, zbottom}/.constval]]
\t};
];\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various interesting groups of lines, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[True,
\twires[sub_] := Table[
\t\tGraphics3D[
\t\t\tLine[
\t\t\t\t{
\t\t\t\t\tb2s[wirelist[[i,w$obj1]],wirelist[[i,w$pos1]]],
\t\t\t\t\tb2s[wirelist[[i,w$obj2]],wirelist[[i,w$pos2]]]
\t\t\t\t}/.constval/.sub
\t\t\t]
\t\t],
\t\t{i,1,10}
\t]
];
\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.415466591729374*^9, 3.415466654431769*^9}, {
  3.4154666899237022`*^9, 3.4154666968120613`*^9}, {3.415466727276897*^9, 
  3.4154667277651377`*^9}, {3.415469035901786*^9, 3.415469036248143*^9}, {
  3.415469066985635*^9, 3.4154690673055983`*^9}, {3.415469336541916*^9, 
  3.41546933818452*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[True,
\tfibres[sub_] := Table[
\t\tGraphics3D[
\t\t\tLine[
\t\t\t\t{
\t\t\t\t\tb2s[wirelist[[i,w$obj1]],wirelist[[i,w$pos1]]],
\t\t\t\t\tb2s[wirelist[[i,w$obj2]],wirelist[[i,w$pos2]]]
\t\t\t\t}/.constval/.sub
\t\t\t]
\t\t],
\t\t{i,11,22}
\t]
];
\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.415466713508532*^9, 3.4154667418539057`*^9}, {
  3.415469041912956*^9, 3.415469062825645*^9}, {3.415469339953045*^9, 
  3.4154693410088463`*^9}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various interesting solids, as 3D graphics", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeULoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\t0, 0, 0
\t\t],
\t\tbladeUL[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeULoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[\t\t
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\t0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\t0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\t0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeUL[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.388856685791905*^9, 3.388861247156967*^9, {3.388861391298101*^9, 
   3.388861433064266*^9}, {3.388861701226256*^9, 3.388861702758912*^9}, {
   3.388861737929062*^9, 3.3888617558747787`*^9}, {3.388861826850439*^9, 
   3.388861946483223*^9}, {3.388862041483224*^9, 3.3888620638873243`*^9}, 
   3.388862129681826*^9, {3.39073277934309*^9, 3.390732830229669*^9}, {
   3.394008691216817*^9, 3.394008698167008*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeURoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\t0, 0, 0
\t\t],
\t\tbladeUR[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeURoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\t0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\t0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\t0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeUR[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.3888566866191072`*^9, 3.388861246317478*^9, 3.388862101636524*^9, {
   3.388862134745468*^9, 3.388862140981388*^9}, {3.3907327098849897`*^9, 
   3.39073276422757*^9}, {3.390732886757392*^9, 3.390732931792983*^9}, 
   3.3907330767402887`*^9, {3.394008685336543*^9, 3.394008707862763*^9}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tmassNoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyOpenCuboid[
\t\t\t\t\t{-nx/2,-ny/2,-nz/2},{nx/2,ny/2,nz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw0, pitch0, roll0
\t\t],
\t\t{x0, y0, z0}
\t]/.constval/.sub,
(* else v6+ *)
\tmassNoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tMyOpenCuboid[
\t\t\t\t\t\t\t{-nx/2,-ny/2,-nz/2},{nx/2,ny/2,nz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\t{x0, y0, z0}
\t\t]
\t]/.constval/.sub


];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.388856687406135*^9, 3.388861246407093*^9, {3.388862161358086*^9, 
   3.3888622132336817`*^9}, 3.390220088224678*^9, {3.390732493419252*^9, 
   3.3907325755142527`*^9}, 3.390732692545031*^9, 3.3907329937326307`*^9, {
   3.390733880393194*^9, 3.3907338977616*^9}, {3.3907345016735277`*^9, 
   3.390734514351266*^9}, 3.3908101677452497`*^9, 3.39400867785091*^9, 
   3.3940087146801643`*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeILoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw0, pitch0, roll0
\t\t],
\t\tbladeIL[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeILoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeIL[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.388856688068359*^9, 3.388861246607704*^9, 3.3888622279435253`*^9, {
   3.39073314920105*^9, 3.39073320922745*^9}, 3.390733246025716*^9, 
   3.3940086613902493`*^9, 3.394008720328972*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeIRoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw0, pitch0, roll0
\t\t],
\t\tbladeIR[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeIRoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll0, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch0, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw0, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeIR[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.38885668868814*^9, 3.388861246646255*^9, 3.388862230651952*^9, {
   3.3907333654880133`*^9, 3.390733374196159*^9}, 3.390733431109486*^9, 
   3.394008651883795*^9, 3.394008726925466*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tmassUoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyOpenCuboid[
\t\t\t\t\t{-ux/2,-uy/2,-uz/2},{ux/2,uy/2,uz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw1, pitch1, roll1
\t\t],
\t\t{x1, y1, z1}
\t]/.constval/.sub,
(* else v6+ *)
\tmassUoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tMyOpenCuboid[
\t\t\t\t\t\t\t{-ux/2,-uy/2,-uz/2},{ux/2,uy/2,uz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll1, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch1, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw1, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tmassU[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.3888566892877083`*^9, 3.388861246683174*^9, 3.3888622342709093`*^9, {
   3.390733383040531*^9, 3.390733428487488*^9}, {3.390733839369864*^9, 
   3.390733856024167*^9}, {3.390734471433147*^9, 3.3907344765579643`*^9}, 
   3.390810155067151*^9, 3.3940086416937857`*^9, 3.394008732693198*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeLLoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw1, pitch1, roll1
\t\t],
\t\tbladeLL[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeLLoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll1, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch1, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw1, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeLL[[{1,2,3}]]
\t\t]
\t]/.constval/.sub

];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.38885668987809*^9, 3.3888612467276077`*^9, 3.388862237838496*^9, {
   3.3907332519136143`*^9, 3.390733287328528*^9}, {3.390733339419382*^9, 
   3.390733345508086*^9}, 3.394008631814787*^9, 3.394008738407485*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tbladeLRoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tGraphics3D[
\t\t\t\tMyCuboid[
\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t]
\t\t\t],
\t\t\tyaw1, pitch1, roll1
\t\t],
\t\tbladeLR[[{1,2,3}]]
\t]/.constval/.sub,
(* else v6+ *)
\tbladeLRoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tCuboid[
\t\t\t\t\t\t\t{-btx/2,-bty/2,-btz/2},{btx/2,bty/2,btz/2}
\t\t\t\t\t\t],
\t\t\t\t\t\troll1, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch1, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw1, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tbladeLR[[{1,2,3}]]
\t\t]
\t]/.constval/.sub

];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.388856690575088*^9, 3.388861246764414*^9, 3.388862241273582*^9, {
   3.390733295291024*^9, 3.390733334147624*^9}, 3.394008623511305*^9, 
   3.394008744006359*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\tmassIoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tRotateShapeXYZ[
\t\t\t\tGraphics3D[
\t\t\t\t\tMyOpenCylinder5[
\t\t\t\t\t\tir,{-ix/2,ix/2},20
\t\t\t\t\t]
\t\t\t\t],
\t\t\t\t0, Pi/2, 0
\t\t\t],
\t\t\tyaw2, pitch2, roll2
\t\t],
\t\t{x2, y2, z2}
\t]/.constval/.sub,
(* else v6+ *)
\tmassIoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tRotate[
\t\t\t\t\t\t\tMyOpenCylinder[
\t\t\t\t\t\t\t\tir,{-ix/2,ix/2},20
\t\t\t\t\t\t\t],
\t\t\t\t\t\t\tPi/2, {0,1,0}, {0,0,0}
\t\t\t\t\t\t],
\t\t\t\t\t\troll2, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch2, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw2, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\tmassI[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.3888566912577963`*^9, 3.388861246809243*^9, 3.388862244253318*^9, {
   3.390733437256215*^9, 3.390733456559395*^9}, {3.39073363128642*^9, 
   3.3907336432332487`*^9}, {3.390733680548012*^9, 3.3907336842890882`*^9}, {
   3.3907410244870043`*^9, 3.3907410581058817`*^9}, {3.390741107516458*^9, 
   3.3907411107319202`*^9}, {3.3907415889633503`*^9, 3.390741613519833*^9}, {
   3.390741659570628*^9, 3.390741659586158*^9}, 3.3907416928764963`*^9, 
   3.390743857507428*^9, {3.394008589574901*^9, 3.3940085933238573`*^9}, 
   3.39400875038463*^9},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If[$VersionNumber<6.,
\topticoutline[sub_] := TranslateShape[
\t\tRotateShapeXYZ[
\t\t\tRotateShapeXYZ[
\t\t\t\tGraphics3D[
\t\t\t\t\tMyOpenCylinder5[
\t\t\t\t\t\ttr,{-tx/2,tx/2},20
\t\t\t\t\t]
\t\t\t\t],
\t\t\t\t0, Pi/2, 0
\t\t\t],
\t\t\tyaw3, pitch3, roll3
\t\t],
\t\t{x3, y3, z3}
\t]/.constval/.sub,
(* else v6+ *)
\topticoutline[sub_] := Graphics3D[
\t\tTranslate[
\t\t\tRotate[
\t\t\t\tRotate[
\t\t\t\t\tRotate[
\t\t\t\t\t\tRotate[
\t\t\t\t\t\t\tMyOpenCylinder[
\t\t\t\t\t\t\t\ttr,{-tx/2,tx/2},20
\t\t\t\t\t\t\t],
\t\t\t\t\t\t\tPi/2, {0,1,0}, {0,0,0}
\t\t\t\t\t\t],
\t\t\t\t\t\troll3, {1,0,0}, {0,0,0}
\t\t\t\t\t],
\t\t\t\t\tpitch3, {0,1,0}, {0,0,0}
\t\t\t\t],
\t\t\t\tyaw3, {0,0,1}, {0,0,0}
\t\t\t],
\t\t\toptic[[{1,2,3}]]
\t\t]
\t]/.constval/.sub
];\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.38885669186707*^9, 3.3888612468490458`*^9, 3.38886224716494*^9, {
   3.390733468720807*^9, 3.390733487854968*^9}, {3.390733546023054*^9, 
   3.3907335509369707`*^9}, {3.3907335856093903`*^9, 3.390733608038183*^9}, {
   3.390733688257399*^9, 3.390733691041258*^9}, {3.390740581388052*^9, 
   3.390740637230397*^9}, 3.3907408437196903`*^9, 3.390740985314378*^9, {
   3.390741588982959*^9, 3.390741613475223*^9}, {3.390741659511055*^9, 
   3.390741659526108*^9}, 3.390741692892099*^9, 3.3908100809141693`*^9, {
   3.394008573626441*^9, 3.3940085837397633`*^9}, 3.3940087568972273`*^9},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["A function to plot an eigenmode", "Text",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
eigenplot::usage = \"eigenplot[e, f, {x, y, z},fm] makes a plot of the \
eigenvector e, scaled by a factor f, with viewpoint {x,y,z} using float \
matrix fm to calculate the values of the floats.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
eigenplot[e_, ff_, {x_, y_, z_},fm_] := If[
\tdoplots,
\tBlock[
\t\t{s=tosub[ff e, fm]},
\t\tShow[
\t\t\treferencemarkers,
\t\t\twires[s],
\t\t\tfibres[s],
\t\t\t(*opticpoints[s],*)
\t\t\t(*supportpoints[s],*)
\t\t\tbladeULoutline[s],
\t\t\tbladeURoutline[s],
\t\t\tmassNoutline[s],
\t\t\tbladeILoutline[s],
\t\t\tbladeIRoutline[s],
\t\t\tmassUoutline[s],
\t\t\tbladeLLoutline[s],
\t\t\tbladeLRoutline[s],
\t\t\tmassIoutline[s],
\t\t\topticoutline[s],
\t\t\tViewPoint->{x, y, z},
\t\t\tPlotRange->{{-1.5 maxx,1.5 \
maxx},{-maxy,maxy},{zbottom-0.1,ztop}}/.constval
\t\t]
\t],
\tPrint[\"Plots switched off (doplots = False)\"]
]\
\>", "Input",
 InitializationCell->True,
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A pretty-printing routine for the eigenvectors in the x/y/z/yaw/pitch/roll \
basis\
\>", "Text",
 InitializationCell->True],

Cell["\<\
pad::usage = \"pad[ev] takes an eigenvector and inserts dummy values where \
angle variables had been suppressed, so as to make even groups of six.\";\
\>", "Input",
 InitializationCell->True],

Cell["\<\
pad[e_]:=Partition[e,6](*{
\tJoin[{Infinity,Infinity},e[[{1}]],{Infinity,Infinity,Infinity}],
\tJoin[{Infinity,Infinity},e[[{2}]],{Infinity,Infinity,Infinity}],
\te[[{3,4,5,6,7,8}]],
\tJoin[{Infinity,Infinity},e[[{9}]],{Infinity,Infinity,Infinity}],
\tJoin[{Infinity,Infinity},e[[{10}]],{Infinity,Infinity,Infinity}],
\te[[{11,12,13,14,15,16}]],
\tJoin[{Infinity,Infinity},e[[{17}]],{Infinity,Infinity,Infinity}],
\tJoin[{Infinity,Infinity},e[[{18}]],{Infinity,Infinity,Infinity}],
\te[[{19,20,21,22,23,24}]],
\te[[{25,26,27,28,29,30}]]
}*)\
\>", "Input",
 InitializationCell->True],

Cell["\<\
pretty::usage = \"pretty[ev] prints an eigenvector in a pretty table format \
with headings.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"pretty", "[", "e_", "]"}], " ", ":=", " ", 
  RowBox[{"TableForm", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<Mass N\>\"", ",", "\"\<Mass U\>\"", ",", 
         "\"\<Mass 2\>\"", ",", "\"\<optic\>\""}], "}"}], "}"}], ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", 
            "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], "}"}],
           "}"}], ",", 
         RowBox[{"pad", "[", "e", "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}], " "}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"pretty", "[", 
   RowBox[{"h_", ",", "e_"}], "]"}], " ", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
       "\"\<f\>\"", ",", "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", 
        ",", "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], 
       "}"}], "}"}], ",", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", "h", "}"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"pad", "[", "e", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell["\<\
oldvars::usage = \"oldvars is like allvars except with the full 6 coordinates \
of each blade tip for comparability with the full model.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettyold", "[", "e_", "]"}], ":=", 
  RowBox[{"TableForm", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<UL blade\>\"", ",", "\"\<UR blade\>\"", ",", 
         "\"\<Mass N\>\"", ",", "\"\<IL blade\>\"", ",", "\"\<IR blade\>\"", 
         ",", "\"\<Mass U\>\"", ",", "\"\<LL blade\>\"", ",", 
         "\"\<LR blade\>\"", ",", "\"\<Mass 2\>\"", ",", "\"\<optic\>\""}], 
        "}"}], "}"}], ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", 
            "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], "}"}],
           "}"}], ",", 
         RowBox[{"Partition", "[", 
          RowBox[{"e", ",", "6"}], "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
prettyold::usage = \"prettyold[ev] is the version of pretty[] from the full \
model for use with oldvars.\";\
\>", "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"prettyold", "[", "e_", "]"}], ":=", 
  RowBox[{"TableForm", "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\>\"", ",", "\"\<UL blade\>\"", ",", "\"\<UR blade\>\"", ",", 
         "\"\<Mass N\>\"", ",", "\"\<IL blade\>\"", ",", "\"\<IR blade\>\"", 
         ",", "\"\<Mass U\>\"", ",", "\"\<LL blade\>\"", ",", 
         "\"\<LR blade\>\"", ",", "\"\<Mass 2\>\"", ",", "\"\<optic\>\""}], 
        "}"}], "}"}], ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
           "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", 
            "\"\<yaw\>\"", ",", "\"\<pitch\>\"", ",", "\"\<roll\>\""}], "}"}],
           "}"}], ",", 
         RowBox[{"Partition", "[", 
          RowBox[{"e", ",", "6"}], "]"}]}], "]"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Functions to classify eigenvectors", "Text",
 InitializationCell->True],

Cell["\<\
longpitchQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"pitch\"]=={{1,5}}
\t||StringPosition[s,\"x\"]=={{1,1}}
]

transrollQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\t(
\t\tStringPosition[s,\"y\"]=={{1,1}}
\t\t&&StringPosition[s,\"yaw\"]=={}
\t)
\t||StringPosition[s,\"roll\"]=={{1,4}}
]

yawQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"yaw\"]=={{1,3}}
]

vertQ[e_] := Block[
\t{s=ToString[important[e][[1]]]},
\tStringPosition[s,\"z\"]=={{1,1}}
]\
\>", "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1033, 936},
WindowMargins->{{166, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 378, 9, 89, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[993, 36, 64, 1, 34, "Subsection",
 InitializationCell->True],
Cell[1060, 39, 222, 5, 27, "Input",
 InitializationCell->True],
Cell[1285, 46, 235, 6, 40, "Input",
 InitializationCell->True],
Cell[1523, 54, 126, 3, 26, "Text",
 InitializationCell->True],
Cell[1652, 59, 760, 12, 41, "Text",
 InitializationCell->True],
Cell[2415, 73, 870, 16, 41, "Text",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3322, 94, 61, 1, 26, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3408, 99, 176, 3, 25, "Subsubsection",
 InitializationCell->True],
Cell[3587, 104, 2929, 55, 146, "Text",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[6553, 164, 64, 1, 25, "Subsubsection",
 InitializationCell->True],
Cell[6620, 167, 2057, 38, 146, "Text",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[8714, 210, 131, 2, 25, "Subsubsection",
 InitializationCell->True],
Cell[8848, 214, 2244, 34, 116, "Text",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[11141, 254, 62, 1, 26, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11228, 259, 142, 4, 26, "Text",
 InitializationCell->True],
Cell[11373, 265, 177, 5, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[11587, 275, 87, 2, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11699, 281, 33, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[11757, 285, 91, 1, 26, "Text",
 InitializationCell->True],
Cell[11851, 288, 194, 3, 27, "Input",
 InitializationCell->True],
Cell[12048, 293, 292, 5, 27, "Input",
 InitializationCell->True],
Cell[12343, 300, 195, 3, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[12575, 308, 116, 3, 26, "Text",
 InitializationCell->True],
Cell[12694, 313, 471, 9, 27, "Input",
 InitializationCell->True],
Cell[13168, 324, 600, 11, 53, "Input",
 InitializationCell->True],
Cell[13771, 337, 266, 8, 27, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14086, 351, 31, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[14142, 355, 114, 3, 26, "Text",
 InitializationCell->True],
Cell[14259, 360, 105, 2, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14401, 367, 80, 1, 26, "Text",
 InitializationCell->True],
Cell[14484, 370, 69, 1, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14590, 376, 82, 1, 26, "Text",
 InitializationCell->True],
Cell[14675, 379, 69, 1, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14781, 385, 64, 1, 26, "Text",
 InitializationCell->True],
Cell[14848, 388, 65, 1, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14950, 394, 54, 1, 26, "Text",
 InitializationCell->True],
Cell[15007, 397, 65, 1, 27, "Input",
 InitializationCell->True],
Cell[15075, 400, 244, 5, 27, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15392, 413, 65, 1, 26, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[15482, 418, 67, 1, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[15574, 423, 346, 6, 41, "Text",
 InitializationCell->True],
Cell[15923, 431, 280, 6, 27, "Input",
 InitializationCell->True],
Cell[16206, 439, 217, 9, 92, "Input",
 InitializationCell->True],
Cell[16426, 450, 418, 38, 482, "Input",
 InitializationCell->True],
Cell[16847, 490, 380, 8, 92, "Input",
 InitializationCell->True],
Cell[17230, 500, 423, 7, 27, "Input",
 InitializationCell->True],
Cell[17656, 509, 845, 46, 508, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[18538, 560, 251, 5, 41, "Text",
 InitializationCell->True],
Cell[18792, 567, 389, 7, 70, "Input",
 InitializationCell->True],
Cell[19184, 576, 289, 7, 70, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19522, 589, 83, 2, 26, "Text",
 InitializationCell->True],
Cell[19608, 593, 297, 6, 41, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19930, 603, 70, 1, 26, "Text",
 InitializationCell->True],
Cell[20003, 606, 144, 4, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[20184, 615, 158, 4, 26, "Text",
 InitializationCell->True],
Cell[20345, 621, 204, 5, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[20586, 631, 193, 4, 26, "Text",
 InitializationCell->True],
Cell[20782, 637, 302, 6, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[21121, 648, 140, 4, 26, "Text",
 InitializationCell->True],
Cell[21264, 654, 376, 11, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[21677, 670, 98, 1, 23, "Text",
 InitializationCell->True],
Cell[21778, 673, 2183, 59, 103, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[23998, 737, 133, 4, 26, "Text",
 InitializationCell->True],
Cell[24134, 743, 331, 8, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[24502, 756, 98, 1, 23, "Text",
 InitializationCell->True],
Cell[24603, 759, 723, 21, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[25363, 785, 166, 4, 23, "Text",
 InitializationCell->True],
Cell[25532, 791, 402, 12, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[25971, 808, 60, 1, 26, "Text",
 InitializationCell->True],
Cell[26034, 811, 356, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[26427, 827, 60, 1, 26, "Text",
 InitializationCell->True],
Cell[26490, 830, 439, 13, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[26966, 848, 158, 4, 26, "Text",
 InitializationCell->True],
Cell[27127, 854, 401, 9, 92, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[27565, 868, 96, 1, 26, "Text",
 InitializationCell->True],
Cell[27664, 871, 3337, 97, 193, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[31038, 973, 166, 4, 26, "Text",
 InitializationCell->True],
Cell[31207, 979, 423, 9, 66, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[31667, 993, 175, 4, 26, "Text",
 InitializationCell->True],
Cell[31845, 999, 409, 12, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[32291, 1016, 63, 1, 23, "Text",
 InitializationCell->True],
Cell[32357, 1019, 359, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[32753, 1035, 63, 1, 26, "Text",
 InitializationCell->True],
Cell[32819, 1038, 379, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[33235, 1054, 143, 4, 26, "Text",
 InitializationCell->True],
Cell[33381, 1060, 779, 19, 170, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[34197, 1084, 89, 1, 26, "Text",
 InitializationCell->True],
Cell[34289, 1087, 3331, 99, 193, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[37657, 1191, 83, 1, 26, "Text",
 InitializationCell->True],
Cell[37743, 1194, 421, 9, 66, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[38201, 1208, 145, 4, 26, "Text",
 InitializationCell->True],
Cell[38349, 1214, 411, 12, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[38797, 1231, 69, 1, 23, "Text",
 InitializationCell->True],
Cell[38869, 1234, 365, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[39271, 1250, 69, 1, 26, "Text",
 InitializationCell->True],
Cell[39343, 1253, 385, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[39765, 1269, 161, 4, 26, "Text",
 InitializationCell->True],
Cell[39929, 1275, 771, 19, 170, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[40737, 1299, 132, 4, 26, "Text",
 InitializationCell->True],
Cell[40872, 1305, 653, 15, 118, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[41562, 1325, 214, 3, 26, "Text",
 InitializationCell->True],
Cell[41779, 1330, 1827, 50, 133, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[43643, 1385, 265, 4, 26, "Text",
 InitializationCell->True],
Cell[43911, 1391, 1851, 50, 133, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[45799, 1446, 84, 1, 26, "Text",
 InitializationCell->True],
Cell[45886, 1449, 383, 12, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[46306, 1466, 57, 1, 23, "Text",
 InitializationCell->True],
Cell[46366, 1469, 337, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[46740, 1485, 57, 1, 26, "Text",
 InitializationCell->True],
Cell[46800, 1488, 356, 11, 43, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[47193, 1504, 113, 3, 26, "Text",
 InitializationCell->True],
Cell[47309, 1509, 625, 16, 118, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47983, 1531, 88, 1, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[48096, 1536, 50, 1, 26, "Text",
 InitializationCell->True],
Cell[48149, 1539, 288, 6, 27, "Input",
 InitializationCell->True],
Cell[48440, 1547, 254, 7, 79, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[48731, 1559, 50, 1, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[48806, 1564, 66, 1, 26, "Text",
 InitializationCell->True],
Cell[48875, 1567, 777, 23, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[49689, 1595, 75, 1, 23, "Text",
 InitializationCell->True],
Cell[49767, 1598, 56, 1, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[49860, 1604, 54, 1, 23, "Text",
 InitializationCell->True],
Cell[49917, 1607, 217, 18, 70, "Input",
 InitializationCell->True],
Cell[50137, 1627, 217, 18, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[50391, 1650, 61, 1, 23, "Text",
 InitializationCell->True],
Cell[50455, 1653, 219, 18, 70, "Input",
 InitializationCell->True],
Cell[50677, 1673, 219, 18, 70, "Input",
 InitializationCell->True],
Cell[50899, 1693, 219, 18, 70, "Input",
 InitializationCell->True],
Cell[51121, 1713, 219, 18, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[51377, 1736, 54, 1, 23, "Text",
 InitializationCell->True],
Cell[51434, 1739, 221, 18, 70, "Input",
 InitializationCell->True],
Cell[51658, 1759, 221, 18, 70, "Input",
 InitializationCell->True],
Cell[51882, 1779, 221, 18, 70, "Input",
 InitializationCell->True],
Cell[52106, 1799, 221, 18, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[52364, 1822, 49, 1, 23, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[52438, 1827, 122, 2, 26, "Text",
 InitializationCell->True],
Cell[52563, 1831, 474, 22, 222, "Input",
 InitializationCell->True],
Cell[53040, 1855, 469, 22, 222, "Input",
 InitializationCell->True],
Cell[53512, 1879, 520, 23, 222, "Input",
 InitializationCell->True],
Cell[54035, 1904, 470, 22, 222, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[54542, 1931, 173, 3, 23, "Text",
 InitializationCell->True],
Cell[54718, 1936, 839, 26, 222, "Input",
 InitializationCell->True],
Cell[55560, 1964, 838, 26, 222, "Input",
 InitializationCell->True],
Cell[56401, 1992, 813, 26, 222, "Input",
 InitializationCell->True],
Cell[57217, 2020, 807, 26, 222, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[58061, 2051, 121, 2, 26, "Text",
 InitializationCell->True],
Cell[58185, 2055, 473, 22, 222, "Input",
 InitializationCell->True],
Cell[58661, 2079, 412, 21, 222, "Input",
 InitializationCell->True],
Cell[59076, 2102, 423, 21, 222, "Input",
 InitializationCell->True],
Cell[59502, 2125, 422, 21, 222, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59985, 2153, 49, 1, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[60059, 2158, 68, 1, 70, "Text",
 InitializationCell->True],
Cell[60130, 2161, 624, 16, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[60791, 2182, 67, 1, 70, "Text",
 InitializationCell->True],
Cell[60861, 2185, 60, 1, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[60958, 2191, 55, 1, 70, "Text",
 InitializationCell->True],
Cell[61016, 2194, 334, 20, 70, "Input",
 InitializationCell->True],
Cell[61353, 2216, 334, 20, 70, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[61724, 2241, 62, 1, 70, "Text",
 InitializationCell->True],
Cell[61789, 2244, 332, 20, 70, "Input",
 InitializationCell->True],
Cell[62124, 2266, 332, 20, 70, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[62493, 2291, 55, 1, 70, "Text",
 InitializationCell->True],
Cell[62551, 2294, 332, 20, 70, "Input",
 InitializationCell->True],
Cell[62886, 2316, 332, 20, 70, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[63257, 2341, 93, 2, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[63375, 2347, 124, 2, 26, "Text",
 InitializationCell->True],
Cell[63502, 2351, 199, 8, 70, "Input",
 InitializationCell->True],
Cell[63704, 2361, 174, 8, 70, "Input",
 InitializationCell->True],
Cell[63881, 2371, 199, 8, 70, "Input",
 InitializationCell->True],
Cell[64083, 2381, 177, 8, 70, "Input",
 InitializationCell->True],
Cell[64263, 2391, 199, 8, 70, "Input",
 InitializationCell->True],
Cell[64465, 2401, 183, 8, 70, "Input",
 InitializationCell->True],
Cell[64651, 2411, 171, 8, 70, "Input",
 InitializationCell->True],
Cell[64825, 2421, 505, 11, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[65367, 2437, 108, 2, 23, "Text",
 InitializationCell->True],
Cell[65478, 2441, 237, 5, 70, "Input",
 InitializationCell->True],
Cell[65718, 2448, 557, 16, 70, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[66324, 2470, 94, 2, 23, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[66443, 2476, 600, 10, 56, "Text",
 InitializationCell->True],
Cell[67046, 2488, 168, 5, 41, "Text",
 InitializationCell->True],
Cell[67217, 2495, 400, 7, 27, "Input",
 InitializationCell->True],
Cell[67620, 2504, 18037, 589, 6579, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[85694, 3098, 75, 1, 26, "Text",
 InitializationCell->True],
Cell[85772, 3101, 22513, 449, 3641, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[108334, 3556, 69, 1, 23, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[108428, 3561, 459, 8, 41, "Text",
 InitializationCell->True],
Cell[108890, 3571, 346, 6, 27, "Input",
 InitializationCell->True],
Cell[109239, 3579, 1466, 73, 885, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[110754, 3658, 73, 1, 26, "Subsection",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[110852, 3663, 72, 1, 26, "Text",
 InitializationCell->True],
Cell[110927, 3666, 292, 6, 41, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[111244, 3676, 225, 5, 26, "Text",
 InitializationCell->True],
Cell[111472, 3683, 738, 26, 313, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[112247, 3714, 214, 5, 26, "Text",
 InitializationCell->True],
Cell[112464, 3721, 487, 18, 209, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[113000, 3745, 161, 4, 26, "Text",
 InitializationCell->True],
Cell[113164, 3751, 213, 5, 70, "Input",
 InitializationCell->True],
Cell[113380, 3758, 296, 12, 70, "Input",
 InitializationCell->True],
Cell[113679, 3772, 214, 5, 70, "Input",
 InitializationCell->True],
Cell[113896, 3779, 296, 12, 70, "Input",
 InitializationCell->True],
Cell[114195, 3793, 237, 5, 70, "Input",
 InitializationCell->True],
Cell[114435, 3800, 333, 12, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[114805, 3817, 114, 3, 23, "Text",
 InitializationCell->True],
Cell[114922, 3822, 161, 4, 70, "Input",
 InitializationCell->True],
Cell[115086, 3828, 152, 4, 70, "Input",
 InitializationCell->True],
Cell[115241, 3834, 161, 4, 70, "Input",
 InitializationCell->True],
Cell[115405, 3840, 152, 4, 70, "Input",
 InitializationCell->True],
Cell[115560, 3846, 161, 4, 70, "Input",
 InitializationCell->True],
Cell[115724, 3852, 152, 4, 70, "Input",
 InitializationCell->True],
Cell[115879, 3858, 165, 4, 70, "Input",
 InitializationCell->True],
Cell[116047, 3864, 158, 4, 70, "Input",
 InitializationCell->True],
Cell[116208, 3870, 169, 4, 70, "Input",
 InitializationCell->True],
Cell[116380, 3876, 164, 4, 70, "Input",
 InitializationCell->True],
Cell[116547, 3882, 167, 4, 70, "Input",
 InitializationCell->True],
Cell[116717, 3888, 161, 4, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[116915, 3897, 116, 3, 23, "Text",
 InitializationCell->True],
Cell[117034, 3902, 160, 4, 70, "Input",
 InitializationCell->True],
Cell[117197, 3908, 160, 4, 70, "Input",
 InitializationCell->True],
Cell[117360, 3914, 160, 4, 70, "Input",
 InitializationCell->True],
Cell[117523, 3920, 164, 4, 70, "Input",
 InitializationCell->True],
Cell[117690, 3926, 168, 4, 70, "Input",
 InitializationCell->True],
Cell[117861, 3932, 166, 4, 70, "Input",
 InitializationCell->True],
Cell[118030, 3938, 198, 6, 70, "Input",
 InitializationCell->True],
Cell[118231, 3946, 202, 6, 70, "Input",
 InitializationCell->True],
Cell[118436, 3954, 200, 6, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[118673, 3965, 120, 2, 23, "Text",
 InitializationCell->True],
Cell[118796, 3969, 91, 2, 27, "Input",
 InitializationCell->True],
Cell[118890, 3973, 134, 4, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[119061, 3982, 115, 2, 26, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[119201, 3988, 179, 2, 26, "Text"],
Cell[119383, 3992, 568, 11, 70, "Input",
 InitializationCell->True],
Cell[119954, 4005, 2428, 62, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[122419, 4072, 127, 2, 23, "Text",
 InitializationCell->True],
Cell[122549, 4076, 125, 4, 40, "Input",
 InitializationCell->True],
Cell[122677, 4082, 136, 4, 40, "Input",
 InitializationCell->True],
Cell[122816, 4088, 645, 18, 209, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[123498, 4111, 126, 2, 26, "Text",
 InitializationCell->True],
Cell[123627, 4115, 645, 22, 196, "Input",
 InitializationCell->True],
Cell[124275, 4139, 500, 20, 196, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[124812, 4164, 117, 2, 26, "Text",
 InitializationCell->True],
Cell[124932, 4168, 1161, 41, 417, "Input",
 InitializationCell->True],
Cell[126096, 4211, 1035, 39, 417, "Input",
 InitializationCell->True],
Cell[127134, 4252, 1143, 43, 443, "Input",
 InitializationCell->True],
Cell[128280, 4297, 958, 38, 417, "Input",
 InitializationCell->True],
Cell[129241, 4337, 957, 38, 417, "Input",
 InitializationCell->True],
Cell[130201, 4377, 1046, 39, 417, "Input",
 InitializationCell->True],
Cell[131250, 4418, 984, 39, 430, "Input",
 InitializationCell->True],
Cell[132237, 4459, 935, 39, 70, "Input",
 InitializationCell->True],
Cell[133175, 4500, 1407, 49, 70, "Input",
 InitializationCell->True],
Cell[134585, 4551, 1447, 49, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[136069, 4605, 106, 2, 23, "Text",
 InitializationCell->True],
Cell[136178, 4609, 250, 5, 70, "Input",
 InitializationCell->True],
Cell[136431, 4616, 710, 30, 70, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[137190, 4652, 133, 4, 26, "Text",
 InitializationCell->True],
Cell[137326, 4658, 202, 4, 70, "Input",
 InitializationCell->True],
Cell[137531, 4664, 592, 14, 70, "Input",
 InitializationCell->True],
Cell[138126, 4680, 147, 4, 70, "Input",
 InitializationCell->True],
Cell[138276, 4686, 821, 23, 70, "Input",
 InitializationCell->True],
Cell[139100, 4711, 669, 20, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[139784, 4734, 191, 4, 21, "Input",
 InitializationCell->True],
Cell[139978, 4740, 1025, 27, 88, "Input",
 InitializationCell->True],
Cell[141006, 4769, 160, 4, 27, "Input",
 InitializationCell->True],
Cell[141169, 4775, 1025, 27, 88, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[142219, 4806, 77, 1, 26, "Text",
 InitializationCell->True],
Cell[142299, 4809, 560, 26, 70, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
